@@ -13,8 +13,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KDEV_VARIABLEWIDGET_H
-#define KDEV_VARIABLEWIDGET_H
+#ifndef KDEVPLATFORM_VARIABLEWIDGET_H
+#define KDEVPLATFORM_VARIABLEWIDGET_H
 
 #include <QTreeView>
 #include <QAction>
@@ -59,7 +59,6 @@ protected:
 
 private:
     VariableTree *varTree_;
-    KLineEdit *watchVarEntry_;
     KHistoryComboBox *watchVarEditor_;
     VariablesRoot *variablesRoot_;
 };
@@ -86,6 +85,7 @@ private slots:
     void changeVariableFormat(int);
     void watchDelete();
     void copyVariableValue();
+    void stopOnChange();
 
 #if 0
 Q_SIGNALS:
@@ -111,6 +111,7 @@ private:
     QMenu *m_formatMenu;
     QAction *m_watchDelete;
     QAction *m_copyVariableValue;
+    QAction *m_stopOnChange;
     QSignalMapper *m_signalMapper;
 };
 
