@@ -18,25 +18,44 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef STANDARDDOCUMENTATIONVIEW_H
-#define STANDARDDOCUMENTATIONVIEW_H
+#ifndef KDEVPLATFORM_STANDARDDOCUMENTATIONVIEW_H
+#define KDEVPLATFORM_STANDARDDOCUMENTATIONVIEW_H
 
 #include <QWebView>
 #include "documentationexport.h"
 #include "documentationfindwidget.h"
+#include <interfaces/idocumentation.h>
 
 namespace KDevelop
 {
 
+/**
+ * The standard documentation view, based on QWebView.
+ */
 class KDEVPLATFORMDOCUMENTATION_EXPORT StandardDocumentationView : public QWebView
 {
     Q_OBJECT
-    public:
-        explicit StandardDocumentationView(DocumentationFindWidget* findWidget, QWidget* parent = 0 );
+public:
+    explicit StandardDocumentationView(DocumentationFindWidget* findWidget, QWidget* parent = 0 );
+    void setDocumentation(const IDocumentation::Ptr& doc);
 
-    public slots:
-        void search(const QString& text, KDevelop::DocumentationFindWidget::FindOptions options);
+public slots:
+    /**
+     * Search for @p text in the documentation view.
+     */
+    void search(const QString& text, KDevelop::DocumentationFindWidget::FindOptions options);
+
+    /**
+     * Updates the contents, in case it was initialized with a documentation instance,
+     * doesn't change anything otherwise
+     *
+     * @sa setDocumentation(IDocumentation::Ptr)
+     */
+    void update();
+
+private:
+    IDocumentation::Ptr m_doc;
 };
 
 }
-#endif // STANDARDDOCUMENTATIONVIEW_H
+#endif // KDEVPLATFORM_STANDARDDOCUMENTATIONVIEW_H
