@@ -38,6 +38,8 @@ const QString ContextMenuExtension::DebugGroup    = "DebugGroup";
 const QString ContextMenuExtension::EditGroup     = "EditGroup";
 const QString ContextMenuExtension::VcsGroup      = "VcsGroup";
 const QString ContextMenuExtension::ProjectGroup  = "ProjectGroup";
+const QString ContextMenuExtension::OpenEmbeddedGroup  = "OpenEmbeddedGroup";
+const QString ContextMenuExtension::OpenExternalGroup  = "OpenExternalGroup";
 const QString ContextMenuExtension::ExtensionGroup  = "ExtensionGroup";
 
 
@@ -75,10 +77,7 @@ ContextMenuExtension& ContextMenuExtension::operator=( const ContextMenuExtensio
 
 QList<QAction*> ContextMenuExtension::actions( const QString& group ) const
 {
-    if( d->extensions.contains( group ) )
-        return d->extensions.value( group );
-    else
-        return QList<QAction*>();
+    return d->extensions.value( group, QList<QAction*>() );
 }
 
 void ContextMenuExtension::addAction( const QString& group, QAction* action )
