@@ -17,8 +17,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef IDOCUMENTATIONPROVIDER_H
-#define IDOCUMENTATIONPROVIDER_H
+#ifndef KDEVPLATFORM_IDOCUMENTATIONPROVIDER_H
+#define KDEVPLATFORM_IDOCUMENTATIONPROVIDER_H
 
 #include <KDE/KSharedPtr>
 #include <QtCore/QObject>
