@@ -16,8 +16,8 @@
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
 */
-#ifndef IPATCHDOCUMENT_H
-#define IPATCHDOCUMENT_H
+#ifndef KDEVPLATFORM_IPATCHDOCUMENT_H
+#define KDEVPLATFORM_IPATCHDOCUMENT_H
 
 #include "interfacesexport.h"
 
