@@ -18,8 +18,8 @@ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
 
-#ifndef IPROJECTCONTROLLER_H
-#define IPROJECTCONTROLLER_H
+#ifndef KDEVPLATFORM_IPROJECTCONTROLLER_H
+#define KDEVPLATFORM_IPROJECTCONTROLLER_H
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
@@ -103,7 +103,7 @@ public:
      * The returned path always has a training slash.
      * @param format formatting used for the string
      */
-    Q_SCRIPTABLE virtual QString prettyFilePath(KUrl url, FormattingOptions format = FormatHtml) const = 0;
+    Q_SCRIPTABLE virtual QString prettyFilePath(const KUrl& url, FormattingOptions format = FormatHtml) const = 0;
     
     /**
      * Returns a pretty short representation of the given url, considering the currently loaded projects:
@@ -111,13 +111,13 @@ public:
      * the full file path.
      * @param format formatting used for the string
      */
-    Q_SCRIPTABLE virtual QString prettyFileName(KUrl url, FormattingOptions format = FormatHtml) const = 0;
+    Q_SCRIPTABLE virtual QString prettyFileName(const KUrl& url, FormattingOptions format = FormatHtml) const = 0;
 
     /**
-     * @returns wether project files should be parsed or not
+     * @returns whether project files should be parsed or not
      */
     static bool parseAllProjectSources();
-    
+
 public Q_SLOTS:
     /**
      * Tries finding a project-file for the given source-url and opens it.
@@ -141,18 +141,22 @@ public Q_SLOTS:
      */
     virtual void closeProject( IProject* ) = 0;
     virtual void configureProject( IProject* ) = 0;
+
+    /// Schedules all files of the @p project for reparsing by @see BackgroundParser
+    virtual void reparseProject( IProject* project, bool ForceUpdate = false ) = 0;
+
 //     virtual void changeCurrentProject( KDevelop::ProjectBaseItem* ) = 0;
 
 Q_SIGNALS:
     /**
-     * emitted right before a project is started to be loaded.
+     * Emitted right before a project is started to be loaded.
+     *
      * At this point all sanity checks have been done, so the project
      * is really going to be loaded. Will be followed by @ref projectOpened signal
      * when loading completes or by @ref projectOpeningAborted if there are errors during loading
      * or it is aborted.
-     * @note the given project won't be very useful as it doesn't have all things
-     * setup properly
-     * @param url the url of the project that is about to be opened.
+     *
+     * @param project the project that is about to be opened.
      */
     void projectAboutToBeOpened( KDevelop::IProject* project );
     /**
