@@ -17,8 +17,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef LAUNCHCONFIGURATIONPAGE_H
-#define LAUNCHCONFIGURATIONPAGE_H
+#ifndef KDEVPLATFORM_LAUNCHCONFIGURATIONPAGE_H
+#define KDEVPLATFORM_LAUNCHCONFIGURATIONPAGE_H
 
 #include "interfacesexport.h"
 
