@@ -22,8 +22,8 @@
 #include "testparsejob.h"
 #include <QTest>
 
-TestParseJob::TestParseJob(const KUrl& url)
-: ParseJob(url)
+TestParseJob::TestParseJob(const IndexedString& url, ILanguageSupport* languageSupport)
+: ParseJob(url, languageSupport)
 , duration_ms(0)
 {
 }
@@ -36,3 +36,16 @@ void TestParseJob::run()
         QTest::qWait(duration_ms);
     }
 }
+
+ControlFlowGraph* TestParseJob::controlFlowGraph()
+{
+    return 0;
+}
+
+DataAccessRepository* TestParseJob::dataAccessInformation()
+{
+    return 0;
+}
+
+
+
