@@ -19,8 +19,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef KDEV_NORMALDECLARATIONCOMPLETIONITEM_H
-#define KDEV_NORMALDECLARATIONCOMPLETIONITEM_H
+#ifndef KDEVPLATFORM_NORMALDECLARATIONCOMPLETIONITEM_H
+#define KDEVPLATFORM_NORMALDECLARATIONCOMPLETIONITEM_H
 
 #include "codecompletionitem.h"
 #include "../languageexport.h"
