@@ -17,15 +17,16 @@
  * 02110-1301, USA.
  */
 
-#ifndef APPLYCHANGESWIDGET_H
-#define APPLYCHANGESWIDGET_H
+#ifndef KDEVPLATFORM_APPLYCHANGESWIDGET_H
+#define KDEVPLATFORM_APPLYCHANGESWIDGET_H
 
 #include <KDE/KDialog>
 #include "../languageexport.h"
 
-namespace KTextEditor { class Document; class Range;}
-class KUrl;
-class QModelIndex;
+namespace KTextEditor {
+class Document;
+}
+
 
 namespace KDevelop
 {
@@ -56,18 +57,9 @@ class KDEVPLATFORMLANGUAGE_EXPORT ApplyChangesWidget : public KDialog
         void updateDiffView(int index = -1);
     
     public Q_SLOTS:
-        ///Called when a change between comparison and edition is requested
-        void switchEditView();
         ///Called to signal a change to the currently viewed index
         void indexChanged(int);
-        
-    private Q_SLOTS:
-        void change (KTextEditor::Document *document, const KTextEditor::Range &oldRange,
-                const KTextEditor::Range &newRange);
-        void insertion (KTextEditor::Document *document, const KTextEditor::Range &range);
-        void removal (KTextEditor::Document *document, const KTextEditor::Range &range, const QString &oldText);
-        void jump( const QModelIndex &);
-        
+
     private:
         ApplyChangesWidgetPrivate * d;
 };
