@@ -16,8 +16,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CODEREPRESENTATION_H
-#define CODEREPRESENTATION_H
+#ifndef KDEVPLATFORM_CODEREPRESENTATION_H
+#define KDEVPLATFORM_CODEREPRESENTATION_H
 
 #include "../languageexport.h"
 #include <language/duchain/indexedstring.h>
@@ -74,14 +74,15 @@ class KDEVPLATFORMLANGUAGE_EXPORT CodeRepresentation : public QSharedData {
       * Returns the specified name as a url for aritificial source code
       * suitable for code being inserted into the parser
       */
-    static KUrl artificialUrl(const QString & name);
+    static QString artificialPath(const QString & name);
  
     typedef KSharedPtr<CodeRepresentation> Ptr;
 };
 
 class KDEVPLATFORMLANGUAGE_EXPORT DynamicCodeRepresentation : public CodeRepresentation {
   public:
-      /** Used to group edit-history together. Call this before a bunch of replace(), and endEdit in the end. */
+      /** Used to group edit-history together. Call this optionally before a bunch
+       *  of replace() calls, and then call endEdit in the end, to group them together. */
       virtual void startEdit() = 0;
       virtual bool replace(const KTextEditor::Range& range, const QString& oldText,
                            const QString& newText, bool ignoreOldText = false) = 0;
