@@ -18,9 +18,11 @@
 */
 
 #include "abstractfunctiondeclaration.h"
-#include <QStringList>
+
 #include "types/functiontype.h"
 #include "declaration.h"
+#include "ducontext.h"
+#include "indexedstring.h"
 
 namespace KDevelop {
 
@@ -75,22 +77,14 @@ IndexedString AbstractFunctionDeclaration::defaultParameterForArgument(int index
   return IndexedString();
 }
 
+void AbstractFunctionDeclaration::setInternalFunctionContext(DUContext* context)
+{
+  Q_ASSERT(!context || context->type() == DUContext::Function);
+  dynamicData()->m_functionContext = context;
+}
 DUContext* AbstractFunctionDeclaration::internalFunctionContext() const {
-  const Declaration* selfDecl = dynamic_cast<const Declaration*>(this);
-  Q_ASSERT(selfDecl);
-  DUContext* ctx = selfDecl->internalContext();
-  //Follow the context imports until a function context is found
-  while(ctx && ctx->type() != DUContext::Function) {
-    QVector< DUContext::Import > imports = ctx->importedParentContexts();
-    if(!imports.isEmpty()) {
-      ctx = imports.first().context(selfDecl->topContext());
-    }else{
-      return 0;
-    }
-  }
-  return ctx;
+  return data()->m_functionContext.context();
 }
-
 
 }
 
