@@ -16,8 +16,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef ABSTRACTDECLARATIONBUILDER_H
-#define ABSTRACTDECLARATIONBUILDER_H
+#ifndef KDEVPLATFORM_ABSTRACTDECLARATIONBUILDER_H
+#define KDEVPLATFORM_ABSTRACTDECLARATIONBUILDER_H
 
 #include <typeinfo>
 
@@ -212,4 +212,4 @@ private:
 
 }
 
-#endif // ABSTRACTDECLARATIONBUILDER_H
+#endif // KDEVPLATFORM_ABSTRACTDECLARATIONBUILDER_H
