@@ -22,6 +22,7 @@
 #include <language/duchain/declaration.h>
 #include <language/duchain/appendedlist.h>
 #include <language/duchain/duchainregister.h>
+#include "types/structuretype.h"
 
 
 namespace KDevelop {
@@ -29,14 +30,14 @@ namespace KDevelop {
 DEFINE_LIST_MEMBER_HASH(ClassDeclarationData, baseClasses, BaseClassInstance)
 
 
-ClassDeclaration::ClassDeclaration(const KDevelop::SimpleRange& range, DUContext* context)
+ClassDeclaration::ClassDeclaration(const KDevelop::RangeInRevision& range, DUContext* context)
   : ClassMemberDeclaration(*new ClassDeclarationData, range)
 {
   d_func_dynamic()->setClassId(this);
   setContext(context);
 }
 
-ClassDeclaration::ClassDeclaration( ClassDeclarationData& data, const KDevelop::SimpleRange& range, DUContext* context )
+ClassDeclaration::ClassDeclaration( ClassDeclarationData& data, const KDevelop::RangeInRevision& range, DUContext* context )
   : ClassMemberDeclaration( data, range )
 {
   setContext(context);
@@ -157,6 +158,9 @@ QString ClassDeclaration::toString() const {
     case ClassDeclarationData::Interface:
       ret += "interface ";
       break;
+    case ClassDeclarationData::Trait:
+      ret += "trait ";
+      break;
     case ClassDeclarationData::Union:
       ret += "union ";
       break;
