@@ -17,21 +17,17 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef CLASSDECLARATION_H
-#define CLASSDECLARATION_H
+#ifndef KDEVPLATFORM_CLASSDECLARATION_H
+#define KDEVPLATFORM_CLASSDECLARATION_H
 
 #include <language/duchain/declaration.h>
 #include <language/duchain/declarationdata.h>
-#include <language/duchain/types/structuretype.h>
 #include <language/duchain/classmemberdeclarationdata.h>
 #include <language/duchain/classmemberdeclaration.h>
 
 namespace KDevelop {
-  class QualifiedIdentifier;
   class DUContext;
   class TopDUContext;
-  class IndexedString;
-  class SimpleRange;
 }
 
 namespace KDevelop {
@@ -52,7 +48,8 @@ public:
     Class,
     Struct,
     Union,
-    Interface
+    Interface,
+    Trait
   };
   
   enum ClassModifier {
@@ -136,5 +133,5 @@ private:
 
 Q_DECLARE_TYPEINFO(KDevelop::BaseClassInstance, Q_MOVABLE_TYPE);
 
-#endif // CLASSDECLARATION_H
+#endif // KDEVPLATFORM_CLASSDECLARATION_H
 
