@@ -42,6 +42,9 @@
 #include "topducontextdynamicdata.h"
 #include "importers.h"
 #include "uses.h"
+#include "navigation/abstractdeclarationnavigationcontext.h"
+#include "navigation/abstractnavigationwidget.h"
+#include "ducontextdynamicdata.h"
 
 ///It is fine to use one global static mutex here
 
@@ -61,8 +64,6 @@ using namespace KTextEditor;
 
 namespace KDevelop
 {
-QMutex DUContextDynamicData::m_localDeclarationsMutex(QMutex::Recursive);
-
 DEFINE_LIST_MEMBER_HASH(DUContextData, m_childContexts, LocalIndexedDUContext)
 DEFINE_LIST_MEMBER_HASH(DUContextData, m_importers, IndexedDUContext)
 DEFINE_LIST_MEMBER_HASH(DUContextData, m_importedContexts, DUContext::Import)
@@ -79,15 +80,28 @@ DUChainVisitor::~DUChainVisitor()
  * We leak here, to prevent a possible crash during destruction, as the destructor
  * of Identifier is not safe to be called after the duchain has been destroyed
  */
-Identifier& globalImportIdentifier() {
-  static Identifier globalImportIdentifierObject(*new Identifier("{...import...}"));
+const Identifier& globalImportIdentifier() {
+  static const Identifier globalImportIdentifierObject(*new Identifier("{...import...}"));
   return globalImportIdentifierObject;
 }
-Identifier& globalAliasIdentifier() {
-  static Identifier globalAliasIdentifierObject(*new Identifier("{...alias...}"));
+
+const Identifier& globalAliasIdentifier() {
+  static const Identifier globalAliasIdentifierObject(*new Identifier("{...alias...}"));
   return globalAliasIdentifierObject;
 }
 
+const IndexedIdentifier& globalIndexedImportIdentifier()
+{
+  static const IndexedIdentifier id(globalImportIdentifier());
+  return id;
+}
+
+const IndexedIdentifier& globalIndexedAliasIdentifier()
+{
+  static const IndexedIdentifier id(globalAliasIdentifier());
+  return id;
+}
+
 void DUContext::rebuildDynamicData(DUContext* parent, uint ownIndex) {
 
   Q_ASSERT(!parent || ownIndex);
@@ -141,40 +155,20 @@ void DUContextDynamicData::scopeIdentifier(bool includeClasses, QualifiedIdentif
     target += m_context->d_func()->m_scopeIdentifier;
 }
 
-bool DUContextDynamicData::importsSafeButSlow(const DUContext* context, const TopDUContext* source,
-                                              ImportsHash& checked) const
-{
-  if( this == context->m_dynamicData )
-    return true;
-
-  if(checked.find(this) != checked.end())
-    return false;
-  checked.insert(std::make_pair(this, true));
-
-  FOREACH_FUNCTION( const DUContext::Import& ctx, m_context->d_func()->m_importedContexts ) {
-    DUContext* import = ctx.context(source);
-    if(import == context || (import && import->m_dynamicData->importsSafeButSlow(context, source, checked)))
-      return true;
-  }
-
-  return false;
-}
-
 bool DUContextDynamicData::imports(const DUContext* context, const TopDUContext* source,
-                                   int maxDepth) const
+                                   QSet<const DUContextDynamicData*>* recursionGuard) const
 {
   if( this == context->m_dynamicData )
     return true;
 
-  if(maxDepth == 0) {
-    ImportsHash checked(500);
-    checked.set_empty_key(0);
-    return importsSafeButSlow(context, source, checked);
+  if (recursionGuard->contains(this)) {
+    return false;
   }
+  recursionGuard->insert(this);
 
   FOREACH_FUNCTION( const DUContext::Import& ctx, m_context->d_func()->m_importedContexts ) {
     DUContext* import = ctx.context(source);
-    if(import == context || (import && import->m_dynamicData->imports(context, source, maxDepth-1)))
+    if(import == context || (import && import->m_dynamicData->imports(context, source, recursionGuard)))
       return true;
   }
 
@@ -264,10 +258,6 @@ void DUContextDynamicData::addDeclaration( Declaration * newDeclaration )
 {
   // The definition may not have its identifier set when it's assigned... 
   // allow dupes here, TODO catch the error elsewhere
-  {
-    QMutexLocker lock(&m_localDeclarationsMutex);
-
-//     m_localDeclarations.append(newDeclaration);
 
   //If this context is temporary, added declarations should be as well, and viceversa
   Q_ASSERT(isContextTemporary(m_indexInTopContext) == isContextTemporary(newDeclaration->ownIndex()));
@@ -294,24 +284,19 @@ void DUContextDynamicData::addDeclaration( Declaration * newDeclaration )
       break;
     }
   }
+
   if( !inserted ) //We haven't found any child that is before this one, so prepend it
     m_context->d_func_dynamic()->m_localDeclarationsList().insert(0, newDeclaration);
 
-    addDeclarationToHash(newDeclaration->identifier(), newDeclaration);
-  }
-
-  //DUChain::contextChanged(m_context, DUChainObserver::Addition, DUChainObserver::LocalDeclarations, newDeclaration);
+  addDeclarationToHash(newDeclaration->identifier(), newDeclaration);
 }
 
 bool DUContextDynamicData::removeDeclaration(Declaration* declaration)
 {
-  QMutexLocker lock(&m_localDeclarationsMutex);
-
   if(!m_topContext->deleting()) //We can save a lot of time by just not caring about the hash while deleting
     removeDeclarationFromHash(declaration->identifier(), declaration);
 
   if( m_context->d_func_dynamic()->m_localDeclarationsList().removeOne(LocalIndexedDeclaration(declaration)) ) {
-    //DUChain::contextChanged(m_context, DUChainObserver::Removal, DUChainObserver::LocalDeclarations, declaration);
     return true;
   }else {
     return false;
@@ -319,7 +304,7 @@ bool DUContextDynamicData::removeDeclaration(Declaration* declaration)
 }
 
 void DUContext::changingIdentifier( Declaration* decl, const Identifier& from, const Identifier& to ) {
-  QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
+  ENSURE_CAN_WRITE
   m_dynamicData->removeDeclarationFromHash(from, decl);
   m_dynamicData->addDeclarationToHash(to, decl);
 }
@@ -357,13 +342,10 @@ void DUContextDynamicData::addChildContext( DUContext * context )
   }
 
   if(context->d_func()->m_propagateDeclarations) {
-    QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
     disableLocalDeclarationsHash();
     if(needsLocalDeclarationsHash())
       enableLocalDeclarationsHash(m_context);
   }
-
-  //DUChain::contextChanged(m_context, DUChainObserver::Addition, DUChainObserver::ChildContexts, context);
 }
 
 bool DUContextDynamicData::removeChildContext( DUContext* context ) {
@@ -392,8 +374,6 @@ void DUContextDynamicData::addImportedChildContext( DUContext * context )
     //Indirect importers are registered separately
     Importers::self().addImporter(import.indirectDeclarationId(), IndexedDUContext(context));
   }
-
-  //DUChain::contextChanged(m_context, DUChainObserver::Addition, DUChainObserver::ImportedChildContexts, context);
 }
 
 //Can also be called with a context that is not in the list
@@ -522,7 +502,6 @@ DUContext::~DUContext( )
   if(!top->deleting() || !top->isOnDisk()) {
     if (m_dynamicData->m_parentContext)
       m_dynamicData->m_parentContext->m_dynamicData->removeChildContext(this);
-    //DUChain::contextChanged(this, DUChainObserver::Deletion, DUChainObserver::NotApplicable);
   }
 
   top->m_dynamicData->clearContextIndex(this);
@@ -578,8 +557,6 @@ void DUContext::setPropagateDeclarations(bool propagate)
   ENSURE_CAN_WRITE
   DUCHAIN_D_DYNAMIC(DUContext);
   
-  QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
-  
   if(propagate == d->m_propagateDeclarations)
     return;
 
@@ -626,8 +603,6 @@ void DUContext::findLocalDeclarationsInternal( const Identifier& identifier,
                                                SearchFlags flags ) const
 {
   {
-     QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
-
      struct Checker {
        Checker(SearchFlags flags, const AbstractType::Ptr& dataType, const CursorInRevision & position, DUContext::ContextType ownType) : m_flags(flags), m_dataType(dataType), m_position(position), m_ownType(ownType) {
        }
@@ -689,7 +664,7 @@ void DUContext::findLocalDeclarationsInternal( const Identifier& identifier,
         if(checked)
             ret.append(checked);
       }
-    }else if(d_func()->m_inSymbolTable && !this->localScopeIdentifier().isEmpty() && !identifier.isEmpty()) {
+    }else if(d_func()->m_inSymbolTable && !indexedLocalScopeIdentifier().isEmpty() && !identifier.isEmpty()) {
        //This context is in the symbol table, use the symbol-table to speed up the search
        QualifiedIdentifier id(scopeIdentifier(true) + identifier);
 
@@ -851,7 +826,9 @@ bool DUContext::imports(const DUContext* origin, const CursorInRevision& /*posit
 {
   ENSURE_CAN_READ
 
-  return m_dynamicData->imports(origin, topContext(), 4);
+  QSet<const DUContextDynamicData*> recursionGuard;
+  recursionGuard.reserve(8);
+  return m_dynamicData->imports(origin, topContext(), &recursionGuard);
 }
 
 bool DUContext::addIndirectImport(const DUContext::Import& import) {
@@ -880,6 +857,10 @@ void DUContext::addImportedParentContext( DUContext * context, const CursorInRev
     kDebug() << "Tried to import self";
     return;
   }
+  if(!context) {
+    kDebug() << "Tried to import invalid context";
+    return;
+  }
 
   Import import(context, this, position);
   if(addIndirectImport(import))
@@ -889,7 +870,6 @@ void DUContext::addImportedParentContext( DUContext * context, const CursorInRev
     ENSURE_CAN_WRITE_(context)
     context->m_dynamicData->addImportedChildContext(this);
   }
-  //DUChain::contextChanged(this, DUChainObserver::Addition, DUChainObserver::ImportedParentContexts, context);
 }
 
 void DUContext::removeImportedParentContext( DUContext * context )
@@ -910,8 +890,6 @@ void DUContext::removeImportedParentContext( DUContext * context )
     return;
 
   context->m_dynamicData->removeImportedChildContext(this);
-
-  //DUChain::contextChanged(this, DUChainObserver::Removal, DUChainObserver::ImportedParentContexts, context);
 }
 
 KDevVarLengthArray<IndexedDUContext> DUContext::indexedImporters() const
@@ -997,7 +975,6 @@ QVector<Declaration*> DUContext::localDeclarations(const TopDUContext* source) c
   Q_UNUSED(source);
   ENSURE_CAN_READ
 
-  QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
   QVector<Declaration*> ret;
   FOREACH_FUNCTION(const LocalIndexedDeclaration& decl, d_func()->m_localDeclarations) {
     ret << decl.data(topContext());
@@ -1012,6 +989,8 @@ void DUContext::mergeDeclarationsInternal(QList< QPair<Declaration*, int> >& def
                                           const TopDUContext* source,
                                           bool searchInParents, int currentDepth) const
 {
+  ENSURE_CAN_READ
+
   if((currentDepth > 300 && currentDepth < 1000) || currentDepth > 1300) {
     kDebug() << "too much depth";
     return;
@@ -1028,7 +1007,6 @@ void DUContext::mergeDeclarationsInternal(QList< QPair<Declaration*, int> >& def
         currentDepth += 1000;
 
       {
-        QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
         DUContextDynamicData::VisibleDeclarationIterator it(m_dynamicData);
         while(it) {
           Declaration* decl = *it;
@@ -1073,7 +1051,6 @@ void DUContext::deleteLocalDeclarations()
   ENSURE_CAN_WRITE
   KDevVarLengthArray<LocalIndexedDeclaration> declarations;
   {
-    QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
     FOREACH_FUNCTION(const LocalIndexedDeclaration& decl, d_func()->m_localDeclarations)
       declarations.append(decl);
   }
@@ -1150,7 +1127,6 @@ void DUContext::setLocalScopeIdentifier(const QualifiedIdentifier & identifier)
   setInSymbolTable(false);
   d_func_dynamic()->m_scopeIdentifier = identifier;
   setInSymbolTable(wasInSymbolTable);
-  //DUChain::contextChanged(this, DUChainObserver::Change, DUChainObserver::Identifier);
 }
 
 QualifiedIdentifier DUContext::localScopeIdentifier() const
@@ -1176,8 +1152,6 @@ void DUContext::setType(ContextType type)
   ENSURE_CAN_WRITE
 
   d_func_dynamic()->m_contextType = type;
-
-  //DUChain::contextChanged(this, DUChainObserver::Change, DUChainObserver::ContextType);
 }
 
 QList<Declaration*> DUContext::findDeclarations(const Identifier& identifier, const CursorInRevision& position,
@@ -1314,13 +1288,12 @@ void DUContext::applyAliases(const SearchItem::PtrList& baseIdentifiers, SearchI
 void DUContext::applyUpwardsAliases(SearchItem::PtrList& identifiers, const TopDUContext* /*source*/) const {
 
   if(type() == Namespace) {
-    QualifiedIdentifier localId = d_func()->m_scopeIdentifier;
-    if(localId.isEmpty())
+    if(d_func()->m_scopeIdentifier.isEmpty())
       return;
 
     //Make sure we search for the items in all namespaces of the same name, by duplicating each one with the namespace-identifier prepended.
     //We do this by prepending items to the current identifiers that equal the local scope identifier.
-    SearchItem::Ptr newItem( new SearchItem(localId) );
+    SearchItem::Ptr newItem( new SearchItem(d_func()->m_scopeIdentifier.identifier()) );
 
     //This will exclude explictly global identifiers
     newItem->addToEachNode( identifiers );
@@ -1496,8 +1469,18 @@ void DUContext::cleanIfNotEncountered(const QSet<DUChainBase*>& encountered)
 {
   ENSURE_CAN_WRITE
 
-  foreach (Declaration* dec, localDeclarations()) {
-    if (!encountered.contains(dec) && (!dec->isAutoDeclaration() || !dec->hasUses()))
+  // It may happen that the deletion of one declaration triggers the deletion of another one
+  // Therefore we copy the list of indexed declarations and work on those. Indexed declarations
+  // will return zero for already deleted declarations.
+  KDevVarLengthArray<LocalIndexedDeclaration, 10> declarationsCopy; 
+  {
+    declarationsCopy = d_func_dynamic()->m_localDeclarationsList();
+  }
+
+  FOREACH_ARRAY(const LocalIndexedDeclaration& indexedDec, declarationsCopy)
+  {
+    Declaration* dec = indexedDec.data(topContext());
+    if (dec && !encountered.contains(dec) && (!dec->isAutoDeclaration() || !dec->hasUses()))
       delete dec;
   }
     
@@ -1514,10 +1497,19 @@ TopDUContext* DUContext::topContext() const
   return m_dynamicData->m_topContext;
 }
 
-QWidget* DUContext::createNavigationWidget(Declaration* /*decl*/, TopDUContext* /*topContext*/,
-                                           const QString& /*htmlPrefix*/, const QString& /*htmlSuffix*/) const
+QWidget* DUContext::createNavigationWidget(Declaration* decl, TopDUContext* topContext,
+                                           const QString& htmlPrefix, const QString& htmlSuffix) const
 {
-  return 0;
+  if (decl) {
+    AbstractNavigationWidget* widget = new AbstractNavigationWidget;
+    AbstractDeclarationNavigationContext* context = new AbstractDeclarationNavigationContext(DeclarationPointer(decl),
+                                                                                            TopDUContextPointer(topContext));
+    context->setPrefixSuffix(htmlPrefix, htmlSuffix);
+    widget->setContext(NavigationContextPointer(context));
+    return widget;
+  } else {
+    return 0;
+  }
 }
 
 void DUContext::squeeze()
@@ -1540,7 +1532,7 @@ QList<RangeInRevision> allUses(DUContext* context, int declarationIndex, bool no
   return ret;
 }
 
-DUContext::SearchItem::SearchItem(const QualifiedIdentifier& id, Ptr nextItem, int start)
+DUContext::SearchItem::SearchItem(const QualifiedIdentifier& id, const Ptr& nextItem, int start)
 : isExplicitlyGlobal(start == 0 ? id.explicitlyGlobal() : false)
 {
   if(!id.isEmpty()) {
@@ -1571,14 +1563,14 @@ DUContext::SearchItem::SearchItem(const QualifiedIdentifier& id, const PtrList&
     next = nextItems;
 }
 
-DUContext::SearchItem::SearchItem(bool explicitlyGlobal, Identifier id, const PtrList& nextItems)
+DUContext::SearchItem::SearchItem(bool explicitlyGlobal, const Identifier& id, const PtrList& nextItems)
   : isExplicitlyGlobal(explicitlyGlobal)
   , identifier(id)
   , next(nextItems)
 {
 }
 
-DUContext::SearchItem::SearchItem(bool explicitlyGlobal, Identifier id, Ptr nextItem)
+DUContext::SearchItem::SearchItem(bool explicitlyGlobal, const Identifier& id, const Ptr& nextItem)
   : isExplicitlyGlobal(explicitlyGlobal)
   , identifier(id)
 {
@@ -1637,11 +1629,11 @@ QList<QualifiedIdentifier> DUContext::SearchItem::toList(const QualifiedIdentifi
 }
 
 
-void DUContext::SearchItem::addNext(SearchItem::Ptr other) {
+void DUContext::SearchItem::addNext(const SearchItem::Ptr& other) {
   next.append(other);
 }
 
-void DUContext::SearchItem::addToEachNode(SearchItem::Ptr other) {
+void DUContext::SearchItem::addToEachNode(const SearchItem::Ptr& other) {
   if(other->isExplicitlyGlobal)
     return;
 
@@ -1650,7 +1642,7 @@ void DUContext::SearchItem::addToEachNode(SearchItem::Ptr other) {
     next[a]->addToEachNode(other);
 }
 
-void DUContext::SearchItem::addToEachNode(SearchItem::PtrList other) {
+void DUContext::SearchItem::addToEachNode(const SearchItem::PtrList& other) {
   int added = 0;
   FOREACH_ARRAY(const SearchItem::Ptr& o, other) {
     if(!o->isExplicitlyGlobal) {
@@ -1682,6 +1674,16 @@ DUContext::Import::Import(const DeclarationId& id, const CursorInRevision& _posi
 DUContext* DUContext::Import::context(const TopDUContext* topContext, bool instantiateIfRequired) const {
   if(m_declaration.isValid()) {
     Declaration* decl = m_declaration.getDeclaration(topContext, instantiateIfRequired);
+    //This first case rests on the assumption that no context will ever import a function's expression context
+    //More accurately, that no specialized or cross-topContext imports will, but if the former assumption fails the latter will too
+    if (AbstractFunctionDeclaration *functionDecl = dynamic_cast<AbstractFunctionDeclaration*>(decl))
+    {
+      if (functionDecl->internalFunctionContext()) {
+        return functionDecl->internalFunctionContext();
+      } else {
+        kWarning() << "Import of function declaration without internal function context encountered!";
+      }
+    }
     if(decl)
       return decl->logicalInternalContext(topContext);
     else
@@ -1697,13 +1699,13 @@ bool DUContext::Import::isDirect() const {
 
 void DUContext::visit(DUChainVisitor& visitor)
 {
+  ENSURE_CAN_READ
+
   visitor.visit(this);
   
   TopDUContext* top = topContext();
   
   {
-    QMutexLocker lock(&DUContextDynamicData::m_localDeclarationsMutex);
-    
     FOREACH_FUNCTION(const LocalIndexedDeclaration& decl, d_func()->m_localDeclarations)
       visitor.visit(decl.data(top));
   }
