@@ -38,6 +38,7 @@
 #include <interfaces/icore.h>
 #include <interfaces/idocumentationcontroller.h>
 #include <duchain/types/typealiastype.h>
+#include <duchain/types/structuretype.h>
 #include <duchain/classdeclaration.h>
 #include <typeinfo>
 
@@ -81,7 +82,7 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
   
   if( !shorten ) {
     doc = ICore::self()->documentationController()->documentationForDeclaration(m_declaration.data());
-    
+
     const AbstractFunctionDeclaration* function = dynamic_cast<const AbstractFunctionDeclaration*>(m_declaration.data());
     if( function ) {
       htmlFunction();
@@ -107,12 +108,12 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
         htmlClass();
       }
       if ( m_declaration->kind() == Declaration::Namespace ) {
-        modifyHtml() += i18n("namespace %1 <br />", nameHighlight(Qt::escape(m_declaration->qualifiedIdentifier().toString())));
+        modifyHtml() += i18n("namespace %1 ", nameHighlight(Qt::escape(m_declaration->qualifiedIdentifier().toString())));
       }
 
       if(m_declaration->type<EnumerationType>()) {
         EnumerationType::Ptr enumeration = m_declaration->type<EnumerationType>();
-        modifyHtml() += i18n("enumeration %1 <br/>", Qt::escape(m_declaration->identifier().toString()) );
+        modifyHtml() += i18n("enumeration %1 ", Qt::escape(m_declaration->identifier().toString()) );
       }
 
       if(m_declaration->isForwardDeclaration()) {
@@ -128,19 +129,16 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
           uint count;
           const IndexedDeclaration* decls;
           PersistentSymbolTable::self().declarations(id, count, decls);
-          bool had = false;
           for(uint a = 0; a < count; ++a) {
             if(decls[a].isValid() && !decls[a].data()->isForwardDeclaration()) {
               modifyHtml() += "<br />";
               makeLink(i18n("possible resolution from"), KDevelop::DeclarationPointer(decls[a].data()), NavigationAction::NavigateDeclaration);
               modifyHtml() += ' ' + decls[a].data()->url().str();
-              had = true;
             }
           }
-          if(had)
-            modifyHtml() += "<br />";
         }
       }
+      modifyHtml() += "<br />";
     }
   }else{
     AbstractType::Ptr showType = m_declaration->abstractType();
@@ -262,11 +260,11 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     if(comment.isEmpty() && doc) {
       comment = doc->description();
       if(!comment.isEmpty()) {
+        connect(doc.data(), SIGNAL(descriptionChanged()), this, SIGNAL(contentsChanged()));
         modifyHtml() += "<br />" + commentHighlight(comment);
       }
     } else if(!comment.isEmpty()) {
-      comment.replace("<br />", "\n"); //do not escape html newlines within the comment
-      comment.replace("<br/>", "\n");
+      comment.replace(QRegExp("<br */>"), "\n"); //do not escape html newlines within the comment
       comment = Qt::escape(comment);
       comment.replace('\n', "<br />"); //Replicate newlines in html
       modifyHtml() += commentHighlight(comment);
@@ -312,34 +310,34 @@ void AbstractDeclarationNavigationContext::htmlFunction()
 
   modifyHtml() += ' ' + nameHighlight(Qt::escape(prettyIdentifier(m_declaration).toString()));
 
-  if( type->arguments().count() == 0 )
+  if( type->indexedArgumentsSize() == 0 )
   {
     modifyHtml() += "()";
   } else {
     modifyHtml() += "( ";
+
     bool first = true;
+    int firstDefaultParam = type->indexedArgumentsSize() - function->defaultParametersSize();
+    int currentArgNum = 0;
 
-    KDevelop::DUContext* argumentContext = DUChainUtils::getArgumentContext(m_declaration.data());
+    QVector<Declaration*> decls;
+    if (KDevelop::DUContext* argumentContext = DUChainUtils::getArgumentContext(m_declaration.data())) {
+      decls = argumentContext->localDeclarations(m_topContext.data());
+    }
+    foreach(const AbstractType::Ptr& argType, type->arguments()) {
+      if( !first )
+        modifyHtml() += ", ";
+      first = false;
 
-    if(argumentContext) {
-      int firstDefaultParam = argumentContext->localDeclarations(m_topContext.data()).count() - function->defaultParametersSize();
-      int currentArgNum = 0;
-
-      foreach(Declaration* argument, argumentContext->localDeclarations(m_topContext.data())) {
-        if( !first )
-          modifyHtml() += ", ";
-        first = false;
-
-        AbstractType::Ptr argType = argument->abstractType();
-
-        eventuallyMakeTypeLinks( argType );
-        modifyHtml() += ' ' + nameHighlight(Qt::escape(argument->identifier().toString()));
-
-        if( currentArgNum >= firstDefaultParam )
-          modifyHtml() += " = " + Qt::escape(function->defaultParameters()[ currentArgNum - firstDefaultParam ].str());
-
-        ++currentArgNum;
+      eventuallyMakeTypeLinks( argType );
+      if (currentArgNum < decls.size()) {
+        modifyHtml() += ' ' + nameHighlight(Qt::escape(decls[currentArgNum]->identifier().toString()));
       }
+
+      if( currentArgNum >= firstDefaultParam )
+        modifyHtml() += " = " + Qt::escape(function->defaultParameters()[ currentArgNum - firstDefaultParam ].str());
+
+      ++currentArgNum;
     }
 
     modifyHtml() += " )";
@@ -482,6 +480,9 @@ void AbstractDeclarationNavigationContext::htmlClass()
       case ClassDeclarationData::Interface:
         modifyHtml() += "interface ";
         break;
+      case ClassDeclarationData::Trait:
+        modifyHtml() += "trait ";
+        break;
       default:
         modifyHtml() += "<unknown type> ";
         break;
@@ -492,12 +493,12 @@ void AbstractDeclarationNavigationContext::htmlClass()
       modifyHtml() += ", " + stringFromAccess(base.access) + " " + (base.virtualInheritance ? QString("virtual") : QString()) + " ";
       eventuallyMakeTypeLinks(base.baseClass.abstractType());
     }
-    modifyHtml() += " ";
   } else {
     /// @todo How can we get here? and should this really be a class?
     modifyHtml() += "class ";
     eventuallyMakeTypeLinks( klass.cast<AbstractType>() );
   }
+  modifyHtml() += " ";
 }
 
 void AbstractDeclarationNavigationContext::htmlIdentifiedType(AbstractType::Ptr type, const IdentifiedType* idType)
