@@ -18,26 +18,21 @@
 
 #include "abstractnavigationcontext.h"
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 #include <klocale.h>
 
 #include "abstractdeclarationnavigationcontext.h"
+#include "abstractnavigationwidget.h"
 #include "usesnavigationcontext.h"
 #include "../../../interfaces/icore.h"
 #include "../../../interfaces/idocumentcontroller.h"
 #include "../functiondeclaration.h"
-#include "../functiondefinition.h"
 #include "../namespacealiasdeclaration.h"
-#include "../classmemberdeclaration.h"
-#include "../classfunctiondeclaration.h"
-#include "../forwarddeclaration.h"
-#include "../duchainutils.h"
 #include "../types/functiontype.h"
-#include "../types/enumeratortype.h"
-#include "../types/enumerationtype.h"
-#include "../types/referencetype.h"
-#include "../types/pointertype.h"
+#include "../types/structuretype.h"
+#include <interfaces/icontextbrowser.h>
 #include <interfaces/idocumentationcontroller.h>
+#include <interfaces/iplugincontroller.h>
 
 
 namespace KDevelop {
@@ -145,7 +140,7 @@ NavigationContextPointer AbstractNavigationContext::executeKeyAction(QString key
   return NavigationContextPointer(this);
 }
 
-NavigationContextPointer AbstractNavigationContext::execute(NavigationAction& action)
+NavigationContextPointer AbstractNavigationContext::execute(const NavigationAction& action)
 {
   if(action.targetContext)
     return NavigationContextPointer(action.targetContext);
@@ -175,6 +170,15 @@ NavigationContextPointer AbstractNavigationContext::execute(NavigationAction& ac
       return AbstractNavigationContext::registerChild(action.decl);
     } break;
     case NavigationAction::NavigateUses:
+    {
+      IContextBrowser* browser = ICore::self()->pluginController()->extensionForPlugin<IContextBrowser>();
+      if (browser) {
+        browser->showUses(action.decl);
+        return NavigationContextPointer(this);
+      }
+      // fall-through
+    }
+    case NavigationAction::ShowUses:
       return registerChild(new UsesNavigationContext(action.decl.data(), this));
     case NavigationAction::JumpToSource:
       {
