@@ -16,16 +16,14 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef ABSTRACTNAVIGATIONWIDGET_H
-#define ABSTRACTNAVIGATIONWIDGET_H
+#ifndef KDEVPLATFORM_ABSTRACTNAVIGATIONWIDGET_H
+#define KDEVPLATFORM_ABSTRACTNAVIGATIONWIDGET_H
 
 
 #include <QtCore/QObject>
 #include <QtCore/QPointer>
-#include <KDE/KSharedPtr>
-#include <ktextbrowser.h>
+#include <QWidget>
 
-#include "../duchainpointer.h"
 #include "../../interfaces/quickopendataprovider.h"
 #include "../../languageexport.h"
 #include "abstractnavigationcontext.h"
@@ -90,7 +88,7 @@ namespace KDevelop {
       void initBrowser(int height);
       void update();
 
-      NavigationContextPointer m_context, m_startContext;
+      NavigationContextPointer m_startContext;
 
       TopDUContextPointer m_topContext;
 
@@ -99,6 +97,8 @@ namespace KDevelop {
       QString m_currentText;
       mutable QSize m_idealTextSize;
 
+    private:
+      NavigationContextPointer m_context;
   };
 }
 
