@@ -17,34 +17,25 @@
 */
 
 #include "useswidget.h"
+
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/uses.h>
 #include <QVBoxLayout>
 #include <QLabel>
-#include <QCompleter>
 #include <QProgressBar>
-#include <KComboBox>
-#include <qpushbutton.h>
-#include <limits>
 #include <klocalizedstring.h>
-#include <qabstractitemview.h>
 #include <QToolButton>
+#include <language/duchain/declaration.h>
 #include <language/duchain/use.h>
 #include <kicon.h>
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
-#include <ktexteditor/document.h>
-#include <QFile>
 #include <interfaces/iprojectcontroller.h>
 #include <qtextdocument.h>
-#include <qevent.h>
-#include <qtextlayout.h>
+#include <QResizeEvent>
 #include <language/duchain/duchainutils.h>
-#include "language/duchain/parsingenvironment.h"
-#include "language/duchain/types/indexedtype.h"
 #include <language/codegen/coderepresentation.h>
-#include <language/backgroundparser/parsejob.h>
 #include <interfaces/iproject.h>
 #include <interfaces/foregroundlock.h>
 
@@ -52,7 +43,6 @@ using namespace KDevelop;
 
 
 const int tooltipContextSize = 2; //How many lines around the use are shown in the tooltip
-const bool showUsesHeader = false;
 
 ///The returned text is fully escaped
 ///@param cutOff The total count of characters that should be cut of, all in all on both sides together.
@@ -136,9 +126,9 @@ OneUseWidget::OneUseWidget(IndexedDeclaration declaration, IndexedString documen
 
     QString toolTipText;
     for(int a = start; a < end; ++a) {
-      QString lineText = code.line(a);
+      QString lineText = Qt::escape(code.line(a));
       if (m_range->range().start.line <= a && m_range->range().end.line >= a) {
-        lineText = QString("<b>") + Qt::escape(lineText) + QString("</b>");
+        lineText = QString("<b>") + lineText + QString("</b>");
       }
       if(!lineText.trimmed().isEmpty()) {
         toolTipText += lineText + "<br>";
@@ -200,7 +190,9 @@ NavigatableWidgetList::~NavigatableWidgetList() {
   delete m_headerLayout;
 }
 
-NavigatableWidgetList::NavigatableWidgetList(bool allowScrolling, uint maxHeight, bool vertical) : m_maxHeight(maxHeight), m_allowScrolling(allowScrolling) {
+NavigatableWidgetList::NavigatableWidgetList(bool allowScrolling, uint maxHeight, bool vertical)
+:  m_allowScrolling(allowScrolling)
+{
   m_layout = new QVBoxLayout;
   m_layout->setMargin(0);
   m_layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
@@ -502,11 +494,16 @@ void TopContextUsesWidget::labelClicked() {
   }
 }
 
-UsesWidget::~UsesWidget() {
-  delete m_collector;
+UsesWidget::~UsesWidget()
+{
+    if (m_collector) {
+        m_collector->setWidget(0);
+    }
 }
 
-UsesWidget::UsesWidget(IndexedDeclaration declaration, UsesWidgetCollector* customCollector) : NavigatableWidgetList(true) {
+UsesWidget::UsesWidget(const IndexedDeclaration& declaration, QSharedPointer<UsesWidgetCollector> customCollector)
+    : NavigatableWidgetList(true)
+{
     DUChainReadLocker lock(DUChain::lock());
     setUpdatesEnabled(false);
 
@@ -521,10 +518,10 @@ UsesWidget::UsesWidget(IndexedDeclaration declaration, UsesWidgetCollector* cust
     m_progressBar = new QProgressBar;
     addHeaderItem(m_progressBar);
 
-    if(!customCollector) {
-      m_collector = new UsesWidgetCollector(declaration);
-    }else{
-      m_collector = customCollector;
+    if (!customCollector) {
+        m_collector = QSharedPointer<UsesWidgetCollector>(new UsesWidgetCollector(declaration));
+    } else {
+        m_collector = customCollector;
     }
 
     m_collector->setProcessDeclarations(true);
@@ -586,6 +583,10 @@ void UsesWidget::UsesWidgetCollector::setWidget(UsesWidget* widget ) {
 
 
 void UsesWidget::UsesWidgetCollector::maximumProgress(uint max) {
+  if (!m_widget) {
+    return;
+  }
+
   if(m_widget->m_progressBar) {
     m_widget->m_progressBar->setMaximum(max);
     m_widget->m_progressBar->setMinimum(0);
@@ -596,6 +597,10 @@ void UsesWidget::UsesWidgetCollector::maximumProgress(uint max) {
 }
 
 void UsesWidget::UsesWidgetCollector::progress(uint processed, uint total) {
+  if (!m_widget) {
+    return;
+  }
+
   m_widget->redrawHeaderLine();
 
   if(m_widget->m_progressBar) {
@@ -614,7 +619,12 @@ void UsesWidget::UsesWidgetCollector::progress(uint processed, uint total) {
 }
 
 void UsesWidget::UsesWidgetCollector::processUses( KDevelop::ReferencedTopDUContext topContext ) {
-  DUChainReadLocker lock(DUChain::lock());
+  if (!m_widget) {
+    return;
+  }
+
+  DUChainReadLocker lock;
+
   kDebug() << "processing" << topContext->url().str();
   TopContextUsesWidget* widget = new TopContextUsesWidget(declaration(), declarations(), topContext.data());
   
