@@ -18,12 +18,14 @@
 
 #include <util/kdevvarlengtharray.h>
 #include <util/convenientfreelist.h>
+#include <language/util/setrepository.h>
 #include "../languageexport.h"
 #include "declaration.h"
 #include "ducontext.h"
+#include "topducontext.h"
 
-#ifndef PERSISTENTSYMBOLTABLE_H
-#define PERSISTENTSYMBOLTABLE_H
+#ifndef KDEVPLATFORM_PERSISTENTSYMBOLTABLE_H
+#define KDEVPLATFORM_PERSISTENTSYMBOLTABLE_H
 
 namespace KDevelop {
 
