@@ -16,25 +16,29 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TYPEREPOSITORY_H
-#define TYPEREPOSITORY_H
+#ifndef KDEVPLATFORM_TYPEREPOSITORY_H
+#define KDEVPLATFORM_TYPEREPOSITORY_H
 
 #include <language/duchain/types/abstracttype.h>
-#include <language/duchain/referencecounting.h>
-#include "itemrepository.h"
 
 namespace KDevelop {
-  class TypeRepository {
-    public:
-      static uint indexForType(AbstractType::Ptr input);
-      static AbstractType::Ptr typeForIndex(uint index);
-      static void increaseReferenceCount(uint index);
-      static void decreaseReferenceCount(uint index);
-      static void increaseReferenceCount(uint index, ReferenceCountManager* manager);
-      static void decreaseReferenceCount(uint index, ReferenceCountManager* manager);
-  };
-  
-  AbstractRepositoryManager* typeRepositoryManager();
+
+struct ReferenceCountManager;
+class AbstractRepositoryManager;
+
+class TypeRepository
+{
+public:
+    static uint indexForType(AbstractType::Ptr input);
+    static AbstractType::Ptr typeForIndex(uint index);
+    static void increaseReferenceCount(uint index);
+    static void decreaseReferenceCount(uint index);
+    static void increaseReferenceCount(uint index, ReferenceCountManager* manager);
+    static void decreaseReferenceCount(uint index, ReferenceCountManager* manager);
+};
+
+AbstractRepositoryManager* typeRepositoryManager();
+
 }
 
 #endif
