@@ -1,7 +1,7 @@
 /*
  * This file is part of KDevelop
  *
- * Copyright 2011 Milian Wolff <mail@milianw.de>
+ * Copyright 2011-2013 Milian Wolff <mail@milianw.de>
  * Copyright 2006 Hamish Rodda <rodda@kde.org>
  * Copyright 2007-2009 David Nolden <david.nolden.kdevelop@art-master.de>
  *
@@ -24,6 +24,8 @@
 #include "test_duchain.h"
 
 #include <QTest>
+#include <QElapsedTimer>
+
 #include <tests/autotestshell.h>
 #include <tests/testcore.h>
 
@@ -31,6 +33,13 @@
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/persistentsymboltable.h>
 #include <language/duchain/codemodel.h>
+#include <language/duchain/types/typesystemdata.h>
+#include <language/duchain/types/integraltype.h>
+#include <language/duchain/types/typeregister.h>
+#include <language/duchain/declarationdata.h>
+#include <language/duchain/duchainregister.h>
+#include <language/duchain/problem.h>
+#include <language/duchain/parsingenvironment.h>
 
 #include <language/codegen/coderepresentation.h>
 
@@ -38,7 +47,6 @@
 #include <language/util/basicsetrepository.h>
 
 // #include <typeinfo>
-#include <time.h>
 #include <set>
 #include <algorithm>
 #include <iterator> // needed for std::insert_iterator on windows
@@ -47,9 +55,6 @@
 //Extremely slow
 // #define TEST_NORMAL_IMPORTS
 
-//Uncomment the following line to get additional output from the string-repository test
-//#define DEBUG_STRINGREPOSITORY
-
 QTEST_MAIN(TestDUChain)
 
 using namespace KDevelop;
@@ -57,6 +62,19 @@ using namespace Utils;
 
 typedef BasicSetRepository::Index Index;
 
+struct Timer
+{
+  Timer()
+  {
+    m_timer.start();
+  }
+  qint64 elapsed()
+  {
+    return m_timer.nsecsElapsed();
+  }
+  QElapsedTimer m_timer;
+};
+
 void TestDUChain::initTestCase()
 {
   AutoTestShell::init();
@@ -73,7 +91,7 @@ void TestDUChain::cleanupTestCase()
 
 void TestDUChain::testStringSets() {
 
-  const unsigned int setCount = 11;
+  const unsigned int setCount = 8;
   const unsigned int choiceCount = 40;
   const unsigned int itemCount = 120;
 
@@ -81,18 +99,18 @@ void TestDUChain::testStringSets() {
 
 //  kDebug() << "Start repository-layout: \n" << rep.dumpDotGraph();
 
-  clock_t repositoryClockTime = 0; //Time spent on repository-operations
-  clock_t genericClockTime = 0; //Time spend on equivalent operations with generic sets
+  qint64 repositoryTime = 0; //Time spent on repository-operations
+  qint64 genericTime = 0; //Time spend on equivalent operations with generic sets
 
-  clock_t repositoryIntersectionClockTime = 0; //Time spent on repository-operations
-  clock_t genericIntersectionClockTime = 0; //Time spend on equivalent operations with generic sets
-  clock_t qsetIntersectionClockTime = 0; //Time spend on equivalent operations with generic sets
+  qint64 repositoryIntersectionTime = 0; //Time spent on repository-operations
+  qint64 genericIntersectionTime = 0; //Time spend on equivalent operations with generic sets
+  qint64 qsetIntersectionTime = 0; //Time spend on equivalent operations with generic sets
 
-  clock_t repositoryUnionClockTime = 0; //Time spent on repository-operations
-  clock_t genericUnionClockTime = 0; //Time spend on equivalent operations with generic sets
+  qint64 repositoryUnionTime = 0; //Time spent on repository-operations
+  qint64 genericUnionTime = 0; //Time spend on equivalent operations with generic sets
 
-  clock_t repositoryDifferenceClockTime = 0; //Time spent on repository-operations
-  clock_t genericDifferenceClockTime = 0; //Time spend on equivalent operations with generic sets
+  qint64 repositoryDifferenceTime = 0; //Time spent on repository-operations
+  qint64 genericDifferenceTime = 0; //Time spend on equivalent operations with generic sets
 
   Set sets[setCount];
   std::set<Index> realSets[setCount];
@@ -110,14 +128,16 @@ void TestDUChain::testStringSets() {
         choose = (rand() % itemCount) + 1;
       }
 
-      clock_t c = clock();
+      Timer t;
       chosenIndices.insert(chosenIndices.end(), choose);
-      genericClockTime += clock() - c;
+      genericTime += t.elapsed();
     }
 
-    clock_t c = clock();
-    sets[a] = rep.createSet(chosenIndices);
-    repositoryClockTime += clock() - c;
+    {
+      Timer t;
+      sets[a] = rep.createSet(chosenIndices);
+      repositoryTime += t.elapsed();
+    }
 
     realSets[a] = chosenIndices;
 
@@ -127,196 +147,218 @@ void TestDUChain::testStringSets() {
       QString dbg = "created set: ";
       for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
         dbg += QString("%1 ").arg(*it);
-      kDebug() << dbg;
+      qDebug() << dbg;
 
       dbg = "repo.   set: ";
       for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
         dbg += QString("%1 ").arg(*it);
-      kDebug() << dbg;
+      qDebug() << dbg;
 
-      kDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
+      qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
+      QFAIL("sets are not the same!");
     }
-    QVERIFY(tempSet == realSets[a]);
   }
 
   for(int cycle = 0; cycle < 100; ++cycle) {
       if(cycle % 10 == 0)
-         kDebug() << "cycle" << cycle;
+         qDebug() << "cycle" << cycle;
 
     for(unsigned int a = 0; a < setCount; a++) {
       for(unsigned int b = 0; b < setCount; b++) {
         /// ----- SUBTRACTION/DIFFERENCE
         std::set<Index> _realDifference;
-        clock_t c = clock();
-        std::set_difference(realSets[a].begin(), realSets[a].end(), realSets[b].begin(), realSets[b].end(), std::insert_iterator<std::set<Index> >(_realDifference, _realDifference.begin()));
-        genericDifferenceClockTime += clock() - c;
+        {
+          Timer t;
+          std::set_difference(realSets[a].begin(), realSets[a].end(), realSets[b].begin(), realSets[b].end(), std::insert_iterator<std::set<Index> >(_realDifference, _realDifference.begin()));
+          genericDifferenceTime += t.elapsed();
+        }
 
-        c = clock();
-        Set _difference = sets[a] - sets[b];
-        repositoryDifferenceClockTime += clock() - c;
+        Set _difference;
+        {
+          Timer t;
+          _difference = sets[a] - sets[b];
+          repositoryDifferenceTime += t.elapsed();
+        }
 
         if(_difference.stdSet() != _realDifference)
         {
           {
-            kDebug() << "SET a:";
+            qDebug() << "SET a:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
           }
           {
-            kDebug() << "SET b:";
+            qDebug() << "SET b:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
           }
 
           {
             std::set<Index> tempSet = _difference.stdSet();
 
-            kDebug() << "SET difference:";
+            qDebug() << "SET difference:";
             QString dbg = "real    set: ";
             for(std::set<Index>::const_iterator it = _realDifference.begin(); it != _realDifference.end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
             dbg = "repo.   set: ";
             for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << _difference.dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << _difference.dumpDotGraph() << "\n\n";
           }
+          QFAIL("difference sets are not the same!");
         }
-        QVERIFY(_difference.stdSet() == _realDifference);
 
 
         /// ------ UNION
 
         std::set<Index> _realUnion;
-        c = clock();
-        std::set_union(realSets[a].begin(), realSets[a].end(), realSets[b].begin(), realSets[b].end(), std::insert_iterator<std::set<Index> >(_realUnion, _realUnion.begin()));
-        genericUnionClockTime += clock() - c;
+        {
+          Timer t;
+          std::set_union(realSets[a].begin(), realSets[a].end(), realSets[b].begin(), realSets[b].end(), std::insert_iterator<std::set<Index> >(_realUnion, _realUnion.begin()));
+          genericUnionTime += t.elapsed();
+        }
 
-        c = clock();
-        Set _union = sets[a] + sets[b];
-        repositoryUnionClockTime += clock() - c;
+        Set _union;
+        {
+          Timer t;
+          _union = sets[a] + sets[b];
+          repositoryUnionTime += t.elapsed();
+        }
 
         if(_union.stdSet() != _realUnion)
         {
           {
-            kDebug() << "SET a:";
+            qDebug() << "SET a:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
           }
           {
-            kDebug() << "SET b:";
+            qDebug() << "SET b:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
           }
 
           {
             std::set<Index> tempSet = _union.stdSet();
 
-            kDebug() << "SET union:";
+            qDebug() << "SET union:";
             QString dbg = "real    set: ";
             for(std::set<Index>::const_iterator it = _realUnion.begin(); it != _realUnion.end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
             dbg = "repo.   set: ";
             for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << _union.dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << _union.dumpDotGraph() << "\n\n";
           }
+
+          QFAIL("union sets are not the same");
         }
-        QVERIFY(_union.stdSet() == _realUnion);
 
         std::set<Index> _realIntersection;
 
         /// -------- INTERSECTION
-        c = clock();
-        std::set_intersection(realSets[a].begin(), realSets[a].end(), realSets[b].begin(), realSets[b].end(), std::insert_iterator<std::set<Index> >(_realIntersection, _realIntersection.begin()));
-        genericIntersectionClockTime += clock() - c;
+        {
+          Timer t;
+          std::set_intersection(realSets[a].begin(), realSets[a].end(), realSets[b].begin(), realSets[b].end(), std::insert_iterator<std::set<Index> >(_realIntersection, _realIntersection.begin()));
+          genericIntersectionTime += t.elapsed();
+        }
 
         //Just for fun: Test how fast QSet intersections are
         QSet<Index> first, second;
-        for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
+        for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it) {
           first.insert(*it);
-        for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
+        }
+        for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it) {
           second.insert(*it);
-        c = clock();
-        QSet<Index> i = first.intersect(second);
-        qsetIntersectionClockTime += clock() - c;
-
-        c = clock();
-        Set _intersection = sets[a] & sets[b];
-        repositoryIntersectionClockTime += clock() - c;
+        }
+        {
+          Timer t;
+          QSet<Index> i = first.intersect(second);
+          qsetIntersectionTime += t.elapsed();
+        }
 
+        Set _intersection;
+        {
+          Timer t;
+          _intersection = sets[a] & sets[b];
+          repositoryIntersectionTime += t.elapsed();
+        }
 
         if(_intersection.stdSet() != _realIntersection)
         {
           {
-            kDebug() << "SET a:";
+            qDebug() << "SET a:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[a].begin(); it != realSets[a].end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << sets[a].dumpDotGraph() << "\n\n";
           }
           {
-            kDebug() << "SET b:";
+            qDebug() << "SET b:";
             QString dbg = "";
             for(std::set<Index>::const_iterator it = realSets[b].begin(); it != realSets[b].end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << sets[b].dumpDotGraph() << "\n\n";
           }
 
           {
             std::set<Index> tempSet = _intersection.stdSet();
 
-            kDebug() << "SET intersection:";
+            qDebug() << "SET intersection:";
             QString dbg = "real    set: ";
             for(std::set<Index>::const_iterator it = _realIntersection.begin(); it != _realIntersection.end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
             dbg = "repo.   set: ";
             for(std::set<Index>::const_iterator it = tempSet.begin(); it != tempSet.end(); ++it)
               dbg += QString("%1 ").arg(*it);
-            kDebug() << dbg;
+            qDebug() << dbg;
 
-            kDebug() << "DOT-Graph:\n\n" << _intersection.dumpDotGraph() << "\n\n";
+            qDebug() << "DOT-Graph:\n\n" << _intersection.dumpDotGraph() << "\n\n";
           }
+          QFAIL("intersection sets are not the same");
         }
-        QVERIFY(_intersection.stdSet() == _realIntersection);
       }
     }
-#ifdef DEBUG_STRINGREPOSITORY
-    kDebug() << "cycle " << cycle;
-  kDebug() << "Clock-cycles needed for set-building: repository-set: " << repositoryClockTime << " generic-set: " << genericClockTime;
-  kDebug() << "Clock-cycles needed for intersection: repository-sets: " << repositoryIntersectionClockTime << " generic-set: " << genericIntersectionClockTime << " QSet: " << qsetIntersectionClockTime;
-  kDebug() << "Clock-cycles needed for union: repository-sets: " << repositoryUnionClockTime << " generic-set: " << genericUnionClockTime;
-  kDebug() << "Clock-cycles needed for difference: repository-sets: " << repositoryDifferenceClockTime << " generic-set: " << genericDifferenceClockTime;
-#endif
+
+    qDebug() << "cycle " << cycle;
+    qDebug() << "ns needed for set-building: repository-set: " << float(repositoryTime)
+             << " generic-set: " << float(genericTime);
+    qDebug() << "ns needed for intersection: repository-sets: " << float(repositoryIntersectionTime)
+             << " generic-set: " << float(genericIntersectionTime) << " QSet: " << float(qsetIntersectionTime);
+    qDebug() << "ns needed for union: repository-sets: " << float(repositoryUnionTime)
+             << " generic-set: " << float(genericUnionTime);
+    qDebug() << "ns needed for difference: repository-sets: " << float(repositoryDifferenceTime)
+             << " generic-set: " << float(genericDifferenceTime);
   }
 }
 
@@ -475,8 +517,8 @@ void collectReachableNodes(QSet<uint>& reachableNodes, uint currentNode) {
   reachableNodes.insert(currentNode);
   const Utils::SetNodeData* node = KDevelop::RecursiveImportRepository::repository()->nodeFromIndex(currentNode);
   Q_ASSERT(node);
-  collectReachableNodes(reachableNodes, node->leftNode);
-  collectReachableNodes(reachableNodes, node->rightNode);
+  collectReachableNodes(reachableNodes, node->leftNode());
+  collectReachableNodes(reachableNodes, node->rightNode());
 }
 
 uint collectNaiveNodeCount(uint currentNode) {
@@ -485,14 +527,14 @@ uint collectNaiveNodeCount(uint currentNode) {
   uint ret = 1;
   const Utils::SetNodeData* node = KDevelop::RecursiveImportRepository::repository()->nodeFromIndex(currentNode);
   Q_ASSERT(node);
-  ret += collectNaiveNodeCount(node->leftNode);
-  ret += collectNaiveNodeCount(node->rightNode);
+  ret += collectNaiveNodeCount(node->leftNode());
+  ret += collectNaiveNodeCount(node->rightNode());
   return ret;
 }
 
 void TestDUChain::testImportStructure()
 {
-  clock_t startClock = clock();
+  Timer total;
   kDebug() << "before: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
 
   ///Maintains a naive import-structure along with a real top-context import structure, and allows comparing both.
@@ -502,8 +544,8 @@ void TestDUChain::testImportStructure()
   for(int t = 0; t < cycles; ++t) {
     QList<TestContext*> allContexts;
     //Create a random structure
-    int contextCount = 120;
-    int verifyOnceIn = contextCount/*((contextCount*contextCount)/20)+1*/; //Verify once in every chances(not in all cases, becase else the import-structure isn't built on-demand!)
+    int contextCount = 50;
+    int verifyOnceIn = contextCount/*((contextCount*contextCount)/20)+1*/; //Verify once in every chances(not in all cases, because else the import-structure isn't built on-demand!)
     int clearOnceIn = contextCount;
     for(int a = 0; a < contextCount; a++)
       allContexts << new TestContext();
@@ -549,16 +591,14 @@ void TestDUChain::testImportStructure()
       }
     }
 
-  kDebug() << "after: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
-
-  for(int a = 0; a < contextCount; ++a)
-    delete allContexts[a];
-  allContexts.clear();
-  kDebug() << "after cleanup: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
+    kDebug() << "after: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
 
+    for(int a = 0; a < contextCount; ++a)
+      delete allContexts[a];
+    allContexts.clear();
+    kDebug() << "after cleanup: " << KDevelop::RecursiveImportRepository::repository()->getDataRepository().statistics().print();
   }
-  clock_t endClock = clock();
-  kDebug() << "total clock cycles needed for import-structure test:" << endClock - startClock;
+  qDebug() << "total ns needed for import-structure test:" << float(total.elapsed());
 }
 
 class TestWorker : public QObject
@@ -570,14 +610,12 @@ public slots:
     for(int i = 0; i < 10000; ++i) {
       DUChainWriteLocker lock;
     }
-    qDebug() << "FINISHED lockForWrite";
   }
   void lockForRead()
   {
     for(int i = 0; i < 10000; ++i) {
       DUChainReadLocker lock;
     }
-    qDebug() << "FINISHED lockForRead";
   }
   void lockForReadWrite()
   {
@@ -589,7 +627,6 @@ public slots:
         DUChainWriteLocker lock;
       }
     }
-    qDebug() << "FINISHED lockForReadWrite";
   }
   static QSharedPointer<QThread> createWorkerThread(const char* workerSlot)
   {
@@ -607,7 +644,6 @@ class ThreadList : public QVector< QSharedPointer<QThread> >
 public:
   bool join(int timeout)
   {
-    qDebug() << "joining" << size() << "threads" << timeout;
     foreach(const QSharedPointer<QThread>& thread, *this) {
       // quit event loop
       Q_ASSERT(thread->isRunning());
@@ -635,6 +671,14 @@ void TestDUChain::testLockForWrite()
     threads << TestWorker::createWorkerThread(SLOT(lockForWrite()));
   }
   threads.start();
+  QBENCHMARK {
+    {
+      DUChainWriteLocker lock;
+    }
+    {
+      DUChainReadLocker lock;
+    }
+  }
   QVERIFY(threads.join(1000));
 }
 
@@ -645,6 +689,9 @@ void TestDUChain::testLockForRead()
     threads << TestWorker::createWorkerThread(SLOT(lockForRead()));
   }
   threads.start();
+  QBENCHMARK {
+    DUChainReadLocker lock;
+  }
   QVERIFY(threads.join(1000));
 }
 
@@ -655,9 +702,89 @@ void TestDUChain::testLockForReadWrite()
     threads << TestWorker::createWorkerThread(SLOT(lockForReadWrite()));
   }
   threads.start();
+  QBENCHMARK {
+    DUChainWriteLocker lock;
+  }
   QVERIFY(threads.join(1000));
 }
 
+void TestDUChain::testProblemSerialization()
+{
+  DUChain::self()->disablePersistentStorage(false);
+
+  auto parent = ProblemPointer{new Problem};
+  parent->setDescription("parent");
+
+  auto child = ProblemPointer{new Problem};
+  child->setDescription("child");
+  parent->addDiagnostic(child);
+
+  const IndexedString url("/my/test/file");
+
+  TopDUContextPointer smartTop;
+
+  { // serialize
+    DUChainWriteLocker lock;
+    auto file = new ParsingEnvironmentFile(url);
+    auto top = new TopDUContext(url, {}, file);
+
+    top->addProblem(parent);
+    QCOMPARE(top->problems().size(), 1);
+    auto p = top->problems().first();
+    QCOMPARE(p->description(), QString("parent"));
+    QCOMPARE(p->diagnostics().size(), 1);
+    auto c = p->diagnostics().first();
+    QCOMPARE(c->description(), QString("child"));
+
+    DUChain::self()->addDocumentChain(top);
+    QVERIFY(DUChain::self()->chainForDocument(url));
+    smartTop = top;
+  }
+
+  DUChain::self()->storeToDisk();
+
+  ProblemPointer parent_deserialized;
+  ProblemPointer child_deserialized;
+
+  { // deserialize
+    DUChainWriteLocker lock;
+    QVERIFY(!smartTop);
+    auto top = DUChain::self()->chainForDocument(url);
+    QVERIFY(top);
+    smartTop = top;
+    QCOMPARE(top->problems().size(), 1);
+    parent_deserialized = top->problems().first();
+    QCOMPARE(parent_deserialized->diagnostics().size(), 1);
+    child_deserialized = parent_deserialized->diagnostics().first();
+
+    QCOMPARE(parent_deserialized->description(), QString("parent"));
+    QCOMPARE(child_deserialized->description(), QString("child"));
+
+    top->clearProblems();
+    QVERIFY(top->problems().isEmpty());
+
+    QCOMPARE(parent_deserialized->description(), QString("parent"));
+    QCOMPARE(child_deserialized->description(), QString("child"));
+
+    DUChain::self()->removeDocumentChain(top);
+
+    QCOMPARE(parent_deserialized->description(), QString("parent"));
+    QCOMPARE(child_deserialized->description(), QString("child"));
+
+    QVERIFY(!smartTop);
+  }
+
+  DUChain::self()->disablePersistentStorage(true);
+
+  QCOMPARE(parent->description(), QString("parent"));
+  QCOMPARE(child->description(), QString("child"));
+  QCOMPARE(parent_deserialized->description(), QString("parent"));
+  QCOMPARE(child_deserialized->description(), QString("child"));
+
+  parent->clearDiagnostics();
+  QVERIFY(parent->diagnostics().isEmpty());
+}
+
 #if 0
 
 ///NOTE: the "unit tests" below are not automated, they - so far - require
@@ -717,5 +844,98 @@ void TestDUChain::benchCodeModel()
   }
 }
 
+void TestDUChain::benchTypeRegistry()
+{
+  IntegralTypeData data;
+  data.m_dataType = IntegralType::TypeInt;
+  data.typeClassId = IntegralType::Identity;
+  data.inRepository = false;
+  data.m_modifiers = 42;
+  data.m_dynamic = false;
+  data.refCount = 1;
+
+  IntegralTypeData to;
+
+  QFETCH(int, func);
+
+  QBENCHMARK {
+    switch(func) {
+      case 0:
+        TypeSystem::self().dataClassSize(data);
+        break;
+      case 1:
+        TypeSystem::self().dynamicSize(data);
+        break;
+      case 2:
+        TypeSystem::self().create(&data);
+        break;
+      case 3:
+        TypeSystem::self().isFactoryLoaded(data);
+        break;
+      case 4:
+        TypeSystem::self().copy(data, to, !data.m_dynamic);
+        break;
+      case 5:
+        TypeSystem::self().copy(data, to, data.m_dynamic);
+        break;
+      case 6:
+        TypeSystem::self().callDestructor(&data);
+        break;
+    }
+  }
+}
+
+void TestDUChain::benchTypeRegistry_data()
+{
+  QTest::addColumn<int>("func");
+  QTest::newRow("dataClassSize") << 0;
+  QTest::newRow("dynamicSize") << 1;
+  QTest::newRow("create") << 2;
+  QTest::newRow("isFactoryLoaded") << 3;
+  QTest::newRow("copy") << 4;
+  QTest::newRow("copyNonDynamic") << 5;
+  QTest::newRow("callDestructor") << 6;
+}
+
+void TestDUChain::benchDuchainReadLocker()
+{
+  QBENCHMARK {
+    DUChainReadLocker lock;
+  }
+}
+
+void TestDUChain::benchDuchainWriteLocker()
+{
+  QBENCHMARK {
+    DUChainWriteLocker lock;
+  }
+}
+
+void TestDUChain::benchDUChainItemFactory_copy()
+{
+  DUChainItemFactory<Declaration, DeclarationData> factory;
+  DeclarationData from, to;
+  from.classId = Declaration::Identity;
+
+  QFETCH(int, constant);
+
+  bool c = constant;
+
+  QBENCHMARK {
+    factory.copy(from, to, c);
+    if (constant == 2) {
+      c = !c;
+    }
+  }
+}
+
+void TestDUChain::benchDUChainItemFactory_copy_data()
+{
+  QTest::addColumn<int>("constant");
+  QTest::newRow("non-const") << 0;
+  QTest::newRow("const") << 1;
+  QTest::newRow("flip") << 2;
+}
+
 #include "test_duchain.moc"
 #include "moc_test_duchain.cpp"
