@@ -1,7 +1,7 @@
 /*
  * This file is part of KDevelop
  *
- * Copyright 2011 Milian Wolff <mail@milianw.de>
+ * Copyright 2011-2013 Milian Wolff <mail@milianw.de>
  * Copyright 2006 Hamish Rodda <rodda@kde.org>
  * Copyright 2007-2009 David Nolden <david.nolden.kdevelop@art-master.de>
  *
@@ -21,8 +21,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef TEST_DUCHAIN_H
-#define TEST_DUCHAIN_H
+#ifndef KDEVPLATFORM_TEST_DUCHAIN_H
+#define KDEVPLATFORM_TEST_DUCHAIN_H
 
 #include <QObject>
 
@@ -38,10 +38,20 @@ private slots:
     void testSymbolTableValid();
     void testIndexedStrings();
     void testImportStructure();
+    void testLockForWrite();
+    void testLockForRead();
+    void testLockForReadWrite();
+    void testProblemSerialization();
     ///NOTE: these are not "automated"!
 //     void testImportCache();
 
     void benchCodeModel();
+    void benchTypeRegistry();
+    void benchTypeRegistry_data();
+    void benchDuchainWriteLocker();
+    void benchDuchainReadLocker();
+    void benchDUChainItemFactory_copy();
+    void benchDUChainItemFactory_copy_data();
 };
 
-#endif // TEST_DUCHAIN_H
+#endif // KDEVPLATFORM_TEST_DUCHAIN_H
