@@ -17,10 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TOPDUCONTEXT_H
-#define TOPDUCONTEXT_H
-
-#include <QtCore/QMutex>
+#ifndef KDEVPLATFORM_TOPDUCONTEXT_H
+#define KDEVPLATFORM_TOPDUCONTEXT_H
 
 #include "ducontext.h"
 #include <language/util/setrepository.h>
@@ -104,37 +102,15 @@ class KDEVPLATFORMLANGUAGE_EXPORT ReferencedTopDUContext {
  *
  * \todo move the registration with DUChain here
  *
- * @warning When you delete a top-context, delete it using TopDUContext::deleteSelf(), else you will leak memory
+ * @warning Do not delete top-contexts directly, use DUChain::removeDocumentChain instead.
  */
 class KDEVPLATFORMLANGUAGE_EXPORT TopDUContext : public DUContext
 {
 public:
   explicit TopDUContext(const IndexedString& url, const RangeInRevision& range, ParsingEnvironmentFile* file = 0);
   explicit TopDUContext(TopDUContextData& data);
-  
-  ///Call this to destroy a top-context.
-  void deleteSelf();
-  
-  /**This creates a top-context that shares most of its data with @param sharedDataFrom. The given context must be the owner of the data
-   * (it must not have been created with this constructor).
-   * 
-   * When creating a context like this, all the data is shared among the context, except:
-   * parsingEnvironmentFile, ownIndex, problems, imports and importers.
-   * 
-   * When you change any other attributes(including duchain data etc.), that data is changed within all contexts that also share the data of the
-   * given one.
-   * 
-   * Special thing to consider: The imported contexts will be merged with the imported contexts of the data owner, and the problems will be merged
-   * with the problems of the data owner. When one of these things changes in the data owner, it will automatically also change in this context.
-   * 
-   * @warning When creating context with shared data, the shared ones always have to be deleted before the owner is deleted.
-   * */
-  explicit TopDUContext(TopDUContext* shareDataFrom, ParsingEnvironmentFile* file = 0);
 
-  ///If this top-context uses the data from another top-context, this returns that one.
-  TopDUContext* sharedDataOwner() const;
-  
-  TopDUContext* topContext() const;
+  TopDUContext* topContext() const override;
 
   ///Returns an indexed representation of this top-context. Indexed representations stay valid even if the top-context is unloaded.
   IndexedTopDUContext indexed() const;
@@ -168,17 +144,25 @@ public:
 
   /**
    * Add a parsing-problem to this context.
+   *
+   * \note you must be holding a write lock when you access this function.
    * */
   void addProblem(const ProblemPointer& problem);
 
   /**
-   * Remove a parsing-problem from this context.
-   * */
-  void removeProblem(const ProblemPointer& problem);
-
-  /// Clear the list of problems
+   * Clear the list of problems
+   *
+   * \note you must be holding a write lock when you access this function.
+   */
   void clearProblems();
 
+  /**
+   * Set the list of problems, replacing all existing ones.
+   *
+   * \note you must be holding a write lock when you access this function.
+   */
+  void setProblems(const QList<ProblemPointer>& pointers);
+
   /**
    * Determine if this chain imports another chain recursively.
    * 
@@ -348,7 +332,6 @@ protected:
   void applyAliases( const SearchItem::PtrList& identifiers, Acceptor& accept, const CursorInRevision& position, bool canBeNamespace ) const;
 
 protected:
-
   virtual ~TopDUContext();
   
   void clearFeaturesSatisfied();
@@ -367,6 +350,9 @@ protected:
   bool importsPrivate(const DUContext * origin, const CursorInRevision& position) const;
   DUCHAIN_DECLARE_DATA(TopDUContext)
   
+  ///Called by DUChain::removeDocumentChain to destroy this top-context.
+  void deleteSelf();
+
   //Most of these classes need access to m_dynamicData
   friend class DUChain;
   friend class DUChainPrivate;
@@ -375,10 +361,12 @@ protected:
   friend class TopDUContextDynamicData;
   friend class Declaration;
   friend class DUContext;
+  friend class Problem;
   friend class IndexedDeclaration;
   friend class IndexedDUContext;
   friend class LocalIndexedDeclaration;
   friend class LocalIndexedDUContext;
+  friend class LocalIndexedProblem;
   friend class DeclarationId;
   friend class ParsingEnvironmentFile;
   
@@ -396,13 +384,9 @@ inline uint qHash(const ReferencedTopDUContext& ctx) {
   return ctx.hash();
 }
 
-inline uint qHash(const IndexedTopDUContext& ctx) {
-  return ctx.index();
-}
-
 }
 Q_DECLARE_METATYPE(KDevelop::ReferencedTopDUContext);
 
-#endif // TOPDUCONTEXT_H
+#endif // KDEVPLATFORM_TOPDUCONTEXT_H
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
