@@ -17,14 +17,15 @@ class QFile;
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TOPDUCONTEXTDYNAMICDATA_H
-#define TOPDUCONTEXTDYNAMICDATA_H
+#ifndef KDEVPLATFORM_TOPDUCONTEXTDYNAMICDATA_H
+#define KDEVPLATFORM_TOPDUCONTEXTDYNAMICDATA_H
 
 #include <QtCore/QVector>
 #include <QtCore/QMutex>
 #include <QtCore/QByteArray>
 #include <QtCore/QPair>
 #include <interfaces/iastcontainer.h>
+#include "problem.h"
 
 namespace KDevelop {
 
@@ -43,8 +44,8 @@ class TopDUContextDynamicData {
   TopDUContextDynamicData(TopDUContext* topContext);
   ~TopDUContextDynamicData();
 
-  void clearContextsAndDeclarations();
-  
+  void clear();
+
   /**
    * Allocates an index for the given declaration in this top-context.
    * The returned index is never zero.
@@ -66,13 +67,22 @@ class TopDUContextDynamicData {
    *                   and a duchain write-lock is not needed. Else, you need a write-lock when calling this.
   */
   uint allocateContextIndex(DUContext* ctx, bool temporary);
-  
+
   DUContext* getContextForIndex(uint index) const;
-  
+
   bool isContextForIndexLoaded(uint index) const;
-  
+
   void clearContextIndex(DUContext* ctx);
-  
+
+
+  /**
+   * Allocates an index for the given problem in this top-context.
+   * The returned index is never zero.
+   */
+  uint allocateProblemIndex(ProblemPointer problem);
+  ProblemPointer getProblemForIndex(uint index) const;
+  void clearProblems();
+
   ///Stores this top-context to disk
   void store();
   
@@ -110,6 +120,8 @@ class TopDUContextDynamicData {
   };
 
   private:
+    bool hasChanged() const;
+
     void unmap();
     //Converts away from an mmap opened file to a data array
     
@@ -117,35 +129,47 @@ class TopDUContextDynamicData {
 
     void loadData() const;
 
-    
-    static void verifyDataInfo(const ItemDataInfo& info, const QList<ArrayWithPosition>& data);
-
-    static const char* pointerInData(const QList<ArrayWithPosition>& data, uint totalOffset);
-    
     const char* pointerInData(uint offset) const;
 
     ItemDataInfo writeDataInfo(const ItemDataInfo& info, const DUChainBaseData* data, uint& totalDataOffset);
 
     TopDUContext* m_topContext;
-    //May contain zero contexts if they were deleted
-    mutable QVector<DUContext*> m_contexts;
-    mutable DUContext** m_fastContexts;
-    mutable int m_fastContextsSize;
-    //May contain zero declarations if they were deleted
-    mutable QVector<Declaration*> m_declarations;
-    mutable Declaration** m_fastDeclarations;
-    mutable int m_fastDeclarationsSize;
-    
-    mutable QVector<ItemDataInfo> m_contextDataOffsets;
-    
-    mutable QVector<ItemDataInfo> m_declarationDataOffsets;
-    
-    //Protects m_temporaryDeclarations, must be locked before accessing that vector
-    static QMutex m_temporaryDataMutex;
+
+    template<class Item>
+    struct DUChainItemStorage
+    {
+      DUChainItemStorage(TopDUContextDynamicData* data);
+      ~DUChainItemStorage();
+
+      void clearItems();
+      bool itemsHaveChanged() const;
+
+      void storeData(uint& currentDataOffset, const QList<ArrayWithPosition>& oldData);
+      Item getItemForIndex(uint index) const;
+
+      void clearItemIndex(const Item& item, const uint index);
+
+      uint allocateItemIndex(const Item& item, const bool temporary);
+
+      void deleteOnDisk();
+      bool isItemForIndexLoaded(uint index) const;
+
+      void loadData(QFile* file) const;
+      void writeData(QFile* file);
+
+      //May contain zero items if they were deleted
+      mutable QVector<Item> items;
+      mutable QVector<ItemDataInfo> offsets;
+      QVector<Item> temporaryItems;
+      TopDUContextDynamicData* const data;
+    };
+
+    DUChainItemStorage<DUContext*> m_contexts;
+    DUChainItemStorage<Declaration*> m_declarations;
+    DUChainItemStorage<ProblemPointer> m_problems;
+
     //For temporary declarations that will not be stored to disk, like template instantiations
-    QVector<Declaration*> m_temporaryDeclarations;
-    QVector<DUContext*> m_temporaryContexts;
-    
+
     mutable QList<ArrayWithPosition> m_data;
     mutable QList<ArrayWithPosition> m_topContextData;
     bool m_onDisk;
