@@ -19,8 +19,8 @@ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
 
-#ifndef EDITORCONTEXT_H
-#define EDITORCONTEXT_H
+#ifndef KDEVPLATFORM_EDITORCONTEXT_H
+#define KDEVPLATFORM_EDITORCONTEXT_H
 
 #include "codecontext.h"
 
