@@ -18,14 +18,19 @@
 
 #include "includeitem.h"
 
-namespace KDevelop {
+#include <QDebug>
+
+using namespace KDevelop;
 
 IncludeItem::IncludeItem()
-	: isDirectory(false), pathNumber(0) {
+    : pathNumber(0)
+    , isDirectory(false)
+{
 }
 
 ///Constructs the url from basePath and name.
-KUrl IncludeItem::url() const {
+KUrl IncludeItem::url() const
+{
   KUrl u;
   if( !basePath.isEmpty() ) {
     u = KUrl( basePath );
@@ -35,5 +40,8 @@ KUrl IncludeItem::url() const {
   }
   return u;
 }
-  
+
+QDebug operator<<(QDebug dbg, const IncludeItem& item)
+{
+    return dbg << item.url();
 }
