@@ -37,7 +37,7 @@
 #ifndef DEBUG
 #define CHECK_SPLIT_POSITION(Node)
 #else
-#define CHECK_SPLIT_POSITION(node) Q_ASSERT(!(node).leftNode || (getLeftNode(&node)->end <= splitPositionForRange((node).start, (node).end) && getRightNode(&node)->start >= splitPositionForRange((node).start, (node).end)))
+#define CHECK_SPLIT_POSITION(node) Q_ASSERT(!(node).leftNode || (getLeftNode(&node)->end() <= splitPositionForRange((node).start, (node).end) && getRightNode(&node)->start() >= splitPositionForRange((node).start, (node).end)))
 #endif
 
 namespace Utils {
@@ -79,7 +79,7 @@ uint splitPositionForRange(uint start, uint end, uchar& splitBit) {
   return 0;
 }
 
-uint SetNodeData::hash() const {
+uint SetNodeData::calculateHash() const {
   //A hash to reduce the amount of clashes
   return hashlittle(this, sizeof(uint)*4, 1748231);
 }
@@ -92,8 +92,8 @@ uint splitPositionForRange(uint start, uint end) {
 
 class SetNodeDataRequest;
 
-    #define getLeftNode(node) repository.itemFromIndex(node->leftNode)
-    #define getRightNode(node) repository.itemFromIndex(node->rightNode)
+    #define getLeftNode(node) repository.itemFromIndex(node->leftNode())
+    #define getRightNode(node) repository.itemFromIndex(node->rightNode())
     #define nodeFromIndex(index) repository.itemFromIndex(index)
 struct SetRepositoryAlgorithms {
   SetRepositoryAlgorithms(SetDataRepository& _repository, BasicSetRepository* _setRepository) : repository(_repository), setRepository(_setRepository) {
@@ -130,9 +130,7 @@ struct SetRepositoryAlgorithms {
         uint endIndex = *(end-1)+1;
         
         if(endIndex == startIndex+1) {
-            SetNodeData data;
-            data.start = startIndex;
-            data.end = endIndex;
+            SetNodeData data(startIndex, endIndex);
             
             return repository.index( SetNodeDataRequest(&data, repository, setRepository) );
         }
@@ -161,17 +159,17 @@ void SetNodeDataRequest::destroy(SetNodeData* data, KDevelop::AbstractItemReposi
 
     if(repository.setRepository->delayedDeletion()) {
 
-        if(data->leftNode){
-            SetDataRepositoryBase::MyDynamicItem left = repository.dynamicItemFromIndex(data->leftNode);
-            SetDataRepositoryBase::MyDynamicItem right = repository.dynamicItemFromIndex(data->rightNode);
+        if(data->leftNode()){
+            SetDataRepositoryBase::MyDynamicItem left = repository.dynamicItemFromIndex(data->leftNode());
+            SetDataRepositoryBase::MyDynamicItem right = repository.dynamicItemFromIndex(data->rightNode());
             Q_ASSERT(left->m_refCount > 0);
             --left->m_refCount;
             Q_ASSERT(right->m_refCount > 0);
             --right->m_refCount;
         }else {
             //Deleting a leaf
-            Q_ASSERT(data->end - data->start == 1);
-            repository.setRepository->itemRemovedFromSets(data->start);
+            Q_ASSERT(data->end() - data->start() == 1);
+            repository.setRepository->itemRemovedFromSets(data->start());
         }
     }
 }
@@ -183,44 +181,44 @@ SetNodeDataRequest::SetNodeDataRequest(const SetNodeData* _data, SetDataReposito
 SetNodeDataRequest::~SetNodeDataRequest() {
     //Eventually increase the reference-count of direct children
     if(m_created) {
-        if(data.leftNode)
-        ++repository.dynamicItemFromIndex(data.leftNode)->m_refCount;
-        if(data.rightNode)
-        ++repository.dynamicItemFromIndex(data.rightNode)->m_refCount;
+        if(data.leftNode())
+        ++repository.dynamicItemFromIndex(data.leftNode())->m_refCount;
+        if(data.rightNode())
+        ++repository.dynamicItemFromIndex(data.rightNode())->m_refCount;
     }
 }
 
 //Should create an item where the information of the requested item is permanently stored. The pointer
 //@param item equals an allocated range with the size of itemSize().
 void SetNodeDataRequest::createItem(SetNodeData* item) const {
-    Q_ASSERT((data.rightNode && data.leftNode) || (!data.rightNode && !data.leftNode));
+    Q_ASSERT((data.rightNode() && data.leftNode()) || (!data.rightNode() && !data.leftNode()));
 
     m_created = true;
 
     *item = data;
 
-    Q_ASSERT((item->rightNode && item->leftNode) || (!item->rightNode && !item->leftNode));
+    Q_ASSERT((item->rightNode() && item->leftNode()) || (!item->rightNode() && !item->leftNode()));
 
     #ifdef DEBUG
     //Make sure we split at the correct split position
     if(item->hasSlaves()) {
         uint split = splitPositionForRange(data.start, data.end);
-        const SetNodeData* left = repository.itemFromIndex(item->leftNode);
-        const SetNodeData* right = repository.itemFromIndex(item->rightNode);
-        Q_ASSERT(split >= left->end && split <= right->start);
+        const SetNodeData* left = repository.itemFromIndex(item->leftNode());
+        const SetNodeData* right = repository.itemFromIndex(item->rightNode());
+        Q_ASSERT(split >= left->end() && split <= right->start());
     }
     #endif
-    if(!data.leftNode && setRepository) {
-        for(uint a = item->start; a < item->end; ++a)
+    if(!data.leftNode() && setRepository) {
+        for(uint a = item->start(); a < item->end(); ++a)
             setRepository->itemAddedToSets(a);
     }
 }
   
 bool SetNodeDataRequest::equals(const SetNodeData* item) const {
-    Q_ASSERT((item->rightNode && item->leftNode) || (!item->rightNode && !item->leftNode));
+    Q_ASSERT((item->rightNode() && item->leftNode()) || (!item->rightNode() && !item->leftNode()));
     //Just compare child nodes, since data must be correctly split, this is perfectly ok
     //Since this happens in very tight loops, we don't call an additional function here, but just do the check.
-    return item->leftNode == data.leftNode && item->rightNode == data.rightNode && item->start == data.start && item->end == data.end;
+    return item->leftNode() == data.leftNode() && item->rightNode() == data.rightNode() && item->start() == data.start() && item->end() == data.end();
 }
 
 class BasicSetRepository::Private {
@@ -276,18 +274,18 @@ QString Set::dumpDotGraph() const {
 }
 
 Index SetRepositoryAlgorithms::count(const SetNodeData* node) const {
-  if(node->leftNode && node->rightNode)
+  if(node->leftNode() && node->rightNode())
     return count(getLeftNode(node)) + count(getRightNode(node));
   else
-    return node->end - node->start;
+    return node->end() - node->start();
 }
 
 void SetRepositoryAlgorithms::localCheck(const SetNodeData* ifDebug(node) ) {
-//   Q_ASSERT(node->start > 0);
-  Q_ASSERT(node->start < node->end);
-  Q_ASSERT((node->leftNode && node->rightNode) || (!node->leftNode && !node->rightNode));
-  Q_ASSERT(!node->leftNode || (getLeftNode(node)->start == node->start && getRightNode(node)->end == node->end));
-  Q_ASSERT(!node->leftNode || (getLeftNode(node)->end <= getRightNode(node)->start));
+//   Q_ASSERT(node->start() > 0);
+  Q_ASSERT(node->start() < node->end());
+  Q_ASSERT((node->leftNode() && node->rightNode()) || (!node->leftNode() && !node->rightNode()));
+  Q_ASSERT(!node->leftNode() || (getLeftNode(node())->start() == node->start() && getRightNode(node)->end() == node->end()));
+  Q_ASSERT(!node->leftNode() || (getLeftNode(node())->end() <= getRightNode(node)->start()));
 }
 
 void SetRepositoryAlgorithms::check(uint node) {
@@ -299,15 +297,15 @@ void SetRepositoryAlgorithms::check(uint node) {
 
 void SetRepositoryAlgorithms::check(const SetNodeData* node) {
   localCheck(node);
-  if(node->leftNode)
+  if(node->leftNode())
     check(getLeftNode(node));
-  if(node->rightNode)
+  if(node->rightNode())
     check(getRightNode(node));
 //  CHECK_SPLIT_POSITION(*node); Re-enable this
 }
 
 QString SetRepositoryAlgorithms::shortLabel(const SetNodeData& node) const {
-  return QString("n%1_%2").arg(node.start).arg(node.end);
+  return QString("n%1_%2").arg(node.start()).arg(node.end());
 }
 
 QString SetRepositoryAlgorithms::dumpDotGraphInternal(uint nodeIndex, bool master) const {
@@ -320,20 +318,20 @@ QString SetRepositoryAlgorithms::dumpDotGraphInternal(uint nodeIndex, bool maste
   if(master)
     color = "red";
 
-  QString label = QString("%1 -> %2").arg(node.start).arg(node.end);
+  QString label = QString("%1 -> %2").arg(node.start()).arg(node.end());
   if(!node.contiguous())
     label += ", with gaps";
   
   QString ret = QString("%1[label=\"%2\", color=\"%3\"];\n").arg(shortLabel(node)).arg(label).arg(color);
 
-  if(node.leftNode) {
-    const SetNodeData& left(*repository.itemFromIndex(node.leftNode));
-    const SetNodeData& right(*repository.itemFromIndex(node.rightNode));
-    Q_ASSERT(node.rightNode);
+  if(node.leftNode()) {
+    const SetNodeData& left(*repository.itemFromIndex(node.leftNode()));
+    const SetNodeData& right(*repository.itemFromIndex(node.rightNode()));
+    Q_ASSERT(node.rightNode());
     ret += QString("%1 -> %2;\n").arg(shortLabel(node)).arg(shortLabel(left));
     ret += QString("%1 -> %2;\n").arg(shortLabel(node)).arg(shortLabel(right));
-    ret += dumpDotGraphInternal(node.leftNode);
-    ret += dumpDotGraphInternal(node.rightNode);
+    ret += dumpDotGraphInternal(node.leftNode());
+    ret += dumpDotGraphInternal(node.rightNode());
   }
   
   return ret;
@@ -375,8 +373,8 @@ public:
    * Pushes the noed on top of the stack, changes currentIndex, and goes as deep as necessary for iteration.
    * */
   void startAtNode(const SetNodeData* node) {
-    Q_ASSERT(node->start != node->end);
-    currentIndex = node->start;
+    Q_ASSERT(node->start() != node->end());
+    currentIndex = node->start();
 
     do {
       nodeStack[nodeStackSize++] = node;
@@ -386,9 +384,9 @@ public:
       
       if(node->contiguous())
         break; //We need no finer granularity, because the range is contiguous
-      node = Set::Iterator::getDataRepository(repository).itemFromIndex(node->leftNode);
+      node = Set::Iterator::getDataRepository(repository).itemFromIndex(node->leftNode());
     } while(node);
-    Q_ASSERT(currentIndex >= nodeStack[0]->start);
+    Q_ASSERT(currentIndex >= nodeStack[0]->start());
   }
 };
 
@@ -432,14 +430,14 @@ Set::Iterator& Set::Iterator::operator++() {
   Q_ASSERT(d->nodeStackSize);
   
   if(d->repository->m_mutex)
-    d->repository->m_mutex->lock();
+    d->repository->m_mutex->lockInline();
   
   ++d->currentIndex;
   
   //const SetNodeData** currentNode = &d->nodeStack[d->nodeStackSize - 1];
-  if(d->currentIndex >= d->nodeStack[d->nodeStackSize - 1]->end) {
+  if(d->currentIndex >= d->nodeStack[d->nodeStackSize - 1]->end()) {
     //Advance to the next node
-    while(d->nodeStackSize && d->currentIndex >= d->nodeStack[d->nodeStackSize - 1]->end) {
+    while(d->nodeStackSize && d->currentIndex >= d->nodeStack[d->nodeStackSize - 1]->end()) {
       --d->nodeStackSize;
     }
     
@@ -448,18 +446,18 @@ Set::Iterator& Set::Iterator::operator++() {
     }else{
       //++d->nodeStackSize;
       //We were iterating the left slave of the node, now continue with the right.
-      ifDebug( const SetNodeData& left = *d->repository->dataRepository.itemFromIndex(d->nodeStack[d->nodeStackSize - 1]->leftNode); Q_ASSERT(left.end == d->currentIndex); )
+      ifDebug( const SetNodeData& left = *d->repository->dataRepository.itemFromIndex(d->nodeStack[d->nodeStackSize - 1]->leftNode()); Q_ASSERT(left.end == d->currentIndex); )
       
-      const SetNodeData& right = *d->repository->dataRepository.itemFromIndex(d->nodeStack[d->nodeStackSize - 1]->rightNode);
+      const SetNodeData& right = *d->repository->dataRepository.itemFromIndex(d->nodeStack[d->nodeStackSize - 1]->rightNode());
       
       d->startAtNode(&right);
     }
   }
 
-  Q_ASSERT(d->nodeStackSize == 0 || d->currentIndex < d->nodeStack[0]->end);
+  Q_ASSERT(d->nodeStackSize == 0 || d->currentIndex < d->nodeStack[0]->end());
   
   if(d->repository->m_mutex)
-    d->repository->m_mutex->unlock();
+    d->repository->m_mutex->unlockInline();
   
   return *this;
 }
@@ -490,20 +488,15 @@ uint SetRepositoryAlgorithms::createSetFromNodes(uint leftNode, uint rightNode,
     if(!right)
       right = nodeFromIndex(rightNode);
   
-    Q_ASSERT(left->end <= right->start);
+    Q_ASSERT(left->end() <= right->start());
     
-    SetNodeData set;
-    set.leftNode = leftNode;
-    set.rightNode = rightNode;
+    SetNodeData set(left->start(), right->end(), leftNode, rightNode);
 
-    set.start = left->start;
-    set.end = right->end;
-
-    Q_ASSERT(set.start < set.end);
+    Q_ASSERT(set.start() < set.end());
     
     uint ret = repository.index(SetNodeDataRequest(&set, repository, setRepository));
-    Q_ASSERT(set.leftNode >= 0x10000);
-    Q_ASSERT(set.rightNode >= 0x10000);
+    Q_ASSERT(set.leftNode() >= 0x10000);
+    Q_ASSERT(set.rightNode() >= 0x10000);
     Q_ASSERT(ret == repository.findIndex(SetNodeDataRequest(&set, repository, setRepository)));
     ifDebug( check(ret) );
     return ret;
@@ -513,35 +506,35 @@ uint SetRepositoryAlgorithms::createSetFromNodes(uint leftNode, uint rightNode,
 //The do not need to be split around their computed split-position.
 uint SetRepositoryAlgorithms::computeSetFromNodes(uint leftNode, uint rightNode, const SetNodeData* left, const SetNodeData* right, uchar splitBit)
 {
-  Q_ASSERT(left->end <= right->start);
-  uint splitPosition = splitPositionForRange(left->start, right->end, splitBit);
+  Q_ASSERT(left->end() <= right->start());
+  uint splitPosition = splitPositionForRange(left->start(), right->end(), splitBit);
   
   Q_ASSERT(splitPosition);
   
-  if(splitPosition < left->end) {
+  if(splitPosition < left->end()) {
     //The split-position intersects the left node
-    uint leftLeftNode = left->leftNode;
-    uint leftRightNode = left->rightNode;
+    uint leftLeftNode = left->leftNode();
+    uint leftRightNode = left->rightNode();
     
     const SetNodeData* leftLeft = this->getLeftNode(left);
     const SetNodeData* leftRight = this->getRightNode(left);
     
-    Q_ASSERT(splitPosition >= leftLeft->end && splitPosition <= leftRight->start);
+    Q_ASSERT(splitPosition >= leftLeft->end() && splitPosition <= leftRight->start());
     
     //Create a new set from leftLeft, and from leftRight + right. That set will have the correct split-position.
     uint newRightNode = computeSetFromNodes(leftRightNode, rightNode, leftRight, right, splitBit);
     
     return createSetFromNodes(leftLeftNode, newRightNode, leftLeft);
   
-  }else if(splitPosition > right->start) {
+  }else if(splitPosition > right->start()) {
     //The split-position intersects the right node
-    uint rightLeftNode = right->leftNode;
-    uint rightRightNode = right->rightNode;
+    uint rightLeftNode = right->leftNode();
+    uint rightRightNode = right->rightNode();
     
     const SetNodeData* rightLeft = this->getLeftNode(right);
     const SetNodeData* rightRight = this->getRightNode(right);
     
-    Q_ASSERT(splitPosition >= rightLeft->end && splitPosition <= rightRight->start);
+    Q_ASSERT(splitPosition >= rightLeft->end() && splitPosition <= rightRight->start());
     
     //Create a new set from left + rightLeft, and from rightRight. That set will have the correct split-position.
     uint newLeftNode = computeSetFromNodes(leftNode, rightLeftNode, left, rightLeft, splitBit);
@@ -557,12 +550,12 @@ uint SetRepositoryAlgorithms::set_union(uint firstNode, uint secondNode, const S
   if(firstNode == secondNode)
     return firstNode;
   
-  uint firstStart = first->start, secondEnd = second->end;
+  uint firstStart = first->start(), secondEnd = second->end();
   
   if(firstStart >= secondEnd)
     return computeSetFromNodes(secondNode, firstNode, second, first, splitBit);
         
-  uint firstEnd = first->end, secondStart = second->start;
+  uint firstEnd = first->end(), secondStart = second->start();
   
   if(secondStart >= firstEnd)
     return computeSetFromNodes(firstNode, secondNode, first, second, splitBit);
@@ -581,30 +574,30 @@ uint SetRepositoryAlgorithms::set_union(uint firstNode, uint secondNode, const S
   if(splitPosition > firstStart && splitPosition < firstEnd && splitPosition > secondStart && splitPosition < secondEnd) {
     //The split-position intersect with both first and second. Continue the union on both sides of the split-position, and merge it.
     
-    uint firstLeftNode = first->leftNode;
-    uint firstRightNode = first->rightNode;
-    uint secondLeftNode = second->leftNode;
-    uint secondRightNode = second->rightNode;
+    uint firstLeftNode = first->leftNode();
+    uint firstRightNode = first->rightNode();
+    uint secondLeftNode = second->leftNode();
+    uint secondRightNode = second->rightNode();
     
     const SetNodeData* firstLeft = repository.itemFromIndex(firstLeftNode);
     const SetNodeData* firstRight = repository.itemFromIndex(firstRightNode);
     const SetNodeData* secondLeft = repository.itemFromIndex(secondLeftNode);
     const SetNodeData* secondRight = repository.itemFromIndex(secondRightNode);
     
-    Q_ASSERT(splitPosition >= firstLeft->end && splitPosition <= firstRight->start);
-    Q_ASSERT(splitPosition >= secondLeft->end && splitPosition <= secondRight->start);
+    Q_ASSERT(splitPosition >= firstLeft->end() && splitPosition <= firstRight->start());
+    Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
     
     return createSetFromNodes( set_union(firstLeftNode, secondLeftNode, firstLeft, secondLeft, splitBit), set_union(firstRightNode, secondRightNode, firstRight, secondRight, splitBit) );
     
   }else if(splitPosition > firstStart && splitPosition < firstEnd) {
     
-    uint firstLeftNode = first->leftNode;
-    uint firstRightNode = first->rightNode;
+    uint firstLeftNode = first->leftNode();
+    uint firstRightNode = first->rightNode();
     
     const SetNodeData* firstLeft = repository.itemFromIndex(firstLeftNode);
     const SetNodeData* firstRight = repository.itemFromIndex(firstRightNode);
     
-    Q_ASSERT(splitPosition >= firstLeft->end && splitPosition <= firstRight->start);
+    Q_ASSERT(splitPosition >= firstLeft->end() && splitPosition <= firstRight->start());
     
     //splitPosition does not intersect second. That means that second is completely on one side of it.
     //So we only need to union that side of first with second.
@@ -618,13 +611,13 @@ uint SetRepositoryAlgorithms::set_union(uint firstNode, uint secondNode, const S
     
   }else if(splitPosition > secondStart && splitPosition < secondEnd) {
     
-    uint secondLeftNode = second->leftNode;
-    uint secondRightNode = second->rightNode;
+    uint secondLeftNode = second->leftNode();
+    uint secondRightNode = second->rightNode();
     
     const SetNodeData* secondLeft = repository.itemFromIndex(secondLeftNode);
     const SetNodeData* secondRight = repository.itemFromIndex(secondRightNode);
     
-    Q_ASSERT(splitPosition >= secondLeft->end && splitPosition <= secondRight->start);
+    Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
     
     if(firstEnd <= splitPosition) {
       return createSetFromNodes( set_union(secondLeftNode, firstNode, secondLeft, first, splitBit), secondRightNode, 0, secondRight );
@@ -643,7 +636,7 @@ uint SetRepositoryAlgorithms::set_union(uint firstNode, uint secondNode, const S
 
 bool SetRepositoryAlgorithms::set_equals(const SetNodeData* lhs, const SetNodeData* rhs)
 {
-  if(lhs->leftNode != rhs->leftNode || lhs->rightNode != rhs->rightNode)
+  if(lhs->leftNode() != rhs->leftNode() || lhs->rightNode() != rhs->rightNode())
     return false;
   else
     return true;
@@ -654,14 +647,14 @@ uint SetRepositoryAlgorithms::set_intersect(uint firstNode, uint secondNode, con
   if(firstNode == secondNode)
     return firstNode;
   
-  if(first->start >= second->end)
+  if(first->start() >= second->end())
     return 0;
         
-  if(second->start >= first->end)
+  if(second->start() >= first->end())
     return 0;
   
   //The ranges of first and second do intersect
-  uint firstStart = first->start, firstEnd = first->end, secondStart = second->start, secondEnd = second->end;
+  uint firstStart = first->start(), firstEnd = first->end(), secondStart = second->start(), secondEnd = second->end();
   
   uint newStart = firstStart < secondStart ? firstStart : secondStart;
   uint newEnd = firstEnd > secondEnd ? firstEnd : secondEnd;
@@ -676,19 +669,19 @@ uint SetRepositoryAlgorithms::set_intersect(uint firstNode, uint secondNode, con
   if(splitPosition > firstStart && splitPosition < firstEnd && splitPosition > secondStart && splitPosition < secondEnd) {
     //The split-position intersect with both first and second. Continue the intersection on both sides
     
-    uint firstLeftNode = first->leftNode;
-    uint firstRightNode = first->rightNode;
+    uint firstLeftNode = first->leftNode();
+    uint firstRightNode = first->rightNode();
     
-    uint secondLeftNode = second->leftNode;
-    uint secondRightNode = second->rightNode;
+    uint secondLeftNode = second->leftNode();
+    uint secondRightNode = second->rightNode();
     
     const SetNodeData* firstLeft = repository.itemFromIndex(firstLeftNode);
     const SetNodeData* firstRight = repository.itemFromIndex(firstRightNode);
     const SetNodeData* secondLeft = repository.itemFromIndex(secondLeftNode);
     const SetNodeData* secondRight = repository.itemFromIndex(secondRightNode);
     
-    Q_ASSERT(splitPosition >= firstLeft->end && splitPosition <= firstRight->start);
-    Q_ASSERT(splitPosition >= secondLeft->end && splitPosition <= secondRight->start);
+    Q_ASSERT(splitPosition >= firstLeft->end() && splitPosition <= firstRight->start());
+    Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
     
     uint newLeftNode = set_intersect(firstLeftNode, secondLeftNode, firstLeft, secondLeft, splitBit);
     uint newRightNode = set_intersect(firstRightNode, secondRightNode, firstRight, secondRight, splitBit);
@@ -702,13 +695,13 @@ uint SetRepositoryAlgorithms::set_intersect(uint firstNode, uint secondNode, con
     
   }else if(splitPosition > firstStart && splitPosition < firstEnd) {
     
-    uint firstLeftNode = first->leftNode;
-    uint firstRightNode = first->rightNode;
+    uint firstLeftNode = first->leftNode();
+    uint firstRightNode = first->rightNode();
     
     const SetNodeData* firstLeft = repository.itemFromIndex(firstLeftNode);
     const SetNodeData* firstRight = repository.itemFromIndex(firstRightNode);
     
-    Q_ASSERT(splitPosition >= firstLeft->end && splitPosition <= firstRight->start);
+    Q_ASSERT(splitPosition >= firstLeft->end() && splitPosition <= firstRight->start());
     
     //splitPosition does not intersect second. That means that second is completely on one side of it.
     //So we can completely ignore the other side of first.
@@ -721,13 +714,13 @@ uint SetRepositoryAlgorithms::set_intersect(uint firstNode, uint secondNode, con
     }
   }else if(splitPosition > secondStart && splitPosition < secondEnd) {
     
-    uint secondLeftNode = second->leftNode;
-    uint secondRightNode = second->rightNode;
+    uint secondLeftNode = second->leftNode();
+    uint secondRightNode = second->rightNode();
     
     const SetNodeData* secondLeft = repository.itemFromIndex(secondLeftNode);
     const SetNodeData* secondRight = repository.itemFromIndex(secondRightNode);
     
-    Q_ASSERT(splitPosition >= secondLeft->end && splitPosition <= secondRight->start);
+    Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
     
     if(firstEnd <= splitPosition) {
       return set_intersect(secondLeftNode, firstNode, secondLeft, first, splitBit);
@@ -746,18 +739,18 @@ uint SetRepositoryAlgorithms::set_intersect(uint firstNode, uint secondNode, con
 bool SetRepositoryAlgorithms::set_contains(const SetNodeData* node, Index index)
 {
   while(true) {
-    if(node->start > index || node->end <= index)
+    if(node->start() > index || node->end() <= index)
       return false;
 
     if(node->contiguous())
       return true;
     
-    const SetNodeData* leftNode = nodeFromIndex(node->leftNode);
+    const SetNodeData* leftNode = nodeFromIndex(node->leftNode());
 
-    if(index < leftNode->end)
+    if(index < leftNode->end())
       node = leftNode;
     else {
-      const SetNodeData* rightNode = nodeFromIndex(node->rightNode);
+      const SetNodeData* rightNode = nodeFromIndex(node->rightNode());
       node = rightNode;
     }
   }
@@ -770,11 +763,11 @@ uint SetRepositoryAlgorithms::set_subtract(uint firstNode, uint secondNode, cons
   if(firstNode == secondNode)
     return 0;
   
-  if(first->start >= second->end || second->start >= first->end)
+  if(first->start() >= second->end() || second->start() >= first->end())
     return firstNode;
         
   //The ranges of first and second do intersect
-  uint firstStart = first->start, firstEnd = first->end, secondStart = second->start, secondEnd = second->end;
+  uint firstStart = first->start(), firstEnd = first->end(), secondStart = second->start(), secondEnd = second->end();
   
   uint newStart = firstStart < secondStart ? firstStart : secondStart;
   uint newEnd = firstEnd > secondEnd ? firstEnd : secondEnd;
@@ -788,11 +781,11 @@ uint SetRepositoryAlgorithms::set_subtract(uint firstNode, uint secondNode, cons
   if(splitPosition > firstStart && splitPosition < firstEnd && splitPosition > secondStart && splitPosition < secondEnd) {
     //The split-position intersect with both first and second. Continue the subtract on both sides of the split-position, and merge it.
     
-    uint firstLeftNode = first->leftNode;
-    uint firstRightNode = first->rightNode;
+    uint firstLeftNode = first->leftNode();
+    uint firstRightNode = first->rightNode();
     
-    uint secondLeftNode = second->leftNode;
-    uint secondRightNode = second->rightNode;
+    uint secondLeftNode = second->leftNode();
+    uint secondRightNode = second->rightNode();
     
     const SetNodeData* firstLeft = repository.itemFromIndex(firstLeftNode);
     const SetNodeData* firstRight = repository.itemFromIndex(firstRightNode);
@@ -800,8 +793,8 @@ uint SetRepositoryAlgorithms::set_subtract(uint firstNode, uint secondNode, cons
     const SetNodeData* secondRight = repository.itemFromIndex(secondRightNode);
     
     
-    Q_ASSERT(splitPosition >= firstLeft->end && splitPosition <= firstRight->start);
-    Q_ASSERT(splitPosition >= secondLeft->end && splitPosition <= secondRight->start);
+    Q_ASSERT(splitPosition >= firstLeft->end() && splitPosition <= firstRight->start());
+    Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
     
     uint newLeftNode = set_subtract(firstLeftNode, secondLeftNode, firstLeft, secondLeft, splitBit);
     uint newRightNode = set_subtract(firstRightNode, secondRightNode, firstRight, secondRight, splitBit);
@@ -815,10 +808,10 @@ uint SetRepositoryAlgorithms::set_subtract(uint firstNode, uint secondNode, cons
     
   }else if(splitPosition > firstStart && splitPosition < firstEnd) {
     
-//    Q_ASSERT(splitPosition >= firstLeft->end && splitPosition <= firstRight->start);
+//    Q_ASSERT(splitPosition >= firstLeft->end() && splitPosition <= firstRight->start());
     
-    uint firstLeftNode = first->leftNode;
-    uint firstRightNode = first->rightNode;
+    uint firstLeftNode = first->leftNode();
+    uint firstRightNode = first->rightNode();
     
     const SetNodeData* firstLeft = repository.itemFromIndex(firstLeftNode);
     const SetNodeData* firstRight = repository.itemFromIndex(firstRightNode);
@@ -844,13 +837,13 @@ uint SetRepositoryAlgorithms::set_subtract(uint firstNode, uint secondNode, cons
   
     }else if(splitPosition > secondStart && splitPosition < secondEnd) {
     
-    uint secondLeftNode = second->leftNode;
-    uint secondRightNode = second->rightNode;
+    uint secondLeftNode = second->leftNode();
+    uint secondRightNode = second->rightNode();
     
     const SetNodeData* secondLeft = repository.itemFromIndex(secondLeftNode);
     const SetNodeData* secondRight = repository.itemFromIndex(secondRightNode);
     
-    Q_ASSERT(splitPosition >= secondLeft->end && splitPosition <= secondRight->start);
+    Q_ASSERT(splitPosition >= secondLeft->end() && splitPosition <= secondRight->start());
     
     if(firstEnd <= splitPosition) {
       return set_subtract(firstNode, secondLeftNode, first, secondLeft, splitBit);
@@ -880,12 +873,9 @@ Set BasicSetRepository::createSetFromIndices(const std::vector<Index>& indices)
 }
 
 Set BasicSetRepository::createSet(Index i) {
-    
     QMutexLocker lock(m_mutex);
-    SetNodeData data;                                                                                                                                                              
-    data.start = i;                                                                                                                                                                
-    data.end = i+1;                                                                                                                                                                
-                                                                                                                                                                                   
+    SetNodeData data(i, i+1);
+
     return Set(dataRepository.index( SetNodeDataRequest(&data, dataRepository, this) ), this);
 }
 
@@ -916,9 +906,9 @@ struct StatisticsVisitor {
     if(item->m_refCount == 0)
         ++zeroRefCountNodes;
     ++nodeCount;
-    uint split = splitPositionForRange(item->start, item->end);
+    uint split = splitPositionForRange(item->start(), item->end());
     if(item->hasSlaves())
-      if(split < rep.itemFromIndex(item->leftNode)->end || split > rep.itemFromIndex(item->rightNode)->start)
+      if(split < rep.itemFromIndex(item->leftNode())->end() || split > rep.itemFromIndex(item->rightNode())->start())
         ++badSplitNodeCount;
     return true;
   }
@@ -1070,10 +1060,10 @@ BasicSetRepository* Set::repository() const {
 void Set::staticRef() {
   if(!m_tree)
     return;
-    m_repository->m_mutex->lock();
+
+    QMutexLocker lock(m_repository->m_mutex);
     SetNodeData* data = m_repository->dataRepository.dynamicItemFromIndexSimple(m_tree);
     ++data->m_refCount;
-    m_repository->m_mutex->unlock();
 }
 
 ///Mutex must be locked
@@ -1084,14 +1074,14 @@ void Set::unrefNode(uint current) {
     if(!m_repository->delayedDeletion()) {
         if(data->m_refCount == 0) {
 
-            if(data->leftNode){
-                Q_ASSERT(data->rightNode);
-                unrefNode(data->rightNode);
-                unrefNode(data->leftNode);
+            if(data->leftNode()){
+                Q_ASSERT(data->rightNode());
+                unrefNode(data->rightNode());
+                unrefNode(data->leftNode());
             }else {
                 //Deleting a leaf
-                Q_ASSERT(data->end - data->start == 1);
-                m_repository->itemRemovedFromSets(data->start);
+                Q_ASSERT(data->end() - data->start() == 1);
+                m_repository->itemRemovedFromSets(data->start());
             }
 
         m_repository->dataRepository.deleteItem(current);
@@ -1106,11 +1096,9 @@ void Set::staticUnref() {
   if(!m_tree)
     return;
   
-    m_repository->m_mutex->lock();
+    QMutexLocker lock(m_repository->m_mutex);
     
     unrefNode(m_tree);
-    
-    m_repository->m_mutex->unlock();
 }
 
 StringSetRepository::StringSetRepository(QString name) : Utils::BasicSetRepository(name) {
