@@ -5,7 +5,7 @@
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
+    the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -27,9 +27,35 @@
 
 QTEST_KDEMAIN(KDevelop::FilteringStrategyTest, NoGUI)
 
+namespace QTest {
+
+template<>
+inline char* toString(const KDevelop::FilteredItem::FilteredOutputItemType& type)
+{
+    switch (type) {
+        case KDevelop::FilteredItem::ActionItem:
+            return qstrdup("ActionItem");
+        case KDevelop::FilteredItem::CustomItem:
+            return qstrdup("CustomItem");
+        case KDevelop::FilteredItem::ErrorItem:
+            return qstrdup("ErrorItem");
+        case KDevelop::FilteredItem::InformationItem:
+            return qstrdup("InformationItem");
+        case KDevelop::FilteredItem::InvalidItem:
+            return qstrdup("InvalidItem");
+        case KDevelop::FilteredItem::StandardItem:
+            return qstrdup("StandardItem");
+        case KDevelop::FilteredItem::WarningItem:
+            return qstrdup("WarningItem");
+    }
+    return qstrdup("unknown");
+}
+
+}
+
 namespace KDevelop
 {
-void FilteringStrategyTest::testNoFilterstrategy_data()
+void FilteringStrategyTest::testNoFilterStrategy_data()
 {
     QTest::addColumn<QString>("line");
     QTest::addColumn<FilteredItem::FilteredOutputItemType>("expected");
@@ -50,18 +76,18 @@ void FilteringStrategyTest::testNoFilterstrategy_data()
     << buildPythonErrorLine() << FilteredItem::InvalidItem;
 }
 
-void FilteringStrategyTest::testNoFilterstrategy()
+void FilteringStrategyTest::testNoFilterStrategy()
 {
     QFETCH(QString, line);
     QFETCH(FilteredItem::FilteredOutputItemType, expected);
     NoFilterStrategy testee;
     FilteredItem item1 = testee.errorInLine(line);
-    QVERIFY(item1.type == expected);
+    QCOMPARE(item1.type, expected);
     item1 = testee.actionInLine(line);
-    QVERIFY(item1.type == expected);
+    QCOMPARE(item1.type, expected);
 }
 
-void FilteringStrategyTest::testCompilerFilterstrategy_data()
+void FilteringStrategyTest::testCompilerFilterStrategy_data()
 {
     QTest::addColumn<QString>("line");
     QTest::addColumn<FilteredItem::FilteredOutputItemType>("expectedError");
@@ -89,6 +115,12 @@ void FilteringStrategyTest::testCompilerFilterstrategy_data()
     << buildCmakeConfigureMultiLine() << FilteredItem::ErrorItem << FilteredItem::InvalidItem;
     QTest::newRow("cmake-warning-line")
     << "CMake Warning (dev) in CMakeLists.txt:" << FilteredItem::WarningItem << FilteredItem::InvalidItem;
+    QTest::newRow("cmake-automoc-error")
+    << "AUTOMOC: error: /foo/bar.cpp The file includes the moc file \"moc_bar1.cpp\"" << FilteredItem::ErrorItem << FilteredItem::InvalidItem;
+    QTest::newRow("cmake-automoc4-error")
+    << "automoc4: The file \"/foo/bar.cpp\" includes the moc file \"bar1.moc\"" << FilteredItem::InformationItem << FilteredItem::InvalidItem;
+    QTest::newRow("cmake-autogen-error")
+    << "AUTOGEN: error: /foo/bar.cpp The file includes the moc file \"moc_bar1.cpp\"" << FilteredItem::ErrorItem << FilteredItem::InvalidItem;
     QTest::newRow("linker-action-line")
     << "linking testCustombuild (g++)" << FilteredItem::InvalidItem << FilteredItem::ActionItem;
     QTest::newRow("linker-error-line")
@@ -97,7 +129,7 @@ void FilteringStrategyTest::testCompilerFilterstrategy_data()
     << buildPythonErrorLine() << FilteredItem::InvalidItem << FilteredItem::InvalidItem;
 }
 
-void FilteringStrategyTest::testCompilerFilterstrategy()
+void FilteringStrategyTest::testCompilerFilterStrategy()
 {
     QFETCH(QString, line);
     QFETCH(FilteredItem::FilteredOutputItemType, expectedError);
@@ -105,9 +137,9 @@ void FilteringStrategyTest::testCompilerFilterstrategy()
     KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     CompilerFilterStrategy testee(projecturl);
     FilteredItem item1 = testee.errorInLine(line);
-    QVERIFY(item1.type == expectedError);
+    QCOMPARE(item1.type, expectedError);
     item1 = testee.actionInLine(line);
-    QVERIFY(item1.type == expectedAction);
+    QCOMPARE(item1.type, expectedAction);
 }
 
 void FilteringStrategyTest::testCompilerFilterstrategyMultipleKeywords_data()
@@ -138,13 +170,44 @@ void FilteringStrategyTest::testCompilerFilterstrategyMultipleKeywords()
     KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
     CompilerFilterStrategy testee(projecturl);
     FilteredItem item1 = testee.errorInLine(line);
-    QVERIFY(item1.type == expectedError);
+    QCOMPARE(item1.type, expectedError);
     item1 = testee.actionInLine(line);
-    QVERIFY(item1.type == expectedAction);
+    QCOMPARE(item1.type, expectedAction);
 }
 
+void FilteringStrategyTest::testCompilerFilterStrategyShortenedText_data()
+{
+    QTest::addColumn<QString>("line");
+    QTest::addColumn<QString>("expectedShortenedText");
 
-void FilteringStrategyTest::testScriptErrorFilterstrategy_data()
+    QTest::newRow("c++-compile")
+    << "g++ -c main.cpp -o main.o" << "compiling main.cpp (g++)";
+    QTest::newRow("clang++-link")
+    << "clang++ -c main.cpp -o main.o" << "compiling main.cpp (clang++)";
+    // see bug: https://bugs.kde.org/show_bug.cgi?id=240017
+    QTest::newRow("mpicc-link")
+    << "/usr/bin/mpicc -c main.cpp -o main.o" << "compiling main.cpp (mpicc)";
+
+    QTest::newRow("c++-link")
+    << "/usr/bin/g++ main.cpp -o main" << "linking main (g++)";
+    QTest::newRow("clang++-link")
+    << "/usr/bin/clang++ main.cpp -o a.out" << "linking a.out (clang++)";
+    QTest::newRow("mpicc-link")
+    << "mpicc main.cpp -o main" << "linking main (mpicc)";
+}
+
+void FilteringStrategyTest::testCompilerFilterStrategyShortenedText()
+{
+    QFETCH(QString, line);
+    QFETCH(QString, expectedShortenedText);
+
+    KUrl projecturl( PROJECTS_SOURCE_DIR"/onefileproject/" );
+    CompilerFilterStrategy testee(projecturl);
+    FilteredItem item = testee.actionInLine(line);
+    QCOMPARE(item.shortenedText, expectedShortenedText);
+}
+
+void FilteringStrategyTest::testScriptErrorFilterStrategy_data()
 {
     QTest::addColumn<QString>("line");
     QTest::addColumn<FilteredItem::FilteredOutputItemType>("expectedError");
@@ -164,16 +227,75 @@ void FilteringStrategyTest::testScriptErrorFilterstrategy_data()
     << buildPythonErrorLine() << FilteredItem::InvalidItem << FilteredItem::InvalidItem;
 }
 
-void FilteringStrategyTest::testScriptErrorFilterstrategy()
+void FilteringStrategyTest::testScriptErrorFilterStrategy()
 {
     QFETCH(QString, line);
     QFETCH(FilteredItem::FilteredOutputItemType, expectedError);
     QFETCH(FilteredItem::FilteredOutputItemType, expectedAction);
     ScriptErrorFilterStrategy testee;
     FilteredItem item1 = testee.errorInLine(line);
-    QVERIFY(item1.type == expectedError);
+    QCOMPARE(item1.type, expectedError);
     item1 = testee.actionInLine(line);
-    QVERIFY(item1.type == expectedAction);
+    QCOMPARE(item1.type, expectedAction);
+}
+
+void FilteringStrategyTest::testNativeAppErrorFilterStrategy_data()
+{
+    QTest::addColumn<QString>("line");
+    QTest::addColumn<QString>("file");
+    QTest::addColumn<int>("lineNo");
+    QTest::addColumn<int>("column");
+    QTest::addColumn<FilteredItem::FilteredOutputItemType>("itemtype");
+
+    // TODO: qt-connect-* and friends shouldn't be error items but warnings items instead
+    // this needs refactoring in outputfilteringstrategies, though...
+    QTest::newRow("qt-connect-nosuch-slot")
+        << "QObject::connect: No such slot Foo::bar() in /foo/bar.cpp:313"
+        << "/foo/bar.cpp"
+        << 312 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qt-connect-nosuch-signal")
+        << "QObject::connect: No such signal Foo::bar() in /foo/bar.cpp:313"
+        << "/foo/bar.cpp"
+        << 312 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qt-connect-parentheses-slot")
+        << "QObject::connect: Parentheses expected, slot Foo::bar() in /foo/bar.cpp:313"
+        << "/foo/bar.cpp"
+        << 312 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qt-connect-parentheses-signal")
+        << "QObject::connect: Parentheses expected, signal Foo::bar() in /foo/bar.cpp:313"
+        << "/foo/bar.cpp"
+        << 312 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qt-assert")
+        << "ASSERT: \"errors().isEmpty()\" in file /tmp/foo/bar.cpp, line 49"
+        << "/tmp/foo/bar.cpp"
+        << 48 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qttest-assert")
+        << "QFATAL : FooTest::testBar() ASSERT: \"index.isValid()\" in file /foo/bar.cpp, line 32"
+        << "/foo/bar.cpp"
+        << 31 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qttest-loc")
+        << "   Loc: [/foo/bar.cpp(33)]"
+        << "/foo/bar.cpp"
+        << 32 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qttest-loc-nocatch")
+        << "   Loc: [Unknown file(0)]"
+        << ""
+        << -1 << -1 << FilteredItem::InvalidItem;
+}
+
+void FilteringStrategyTest::testNativeAppErrorFilterStrategy()
+{
+    QFETCH(QString, line);
+    QFETCH(QString, file);
+    QFETCH(int, lineNo);
+    QFETCH(int, column);
+    QFETCH(FilteredItem::FilteredOutputItemType, itemtype);
+    NativeAppErrorFilterStrategy testee;
+    FilteredItem item = testee.errorInLine(line);
+    QCOMPARE(item.url.path(), file);
+    QCOMPARE(item.lineNo , lineNo);
+    QCOMPARE(item.columnNo , column);
+    QCOMPARE(item.type , itemtype);
 }
 
 void FilteringStrategyTest::testStaticAnalysisFilterStrategy_data()
@@ -216,9 +338,9 @@ void FilteringStrategyTest::testStaticAnalysisFilterStrategy()
     FilteredItem item1 = testee.errorInLine(line);
     QString extractedPath = item1.url.toLocalFile();
     QVERIFY((item1.type != FilteredItem::ErrorItem) || ( extractedPath == referencePath));
-    QVERIFY(item1.type == expectedError);
+    QCOMPARE(item1.type, expectedError);
     item1 = testee.actionInLine(line);
-    QVERIFY(item1.type == expectedAction);
+    QCOMPARE(item1.type, expectedAction);
 }
 
 void FilteringStrategyTest::testCompilerFilterstrategyUrlFromAction_data()
@@ -240,6 +362,8 @@ void FilteringStrategyTest::testCompilerFilterstrategyUrlFromAction_data()
     << "[ 26%] Building CXX object /path/to/two/CMakeFiles/file.o" << QString( basepath + "path/to/two/");
     QTest::newRow("cd-line6")
     << QString("make[4]: Entering directory '" + basepath + "path/to/one/'") << QString( basepath + "path/to/one/");
+    QTest::newRow("waf-cd")
+    << QString("Waf: Entering directory `" + basepath + "path/to/two/'") << QString( basepath + "path/to/two/");
     QTest::newRow("cmake-line7")
     << QString("[ 50%] Building CXX object CMakeFiles/testdeque.dir/RingBuffer.cpp.o") << QString( basepath);
 }
@@ -302,7 +426,7 @@ void FilteringStrategyTest::benchMarkCompilerFilterAction()
     QVERIFY(avgDirectoryInsertion < 2);
 }
 
-void FilteringStrategyTest::testExtractionOfLineAndCulmn_data()
+void FilteringStrategyTest::testExtractionOfLineAndColumn_data()
 {
     QTest::addColumn<QString>("line");
     QTest::addColumn<QString>("file");
@@ -339,7 +463,7 @@ void FilteringStrategyTest::testExtractionOfLineAndCulmn_data()
         << "/path/flib.f90" << 3566 << 21 << FilteredItem::ErrorItem;
 }
 
-void FilteringStrategyTest::testExtractionOfLineAndCulmn()
+void FilteringStrategyTest::testExtractionOfLineAndColumn()
 {
     QFETCH(QString, line);
     QFETCH(QString, file);
