@@ -64,21 +64,16 @@ using KDevelop::IDistributedVersionControl;
 using KDevelop::IPlugin;
 using KDevelop::VcsJob;
 using KDevelop::VcsLocation;
+using KDevelop::ICore;
 
-K_PLUGIN_FACTORY(AppWizardFactory,
-    registerPlugin<AppWizardPlugin>();
-    KComponentData compData = componentData();
-    KStandardDirs *dirs = compData.dirs();
-    dirs->addResourceType("apptemplates", "data", "kdevappwizard/templates/");
-    dirs->addResourceType("apptemplate_descriptions","data", "kdevappwizard/template_descriptions/");
-    dirs->addResourceType("apptemplate_previews","data", "kdevappwizard/template_previews/");
-    setComponentData(compData);
-)
+K_PLUGIN_FACTORY(AppWizardFactory, registerPlugin<AppWizardPlugin>();)
 K_EXPORT_PLUGIN(AppWizardFactory(KAboutData("kdevappwizard","kdevappwizard", ki18n("Project Wizard"), "0.1", ki18n("Support for creating and importing projects"), KAboutData::License_GPL)))
 
 AppWizardPlugin::AppWizardPlugin(QObject *parent, const QVariantList &)
-    :KDevelop::IPlugin(AppWizardFactory::componentData(), parent)
+    : KDevelop::IPlugin(AppWizardFactory::componentData(), parent)
+    , m_templatesModel(0)
 {
+    KDEV_USE_EXTENSION_INTERFACE(KDevelop::ITemplateProvider);
     setXMLFile("kdevappwizard.rc");
 
     m_newFromTemplate = actionCollection()->addAction("project_new");
@@ -86,12 +81,9 @@ AppWizardPlugin::AppWizardPlugin(QObject *parent, const QVariantList &)
     m_newFromTemplate->setText(i18n("New From Template..."));
     connect(m_newFromTemplate, SIGNAL(triggered(bool)), this, SLOT(slotNewProject()));
     m_newFromTemplate->setToolTip( i18n("Generate a new project from a template") );
-    m_newFromTemplate->setWhatsThis( i18n("<b>New project</b><p>"
-                               "This starts KDevelop's application wizard. "
-                               "It helps you to generate a skeleton for your "
-                               "application from a set of templates.</p>") );
-
-    m_templatesModel = new ProjectTemplatesModel(this);
+    m_newFromTemplate->setWhatsThis( i18n("This starts KDevelop's application wizard. "
+                                          "It helps you to generate a skeleton for your "
+                                          "application from a set of templates.") );
 }
 
 AppWizardPlugin::~AppWizardPlugin()
@@ -100,7 +92,7 @@ AppWizardPlugin::~AppWizardPlugin()
 
 void AppWizardPlugin::slotNewProject()
 {
-    m_templatesModel->refresh();
+    model()->refresh();
     AppWizardDialog dlg(core()->pluginController(), m_templatesModel);
 
     if (dlg.exec() == QDialog::Accepted)
@@ -119,7 +111,7 @@ void AppWizardPlugin::slotNewProject()
                 core()->documentController()->openDocument(file);
             }
         } else {
-            KMessageBox::error( KDevelop::ICore::self()->uiController()->activeMainWindow(), i18n("Could not create project from template\n"), i18n("Failed to create project") );
+            KMessageBox::error( ICore::self()->uiController()->activeMainWindow(), i18n("Could not create project from template\n"), i18n("Failed to create project") );
         }
     }
 }
@@ -140,9 +132,14 @@ ICentralizedVersionControl* toCVCS(IPlugin* plugin)
 }
 
 /*! Trouble while initializing version control. Show failure message to user. */
-void vcsError(const QString &errorMsg, KTempDir &tmpdir, const KUrl &dest)
+void vcsError(const QString &errorMsg, KTempDir &tmpdir, const KUrl &dest, const QString &details = QString())
 {
-    KMessageBox::error(0, errorMsg);
+    QString displayDetails = details;
+    if (displayDetails.isEmpty())
+    {
+        displayDetails = i18n("Please see the Version Control toolview");
+    }
+    KMessageBox::detailedError(0, errorMsg, displayDetails, i18n("Version Control System Error"));
     KIO::NetAccess::del(dest, 0);
     tmpdir.unlink();
 }
@@ -173,7 +170,7 @@ bool initializeDVCS(IDistributedVersionControl* dvcs, const ApplicationInfo& inf
                             KDevelop::IBasicVersionControl::Recursive);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded)
     {
-        vcsError(i18n("Could not import project into %1.", dvcs->name()), scratchArea, dest);
+        vcsError(i18n("Could not import project into %1.", dvcs->name()), scratchArea, dest, job ? job->errorString() : QString());
         return false;
     }
 
@@ -190,7 +187,7 @@ bool initializeCVCS(ICentralizedVersionControl* cvcs, const ApplicationInfo& inf
     VcsJob* job = cvcs->import( info.importCommitMessage, scratchArea.name(), info.repository);
     if (!job || !job->exec() || job->status() != VcsJob::JobSucceeded )
     {
-    vcsError(i18n("Could not import project"), scratchArea, info.repository.repositoryServer());
+        vcsError(i18n("Could not import project"), scratchArea, info.repository.repositoryServer());
         return false;
     }
 
@@ -217,23 +214,20 @@ QString generateIdentifier( const QString& appname )
 QString AppWizardPlugin::createProject(const ApplicationInfo& info)
 {
     QFileInfo templateInfo(info.appTemplate);
-    if (!templateInfo.exists())
+    if (!templateInfo.exists()) {
+        kWarning() << "Project app template does not exist:" << info.appTemplate;
         return QString();
+    }
 
     QString templateName = templateInfo.baseName();
     kDebug() << "creating project for template:" << templateName << " with VCS:" << info.vcsPluginName;
 
-    QString templateArchive = componentData().dirs()->findResource("apptemplates", templateName + ".zip");
-    if( templateArchive.isEmpty() )
-    {
-        templateArchive = componentData().dirs()->findResource("apptemplates", templateName + ".tar.bz2");
+    QStringList matches = ICore::self()->componentData().dirs()->findAllResources("data", QString("kdevappwizard/templates/%1*").arg(templateName));
+    if (matches.isEmpty()) {
+        kWarning() << "Could not find project template" << templateName;
+        return QString();;
     }
-
-    kDebug() << "Using archive:" << templateArchive;
-
-    if (templateArchive.isEmpty())
-        return QString();
-
+    QString templateArchive = matches.first();
 
     KUrl dest = info.location;
 
@@ -244,6 +238,8 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
     m_variables["APPNAMELC"] = info.name.toLower();
     m_variables["APPNAMEID"] = generateIdentifier(info.name);
     m_variables["PROJECTDIR"] = dest.toLocalFile();
+    // backwards compatibility
+    m_variables["dest"] = m_variables["PROJECTDIR"];
     m_variables["PROJECTDIRNAME"] = dest.fileName();
     m_variables["VERSIONCONTROLPLUGIN"] = info.vcsPluginName;
 
@@ -347,7 +343,7 @@ QString AppWizardPlugin::createProject(const ApplicationInfo& info)
         QString manager = "KDevGenericManager";
 
         QDir d( dest.toLocalFile() );
-        foreach(const KPluginInfo& info, KDevelop::IPluginController::queryExtensionPlugins( "org.kdevelop.IProjectFileManager" ) )
+        foreach(const KPluginInfo& info, ICore::self()->pluginController()->queryExtensionPlugins( "org.kdevelop.IProjectFileManager" ) )
         {
             QVariant filter = info.property("X-KDevelop-ProjectFilesFilter");
             if( filter.isValid() )
@@ -392,7 +388,7 @@ bool AppWizardPlugin::unpackArchive(const KArchiveDirectory *dir, const QString
         if (dir->entry(entry)->isDirectory())
         {
             const KArchiveDirectory *file = (KArchiveDirectory *)dir->entry(entry);
-            QString newdest = dest + '/' + file->name();
+            QString newdest = dest + '/' + KMacroExpander::expandMacros(file->name(), m_variables);
             if( !QFileInfo( newdest ).exists() )
             {
                 QDir::root().mkdir( newdest  );
@@ -468,4 +464,51 @@ KDevelop::ContextMenuExtension AppWizardPlugin::contextMenuExtension(KDevelop::C
     return ext;
 }
 
+ProjectTemplatesModel* AppWizardPlugin::model()
+{
+    if(!m_templatesModel)
+        m_templatesModel = new ProjectTemplatesModel(this);
+    return m_templatesModel;
+}
+
+QAbstractItemModel* AppWizardPlugin::templatesModel()
+{
+    return model();
+}
+
+QString AppWizardPlugin::knsConfigurationFile() const
+{
+    return "kdevappwizard.knsrc";
+}
+
+QStringList AppWizardPlugin::supportedMimeTypes() const
+{
+    QStringList types;
+    types << "application/x-desktop";
+    types << "application/x-bzip-compressed-tar";
+    types << "application/zip";
+    return types;
+}
+
+QIcon AppWizardPlugin::icon() const
+{
+    return KIcon("project-development-new-template");
+}
+
+QString AppWizardPlugin::name() const
+{
+    return i18n("Project Templates");
+}
+
+void AppWizardPlugin::loadTemplate(const QString& fileName)
+{
+    model()->loadTemplateFile(fileName);
+}
+
+void AppWizardPlugin::reload()
+{
+    model()->refresh();
+}
+
+
 #include "appwizardplugin.moc"
