@@ -11,6 +11,14 @@
 #define _PROJECTSELECTIONPAGE_H_
 
 #include "appwizardpagewidget.h"
+#include "appwizarddialog.h"
+#include <knewstuff3/entry.h>
+#include <QRegExpValidator>
+
+namespace KDevelop
+{
+class MultiLevelListView;
+}
 
 namespace Ui {
 class ProjectSelectionPage;
@@ -24,7 +32,7 @@ class KUrl;
 class ProjectSelectionPage : public AppWizardPageWidget {
 Q_OBJECT
 public:
-    explicit ProjectSelectionPage(ProjectTemplatesModel *templatesModel, QWidget *parent = 0);
+    explicit ProjectSelectionPage(ProjectTemplatesModel *templatesModel, AppWizardDialog *wizardDialog);
     ~ProjectSelectionPage();
 
     bool shouldContinue();
@@ -38,20 +46,25 @@ signals:
     void invalid();
 private slots:
     void itemChanged( const QModelIndex& current );
-    void templateFamilyChanged(const QModelIndex&, const QModelIndex&);
     void urlEdited();
     void validateData();
     void nameChanged();
     void typeChanged(const QModelIndex& idx);
     void templateChanged(int);
-    
+
+    void loadFileClicked();
+    void templatesDownloaded (const KNS3::Entry::List& entries);
+
+
 private:
     inline QByteArray encodedAppName();
-    inline QString pathUp(const QString& aPath);
     inline QStandardItem* getCurrentItem() const;
+    void setCurrentTemplate(const QString& fileName);
 
     Ui::ProjectSelectionPage *ui;
+    KDevelop::MultiLevelListView* m_listView;
     ProjectTemplatesModel *m_templatesModel;
+    AppWizardDialog *m_wizardDialog;
 };
 
 #endif
