@@ -36,8 +36,7 @@ ProjectVcsPage::ProjectVcsPage( KDevelop::IPluginController* controller, QWidget
     : AppWizardPageWidget( parent ), m_ui( new Ui::ProjectVcsPage )
 {
     m_ui->setupUi( this );
-    QList<KDevelop::IPlugin*> vcsplugins = controller->allPluginsForExtension (
-            "org.kdevelop.IBasicVersionControl", QStringList() );
+    QList<KDevelop::IPlugin*> vcsplugins = controller->allPluginsForExtension ( "org.kdevelop.IBasicVersionControl" );
     int idx = 1;
     m_ui->vcsImportOptions->insertWidget( 0, new QWidget(this) );
     m_ui->vcsTypes->insertItem( 0, i18nc("No Version Control Support chosen", "None") );
