@@ -19,8 +19,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef ALLCLASSESFOLDER_H
-#define ALLCLASSESFOLDER_H
+#ifndef KDEVPLATFORM_PLUGIN_ALLCLASSESFOLDER_H
+#define KDEVPLATFORM_PLUGIN_ALLCLASSESFOLDER_H
 
 #include "documentclassesfolder.h"
 
