@@ -176,6 +176,10 @@ QModelIndex ClassModel::parent(const QModelIndex& childIndex) const
 
 QModelIndex ClassModel::index(ClassModelNodes::Node* a_node) const
 {
+  if (!a_node) {
+    return QModelIndex();
+  }
+
   // If no parent exists, we have an invalid index (root node or not part of a model).
   if ( a_node->getParent() == 0 )
     return QModelIndex();
@@ -253,7 +257,9 @@ void ClassModel::nodesAdded(ClassModelNodes::Node*)
 void ClassModel::addProjectNode( IProject* project )
 {
   m_projectNodes[project] = new ClassModelNodes::FilteredProjectFolder(this, project);
+  nodesLayoutAboutToBeChanged(m_projectNodes[project]);
   m_topNode->addNode(m_projectNodes[project]);
+  nodesLayoutChanged(m_projectNodes[project]);
 }
 
 void ClassModel::removeProjectNode( IProject* project )
