@@ -20,8 +20,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef CLASSMODELNODE_H
-#define CLASSMODELNODE_H
+#ifndef KDEVPLATFORM_PLUGIN_CLASSMODELNODE_H
+#define KDEVPLATFORM_PLUGIN_CLASSMODELNODE_H
 
 #include "classmodel.h"
 #include <qicon.h>
@@ -208,7 +208,7 @@ public:
   virtual ~ClassNode();
 
   /// Lookup a contained class and return the related node.
-  /// @return the the node pointer or 0 if non was found.
+  /// @return the node pointer or 0 if non was found.
   ClassNode* findSubClass(const KDevelop::IndexedQualifiedIdentifier& a_id);
 
 public: // Node overrides
