@@ -24,20 +24,16 @@
 #include "contextbrowserview.h"
 #include "browsemanager.h"
 
-///TODO: remove unneeded includes
-#include <memory>
 #include <cstdlib>
 
 #include <QTimer>
-#include <QApplication>
 #include <QToolButton>
 #include <QLayout>
+#include <QMenu>
 #include <qalgorithms.h>
 
 #include <KLocale>
 #include <KAction>
-#include <KPluginFactory>
-#include <KPluginLoader>
 #include <KActionCollection>
 #include <KAboutData>
 #include <KDebug>
@@ -59,20 +55,17 @@
 #include <language/interfaces/ilanguagesupport.h>
 #include <language/interfaces/iquickopen.h>
 
-#include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/ducontext.h>
 #include <language/duchain/declaration.h>
 #include <language/duchain/use.h>
 #include <language/duchain/duchainutils.h>
-#include <language/duchain/dumpchain.h>
 #include <language/duchain/functiondefinition.h>
 #include <language/duchain/parsingenvironment.h>
 #include <language/duchain/uses.h>
 #include <language/duchain/specializationstore.h>
 #include <language/duchain/aliasdeclaration.h>
 #include <language/duchain/types/functiontype.h>
-
 #include <language/duchain/navigation/abstractnavigationwidget.h>
 
 #include <language/backgroundparser/backgroundparser.h>
@@ -82,23 +75,23 @@
 
 #include <sublime/mainwindow.h>
 
-static const unsigned int highlightingTimeout = 150;
-static const float highlightingZDepth = -5000;
-static const int maxHistoryLength = 30;
-
 using KDevelop::ILanguage;
 using KTextEditor::Attribute;
 using KTextEditor::View;
 
-bool toolTipEnabled = true;
-
 // Helper that follows the QObject::parent() chain, and returns the highest widget that has no parent.
-QWidget* masterWidget(QWidget* w) {
+QWidget* masterWidget(QWidget* w)
+{
   while(w && w->parent() && qobject_cast<QWidget*>(w->parent()))
     w = qobject_cast<QWidget*>(w->parent());
   return w;
 }
 
+namespace {
+const unsigned int highlightingTimeout = 150;
+const float highlightingZDepth = -5000;
+const int maxHistoryLength = 30;
+
 // Helper that determines the context to use for highlighting at a specific position
 DUContext* contextForHighlightingAt(const SimpleCursor& position, TopDUContext* topContext)
 {
@@ -113,12 +106,37 @@ DUContext* contextForHighlightingAt(const SimpleCursor& position, TopDUContext*
 }
 
 ///Duchain must be locked
-DUContext* getContextAt(KUrl url, KTextEditor::Cursor cursor) {
+DUContext* getContextAt(const KUrl& url, KTextEditor::Cursor cursor)
+{
   TopDUContext* topContext = DUChainUtils::standardContextForUrl(url);
   if (!topContext) return 0;
   return contextForHighlightingAt(SimpleCursor(cursor), topContext);
 }
 
+DeclarationPointer cursorDeclaration()
+{
+  IDocument* doc = ICore::self()->documentController()->activeDocument();
+  if (!doc) {
+    return DeclarationPointer();
+  }
+
+  KTextEditor::Document* textDoc = doc->textDocument();
+  if (!textDoc) {
+    return DeclarationPointer();
+  }
+
+  KTextEditor::View* view = textDoc->activeView();
+  if (!view) {
+    return DeclarationPointer();
+  }
+
+  DUChainReadLocker lock;
+
+  Declaration *decl = DUChainUtils::declarationForDefinition(DUChainUtils::itemUnderCursor(doc->url(), SimpleCursor(view->cursorPosition())));
+  return DeclarationPointer(decl);
+}
+
+}
 
 class ContextBrowserViewFactory: public KDevelop::IToolViewFactory
 {
@@ -144,6 +162,7 @@ public:
 private:
     ContextBrowserPlugin *m_plugin;
 };
+
 KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow* window )
 {
     KXMLGUIClient* ret = KDevelop::IPlugin::createGUIForMainWindow( window );
@@ -271,7 +290,7 @@ void ContextBrowserPlugin::previousContextShortcut()
 }
 
 K_PLUGIN_FACTORY(ContextBrowserFactory, registerPlugin<ContextBrowserPlugin>(); )
-K_EXPORT_PLUGIN(ContextBrowserFactory(KAboutData("kdevcontextbrowser","kdevcontextbrowser",ki18n("Context Browser"), "0.1", ki18n("Shows information for the current context"), KAboutData::License_GPL)))
+K_EXPORT_PLUGIN(ContextBrowserFactory(KAboutData("kdevcontextbrowser","kdevcontextbrowser",ki18n("Context Browser"), "0.1", ki18n("This plugin shows information about the current language context in a side view, and highlights relevant declarations and uses."), KAboutData::License_GPL)))
 
 ContextBrowserPlugin::ContextBrowserPlugin(QObject *parent, const QVariantList&)
     : KDevelop::IPlugin(ContextBrowserFactory::componentData(), parent)
@@ -285,8 +304,8 @@ ContextBrowserPlugin::ContextBrowserPlugin(QObject *parent, const QVariantList&)
   connect( core()->documentController(), SIGNAL(textDocumentCreated(KDevelop::IDocument*)), this, SLOT(textDocumentCreated(KDevelop::IDocument*)) );
   connect( core()->languageController()->backgroundParser(), SIGNAL(parseJobFinished(KDevelop::ParseJob*)), this, SLOT(parseJobFinished(KDevelop::ParseJob*)));
 
-  connect( DUChain::self(), SIGNAL(declarationSelected(DeclarationPointer)), this, SLOT(declarationSelectedInUI(DeclarationPointer)) );
-
+  connect( DUChain::self(), SIGNAL(declarationSelected(KDevelop::DeclarationPointer)),
+           this, SLOT(declarationSelectedInUI(KDevelop::DeclarationPointer)) );
 
   m_updateTimer = new QTimer(this);
   m_updateTimer->setSingleShot(true);
@@ -331,7 +350,6 @@ KDevelop::ContextMenuExtension ContextBrowserPlugin::contextMenuExtension(KDevel
   
   qRegisterMetaType<KDevelop::IndexedDeclaration>("KDevelop::IndexedDeclaration");
   
-  m_findUses->setData(QVariant::fromValue(codeContext->declaration()));
   menuExt.addAction(KDevelop::ContextMenuExtension::ExtensionGroup, m_findUses);
 
   return menuExt;
@@ -373,11 +391,7 @@ void ContextBrowserPlugin::showUsesDelayed(const DeclarationPointer& declaration
 
 void ContextBrowserPlugin::findUses()
 {
-  QAction* action = qobject_cast<QAction*>(sender());
-  Q_ASSERT(action);
-  
-  KDevelop::IndexedDeclaration decl = action->data().value<KDevelop::IndexedDeclaration>();
-  showUses(DeclarationPointer(decl.declaration()));
+  showUses(cursorDeclaration());
 }
 
 void ContextBrowserPlugin::textHintRequested(const KTextEditor::Cursor& cursor, QString&) {
@@ -391,8 +405,7 @@ void ContextBrowserPlugin::textHintRequested(const KTextEditor::Cursor& cursor,
   }
   m_updateTimer->start(1); // triggers updateViews()
   
-  if(toolTipEnabled)
-    showToolTip(view, cursor);
+  showToolTip(view, cursor);
 }
 
 void ContextBrowserPlugin::stopDelayedBrowsing() {
@@ -409,7 +422,7 @@ void ContextBrowserPlugin::startDelayedBrowsing(KTextEditor::View* view) {
   }
 }
 
-void ContextBrowserPlugin::hideTooTip() {
+void ContextBrowserPlugin::hideToolTip() {
   if(m_currentToolTip) {
     m_currentToolTip->deleteLater();
     m_currentToolTip = 0;
@@ -495,11 +508,15 @@ void ContextBrowserPlugin::showToolTip(KTextEditor::View* view, KTextEditor::Cur
     m_currentNavigationWidget = navigationWidget;
     ActiveToolTip::showToolTip(tooltip);
 
-    //First disconnect to prevent multiple connections
-    disconnect(view, SIGNAL(cursorPositionChanged(KTextEditor::View*,KTextEditor::Cursor)), this, SLOT(hideTooTip()));
-    disconnect(view, SIGNAL(focusOut(KTextEditor::View*)), this, SLOT(hideTooTip()));
-    connect(view, SIGNAL(cursorPositionChanged(KTextEditor::View*,KTextEditor::Cursor)), this, SLOT(hideTooTip()));
-    connect(view, SIGNAL(focusOut(KTextEditor::View*)), this, SLOT(hideTooTip()));
+    if ( ! navigationWidget->property("DoNotCloseOnCursorMove").toBool() ) {
+      connect(view, SIGNAL(cursorPositionChanged(KTextEditor::View*,KTextEditor::Cursor)),
+              this, SLOT(hideToolTip()), Qt::UniqueConnection);
+    } else {
+      disconnect(view, SIGNAL(cursorPositionChanged(KTextEditor::View*,KTextEditor::Cursor)),
+                 this, SLOT(hideToolTip()));
+    }
+
+    connect(view, SIGNAL(focusOut(KTextEditor::View*)), this, SLOT(hideToolTip()), Qt::UniqueConnection);
     
   }else{
     kDebug() << "not showing tooltip, no navigation-widget";
@@ -614,7 +631,7 @@ void ContextBrowserPlugin::updateForView(View* view)
     if(view->selection())
     {
       // If something is selected, we unhighlight everything, so that we don't conflict with the
-      // kate plugin that highlights occurences of the selected string, and also to reduce the
+      // kate plugin that highlights occurrences of the selected string, and also to reduce the
       // overall amount of concurrent highlighting.
       allowHighlight = false;
     }
@@ -714,7 +731,7 @@ void ContextBrowserPlugin::updateViews()
   m_useDeclaration = IndexedDeclaration();
 }
 
-void ContextBrowserPlugin::declarationSelectedInUI(DeclarationPointer decl)
+void ContextBrowserPlugin::declarationSelectedInUI(const DeclarationPointer& decl)
 {
   m_useDeclaration = IndexedDeclaration(decl.data());
   if(core()->documentController()->activeDocument() && core()->documentController()->activeDocument()->textDocument() && core()->documentController()->activeDocument()->textDocument()->activeView())
