@@ -25,8 +25,6 @@
 #include <KAction>
 #include <KAboutData>
 
-#include <memory>
-
 #include <interfaces/iproject.h>
 #include <project/projectmodel.h>
 #include <interfaces/iuicontroller.h>
@@ -81,7 +79,7 @@ public:
 
     KDevCvsViewFactory* m_factory;
     QPointer<CvsProxy> m_proxy;
-    std::auto_ptr<KDevelop::VcsPluginHelper> m_common;
+    QScopedPointer<KDevelop::VcsPluginHelper> m_common;
 };
 
 CvsPlugin::CvsPlugin(QObject *parent, const QVariantList &)
@@ -169,7 +167,7 @@ void CvsPlugin::slotStatus()
     KDevelop::VcsJob* j = status(url, KDevelop::IBasicVersionControl::Recursive);
     CvsJob* job = dynamic_cast<CvsJob*>(j);
     if (job) {
-        CvsGenericOutputView* view = new CvsGenericOutputView(this, job);
+        CvsGenericOutputView* view = new CvsGenericOutputView(job);
         emit addNewTabToMainView(view, i18n("Status"));
         KDevelop::ICore::self()->runController()->registerJob(job);
     }
@@ -254,7 +252,7 @@ void CvsPlugin::ctxEditors()
                                       urls);
     if (job) {
         KDevelop::ICore::self()->runController()->registerJob(job);
-        EditorsView* view = new EditorsView(this, job);
+        EditorsView* view = new EditorsView(job);
         emit addNewTabToMainView(view, i18n("Editors"));
     }
 }
