@@ -1,5 +1,6 @@
 /* This file is part of KDevelop
 Copyright 2005 Adam Treat <treat@kde.org>
+Copyright 2013 Sebastian Kügler <sebas@kde.org>
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
@@ -21,6 +22,7 @@ Boston, MA 02110-1301, USA.
 #include "kdevdocumentviewplugin.h"
 #include "kdevdocumentmodel.h"
 
+#include <QDir>
 #include <QHeaderView>
 #include <QContextMenuEvent>
 #include <QSortFilterProxyModel>
@@ -39,6 +41,8 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iplugincontroller.h>
+#include <interfaces/iproject.h>
+#include <interfaces/iprojectcontroller.h>
 #include <interfaces/context.h>
 #include <interfaces/idocument.h>
 
@@ -46,9 +50,14 @@ KDevDocumentView::KDevDocumentView( KDevDocumentViewPlugin *plugin, QWidget *par
     : QTreeView( parent ),
         m_plugin( plugin )
 {
-    m_documentModel = new KDevDocumentModel();
+    connect(KDevelop::ICore::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
+            SLOT(updateProjectPaths()));
+    connect(KDevelop::ICore::self()->projectController(), SIGNAL(projectClosed(KDevelop::IProject*)),
+            SLOT(updateProjectPaths()));
 
-    m_delegate = new KDevDocumentViewDelegate( this, this );
+    m_documentModel = new KDevDocumentModel(this);
+
+    m_delegate = new KDevDocumentViewDelegate( this );
 
     m_proxy = new QSortFilterProxyModel( this );
     m_proxy->setSourceModel( m_documentModel );
@@ -66,11 +75,9 @@ KDevDocumentView::KDevDocumentView( KDevDocumentViewPlugin *plugin, QWidget *par
 
     setWindowIcon( SmallIcon( "document-multiple" ) );
     setWindowTitle( i18n( "Documents" ) );
-    setWhatsThis( i18n( "Document View" ) );
 
     setFocusPolicy( Qt::NoFocus );
 
-    setRootIsDecorated( false );
     header()->hide();
 
     setSelectionBehavior( QAbstractItemView::SelectRows );
@@ -90,24 +97,22 @@ void KDevDocumentView::mousePressEvent( QMouseEvent * event )
     QModelIndex proxyIndex = indexAt( event->pos() );
     QModelIndex index = m_proxy->mapToSource( proxyIndex );
 
-    if ( event->button() == Qt::LeftButton && proxyIndex.parent().isValid() &&
-            event->modifiers() == Qt::NoModifier )
-    {
-        KDevelop::IDocumentController* dc = m_plugin->core()->documentController();
-        KUrl documentUrl = static_cast<KDevDocumentItem*>( m_documentModel->itemFromIndex( index ) )->fileItem()->url();
-        if (dc->documentForUrl(documentUrl) != dc->activeDocument())
-        {
-            dc->openDocument(documentUrl);
+    if (event->button() == Qt::LeftButton && event->modifiers() == Qt::NoModifier) {
+        if (proxyIndex.parent().isValid()) {
+            // this is a document item
+            KDevelop::IDocumentController* dc = m_plugin->core()->documentController();
+            KUrl documentUrl = static_cast<KDevDocumentItem*>(m_documentModel->itemFromIndex(index))->fileItem()->url();
+            if (dc->documentForUrl(documentUrl) != dc->activeDocument()) {
+                dc->openDocument(documentUrl);
+                return;
+            }
+        } else {
+            // this is a folder item
+            setExpanded(proxyIndex, !isExpanded(proxyIndex));
             return;
         }
     }
 
-    if ( !proxyIndex.parent().isValid() )
-    {
-        setExpanded( proxyIndex, !isExpanded( proxyIndex ) );
-        return;
-    }
-
     QTreeView::mousePressEvent( event );
 }
 
@@ -160,8 +165,14 @@ void KDevDocumentView::reloadSelected()
 
 void KDevDocumentView::contextMenuEvent( QContextMenuEvent * event )
 {
+    QModelIndex proxyIndex = indexAt( event->pos() );
+    // for now, ignore clicks on empty space or folder items
+    if (!proxyIndex.isValid() || !proxyIndex.parent().isValid()) {
+        return;
+    }
+
     updateSelectedDocs();
-    
+
     if (!m_selectedDocs.isEmpty())
     {
         KMenu* ctxMenu = new KMenu(this);
@@ -257,19 +268,22 @@ void KDevDocumentView::saved( KDevelop::IDocument* )
 
 void KDevDocumentView::opened( KDevelop::IDocument* document )
 {
-    QString mimeType = document->mimeType()->comment();
-    KDevMimeTypeItem *mimeItem = m_documentModel->mimeType( mimeType );
-    if ( !mimeItem )
+    const QString path = QFileInfo( document->url().path() ).path();
+
+    KDevCategoryItem *categoryItem = m_documentModel->category( path );
+    if ( !categoryItem )
     {
-        mimeItem = new KDevMimeTypeItem( mimeType );
-        m_documentModel->insertRow( m_documentModel->rowCount(), mimeItem );
-        setExpanded( m_proxy->mapFromSource( m_documentModel->indexFromItem( mimeItem ) ), false);
+        categoryItem = new KDevCategoryItem( path );
+        categoryItem->setUrl( document->url() );
+        m_documentModel->insertRow( m_documentModel->rowCount(), categoryItem );
+        setExpanded( m_proxy->mapFromSource( m_documentModel->indexFromItem( categoryItem ) ), false);
+        updateCategoryItem( categoryItem );
     }
 
-    if ( !mimeItem->file( document->url() ) )
+    if ( !categoryItem->file( document->url() ) )
     {
         KDevFileItem * fileItem = new KDevFileItem( document->url() );
-        mimeItem->setChild( mimeItem->rowCount(), fileItem );
+        categoryItem->setChild( categoryItem->rowCount(), fileItem );
         setCurrentIndex( m_proxy->mapFromSource( m_documentModel->indexFromItem( fileItem ) ) );
         m_doc2index[ document ] = fileItem;
     }
@@ -281,20 +295,36 @@ void KDevDocumentView::closed( KDevelop::IDocument* document )
     if ( !file )
         return;
 
-    QStandardItem* mimeItem = file->parent();
+    QStandardItem* categoryItem = file->parent();
 
-    qDeleteAll(mimeItem->takeRow(m_documentModel->indexFromItem(file).row()));
+    qDeleteAll(categoryItem->takeRow(m_documentModel->indexFromItem(file).row()));
 
     m_doc2index.remove(document);
 
-    if ( mimeItem->hasChildren() )
+    if ( categoryItem->hasChildren() )
         return;
 
-    qDeleteAll(m_documentModel->takeRow(m_documentModel->indexFromItem(mimeItem).row()));
+    qDeleteAll(m_documentModel->takeRow(m_documentModel->indexFromItem(categoryItem).row()));
 
     doItemsLayout();
 }
 
+void KDevDocumentView::updateCategoryItem( KDevCategoryItem *item )
+{
+    QString text = KDevelop::ICore::self()->projectController()->prettyFilePath(item->url(), KDevelop::IProjectController::FormatPlain);
+    // remove trailing slash
+    if (text.length() > 1) {
+        text.chop(1);
+    }
+    item->setText(text);
+}
+
+void KDevDocumentView::updateProjectPaths()
+{
+    foreach ( KDevCategoryItem *it, m_documentModel->categoryList() )
+        updateCategoryItem( it );
+}
+
 void KDevDocumentView::contentChanged( KDevelop::IDocument* )
 {
 }
