@@ -1,5 +1,6 @@
 /* This file is part of KDevelop
    Copyright 2005 Adam Treat <treat@kde.org>
+   Copyright 2013 Sebastian Kügler <sebas@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -17,11 +18,12 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVDOCUMENTVIEW_H
-#define KDEVDOCUMENTVIEW_H
+#ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_H
+#define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_H
 
 #include <QTreeView>
 
+class QSortFilterProxyModel;
 class KAction;
 class KUrl;
 class KDevDocumentViewPlugin;
@@ -33,8 +35,10 @@ class KMenu;
 namespace KDevelop
 {
     class IDocument;
+    class IProject;
 }
 
+class KDevCategoryItem;
 class KDevDocumentModel;
 class KDevDocumentItem;
 
@@ -60,6 +64,8 @@ private slots:
     void contentChanged( KDevelop::IDocument* document );
     void stateChanged( KDevelop::IDocument* document );
     void documentUrlChanged( KDevelop::IDocument* document );
+    void updateCategoryItem( KDevCategoryItem *item );
+    void updateProjectPaths();
 
     void saveSelected();
     void reloadSelected();
@@ -80,11 +86,12 @@ private:
     KDevDocumentViewPlugin *m_plugin;
     KDevDocumentModel *m_documentModel;
     KDevDocumentSelection* m_selectionModel;
+    QSortFilterProxyModel* m_proxy;
     KDevDocumentViewDelegate* m_delegate;
     QHash< KDevelop::IDocument*, KDevFileItem* > m_doc2index;
     QList<KUrl> m_selectedDocs; // used for ctx menu
     QList<KUrl> m_unselectedDocs; // used for ctx menu
 };
 
-#endif // KDEVDOCUMENTVIEW_H
+#endif // KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEW_H
 
