@@ -17,8 +17,8 @@ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVDOCUMENTVIEWDELEGATE_H
-#define KDEVDOCUMENTVIEWDELEGATE_H
+#ifndef KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWDELEGATE_H
+#define KDEVPLATFORM_PLUGIN_KDEVDOCUMENTVIEWDELEGATE_H
 
 #include <QtGui/QItemDelegate>
 class QTreeView;
@@ -27,15 +27,10 @@ class KDevDocumentViewDelegate: public QItemDelegate
 {
     Q_OBJECT
 public:
-    explicit KDevDocumentViewDelegate( QTreeView *view, QObject *parent = 0 );
+    explicit KDevDocumentViewDelegate( QObject *parent = 0 );
     virtual ~KDevDocumentViewDelegate();
 
     virtual void paint( QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index ) const;
-    virtual QSize sizeHint( const QStyleOptionViewItem &opt, const QModelIndex &index ) const;
-
-private:
-    QTreeView *m_view;
 };
 
-#endif // KDEVCLASSVIEWDELEGATE_H
-
+#endif // KDEVPLATFORM_PLUGIN_KDEVCLASSVIEWDELEGATE_H
