@@ -19,8 +19,8 @@
  * 02110-1301, USA.
  */
 
-#ifndef IEXECUTESCRIPTPLUGIN_H
-#define IEXECUTESCRIPTPLUGIN_H
+#ifndef KDEVPLATFORM_PLUGIN_IEXECUTESCRIPTPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_IEXECUTESCRIPTPLUGIN_H
 
 #include <QObject>
 #include <QtCore/QString>
@@ -53,6 +53,7 @@ public:
     //virtual bool useTerminal( KDevelop::ILaunchConfiguration* ) const = 0;
     virtual QString scriptAppConfigTypeId() const = 0;
     virtual int outputFilterModeId( KDevelop::ILaunchConfiguration* ) const = 0;
+    virtual bool runCurrentFile( KDevelop::ILaunchConfiguration* ) const = 0;
 };
 
 Q_DECLARE_INTERFACE( IExecuteScriptPlugin, "org.kdevelop.IExecuteScriptPlugin" )
