@@ -18,8 +18,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#ifndef EXTERNALSCRIPTITEM_H
-#define EXTERNALSCRIPTITEM_H
+#ifndef KDEVPLATFORM_PLUGIN_EXTERNALSCRIPTITEM_H
+#define KDEVPLATFORM_PLUGIN_EXTERNALSCRIPTITEM_H
 
 #include <QStandardItemModel>
 
@@ -80,6 +80,16 @@ public:
    */
   void setSaveMode( SaveMode mode );
 
+  /**
+   * @return what type of filter should be applied to the execution of the external script
+   **/
+  int filterMode() const;
+
+  /**
+   * Sets the filtering mode 
+   **/
+  void setFilterMode( int mode );
+
   /// Defines what should be done with the @c STDOUT of a script run.
   enum OutputMode {
     /// Ignore output and do nothing.
@@ -196,11 +206,12 @@ private:
   InputMode m_inputMode;
   KAction* m_action;
   bool m_showOutput;
+  int m_filterMode;
   bool m_performReplacements;
 };
 
 Q_DECLARE_METATYPE(ExternalScriptItem*)
 
-#endif // EXTERNALSCRIPTITEM_H
+#endif // KDEVPLATFORM_PLUGIN_EXTERNALSCRIPTITEM_H
 
 // kate: indent-mode cstyle; space-indent on; indent-width 2; replace-tabs on; 
