@@ -21,7 +21,6 @@
 #include "externalscriptjob.h"
 
 #include "externalscriptitem.h"
-#include "externalscriptoutputmodel.h"
 #include "externalscriptdebug.h"
 #include "externalscriptplugin.h"
 
@@ -45,15 +44,15 @@
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iproject.h>
+#include <project/projectmodel.h>
+#include <util/path.h>
 
-
-ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, ExternalScriptPlugin* parent )
+ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, const KUrl& url, ExternalScriptPlugin* parent )
     : KDevelop::OutputJob( parent ),
-    m_plugin( parent ),
     m_proc( 0 ), m_lineMaker( 0 ),
     m_outputMode( item->outputMode() ), m_inputMode( item->inputMode() ),
     m_errorMode( item->errorMode() ), m_filterMode( item->filterMode() ),
-    m_document( 0 ), m_selectionRange( KTextEditor::Range::invalid() ),
+    m_document( 0 ), m_url( url ), m_selectionRange( KTextEditor::Range::invalid() ),
     m_showOutput( item->showOutput() )
 {
   debug() << "creating external script job";
@@ -62,7 +61,7 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, ExternalScriptPl
   setStandardToolView( KDevelop::IOutputView::RunView );
   setBehaviours( KDevelop::IOutputView::AllowUserClose | KDevelop::IOutputView::AutoScroll );
 
-  ExternalScriptOutputModel* model = new ExternalScriptOutputModel;
+  KDevelop::OutputModel* model = new KDevelop::OutputModel;
   model->setFilteringStrategy(static_cast<KDevelop::OutputModel::OutputFilterStrategy>(m_filterMode));
   setModel( model );
 
@@ -123,33 +122,58 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, ExternalScriptPl
   if(item->performParameterReplacement())
     command.replace( "%i", QString::number( QCoreApplication::applicationPid() ) );
 
-  if ( active ) {
-    const KUrl url = active->url();
+  if ( !m_url.isEmpty() ) {
+    const KUrl url = m_url;
 
-    if ( url.isLocalFile() && workingDir.isEmpty() ) {
-      ///TODO: make configurable, use fallback to project dir
-      workingDir = active->url().directory();
+    KDevelop::ProjectFolderItem* folder = 0;
+    if ( KDevelop::ICore::self()->projectController()->findProjectForUrl( url ) ) {
+      QList<KDevelop::ProjectFolderItem*> folders = KDevelop::ICore::self()->projectController()->findProjectForUrl(url)->foldersForUrl(url);
+      if ( !folders.isEmpty() ) {
+        folder = folders.first();
+      }
     }
 
-    ///TODO: make those placeholders escapeable
-    if(item->performParameterReplacement())
-    {
-      command.replace( "%u", KShell::quoteArg( url.pathOrUrl() ) );
-
-      ///TODO: does that work with remote files?
-      QFileInfo info( url.pathOrUrl() );
-
-      command.replace( "%f", KShell::quoteArg( info.filePath() ) );
-      command.replace( "%b", KShell::quoteArg( info.baseName() ) );
-      command.replace( "%n", KShell::quoteArg( info.fileName() ) );
-      command.replace( "%d", KShell::quoteArg( info.path() ) );
-
-      if ( active->textDocument() && active->textDocument()->activeView() && active->textDocument()->activeView()->selection() ) {
-        command.replace( "%s", KShell::quoteArg( active->textDocument()->activeView()->selectionText() ) );
+    if ( folder ) {
+      if ( folder->path().isLocalFile() && workingDir.isEmpty() ) {
+        ///TODO: make configurable, use fallback to project dir
+        workingDir = folder->path().toLocalFile();
       }
 
-      if ( KDevelop::IProject* project = KDevelop::ICore::self()->projectController()->findProjectForUrl( url ) ) {
-        command.replace( "%p", project->folder().pathOrUrl() );
+      ///TODO: make those placeholders escapeable
+      if(item->performParameterReplacement())
+      {
+        command.replace( "%d", KShell::quoteArg( m_url.pathOrUrl() ) );
+
+        if ( KDevelop::IProject* project = KDevelop::ICore::self()->projectController()->findProjectForUrl( m_url ) ) {
+          command.replace( "%p", project->folder().pathOrUrl() );
+        }
+      }
+    } else {
+      if ( m_url.isLocalFile() && workingDir.isEmpty() ) {
+        ///TODO: make configurable, use fallback to project dir
+        workingDir = active->url().directory();
+      }
+
+      ///TODO: make those placeholders escapeable
+      if(item->performParameterReplacement())
+      {
+        command.replace( "%u", KShell::quoteArg( m_url.pathOrUrl() ) );
+
+        ///TODO: does that work with remote files?
+        QFileInfo info( m_url.pathOrUrl() );
+
+        command.replace( "%f", KShell::quoteArg( info.filePath() ) );
+        command.replace( "%b", KShell::quoteArg( info.baseName() ) );
+        command.replace( "%n", KShell::quoteArg( info.fileName() ) );
+        command.replace( "%d", KShell::quoteArg( info.path() ) );
+
+        if ( active->textDocument() && active->textDocument()->activeView() && active->textDocument()->activeView()->selection() ) {
+          command.replace( "%s", KShell::quoteArg( active->textDocument()->activeView()->selectionText() ) );
+        }
+
+        if ( KDevelop::IProject* project = KDevelop::ICore::self()->projectController()->findProjectForUrl( m_url ) ) {
+          command.replace( "%p", project->folder().pathOrUrl() );
+        }
       }
     }
   }
@@ -160,9 +184,13 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, ExternalScriptPl
   }
   m_lineMaker = new KDevelop::ProcessLineMaker( m_proc, this );
   connect( m_lineMaker, SIGNAL(receivedStdoutLines(QStringList)),
-           model, SLOT(appendStdoutLines(QStringList)) );
+           model, SLOT(appendLines(QStringList)) );
+  connect( m_lineMaker, SIGNAL(receivedStdoutLines(QStringList)),
+           this, SLOT(receivedStdoutLines(QStringList)) );
   connect( m_lineMaker, SIGNAL(receivedStderrLines(QStringList)),
-           model, SLOT(appendStderrLines(QStringList)) );
+           model, SLOT(appendLines(QStringList)) );
+  connect( m_lineMaker, SIGNAL(receivedStderrLines(QStringList)),
+           this, SLOT(receivedStderrLines(QStringList)) );
   connect( m_proc, SIGNAL(error(QProcess::ProcessError)),
            SLOT(processError(QProcess::ProcessError)) );
   connect( m_proc, SIGNAL(finished(int,QProcess::ExitStatus)),
@@ -244,15 +272,9 @@ void ExternalScriptJob::processFinished( int exitCode , QProcess::ExitStatus sta
   m_lineMaker->flushBuffers();
 
   if ( exitCode == 0 && status == QProcess::NormalExit ) {
-
-    ExternalScriptOutputModel* model = dynamic_cast<ExternalScriptOutputModel*>(OutputJob::model());
-    Q_ASSERT(model);
-
     if ( m_outputMode != ExternalScriptItem::OutputNone ) {
-      QStringList lines = model->stdOut();
-
-      if ( !lines.isEmpty() ) {
-        QString output = lines.join( "\n" );
+      if ( !m_stdout.isEmpty() ) {
+        QString output = m_stdout.join( "\n" );
         switch ( m_outputMode ) {
           case ExternalScriptItem::OutputNone:
             // do nothing;
@@ -284,7 +306,7 @@ void ExternalScriptJob::processFinished( int exitCode , QProcess::ExitStatus sta
       }
     }
     if ( m_errorMode != ExternalScriptItem::ErrorNone && m_errorMode != ExternalScriptItem::ErrorMergeOutput ) {
-      QString output = model->stdErr().join( "\n" );
+      QString output = m_stderr.join( "\n" );
 
       if ( !output.isEmpty() ) {
         switch ( m_errorMode ) {
@@ -339,9 +361,9 @@ void ExternalScriptJob::processError( QProcess::ProcessError error )
 {
   if ( error == QProcess::FailedToStart ) {
     setError( -1 );
-    QString errmsg =  i18n( "Could not start program '%1'. Make sure that the "
-                            "path is specified correctly.", m_proc->program().join( " " ) );
-    KMessageBox::error( QApplication::activeWindow(), errmsg, i18n( "Could not start application" ) );
+    QString errmsg =  i18n("*** Could not start program '%1'. Make sure that the "
+                           "path is specified correctly ***", m_proc->program().join(" ") );
+    appendLine( errmsg );
     setErrorText( errmsg );
     emitResult();
   }
@@ -361,6 +383,15 @@ KDevelop::OutputModel* ExternalScriptJob::model()
   return dynamic_cast<KDevelop::OutputModel*>( OutputJob::model() );
 }
 
+void ExternalScriptJob::receivedStderrLines(const QStringList& lines)
+{
+  m_stderr += lines;
+}
+
+void ExternalScriptJob::receivedStdoutLines(const QStringList& lines)
+{
+  m_stdout += lines;
+}
 
 #include "externalscriptjob.moc"
 
