@@ -30,6 +30,9 @@
 #include <QFileInfo>
 #include <QDir>
 #include <QDateTime>
+#include <QFileSystemWatcher>
+#include <QTimer>
+#include <QTextCodec>
 
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
@@ -51,8 +54,11 @@
 #include <KMessageBox>
 #include <KStandardDirs>
 #include <KTextEdit>
+#include <KDirWatch>
+#include <KTextEditor/Document>
 #include "gitjob.h"
 #include "gitmessagehighlighter.h"
+#include "gitplugincheckinrepositoryjob.h"
 
 K_PLUGIN_FACTORY(KDevGitFactory, registerPlugin<GitPlugin>(); )
 K_EXPORT_PLUGIN(KDevGitFactory(KAboutData("kdevgit","kdevgit",ki18n("Git"),"0.1",ki18n("A plugin to support git version control systems"), KAboutData::License_GPL)))
@@ -139,7 +145,7 @@ QString revisionInterval(const KDevelop::VcsRevision& rev, const KDevelop::VcsRe
 {
     QString ret;
     if(rev.revisionType()==VcsRevision::Special &&
-                rev.revisionValue().value<VcsRevision::RevisionSpecialType>()==VcsRevision::Start) //if we want it to the begining just put the revisionInterval
+                rev.revisionValue().value<VcsRevision::RevisionSpecialType>()==VcsRevision::Start) //if we want it to the beginning just put the revisionInterval
         ret = toRevisionName(limit, QString());
     else {
         QString dst = toRevisionName(limit);
@@ -169,7 +175,7 @@ QDir urlDir(const KUrl::List& urls) { return urlDir(urls.first()); } //TODO: cou
 }
 
 GitPlugin::GitPlugin( QObject *parent, const QVariantList & )
-    : DistributedVersionControlPlugin(parent, KDevGitFactory::componentData()), m_oldVersion(false)
+    : DistributedVersionControlPlugin(parent, KDevGitFactory::componentData()), m_oldVersion(false), m_usePrefix(true)
 {
     if (KStandardDirs::findExe("git").isEmpty()) {
         m_hasError = true;
@@ -182,13 +188,16 @@ GitPlugin::GitPlugin( QObject *parent, const QVariantList & )
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IBranchingVersionControl )
 
     m_hasError = false;
-    core()->uiController()->addToolView(i18n("Git"), dvcsViewFactory());
     setObjectName("Git");
     
     DVcsJob* versionJob = new DVcsJob(QDir::tempPath(), this, KDevelop::OutputJob::Silent);
     *versionJob << "git" << "--version";
     connect(versionJob, SIGNAL(readyForParsing(KDevelop::DVcsJob*)), SLOT(parseGitVersionOutput(KDevelop::DVcsJob*)));
     ICore::self()->runController()->registerJob(versionJob);
+    
+    m_watcher = new KDirWatch(this);
+    connect(m_watcher, SIGNAL(dirty(QString)), SLOT(fileChanged(QString)));
+    connect(m_watcher, SIGNAL(created(QString)), SLOT(fileChanged(QString)));
 }
 
 GitPlugin::~GitPlugin()
@@ -213,6 +222,11 @@ bool GitPlugin::hasModifications(const QDir& d)
     return !emptyOutput(lsFiles(d, QStringList("-m"), OutputJob::Silent));
 }
 
+bool GitPlugin::hasModifications(const QDir& repo, const KUrl& file)
+{
+    return !emptyOutput(lsFiles(repo, QStringList() << "-m" << file.path(), OutputJob::Silent));
+}
+
 void GitPlugin::additionalMenuEntries(QMenu* menu, const KUrl::List& urls)
 {
     m_urls = urls;
@@ -252,12 +266,6 @@ DVcsJob* GitPlugin::errorsFound(const QString& error, KDevelop::OutputJob::Outpu
     return j;
 }
 
-void GitPlugin::unload()
-{
-    core()->uiController()->removeToolView( dvcsViewFactory() );
-}
-
-
 QString GitPlugin::name() const
 {
     return QLatin1String("Git");
@@ -272,7 +280,7 @@ bool GitPlugin::isValidDirectory(const KUrl & dirPath)
 {
     QDir dir=dotGitDirectory(dirPath);
 
-    return dir.exists(".git");
+    return dir.cd(".git") && dir.exists("HEAD");
 }
 
 bool GitPlugin::isVersionControlled(const KUrl &path)
@@ -331,6 +339,7 @@ KDevelop::VcsJob* GitPlugin::status(const KUrl::List& localLocations, KDevelop::
         connect(job, SIGNAL(readyForParsing(KDevelop::DVcsJob*)), SLOT(parseGitStatusOutput_old(KDevelop::DVcsJob*)));
     } else {
         *job << "git" << "status" << "--porcelain";
+        job->setIgnoreError(true);
         connect(job, SIGNAL(readyForParsing(KDevelop::DVcsJob*)), SLOT(parseGitStatusOutput(KDevelop::DVcsJob*)));
     }
     *job << "--" << (recursion == IBasicVersionControl::Recursive ? localLocations : preventRecursion(localLocations));
@@ -345,7 +354,12 @@ VcsJob* GitPlugin::diff(const KUrl& fileOrDirectory, const KDevelop::VcsRevision
     
     DVcsJob* job = new GitJob(dotGitDirectory(fileOrDirectory), this, KDevelop::OutputJob::Silent);
     job->setType(VcsJob::Diff);
-    *job << "git" << "diff" << "--no-prefix" << "--no-color" << "--no-ext-diff";
+    *job << "git" << "diff" << "--no-color" << "--no-ext-diff";
+    if (!usePrefix()) {
+        // KDE's ReviewBoard now requires p1 patchfiles, so `git diff --no-prefix` to generate p0 patches
+        // has become optional.
+        *job << "--no-prefix";
+    }
     if(srcRevision.revisionType()==VcsRevision::Special
         && dstRevision.revisionType()==VcsRevision::Special
         && srcRevision.specialType()==VcsRevision::Base
@@ -368,6 +382,21 @@ VcsJob* GitPlugin::revert(const KUrl::List& localLocations, IBasicVersionControl
     if(localLocations.isEmpty() )
         return errorsFound(i18n("Could not revert changes"), OutputJob::Verbose);
     
+    QDir repo = urlDir(repositoryRoot(localLocations.first()));
+    QString modified;
+    for (const auto& file: localLocations) {
+        if (hasModifications(repo, file)) {
+            modified.append(file.pathOrUrl() + "<br/>");
+        }
+    }
+    if (!modified.isEmpty()) {
+        auto res = KMessageBox::questionYesNo(nullptr, i18n("The following files have uncommited changes, "
+                                              "which will be lost. Continue?") + "<br/><br/>" + modified);
+        if (res != KMessageBox::Yes) {
+            return errorsFound(QString(), OutputJob::Silent);
+        }
+    }
+
     DVcsJob* job = new GitJob(dotGitDirectory(localLocations.front()), this);
     job->setType(VcsJob::Revert);
     *job << "git" << "checkout" << "--";
@@ -448,7 +477,6 @@ VcsJob* GitPlugin::remove(const KUrl::List& files)
         QFileInfo fileInfo(file.toLocalFile());
 
         QStringList otherStr = getLsFiles(dotGitDir, QStringList() << "--others" << "--" << file.toLocalFile(), KDevelop::OutputJob::Silent);
-        kDebug() << "other files" << otherStr;
         if(!otherStr.isEmpty()) {
             //remove files not under version control
             KUrl::List otherFiles;
@@ -459,6 +487,7 @@ VcsJob* GitPlugin::remove(const KUrl::List& files)
                 //if it's an unversioned file we are done, don't use git rm on it
                 i.remove();
             }
+            kDebug() << "other files" << otherFiles;
             KIO::NetAccess::synchronousRun(KIO::trash(otherFiles), 0);
         }
 
@@ -477,7 +506,9 @@ VcsJob* GitPlugin::remove(const KUrl::List& files)
 
     DVcsJob* job = new GitJob(dotGitDir, this);
     job->setType(VcsJob::Remove);
-    *job << "git" << "rm" << "-r";
+    // git refuses to delete files with local modifications
+    // use --force to overcome this
+    *job << "git" << "rm" << "-r" << "--force";
     *job << "--" << files_;
     return job;
 }
@@ -487,7 +518,7 @@ VcsJob* GitPlugin::log(const KUrl& localLocation,
 {
     DVcsJob* job = new GitJob(dotGitDirectory(localLocation), this, KDevelop::OutputJob::Silent);
     job->setType(VcsJob::Log);
-    *job << "git" << "log" << "--date=raw" /*<< "--numstat"*/;
+    *job << "git" << "log" << "--date=raw" << "--name-status" << "-M80%" << "--follow";
     QString rev = revisionInterval(dst, src);
     if(!rev.isEmpty())
         *job << rev;
@@ -501,7 +532,10 @@ VcsJob* GitPlugin::log(const KUrl& localLocation, const KDevelop::VcsRevision& r
 {
     DVcsJob* job = new GitJob(dotGitDirectory(localLocation), this, KDevelop::OutputJob::Silent);
     job->setType(VcsJob::Log);
-    *job << "git" << "log" << "--date=raw" /*<< "--numstat"*/ << toRevisionName(rev, QString());
+    *job << "git" << "log" << "--date=raw" << "--name-status" << "-M80%" << "--follow";
+    QString revStr = toRevisionName(rev, QString());
+    if(!revStr.isEmpty())
+        *job << revStr;
     if(limit>0)
         *job << QString("-%1").arg(limit);
     
@@ -649,7 +683,8 @@ VcsJob* GitPlugin::renameBranch(const KUrl& repository, const QString& oldBranch
 VcsJob* GitPlugin::currentBranch(const KUrl& repository)
 {
     DVcsJob* job = new DVcsJob(urlDir(repository), this, OutputJob::Silent);
-    *job << "git" << "symbolic-ref" << "HEAD";
+    job->setIgnoreError(true);
+    *job << "git" << "symbolic-ref" << "-q" << "--short" << "HEAD";
     connect(job, SIGNAL(readyForParsing(KDevelop::DVcsJob*)), SLOT(parseGitCurrentBranch(KDevelop::DVcsJob*)));
     return job;
 }
@@ -657,7 +692,8 @@ VcsJob* GitPlugin::currentBranch(const KUrl& repository)
 void GitPlugin::parseGitCurrentBranch(DVcsJob* job)
 {
     QString out = job->output().trimmed();
-    job->setResults(out.right(out.size()-11));
+
+    job->setResults(out);
 }
 
 VcsJob* GitPlugin::branches(const KUrl &repository)
@@ -679,7 +715,11 @@ void GitPlugin::parseGitBranchOutput(DVcsJob* job)
         // "git rev-list" chokes on these entries and we do not need duplicate branches altogether.
         if (branch.contains("->"))
             continue;
-        
+
+        // Skip entries such as '(no branch)'
+        if (branch.contains("(no branch)"))
+            continue;
+
         if (branch.startsWith('*'))
             branch = branch.right(branch.size()-2);
         
@@ -944,11 +984,24 @@ void GitPlugin::parseLogOutput(const DVcsJob * job, QList<DVcsEvent>& commits) c
     }
 }
 
+VcsItemEvent::Actions actionsFromString(char c)
+{
+    switch(c) {
+        case 'A': return VcsItemEvent::Added;
+        case 'D': return VcsItemEvent::Deleted;
+        case 'R': return VcsItemEvent::Replaced;
+        case 'M': return VcsItemEvent::Modified;
+    }
+    return VcsItemEvent::Modified;
+}
+
 void GitPlugin::parseGitLogOutput(DVcsJob * job)
 {
     static QRegExp commitRegex( "^commit (\\w{8})\\w{32}" );
     static QRegExp infoRegex( "^(\\w+):(.*)" );
-    static QRegExp modificationsRegex("(\\d+)\\s+(\\d+)\\s+(.+)"); //18      2       shell/workingsets/workingsetwidget.cpp
+    static QRegExp modificationsRegex("^([A-Z])[0-9]*\t([^\t]+)\t?(.*)", Qt::CaseSensitive, QRegExp::RegExp2);
+    //R099    plugins/git/kdevgit.desktop     plugins/git/kdevgit.desktop.cmake
+    //M       plugins/grepview/CMakeLists.txt
 
     QList<QVariant> commits;
 
@@ -973,6 +1026,7 @@ void GitPlugin::parseGitLogOutput(DVcsJob * job)
             if (pushCommit) {
                 item.setMessage(message.trimmed());
                 commits.append(QVariant::fromValue(item));
+                item.setItems(QList<VcsItemEvent>());
             } else {
                 pushCommit = true;
             }
@@ -988,17 +1042,16 @@ void GitPlugin::parseGitLogOutput(DVcsJob * job)
                 item.setDate(QDateTime::fromTime_t(infoRegex.cap(2).trimmed().split(' ')[0].toUInt()));
             }
         } else if (modificationsRegex.exactMatch(line)) {
-            int additions = modificationsRegex.cap(1).toUInt();
-            int removals = modificationsRegex.cap(2).toUInt();
-            QString filename = modificationsRegex.cap(3);
-            
-            VcsItemEvent::Actions a;
-            if(additions>0 || removals>0)
-                a=VcsItemEvent::Modified;
+            VcsItemEvent::Actions a = actionsFromString(modificationsRegex.cap(1)[0].toAscii());
+            QString filenameA = modificationsRegex.cap(2);
             
             VcsItemEvent itemEvent;
             itemEvent.setActions(a);
-            itemEvent.setRepositoryLocation(filename);
+            itemEvent.setRepositoryLocation(filenameA);
+            if(a==VcsItemEvent::Replaced) {
+                QString filenameB = modificationsRegex.cap(3);
+                itemEvent.setRepositoryCopySourceLocation(filenameB);
+            }
             
             item.addItem(itemEvent);
         } else if (line.startsWith("    ")) {
@@ -1017,6 +1070,7 @@ void GitPlugin::parseGitDiffOutput(DVcsJob* job)
     VcsDiff diff;
     diff.setDiff(job->output());
     diff.setBaseDiff(repositoryRoot(KUrl(job->directory().absolutePath())));
+    diff.setDepth(usePrefix()? 1 : 0);
     
     job->setResults(qVariantFromValue(diff));
 }
@@ -1190,9 +1244,11 @@ VcsStatusInfo::State GitPlugin::messageToState(const QString& msg)
             ret = VcsStatusInfo::ItemAdded;
             break;
         case 'R':
-        case 'C':
             ret = VcsStatusInfo::ItemModified;
             break;
+        case 'C':
+            ret = VcsStatusInfo::ItemHasConflicts;
+            break;
         case ' ':
             ret = msg[1] == 'M' ? VcsStatusInfo::ItemModified : VcsStatusInfo::ItemDeleted;
             break;
@@ -1239,6 +1295,16 @@ VcsJob* GitPlugin::copy(const KUrl& localLocationSrc, const KUrl& localLocationD
 VcsJob* GitPlugin::move(const KUrl& source, const KUrl& destination)
 {
     QDir dir = urlDir(source);
+
+    QFileInfo fileInfo(source.toLocalFile());
+    if (fileInfo.isDir()) {
+        if (isEmptyDirStructure(QDir(source.toLocalFile()))) {
+            //move empty folder, git doesn't do that
+            kDebug() << "empty folder" << source;
+            return new StandardJob(this, KIO::move(source, destination), KDevelop::OutputJob::Silent);
+        }
+    }
+
     QStringList otherStr = getLsFiles(dir, QStringList() << "--others" << "--" << source.toLocalFile(), KDevelop::OutputJob::Silent);
     if(otherStr.isEmpty()) {
         DVcsJob* job = new DVcsJob(dir, this, KDevelop::OutputJob::Verbose);
@@ -1267,7 +1333,7 @@ VcsJob* GitPlugin::pull(const KDevelop::VcsLocation& localOrRepoLocationSrc, con
 {
     DVcsJob* job = new DVcsJob(urlDir(localRepositoryLocation), this);
     job->setCommunicationMode(KProcess::MergedChannels);
-    *job << "git" << "pull";
+    *job << "git" << "-c" << "color.diff=false" << "pull";
     if(!localOrRepoLocationSrc.localUrl().isEmpty())
         *job << localOrRepoLocationSrc.localUrl().url();
     return job;
@@ -1344,3 +1410,37 @@ QString GitPlugin::errorDescription() const
 {
     return m_errorDescription;
 }
+
+void GitPlugin::registerRepositoryForCurrentBranchChanges(const KUrl& repository)
+{
+    QDir dir = dotGitDirectory(repository);
+    QString headFile = dir.absoluteFilePath(".git/HEAD");
+    m_watcher->addFile(headFile);
+}
+
+void GitPlugin::fileChanged(const QString& file)
+{
+    Q_ASSERT(file.endsWith("HEAD"));
+    KUrl fileUrl(KUrl::fromPath(file));
+    fileUrl = fileUrl.upUrl(); //SMTH/.git/HEAD -> SMTH/.git/
+    fileUrl = fileUrl.upUrl(); //SMTH/.git/ -> SMTH/
+    
+    //We need to delay the emitted signal, otherwise the branch hasn't change yet
+    //and the repository is not functional
+    m_branchesChange.append(fileUrl);
+    QTimer::singleShot(1000, this, SLOT(delayedBranchChanged()));
+}
+
+void GitPlugin::delayedBranchChanged()
+{
+    emit repositoryBranchChanged(m_branchesChange.takeFirst());
+}
+
+CheckInRepositoryJob* GitPlugin::isInRepository(KTextEditor::Document* document)
+{
+    CheckInRepositoryJob* job = new GitPluginCheckInRepositoryJob(document, repositoryRoot(document->url()).path());
+    job->start();
+    return job;
+}
+
+
