@@ -19,16 +19,19 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#ifndef GIT_PLUGIN_H
-#define GIT_PLUGIN_H
+#ifndef KDEVPLATFORM_PLUGIN_GIT_PLUGIN_H
+#define KDEVPLATFORM_PLUGIN_GIT_PLUGIN_H
 
 #include <vcs/interfaces/idistributedversioncontrol.h>
+#include <vcs/interfaces/icontentawareversioncontrol.h>
 #include <vcs/dvcs/dvcsplugin.h>
 #include <QObject>
+#include <QProcess>
 #include <vcs/vcsstatusinfo.h>
 #include <outputview/outputjob.h>
 #include <vcs/vcsjob.h>
 
+class KDirWatch;
 class QDir;
 
 namespace KDevelop
@@ -63,17 +66,15 @@ class StandardJob : public KDevelop::VcsJob
  * It implements the DVCS dependent things not implemented in KDevelop::DistributedVersionControlPlugin
  * @author Evgeniy Ivanov <powerfox@kde.ru>
  */
-class GitPlugin: public KDevelop::DistributedVersionControlPlugin
+class GitPlugin: public KDevelop::DistributedVersionControlPlugin, public KDevelop::IContentAwareVersionControl
 {
     Q_OBJECT
-    Q_INTERFACES(KDevelop::IBasicVersionControl KDevelop::IDistributedVersionControl)
+    Q_INTERFACES(KDevelop::IBasicVersionControl KDevelop::IDistributedVersionControl KDevelop::IContentAwareVersionControl)
     friend class GitInitTest;
 public:
     GitPlugin(QObject *parent, const QVariantList & args = QVariantList() );
     ~GitPlugin();
    
-    virtual void unload();
-
     QString name() const;
 
     bool isVersionControlled(const KUrl &path);
@@ -136,9 +137,26 @@ public:
     
     bool hasStashes(const QDir& repository);
     bool hasModifications(const QDir& repository);
+    bool hasModifications(const QDir& repo, const KUrl& file);
 
     virtual bool hasError() const;
     virtual QString errorDescription() const;
+    virtual void registerRepositoryForCurrentBranchChanges(const KUrl& repository);
+
+    KDevelop::CheckInRepositoryJob* isInRepository(KTextEditor::Document* document);
+
+    // this indicates whether the diff() function will generate a diff (patch) which
+    // includes the working copy directory name or not (in which case git diff is called
+    // with --no-prefix).
+    bool usePrefix() const
+    {
+        return m_usePrefix;
+    }
+
+    void setUsePrefix(bool p)
+    {
+        m_usePrefix = p;
+    }
 protected:
   
     KUrl repositoryRoot(const KUrl& path);
@@ -169,6 +187,12 @@ private slots:
     void ctxPopStash();
     void ctxStashManager();
 
+    void fileChanged(const QString& file);
+    void delayedBranchChanged();
+
+signals:
+    void repositoryBranchChanged(const KUrl& repository);
+
 private:
     void addNotVersionedFiles(const QDir& dir, const KUrl::List& files);
     
@@ -189,6 +213,9 @@ private:
 
     bool m_hasError;
     QString m_errorDescription;
+    KDirWatch* m_watcher;
+    KUrl::List m_branchesChange;
+    bool m_usePrefix;
 };
 
 QVariant runSynchronously(KDevelop::VcsJob* job);
