@@ -11,8 +11,8 @@
 *                                                                         *
 ***************************************************************************/
 
-#ifndef GREPDIALOG_H
-#define GREPDIALOG_H
+#ifndef KDEVPLATFORM_PLUGIN_GREPDIALOG_H
+#define KDEVPLATFORM_PLUGIN_GREPDIALOG_H
 
 #include <kdialog.h>
 #include "ui_grepwidget.h"
@@ -30,11 +30,10 @@ class GrepDialog : public KDialog, private Ui::GrepWidget
 public:
     static const KDialog::ButtonCode SearchButton;
     
-    explicit GrepDialog( GrepViewPlugin * plugin, QWidget *parent=0, bool setLastUsed=false );
+    explicit GrepDialog( GrepViewPlugin * plugin, QWidget *parent=0 );
     ~GrepDialog();
 
     void setPattern(const QString &pattern);
-    void setDirectory(const QString &dir);
     void setEnableProjectBox(bool enable);
 
     QString patternString() const;
@@ -42,21 +41,40 @@ public:
     QString replacementTemplateString() const;
     QString filesString() const;
     QString excludeString() const;
-    KUrl directory() const;
 
     bool useProjectFilesFlag() const;
     bool regexpFlag() const;
-    bool recursiveFlag() const;
     bool caseSensitiveFlag() const;
 
+    int depthValue() const;
+
+    void start();
+    
+public Q_SLOTS:
+    ///Sets directory(ies)/files to search in. Also it can be semicolon separated list of directories/files or one of special strings: allOpenFilesString, allOpenProjectsString
+    void setSearchLocations(const QString &dir);
+
 private Q_SLOTS:
+
     void performAction(KDialog::ButtonCode button);
     void templateTypeComboActivated(int);
-    void syncButtonClicked();
     void patternComboEditTextChanged( const QString& );
     void directoryChanged(const QString &dir);
+    QMenu* createSyncButtonMenu();
+    void addUrlToMenu(QMenu* ret, KUrl url);
+    void addStringToMenu(QMenu* ret, QString string);
+    void synchronizeDirActionTriggered(bool);
+
+    ///Opens the dialog to select a directory to search in, and inserts it into Location(s) field.
+    void selectDirectoryDialog();
 
 private:
+    // Returns the chosen directories or files (only the top directories, not subfiles)
+    QList< KUrl > getDirectoryChoice() const;
+    // Returns whether the given url is a subfile/subdirectory of one of the chosen directories/files
+    // This is slow, so don't call it too often
+    bool isPartOfChoice(KUrl url) const;
+    
     GrepViewPlugin * m_plugin;
 };
 
