@@ -9,8 +9,8 @@
  ***************************************************************************/
 
 // some utility functions used at various places
-#ifndef GREPUTIL_H
-#define GREPUTIL_H
+#ifndef KDEVPLATFORM_PLUGIN_GREPUTIL_H
+#define KDEVPLATFORM_PLUGIN_GREPUTIL_H
 
 #include <QStringList>
 #include <QString>
@@ -20,7 +20,7 @@ class QComboBox;
 /// Returns the contents of a QComboBox as a QStringList
 QStringList qCombo2StringList( QComboBox* combo, bool allowEmpty = false );
 
-/// Replaces each occurence of "%s" in pattern by searchString (and "%%" by "%")
+/// Replaces each occurrence of "%s" in pattern by searchString (and "%%" by "%")
 QString substitudePattern(const QString& pattern, const QString& searchString);
 
 #endif
