@@ -9,8 +9,8 @@
 *                                                                         *
 ***************************************************************************/
 
-#ifndef KDEVKONSOLEVIEW_H
-#define KDEVKONSOLEVIEW_H
+#ifndef KDEVPLATFORM_PLUGIN_KDEVKONSOLEVIEW_H
+#define KDEVPLATFORM_PLUGIN_KDEVKONSOLEVIEW_H
 
 #include <QWidget>
 
@@ -30,6 +30,9 @@ public:
 public slots:
     void setDirectory( const KUrl &dirUrl );
 
+protected:
+    virtual bool eventFilter( QObject *obj, QEvent *e );
+
 private :
     class KDevKonsoleViewPrivate* const d;
 
