@@ -30,6 +30,7 @@
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/context.h>
 #include <project/projectmodel.h>
+#include <util/path.h>
 #include <kmimetype.h>
 #include <kservice.h>
 #include <kservicetypetrader.h>
@@ -48,8 +49,42 @@
 using namespace KDevelop;
 
 K_PLUGIN_FACTORY(KDevOpenWithFactory, registerPlugin<OpenWithPlugin>(); )
-K_EXPORT_PLUGIN(KDevOpenWithFactory(KAboutData("kdevopenwith","kdevopenwith", ki18n("Open With"), "0.1", ki18n("Open files with external applications."), KAboutData::License_GPL)))
+K_EXPORT_PLUGIN(KDevOpenWithFactory(KAboutData("kdevopenwith","kdevopenwith", ki18n("Open With"), "0.1", ki18n("This plugin allows to open files with associated external applications."), KAboutData::License_GPL)))
 
+namespace {
+
+bool sortActions(QAction* left, QAction* right)
+{
+    return left->text() < right->text();
+}
+
+bool isTextEditor(const KService::Ptr& service)
+{
+    return service->serviceTypes().contains( "KTextEditor/Document" );
+}
+
+QString defaultForMimeType(const QString& mimeType)
+{
+    KConfigGroup config = KGlobal::config()->group("Open With Defaults");
+    if (config.hasKey(mimeType)) {
+        QString storageId = config.readEntry(mimeType, QString());
+        if (!storageId.isEmpty() && KService::serviceByStorageId(storageId)) {
+            return storageId;
+        }
+    }
+    return QString();
+}
+
+bool canOpenDefault(const QString& mimeType)
+{
+    if (defaultForMimeType(mimeType).isEmpty() && mimeType == "inode/directory") {
+        // potentially happens in non-kde environments apparently, see https://git.reviewboard.kde.org/r/122373
+        return KMimeTypeTrader::self()->preferredService(mimeType);
+    } else {
+        return true;
+    }
+}
+}
 
 OpenWithPlugin::OpenWithPlugin ( QObject* parent, const QVariantList& )
     : IPlugin ( KDevOpenWithFactory::componentData(), parent ),
@@ -78,9 +113,13 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
     if ( filectx && filectx->urls().count() > 0 ) {
         m_urls = filectx->urls();
     } else if ( projctx && projctx->items().count() > 0 ) {
+        // For now, let's handle *either* files only *or* directories only
+        const int wantedType = projctx->items().first()->type();
         foreach( ProjectBaseItem* item, projctx->items() ) {
-            if( item->file() ) {
-                m_urls << item->file()->url();
+            if (wantedType == ProjectBaseItem::File && item->file()) {
+                m_urls << item->file()->path().toUrl();
+            } else if ((wantedType == ProjectBaseItem::Folder || wantedType == ProjectBaseItem::BuildFolder) && item->folder()) {
+                m_urls << item->folder()->path().toUrl();
             }
         }
     }
@@ -95,10 +134,6 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
     // Ok, lets fetch the mimetype for the !!first!! url and the relevant services
     // TODO: Think about possible alternatives to using the mimetype of the first url.
     KMimeType::Ptr mimetype = KMimeType::findByUrl( m_urls.first() );
-    if (mimetype->is("inode/directory")) {
-        return KDevelop::ContextMenuExtension();
-    }
-
     m_mimeType = mimetype->name();
 
     QList<QAction*> partActions = actionsForServiceType("KParts/ReadOnlyPart");
@@ -115,41 +150,30 @@ KDevelop::ContextMenuExtension OpenWithPlugin::contextMenuExtension( KDevelop::C
     KMenu* menu = new KMenu( i18n("Open With" ) );
     menu->setIcon( SmallIcon( "document-open" ) );
 
-    menu->addTitle(i18n("Embedded Editors"));
-    menu->addActions( partActions );
-    menu->addTitle(i18n("External Applications"));
-    menu->addActions( appActions );
-
-    KAction* openAction = new KAction( i18n( "Open" ), this );
-    openAction->setIcon( SmallIcon( "document-open" ) );
-    connect( openAction, SIGNAL(triggered()), SLOT(openDefault()) );
+    if (!partActions.isEmpty()) {
+        menu->addTitle(i18n("Embedded Editors"));
+        menu->addActions( partActions );
+    }
+    if (!appActions.isEmpty()) {
+        menu->addTitle(i18n("External Applications"));
+        menu->addActions( appActions );
+    }
 
     KDevelop::ContextMenuExtension ext;
-    ext.addAction( KDevelop::ContextMenuExtension::FileGroup, openAction );
-    ext.addAction( KDevelop::ContextMenuExtension::FileGroup, menu->menuAction() );
-    return ext;
-}
 
-bool sortActions(QAction* left, QAction* right)
-{
-    return left->text() < right->text();
-}
-
-bool isTextEditor(const KService::Ptr& service)
-{
-    return service->serviceTypes().contains( "KTextEditor/Document" );
-}
-
-QString defaultForMimeType(const QString& mimeType)
-{
-    KConfigGroup config = KGlobal::config()->group("Open With Defaults");
-    if (config.hasKey(mimeType)) {
-        QString storageId = config.readEntry(mimeType, QString());
-        if (!storageId.isEmpty() && KService::serviceByStorageId(storageId)) {
-            return storageId;
-        }
+    if (canOpenDefault(m_mimeType)) {
+        KAction* openAction = new KAction( i18n( "Open" ), this );
+        openAction->setIcon( SmallIcon( "document-open" ) );
+        connect( openAction, SIGNAL(triggered()), SLOT(openDefault()) );
+        ext.addAction( KDevelop::ContextMenuExtension::FileGroup, openAction );
     }
-    return QString();
+
+    if (!menu->isEmpty()) {
+        ext.addAction(KDevelop::ContextMenuExtension::FileGroup, menu->menuAction());
+    } else {
+        delete menu;
+    }
+    return ext;
 }
 
 QList<QAction*> OpenWithPlugin::actionsForServiceType( const QString& serviceType )
@@ -188,13 +212,21 @@ QList<QAction*> OpenWithPlugin::actionsForServiceType( const QString& serviceTyp
 
 void OpenWithPlugin::openDefault()
 {
+    //  check preferred handler
     const QString defaultId = defaultForMimeType(m_mimeType);
     if (!defaultId.isEmpty()) {
         open(defaultId);
         return;
     }
-    foreach( const KUrl& u, m_urls ) {
-        ICore::self()->documentController()->openDocument( u );
+
+    // default handlers
+    if (m_mimeType == "inode/directory") {
+        KService::Ptr service = KMimeTypeTrader::self()->preferredService(m_mimeType);
+        KRun::run(*service, m_urls, ICore::self()->uiController()->activeMainWindow());
+    } else {
+        foreach( const KUrl& u, m_urls ) {
+            ICore::self()->documentController()->openDocument( u );
+        }
     }
 }
 
