@@ -12,7 +12,10 @@
 ***************************************************************************/
 
 #include "patchhighlighter.h"
+
 #include "libdiff2/difference.h"
+#include "libdiff2/diffmodel.h"
+
 #include "patchreview.h"
 #include <language/highlighting/colorcache.h>
 #include <interfaces/idocument.h>
@@ -26,12 +29,16 @@
 #include <KTextEditor/View>
 #include <KMessageBox>
 #include <ktexteditor/movinginterface.h>
+#include <ktexteditor/markinterface.h>
 #include <interfaces/icore.h>
 #include <interfaces/iuicontroller.h>
+
+#include <QApplication>
 #include <QTextCharFormat>
 #include <QWidget>
 #include <QTextDocument>
 #include <QPointer>
+#include <QVBoxLayout>
 
 using namespace KDevelop;
 
@@ -76,33 +83,35 @@ void PatchHighlighter::showToolTipForMark( QPoint pos, KTextEditor::MovingRange*
 
     Diff2::DifferenceStringList lines;
 
-    if( m_plugin->patch()->isAlreadyApplied() && !diff->applied() )
-        html += i18n( "<b>Reverted.</b><br/>" );
-    else if( !m_plugin->patch()->isAlreadyApplied() && diff->applied() )
-        html += i18n( "<b>Applied.</b><br/>" );
-
+    html += "<b>";
     if( diff->applied() ) {
-        if( isInsertion( diff ) )
-        {
-            html += i18n( "<b>Insertion</b><br/>" );
-        }else{
+        if( !m_plugin->patch()->isAlreadyApplied() )
+            html += i18n( "Applied.<br/>" );
+
+        if( isInsertion( diff ) ) {
+            html += i18n( "Insertion<br/>" );
+        } else {
             if( isRemoval( diff ) )
-                html += i18n( "<b>Removal</b><br/>" );
-            html += i18n( "<b>Previous:</b><br/>" );
+                html += i18n( "Removal<br/>" );
+            html += i18n( "Previous:<br/>" );
             lines = diff->sourceLines();
         }
-    }else{
-        if( isRemoval( diff ) ) {
-            html += i18n( "<b>Removal</b><br/>" );
-        }else{
-            if( isInsertion( diff ) )
-                html += i18n( "<b>Insertion</b><br/>" );
+    } else {
+        if( m_plugin->patch()->isAlreadyApplied() )
+            html += i18n( "Reverted.<br/>" );
 
-            html += i18n( "<b>Alternative:</b><br/>" );
+        if( isRemoval( diff ) ) {
+            html += i18n( "Removal<br/>" );
+        } else {
+            if( isInsertion( diff ) )
+                html += i18n( "Insertion<br/>" );
+
+            html += i18n( "Alternative:<br/>" );
 
             lines = diff->destinationLines();
         }
     }
+    html += "</b>";
 
     for( int a = 0; a < lines.size(); ++a ) {
         Diff2::DifferenceString* line = lines[a];
@@ -156,7 +165,7 @@ void PatchHighlighter::showToolTipForMark( QPoint pos, KTextEditor::MovingRange*
     ActiveToolTip::showToolTip( tooltip );
 }
 
-void PatchHighlighter::markClicked( KTextEditor::Document* doc, KTextEditor::Mark mark, bool& handled ) {
+void PatchHighlighter::markClicked( KTextEditor::Document* doc, const KTextEditor::Mark& mark, bool& handled ) {
     m_applying = true;
     if( handled )
         return;
@@ -179,14 +188,14 @@ void PatchHighlighter::markClicked( KTextEditor::Document* doc, KTextEditor::Mar
 
         for( int a = 0; a < diff->sourceLineCount(); ++a ) {
             sourceText += diff->sourceLineAt( a )->string();
-            if( !sourceText.endsWith( "\n" ) )
-                sourceText += "\n";
+            if( !sourceText.endsWith( '\n' ) )
+                sourceText += '\n';
         }
 
         for( int a = 0; a < diff->destinationLineCount(); ++a ) {
             targetText += diff->destinationLineAt( a )->string();
-            if( !targetText.endsWith( "\n" ) )
-                targetText += "\n";
+            if( !targetText.endsWith( '\n' ) )
+                targetText += '\n';
         }
 
         QString replace;
@@ -227,7 +236,7 @@ void PatchHighlighter::markClicked( KTextEditor::Document* doc, KTextEditor::Mar
     m_applying = false;
 }
 
-KTextEditor::MovingRange* PatchHighlighter::rangeForMark( KTextEditor::Mark mark ) {
+KTextEditor::MovingRange* PatchHighlighter::rangeForMark( const KTextEditor::Mark& mark ) {
     for( QMap<KTextEditor::MovingRange*, Diff2::Difference*>::const_iterator it = m_differencesForRanges.constBegin(); it != m_differencesForRanges.constEnd(); ++it ) {
         if( it.key()->start().line() == mark.line )
         {
@@ -238,7 +247,7 @@ KTextEditor::MovingRange* PatchHighlighter::rangeForMark( KTextEditor::Mark mark
     return 0;
 }
 
-void PatchHighlighter::markToolTipRequested( KTextEditor::Document*, KTextEditor::Mark mark, QPoint pos, bool& handled ) {
+void PatchHighlighter::markToolTipRequested( KTextEditor::Document*, const KTextEditor::Mark& mark, QPoint pos, bool& handled ) {
     if( handled )
         return;
 
@@ -441,6 +450,8 @@ PatchHighlighter::PatchHighlighter( Diff2::DiffModel* model, IDocument* kdoc, Pa
     connect( doc, SIGNAL( markToolTipRequested( KTextEditor::Document*, KTextEditor::Mark, QPoint, bool & ) ), this, SLOT( markToolTipRequested( KTextEditor::Document*, KTextEditor::Mark, QPoint, bool & ) ) );
     connect( doc, SIGNAL( markClicked( KTextEditor::Document*, KTextEditor::Mark, bool & ) ), this, SLOT( markClicked( KTextEditor::Document*, KTextEditor::Mark, bool & ) ) );
     connect( doc, SIGNAL( aboutToDeleteMovingInterfaceContent( KTextEditor::Document* ) ), this, SLOT( aboutToDeleteMovingInterfaceContent( KTextEditor::Document* ) ) );
+    connect( doc, SIGNAL( aboutToInvalidateMovingInterfaceContent( KTextEditor::Document* ) ),
+             this, SLOT( aboutToDeleteMovingInterfaceContent( KTextEditor::Document* ) ) );
 
     textInserted( kdoc->textDocument(), kdoc->textDocument()->documentRange() );
 }
