@@ -13,29 +13,26 @@
 
 #include "patchreview.h"
 
-#include <kmimetype.h>
-#include <kmimetypechooser.h>
-#include <kmimetypetrader.h>
-#include <krandom.h>
 #include <QTabWidget>
 #include <QTimer>
-#include <QPersistentModelIndex>
-#include <kfiledialog.h>
+#include <QFileInfo>
+
 #include <interfaces/idocument.h>
 #include <interfaces/icore.h>
-#include <kde_terminal_interface.h>
+#include <interfaces/iplugincontroller.h>
+#include <interfaces/ipatchexporter.h>
+#include <interfaces/idocumentcontroller.h>
+#include <interfaces/iuicontroller.h>
+
 #include <kparts/part.h>
 #include <kparts/factory.h>
 
 #include "libdiff2/komparemodellist.h"
 #include "libdiff2/kompare.h"
+
 #include <kmessagebox.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
-#include <ktexteditor/markinterface.h>
-#include <ktexteditor/movinginterface.h>
-#include <interfaces/idocumentcontroller.h>
-#include <interfaces/iuicontroller.h>
 
 ///Whether arbitrary exceptions that occurred while diff-parsing within the library should be caught
 #define CATCHLIBDIFF
@@ -49,14 +46,13 @@
 #include <sublime/document.h>
 #include <sublime/view.h>
 #include "diffsettings.h"
-#include <interfaces/iplugincontroller.h>
-#include <interfaces/ipatchexporter.h>
 #include "patchhighlighter.h"
 #include "patchreviewtoolview.h"
-#include <vcs/models/vcsfilechangesmodel.h>
-#include <shell/core.h>
+#include "localpatchsource.h"
 #include <ktexteditor/modificationinterface.h>
+#include <ktexteditor/movingrange.h>
 #include <KIO/NetAccess>
+#include <KActionCollection>
 
 using namespace KDevelop;
 
@@ -71,7 +67,7 @@ Q_DECLARE_METATYPE( const Diff2::DiffModel* )
 void PatchReviewPlugin::seekHunk( bool forwards, const KUrl& fileName ) {
     try {
         kDebug() << forwards << fileName << fileName.isEmpty();
-        if ( !m_modelList.get() )
+        if ( !m_modelList )
             throw "no model";
 
         for ( int a = 0; a < m_modelList->modelCount(); ++a ) {
@@ -197,8 +193,12 @@ void PatchReviewPlugin::removeHighlighting( const KUrl& file ) {
 }
 
 void PatchReviewPlugin::notifyPatchChanged() {
-    kDebug() << "notifying patch change: " << m_patch->file();
-    m_updateKompareTimer->start( 500 );
+    if (m_patch) {
+        kDebug() << "notifying patch change: " << m_patch->file();
+        m_updateKompareTimer->start( 500 );
+    } else {
+        m_updateKompareTimer->stop();
+    }
 }
 
 void PatchReviewPlugin::forceUpdate() {
@@ -245,7 +245,7 @@ void PatchReviewPlugin::updateKompareModel() {
         m_kompareInfo->applied = m_patch->isAlreadyApplied();
 
         m_modelList.reset( new Diff2::KompareModelList( m_diffSettings.data(), new QWidget, this ) );
-        m_modelList->slotKompareInfo( m_kompareInfo.get() );
+        m_modelList->slotKompareInfo( m_kompareInfo.data() );
 
         try {
             m_modelList->openDirAndDiff();
@@ -304,30 +304,23 @@ private:
     PatchReviewPlugin *m_plugin;
 };
 
-PatchReviewPlugin::~PatchReviewPlugin() {
+PatchReviewPlugin::~PatchReviewPlugin()
+{
     removeHighlighting();
-    delete m_patch;
-}
 
-void PatchReviewPlugin::registerPatch( IPatchSource::Ptr patch ) {
-    if( !m_knownPatches.contains( patch ) ) {
-        m_knownPatches << patch;
-        connect( patch, SIGNAL( destroyed( QObject* ) ), SLOT( clearPatch( QObject* ) ) );
-    }
+    // Tweak to work around a crash on OS X; see https://bugs.kde.org/show_bug.cgi?id=338829
+    // and http://qt-project.org/forums/viewthread/38406/#162801
+    // modified tweak: use setPatch() and deleteLater in that method.
+    setPatch(0);
 }
 
 void PatchReviewPlugin::clearPatch( QObject* _patch ) {
     kDebug() << "clearing patch" << _patch << "current:" << ( QObject* )m_patch;
     IPatchSource::Ptr patch( ( IPatchSource* )_patch );
-    m_knownPatches.removeAll( patch );
-    m_knownPatches.removeAll( 0 );
 
     if( patch == m_patch ) {
         kDebug() << "is current patch";
-        if( !m_knownPatches.empty() )
-            setPatch( m_knownPatches.first() );
-        else
-            setPatch( IPatchSource::Ptr( new LocalPatchSource ) );
+        setPatch( IPatchSource::Ptr( new LocalPatchSource ) );
     }
 }
 
@@ -415,7 +408,7 @@ void PatchReviewPlugin::updateReview() {
 
     switchAreaAndMakeWorkingSetUique();
 
-    if( !m_modelList.get() )
+    if( !m_modelList )
         return;
 
     // list of opened documents to prevent flicker
@@ -490,17 +483,20 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
         if ( qobject_cast<LocalPatchSource*>( m_patch ) ) {
             // make sure we don't leak this
             // TODO: what about other patch sources?
-            delete m_patch;
+            m_patch->deleteLater();
         }
     }
     m_patch = patch;
 
     if( m_patch ) {
         kDebug() << "setting new patch" << patch->name() << "with file" << patch->file() << "basedir" << patch->baseDir();
-        registerPatch( patch );
 
         connect( m_patch, SIGNAL( patchChanged() ), this, SLOT( notifyPatchChanged() ) );
     }
+    QString finishText = i18n( "Finish Review" );
+    if( m_patch && !m_patch->finishReviewCustomText().isEmpty() )
+      finishText = m_patch->finishReviewCustomText();
+    m_finishReview->setText( finishText );
 
     notifyPatchChanged();
 }
@@ -511,7 +507,6 @@ PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IPatchReview )
     qRegisterMetaType<const Diff2::DiffModel*>( "const Diff2::DiffModel*" );
 
-    core()->uiController()->addToolView( i18n( "Patch Review" ), m_factory );
     setXMLFile( "kdevpatchreview.rc" );
 
     connect( ICore::self()->documentController(), SIGNAL( documentClosed( KDevelop::IDocument* ) ), this, SLOT( documentClosed( KDevelop::IDocument* ) ) );
@@ -522,7 +517,16 @@ PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
     m_updateKompareTimer->setSingleShot( true );
     connect( m_updateKompareTimer, SIGNAL( timeout() ), this, SLOT( updateKompareModel() ) );
 
+    m_finishReview = new KAction(this);
+    m_finishReview->setIcon( KIcon( "dialog-ok" ) );
+    m_finishReview->setShortcut( Qt::CTRL|Qt::Key_Return );
+    actionCollection()->addAction("commit_or_finish_review", m_finishReview);
+    ICore::self()->uiController()->activeArea()->addAction(m_finishReview);
+
     setPatch( IPatchSource::Ptr( new LocalPatchSource ) );
+
+    core()->uiController()->addToolView( i18n( "Patch Review" ), m_factory );
+    areaChanged(ICore::self()->uiController()->activeArea());
 }
 
 void PatchReviewPlugin::documentClosed( IDocument* doc ) {
@@ -556,10 +560,20 @@ void PatchReviewPlugin::exporterSelected( QAction* action ) {
 
     if( exporter ) {
         qDebug() << "exporting patch" << exporter << action->text();
+        // for git projects, m_patch will be a VCSDiffPatchSource instance
         exporter->extension<IPatchExporter>()->exportPatch( patch() );
     }
 }
 
+void PatchReviewPlugin::areaChanged(Sublime::Area* area)
+{
+    bool reviewing = area->objectName() == "review";
+    m_finishReview->setEnabled(reviewing);
+    if(!reviewing) {
+        closeReview();
+    }
+}
+
 #include "patchreview.moc"
 
 // kate: space-indent on; indent-width 2; tab-width 2; replace-tabs on
