@@ -11,25 +11,28 @@
 *                                                                         *
 ***************************************************************************/
 
-#ifndef PATCHREVIEW_H
-#define PATCHREVIEW_H
+#ifndef KDEVPLATFORM_PLUGIN_PATCHREVIEW_H
+#define KDEVPLATFORM_PLUGIN_PATCHREVIEW_H
 
 #include <QObject>
 #include <QPointer>
-#include <memory>
-#include <qstandarditemmodel.h>
+
+#include <kaction.h>
+
 #include <interfaces/iplugin.h>
-#include "localpatchsource.h"
-#include "ui_patchreview.h"
-#include <language/duchain/indexedstring.h>
-#include "libdiff2/diffmodel.h"
+#include <interfaces/ipatchsource.h>
 
 class PatchHighlighter;
+class PatchReviewToolViewFactory;
+
+class QTimer;
+
 namespace KDevelop {
 class IDocument;
 }
-
-class PatchReviewToolViewFactory;
+namespace Sublime {
+class Area;
+}
 
 namespace Diff2
 {
@@ -38,7 +41,7 @@ class DiffModel;
 }
 namespace Kompare
 {
-class Info;
+struct Info;
 }
 
 class DiffSettings;
@@ -50,7 +53,7 @@ class PatchReviewPlugin : public KDevelop::IPlugin, public KDevelop::IPatchRevie
     Q_INTERFACES( KDevelop::IPatchReview )
 
 public :
-        PatchReviewPlugin( QObject *parent, const QVariantList & = QVariantList() );
+    PatchReviewPlugin( QObject *parent, const QVariantList & = QVariantList() );
     ~PatchReviewPlugin();
     virtual void unload();
 
@@ -60,27 +63,23 @@ public :
         return m_patch;
     }
 
-    QList< KDevelop::IPatchSource::Ptr > knownPatches() const {
-        return m_knownPatches;
-    }
-
     Diff2::KompareModelList* modelList() const {
-        return m_modelList.get();
+        return m_modelList.data();
     }
 
     void seekHunk( bool forwards, const KUrl& file = KUrl() );
 
     void setPatch( KDevelop::IPatchSource* patch );
 
-    void registerPatch( KDevelop::IPatchSource::Ptr patch );
-
     virtual void startReview( KDevelop::IPatchSource* patch, ReviewMode mode );
 
     void finishReview( QList< KUrl > selection );
 
     KUrl urlForFileModel( const Diff2::DiffModel* model );
+    KAction* finishReviewAction() const { return m_finishReview; }
 
 Q_SIGNALS:
+    void startingNewReview();
     void patchChanged();
 
 public Q_SLOTS :
@@ -92,8 +91,8 @@ public Q_SLOTS :
     void notifyPatchChanged();
     void highlightPatch();
     void updateKompareModel();
-    void showPatch();
     void forceUpdate();
+    void areaChanged(Sublime::Area* area);
 
 private Q_SLOTS :
     void documentClosed( KDevelop::IDocument* );
@@ -113,8 +112,6 @@ private:
     // Returns false on failure (if the user disagreed).
     bool setUniqueEmptyWorkingSet();
 
-    QList< KDevelop::IPatchSource::Ptr > m_knownPatches;
-
     void addHighlighting( const KUrl& file, KDevelop::IDocument* document = 0 );
     void removeHighlighting( const KUrl& file = KUrl() );
 
@@ -123,14 +120,15 @@ private:
     QTimer* m_updateKompareTimer;
 
     PatchReviewToolViewFactory* m_factory;
+    KAction* m_finishReview;
 
     #if 0
     void determineState();
     #endif
 
     QPointer< DiffSettings > m_diffSettings;
-    std::auto_ptr< Kompare::Info > m_kompareInfo;
-    std::auto_ptr< Diff2::KompareModelList > m_modelList;
+    QScopedPointer< Kompare::Info > m_kompareInfo;
+    QScopedPointer< Diff2::KompareModelList > m_modelList;
     typedef QMap< KUrl, QPointer< PatchHighlighter > > HighlightMap;
     HighlightMap m_highlighters;
 };
