@@ -42,6 +42,7 @@
 #include <language/backgroundparser/backgroundparser.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
+#include <util/kdevstringhandler.h>
 
 #include "problemhighlighter.h"
 #include "problemwidget.h"
@@ -129,7 +130,8 @@ void ProblemReporterPlugin::textDocumentCreated(KDevelop::IDocument* document)
   DUChain::self()->updateContextForUrl(IndexedString(document->url()), KDevelop::TopDUContext::AllDeclarationsContextsAndUses, this);
 }
 
-void ProblemReporterPlugin::updateReady(const KDevelop::IndexedString& url) {
+void ProblemReporterPlugin::updateReady(const IndexedString &url, const KDevelop::ReferencedTopDUContext&)
+{
   m_model->problemsUpdated(url);
   ProblemHighlighter* ph = m_highlighters.value(url);
   if (ph) {
@@ -177,8 +179,7 @@ KDevelop::ContextMenuExtension ProblemReporterPlugin::contextMenuExtension(KDeve
       if(title.isEmpty())
         text = i18n("Solve Problem");
       else {
-        title.remove(QRegExp("<[^>]+>"));
-        text = i18n("Solve: %1", title);
+        text = i18n("Solve: %1", KDevelop::htmlToPlainText(title));
       }
       
       QAction* menuAction = new QAction(text, 0);
