@@ -22,22 +22,13 @@
 #include "projectmanagerview.h"
 
 #include <QtGui/QHeaderView>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QStandardItem>
-#include <QtGui/QToolButton>
 #include <QtGui/QKeyEvent>
 
-#include <kxmlguiwindow.h>
 #include <kiconloader.h>
-#include <kmenu.h>
 #include <kdebug.h>
 #include <kurl.h>
 #include <klocale.h>
 #include <kactioncollection.h>
-#include <kfadewidgeteffect.h>
-#include <kcombobox.h>
-#include <kjob.h>
 #include <KLineEdit>
 
 #include <interfaces/iselectioncontroller.h>
@@ -46,55 +37,36 @@
 #include <interfaces/isession.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iuicontroller.h>
-#include <interfaces/iruncontroller.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iproject.h>
-#include <project/interfaces/ibuildsystemmanager.h>
-#include <project/interfaces/iprojectbuilder.h>
+#include <project/projectproxymodel.h>
 #include <project/projectmodel.h>
+#include <util/path.h>
 
 #include "../openwith/iopenwith.h"
 
-#include <KParts/MainWindow>
 #include <sublime/mainwindow.h>
 
 #include "tests/modeltest.h"
-#include <project/projectproxymodel.h>
 #include "projectmanagerviewplugin.h"
+#include "vcsoverlayproxymodel.h"
 #include "ui_projectmanagerview.h"
 
 using namespace KDevelop;
 
-//BEGIN ProjectManagerFilterAction
-
-ProjectManagerFilterAction::ProjectManagerFilterAction(  const QString &initialFilter, QObject* parent )
-    : KAction( parent )
-    , m_intialFilter(initialFilter)
+ProjectManagerViewItemContext::ProjectManagerViewItemContext(const QList< ProjectBaseItem* >& items, ProjectManagerView* view)
+    : ProjectItemContext(items), m_view(view)
 {
-    setIcon(KIcon("view-filter"));
-    setText(i18n("Filter..."));
-    setToolTip(i18n("Insert wildcard patterns to filter the project view"
-                    " for files and targets for matching items."));
 }
 
-QWidget* ProjectManagerFilterAction::createWidget( QWidget* parent )
+ProjectManagerView *ProjectManagerViewItemContext::view() const
 {
-    KLineEdit* edit = new KLineEdit(parent);
-    edit->setClickMessage(i18n("Filter..."));
-    edit->setClearButtonShown(true);
-    connect(edit, SIGNAL(textChanged(QString)), this, SIGNAL(filterChanged(QString)));
-    if (!m_intialFilter.isEmpty()) {
-        edit->setText(m_intialFilter);
-    }
-
-    return edit;
+    return m_view;
 }
 
-//END ProjectManagerFilterAction
 
 static const char* sessionConfigGroup = "ProjectManagerView";
 static const char* splitterStateConfigKey = "splitterState";
-static const char* filterConfigKey = "filter";
 static const int projectTreeViewStrechFactor = 75; // %
 static const int projectBuildSetStrechFactor = 25; // %
 
@@ -131,31 +103,16 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
     addAction(plugin->actionCollection()->action("project_install"));
     addAction(plugin->actionCollection()->action("project_clean"));
 
-    connect(m_ui->projectTreeView, SIGNAL(activateUrl(KUrl)), this, SLOT(openUrl(KUrl)));
-
-//     m_filters = new KLineEdit(this);
-//     m_filters->setClearButtonShown(true);
-//     connect(d->m_filters, SIGNAL(returnPressed()), this, SLOT(filtersChanged()));
-//     vbox->addWidget( m_filters );
+    connect(m_ui->projectTreeView, SIGNAL(activate(KDevelop::Path)), this, SLOT(open(KDevelop::Path)));
 
     m_ui->buildSetView->setProjectView( this );
 
     m_modelFilter = new ProjectProxyModel( this );
-    m_modelFilter->setDynamicSortFilter( true );
     m_modelFilter->setSourceModel(ICore::self()->projectController()->projectModel());
+    m_overlayProxy = new VcsOverlayProxyModel( this );
+    m_overlayProxy->setSourceModel(m_modelFilter);
 
-    m_ui->projectTreeView->setModel( m_modelFilter );
-
-    QString filterText;
-
-    if (pmviewConfig.hasKey(filterConfigKey)) {
-        filterText = pmviewConfig.readEntry(filterConfigKey, QString());
-    }
-
-    ProjectManagerFilterAction* filterAction = new ProjectManagerFilterAction(filterText, this);
-    connect(filterAction, SIGNAL(filterChanged(QString)),
-            this, SLOT(filterChanged(QString)));
-    addAction(filterAction);
+    m_ui->projectTreeView->setModel( m_overlayProxy );
 
     connect( m_ui->projectTreeView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
              this, SLOT(selectionChanged()) );
@@ -180,12 +137,18 @@ bool ProjectManagerView::eventFilter(QObject* obj, QEvent* event)
     if (obj == m_ui->projectTreeView) {
         if (event->type() == QEvent::KeyRelease) {
             QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
-            if (keyEvent->key() == Qt::Key_Delete) {
+            if (keyEvent->key() == Qt::Key_Delete && keyEvent->modifiers() == Qt::NoModifier) {
                 m_plugin->removeItems(selectedItems());
                 return true;
-            } else if (keyEvent->key() == Qt::Key_F2) {
+            } else if (keyEvent->key() == Qt::Key_F2 && keyEvent->modifiers() == Qt::NoModifier) {
                 m_plugin->renameItems(selectedItems());
                 return true;
+            } else if (keyEvent->key() == Qt::Key_C && keyEvent->modifiers() == Qt::ControlModifier) {
+                m_plugin->copyFromContextMenu();
+                return true;
+            } else if (keyEvent->key() == Qt::Key_V && keyEvent->modifiers() == Qt::ControlModifier) {
+                m_plugin->pasteFromContextMenu();
+                return true;
             }
         }
     }
@@ -198,9 +161,10 @@ void ProjectManagerView::selectionChanged()
     QList<ProjectBaseItem*> selected;
     foreach( const QModelIndex& idx, m_ui->projectTreeView->selectionModel()->selectedRows() )
     {
-        selected << m_modelFilter->itemFromProxyIndex( idx );
+        selected << ICore::self()->projectController()->projectModel()->itemFromIndex(indexFromView( idx ));
     }
-    KDevelop::ICore::self()->selectionController()->updateSelection( new ProjectItemContext( selected ) );
+    selected.removeAll(0);
+    KDevelop::ICore::self()->selectionController()->updateSelection( new ProjectManagerViewItemContext( selected, this ) );
 }
 
 void ProjectManagerView::updateSyncAction()
@@ -212,8 +176,9 @@ ProjectManagerView::~ProjectManagerView()
 {
     KConfigGroup pmviewConfig(ICore::self()->activeSession()->config(), sessionConfigGroup);
     pmviewConfig.writeEntry(splitterStateConfigKey, m_ui->splitter->saveState());
-    pmviewConfig.writeEntry(filterConfigKey, m_filterString);
     pmviewConfig.sync();
+
+    delete m_ui;
 }
 
 QList<KDevelop::ProjectBaseItem*> ProjectManagerView::selectedItems() const
@@ -221,8 +186,7 @@ QList<KDevelop::ProjectBaseItem*> ProjectManagerView::selectedItems() const
     QList<KDevelop::ProjectBaseItem*> items;
     foreach( const QModelIndex &idx, m_ui->projectTreeView->selectionModel()->selectedIndexes() )
     {
-        KDevelop::ProjectBaseItem* item =
-                ICore::self()->projectController()->projectModel()->itemFromIndex( m_modelFilter->mapToSource(idx) );
+        KDevelop::ProjectBaseItem* item = ICore::self()->projectController()->projectModel()->itemFromIndex(indexFromView(idx));
         if( item )
             items << item;
         else
@@ -231,6 +195,22 @@ QList<KDevelop::ProjectBaseItem*> ProjectManagerView::selectedItems() const
     return items;
 }
 
+void ProjectManagerView::selectItems(const QList< ProjectBaseItem* >& items)
+{
+    QItemSelection selection;
+    foreach (ProjectBaseItem *item, items) {
+        QModelIndex indx = indexToView(item->index());
+        selection.append(QItemSelectionRange(indx, indx));
+        m_ui->projectTreeView->setCurrentIndex(indx);
+    }
+    m_ui->projectTreeView->selectionModel()->select(selection, QItemSelectionModel::ClearAndSelect);
+}
+
+void ProjectManagerView::expandItem(ProjectBaseItem* item)
+{
+    m_ui->projectTreeView->expand( indexToView(item->index()));
+}
+
 void ProjectManagerView::locateCurrentDocument()
 {
     ICore::self()->uiController()->raiseToolView(this);
@@ -248,7 +228,7 @@ void ProjectManagerView::locateCurrentDocument()
     QModelIndex bestMatch;
     foreach (IProject* proj, ICore::self()->projectController()->projects()) {
         foreach (KDevelop::ProjectFileItem* item, proj->filesForUrl(doc->url())) {
-            QModelIndex index = m_modelFilter->proxyIndexFromItem(item);
+            QModelIndex index = indexToView(item->index());
             if (index.isValid()) {
                 if (!bestMatch.isValid()) {
                     bestMatch = index;
@@ -270,15 +250,19 @@ void ProjectManagerView::locateCurrentDocument()
     }
 }
 
-void ProjectManagerView::openUrl( const KUrl& url )
+void ProjectManagerView::open( const Path& path )
 {
-    IOpenWith::openFiles(KUrl::List() << url);
+    IOpenWith::openFiles(KUrl::List() << path.toUrl());
 }
 
-void ProjectManagerView::filterChanged(const QString &text)
+QModelIndex ProjectManagerView::indexFromView(const QModelIndex& index) const
 {
-    m_filterString = text;
-    m_modelFilter->setFilterString(text);
+    return m_modelFilter->mapToSource( m_overlayProxy->mapToSource(index) );
+}
+
+QModelIndex ProjectManagerView::indexToView(const QModelIndex& index) const
+{
+    return m_overlayProxy->mapFromSource( m_modelFilter->mapFromSource(index) );
 }
 
 #include "projectmanagerview.moc"
