@@ -18,42 +18,40 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVPROJECTMANAGERVIEW_H
-#define KDEVPROJECTMANAGERVIEW_H
+#ifndef KDEVPLATFORM_PLUGIN_PROJECTMANAGERVIEW_H
+#define KDEVPLATFORM_PLUGIN_PROJECTMANAGERVIEW_H
 
 #include <QtGui/QWidget>
 #include <KAction>
+#include <interfaces/context.h>
 
 class QModelIndex;
 
-class KUrl;
-
 namespace Ui
 {
 class ProjectManagerView;
 }
 
 class ProjectProxyModel;
+class VcsOverlayProxyModel;
 
 namespace KDevelop
 {
 class ProjectBaseItem;
+class Path;
 }
 
+class ProjectManagerView;
 class ProjectManagerViewPlugin;
 
-class ProjectManagerFilterAction : public KAction {
-    Q_OBJECT
-
+//own subclass to the current view can be passed from ProjectManagetView to ProjectManagerViewPlugin
+class ProjectManagerViewItemContext : public KDevelop::ProjectItemContext
+{
 public:
-    explicit ProjectManagerFilterAction( const QString &initialFilter, QObject* parent );
-
-signals:
-    void filterChanged(const QString& filter);
-
-protected:
-    virtual QWidget* createWidget( QWidget* parent );
-    QString m_intialFilter;
+    ProjectManagerViewItemContext(const QList< KDevelop::ProjectBaseItem* >& items, ProjectManagerView *view);
+    ProjectManagerView *view() const;
+private:
+    ProjectManagerView *m_view;
 };
 
 class ProjectManagerView: public QWidget
@@ -65,6 +63,8 @@ public:
 
     ProjectManagerViewPlugin* plugin() const { return m_plugin; }
     QList<KDevelop::ProjectBaseItem*> selectedItems() const;
+    void selectItems(const QList<KDevelop::ProjectBaseItem*> &items);
+    void expandItem(KDevelop::ProjectBaseItem *item);
 
 protected:
     virtual bool eventFilter(QObject* obj, QEvent* event);
@@ -73,17 +73,19 @@ private slots:
     void selectionChanged();
     void locateCurrentDocument();
     void updateSyncAction();
-    void openUrl( const KUrl& );
-    void filterChanged(const QString&);
+    void open( const KDevelop::Path& );
 
 private:
+    QModelIndex indexFromView(const QModelIndex& index) const;
+    QModelIndex indexToView(const QModelIndex& index) const;
+
     QAction* m_syncAction;
     Ui::ProjectManagerView* m_ui;
     QStringList m_cachedFileList;
     ProjectProxyModel* m_modelFilter;
+    VcsOverlayProxyModel* m_overlayProxy;
     ProjectManagerViewPlugin* m_plugin;
-    QString m_filterString;
 };
 
-#endif // KDEVPROJECTMANAGER_H
+#endif // KDEVPLATFORM_PLUGIN_PROJECTMANAGERVIEW_H
 
