@@ -80,7 +80,7 @@ public:
     virtual void setFilterText( const QString& text );
     virtual uint itemCount() const;
     virtual uint unfilteredItemCount() const;
-    virtual QList<KDevelop::QuickOpenDataPointer> data( uint start, uint end ) const;
+    virtual KDevelop::QuickOpenDataPointer data( uint row ) const;
 
     virtual void reset();
 
