@@ -53,7 +53,7 @@ if (option.showDecorationSelected && (option.state & QStyle::State_Selected)) {
 	    return qvariant_cast<QBrush>(value).color();
     }
     
-    return QApplication::palette().background().color();
+    return QApplication::palette().base().color();
 }
 
 static void dampColors(QColor& col) {
@@ -164,8 +164,6 @@ void ExpandingDelegate::drawDisplay( QPainter * painter, const QStyleOptionViewI
 
   QTextLayout layout(text, option.font, painter->device());
 
-  QRect textRect = rect.adjusted(1, 0, -1, 0); // remove width padding
-
   QList<QTextLayout::FormatRange> additionalFormats;
 
   int missingFormats = text.length();
@@ -300,10 +298,6 @@ void ExpandingDelegate::heightChanged() const {
 
 bool ExpandingDelegate::editorEvent ( QEvent * event, QAbstractItemModel * /*model*/, const QStyleOptionViewItem & /*option*/, const QModelIndex & index )
 {
-  QKeyEvent* keyEvent = 0;
-  if( event->type() == QEvent::KeyPress )
-    keyEvent = reinterpret_cast<QKeyEvent*>(event);
-  
   if( event->type() == QEvent::MouseButtonRelease )
   {
     event->accept();
