@@ -27,6 +27,7 @@
 #include <language/duchain/duchainutils.h>
 #include <language/duchain/codemodel.h>
 #include <language/interfaces/iquickopen.h>
+#include <language/interfaces/abbreviations.h>
 
 #include <interfaces/iproject.h>
 #include <interfaces/icore.h>
@@ -55,6 +56,10 @@ struct SubstringCache
         const QString idStr = id.identifier().str();
 
         int result = idStr.lastIndexOf(substring, -1, Qt::CaseInsensitive);
+        if (result < 0 && !idStr.isEmpty() && !substring.isEmpty()) {
+            // no match; try abbreviations
+            result = matchesAbbreviation(idStr.midRef(0), substring) ? 0 : -1;
+        }
 
         //here we shift the values if the matched string is bigger than the substring,
         //so closer matches will appear first
@@ -122,7 +127,7 @@ void ProjectItemDataProvider::setFilterText( const QString& text )
         }
     }
     if(!search.isEmpty() && search.back().endsWith('(')) {
-        search.back() = search.back().left(search.back().length()-1);
+        search.back().chop(1);
     }
 
     if(text.isEmpty() || search.isEmpty()) {
@@ -218,10 +223,16 @@ KDevelop::QuickOpenDataPointer ProjectItemDataProvider::data( uint pos ) const
     if(ctx) {
         QList<Declaration*> decls = ctx->findDeclarations(m_filteredItems[a].m_id, CursorInRevision::invalid(), AbstractType::Ptr(), 0, DUContext::DirectQualifiedLookup);
 
-        //Filter out forward-declarations
+        //Filter out forward-declarations or duplicate imported declarations
         foreach(Declaration* decl, decls) {
-            if(decl->isForwardDeclaration() && decls.size() > 1) {
-                decls.removeAll(decl);
+            bool filter = false;
+            if (decls.size() > 1 && decl->isForwardDeclaration()) {
+                filter = true;
+            } else if (decl->url() != m_filteredItems[a].m_file && m_files.contains(decl->url())) {
+                filter = true;
+            }
+            if (filter) {
+                decls.removeOne(decl);
             }
         }
 
@@ -230,7 +241,7 @@ KDevelop::QuickOpenDataPointer ProjectItemDataProvider::data( uint pos ) const
             item.m_item = decl;
             item.m_text = decl->qualifiedIdentifier().toString();
             //item.m_project =  .. @todo fill
-            ret << QuickOpenDataPointer(new DUChainItemData(item, true));
+            ret << QuickOpenDataPointer(new DUChainItemData(item));
         }
         if(decls.isEmpty()) {
             DUChainItem item;
@@ -271,12 +282,12 @@ KDevelop::QuickOpenDataPointer ProjectItemDataProvider::data( uint pos ) const
 
 void ProjectItemDataProvider::reset()
 {
-    m_usingFiles = m_quickopen->fileSet();
+    m_files = m_quickopen->fileSet();
     m_currentItems.clear();
     m_addedItems.clear();
 
     KDevelop::DUChainReadLocker lock( DUChain::lock() );
-    foreach( const IndexedString& u, m_usingFiles ) {
+    foreach( const IndexedString& u, m_files ) {
         uint count;
         const KDevelop::CodeModelItem* items;
         CodeModel::self().items( u, count, items );
@@ -336,6 +347,7 @@ QStringList ProjectItemDataProvider::supportedItemTypes()
 
 void ProjectItemDataProvider::enableData( const QStringList& items, const QStringList& scopes )
 {
+    //FIXME: property support different scopes
     if(scopes.contains(i18n("Project"))) {
         m_itemTypes = NoItems;
         if(items.contains(i18n("Classes"))) {
