@@ -19,8 +19,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef QUICKOPENPLUGIN_H
-#define QUICKOPENPLUGIN_H
+#ifndef KDEVPLATFORM_PLUGIN_QUICKOPENPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_QUICKOPENPLUGIN_H
 
 #include <QtCore/QVariant>
 #include <QtCore/QTimer>
@@ -94,9 +94,10 @@ public slots:
     void quickOpenFunction();
     void quickOpenClass();
     void quickOpenDeclaration();
+    void quickOpenOpenFile();
     void quickOpenDefinition();
-    void quickOpenNavigate();
     void quickOpenNavigateFunctions();
+    void quickOpenDocumentation();
 
     void previousFunction();
     void nextFunction();
@@ -122,6 +123,7 @@ private:
     class ProjectFileDataProvider* m_projectFileData;
     class ProjectItemDataProvider* m_projectItemData;
     class OpenFilesDataProvider* m_openFilesData;
+    class DocumentationQuickOpenProvider* m_documentationItemData;
     QStringList lastUsedScopes;
     QStringList lastUsedItems;
   
@@ -158,9 +160,8 @@ class QuickOpenWidget : public QMenu {
   void ready();
 
   private slots:
-  void currentChanged( const QModelIndex& current, const QModelIndex& previous );
-  void currentChanged( const QItemSelection& current, const QItemSelection& previous );
-  
+  void callRowSelected();
+
   void updateTimerInterval( bool cheapFilterChange );
 
   void accept();
@@ -168,13 +169,10 @@ class QuickOpenWidget : public QMenu {
   void updateProviders();
   void doubleClicked ( const QModelIndex & index );
 
-  void updateScrollBarState();
-
   void applyFilter();
 
   private:
   virtual void showEvent(QShowEvent *);
-  void callRowSelected();
   
   virtual bool eventFilter ( QObject * watched, QEvent * event );
 
@@ -238,6 +236,6 @@ class QuickOpenLineEdit : public KDevelop::IQuickOpenLine {
     QuickOpenWidgetCreator* m_widgetCreator;
 };
 
-#endif // QUICKOPENPLUGIN_H
+#endif // KDEVPLATFORM_PLUGIN_QUICKOPENPLUGIN_H
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
