@@ -24,7 +24,6 @@
 #include "toolviewdata.h"
 
 #include <QtCore/QList>
-#include <QtDesigner/QExtensionFactory>
 #include <QtCore/QAbstractItemModel>
 #include <QtGui/QAction>
 #include <QtGui/QAbstractItemDelegate>
@@ -52,7 +51,7 @@ K_EXPORT_PLUGIN(StandardOutputViewFactory(KAboutData("kdevstandardoutputview","k
 
 class OutputViewFactory : public KDevelop::IToolViewFactory{
 public:
-    OutputViewFactory(ToolViewData* data): m_data(data) {}
+    OutputViewFactory(const ToolViewData* data): m_data(data) {}
     virtual QWidget* create(QWidget *parent = 0)
     {
         return new OutputWidget( parent, m_data );
@@ -71,7 +70,7 @@ public:
         return "org.kdevelop.OutputView." + QString::number(m_data->toolViewId);
     }
 private:
-    ToolViewData *m_data;
+    const ToolViewData *m_data;
 };
 
 StandardOutputView::StandardOutputView(QObject *parent, const QVariantList &)
@@ -86,11 +85,13 @@ StandardOutputView::StandardOutputView(QObject *parent, const QVariantList &)
     action = actionCollection()->addAction("next_error");
     action->setText(i18n("Jump to Next Outputmark"));
     action->setShortcut( QKeySequence(Qt::Key_F4) );
+    action->setIcon(KIcon("arrow-right"));
     connect(action, SIGNAL(triggered(bool)), this, SIGNAL(selectNextItem()));
 
     action = actionCollection()->addAction("prev_error");
     action->setText(i18n("Jump to Previous Outputmark"));
     action->setShortcut( QKeySequence(Qt::SHIFT | Qt::Key_F4) );
+    action->setIcon(KIcon("arrow-left"));
     connect(action, SIGNAL(triggered(bool)), this, SIGNAL(selectPrevItem()));
 
     connect(KDevelop::ICore::self()->uiController()->controller(), SIGNAL(aboutToRemoveView(Sublime::View*)),
@@ -167,21 +168,17 @@ int StandardOutputView::registerToolView( const QString& title,
                                           const KIcon& icon, Options option,
                                           const QList<QAction*>& actionList )
 {
-    int newid = -1;
-    if( ids.isEmpty() )
-        newid = 0;
-    else
+    // try to reuse existing toolview
+    foreach( ToolViewData* d, toolviews )
     {
-#ifndef NDEBUG
-        //verify that the title stays unique
-        foreach( ToolViewData* d, toolviews )
-        {
-            Q_ASSERT(d->title != title );
+        if ( d->type == type && d->title == title ) {
+            return d->toolViewId;
         }
-#endif
-        newid = ids.last()+1;
     }
-    kDebug() << "Registering view" << title << "with type:" << type;
+
+    // register new tool view
+    const int newid = ids.isEmpty() ? 0 : (ids.last() + 1);
+    kDebug() << "Registering view" << title << "with type:" << type << "id:" << newid;
     ToolViewData* tvdata = new ToolViewData( this );
     tvdata->toolViewId = newid;
     tvdata->type = type;
@@ -233,7 +230,7 @@ void StandardOutputView::raiseOutput(int outputId)
     }
 }
 
-void StandardOutputView::setModel( int outputId, QAbstractItemModel* model, Ownership takeOwnership )
+void StandardOutputView::setModel( int outputId, QAbstractItemModel* model )
 {
     int tvid = -1;
     foreach( int _id, toolviews.keys() )
@@ -248,11 +245,11 @@ void StandardOutputView::setModel( int outputId, QAbstractItemModel* model, Owne
         kDebug() << "Trying to set model on unknown view-id:" << outputId;
     else
     {
-        toolviews.value( tvid )->outputdata.value( outputId )->setModel( model, takeOwnership == TakeOwnership );
+        toolviews.value( tvid )->outputdata.value( outputId )->setModel( model );
     }
 }
 
-void StandardOutputView::setDelegate( int outputId, QAbstractItemDelegate* delegate, Ownership takeOwnership )
+void StandardOutputView::setDelegate( int outputId, QAbstractItemDelegate* delegate )
 {
     int tvid = -1;
     foreach( int _id, toolviews.keys() )
@@ -267,7 +264,7 @@ void StandardOutputView::setDelegate( int outputId, QAbstractItemDelegate* deleg
         kDebug() << "Trying to set model on unknown view-id:" << outputId;
     else
     {
-        toolviews.value( tvid )->outputdata.value( outputId )->setDelegate( delegate, takeOwnership == TakeOwnership );
+        toolviews.value( tvid )->outputdata.value( outputId )->setDelegate( delegate );
     }
 }
 
@@ -336,4 +333,9 @@ void StandardOutputView::removeOutput( int outputId )
     }
 }
 
+void StandardOutputView::setTitle(int outputId, const QString& title)
+{
+    outputWidgetForId(outputId)->setTitle(outputId, title);
+}
+
 #include "standardoutputview.moc"
