@@ -113,10 +113,7 @@ void StandardOutputViewTest::testActions()
     QVERIFY(outputWidget);
 
     QList<QAction*> actions = outputWidget->actions();
-    QCOMPARE(actions.takeFirst()->text(), QString("Select activated Item"));
-    QCOMPARE(actions.takeFirst()->text(), QString("Focus when selecting Item"));
-    QCOMPARE(actions.takeFirst()->text(), QString("Select &All"));
-    QCOMPARE(actions.takeFirst()->text(), QString("&Copy"));
+    QCOMPARE(actions.size(), 7);
 
     m_stdOutputView->removeToolView(toolviewId);
     QVERIFY(!toolviewPointer(toolviewTitle));
@@ -132,16 +129,9 @@ void StandardOutputViewTest::testActions()
     QVERIFY(outputWidget);
 
     actions = outputWidget->actions();
-    QCOMPARE(actions.takeFirst()->text(), QString("Previous"));
-    QCOMPARE(actions.takeFirst()->text(), QString("Next"));
-    QCOMPARE(actions.takeFirst()->text(), QString("Select activated Item"));
-    QCOMPARE(actions.takeFirst()->text(), QString("Focus when selecting Item"));
-    QCOMPARE(actions.takeFirst()->text(), QString("Select &All"));
-    QCOMPARE(actions.takeFirst()->text(), QString("&Copy"));
-    QCOMPARE(actions.takeFirst()->text(), QString("")); // separator
-    QCOMPARE(actions.takeFirst()->text(), QString("")); // filter
-    QCOMPARE(actions.takeFirst()->text(), addedActions[0]->text());
-    QCOMPARE(actions.takeFirst()->text(), addedActions[1]->text());
+    QCOMPARE(actions.size(), 12);
+    QCOMPARE(actions[actions.size()-2]->text(), addedActions[0]->text());
+    QCOMPARE(actions[actions.size()-1]->text(), addedActions[1]->text());
 
     m_stdOutputView->removeToolView(toolviewId);
     QVERIFY(!toolviewPointer(toolviewTitle));
@@ -155,12 +145,12 @@ void StandardOutputViewTest::testRegisterAndRemoveOutput()
 
     for(int i = 0; i < 5; i++)
     {
-        outputId[i] = m_stdOutputView->registerOutputInToolView(toolviewId, "output" + i);
+        outputId[i] = m_stdOutputView->registerOutputInToolView(toolviewId, QString("output%1").arg(i));
     }
     for(int i = 0; i < 5; i++)
     {
-        QCOMPARE(outputWidget->data->outputdata.value(outputId[i])->title, QString("output" + i));
-        QCOMPARE(outputWidget->tabwidget->tabText(i), QString("output" + i));
+        QCOMPARE(outputWidget->data->outputdata.value(outputId[i])->title, QString("output%1").arg(i));
+        QCOMPARE(outputWidget->tabwidget->tabText(i), QString("output%1").arg(i));
     }
     for(int i = 0; i < 5; i++)
     {
@@ -179,11 +169,11 @@ void StandardOutputViewTest::testRegisterAndRemoveOutput()
 
     for(int i = 0; i < 5; i++)
     {
-        outputId[i] = m_stdOutputView->registerOutputInToolView(toolviewId, "output" + i);
+        outputId[i] = m_stdOutputView->registerOutputInToolView(toolviewId, QString("output%1").arg(i));
     }
     for(int i = 0; i < 5; i++)
     {
-        QCOMPARE(outputWidget->data->outputdata.value(outputId[i])->title, QString("output" + i));
+        QCOMPARE(outputWidget->data->outputdata.value(outputId[i])->title, QString("output%1").arg(i));
     }
     for(int i = 0; i < 5; i++)
     {
