@@ -11,7 +11,6 @@
 
 #include "kdevsvnplugin.h"
 
-#include <QtDesigner/QExtensionFactory>
 #include <QAction>
 #include <QVariant>
 #include <QTextStream>
@@ -47,7 +46,6 @@
 #include <vcs/vcsevent.h>
 #include <vcs/vcsstatusinfo.h>
 #include <vcs/vcsannotation.h>
-#include <vcs/widgets/vcsannotationwidget.h>
 #include <vcs/widgets/vcseventwidget.h>
 #include <vcs/widgets/vcsdiffwidget.h>
 #include <vcs/widgets/vcscommitdialog.h>
@@ -81,7 +79,7 @@ K_EXPORT_PLUGIN(KDevSvnFactory(KAboutData("kdevsubversion", "kdevsubversion", ki
 
 KDevSvnPlugin::KDevSvnPlugin(QObject *parent, const QVariantList &)
         : KDevelop::IPlugin(KDevSvnFactory::componentData(), parent)
-        , m_common(new KDevelop::VcsPluginHelper(this, this)), svnmenu( 0 ),
+        , m_common(new KDevelop::VcsPluginHelper(this, this)),
         copy_action( 0 ), move_action( 0 )
 {
     KDEV_USE_EXTENSION_INTERFACE(KDevelop::IBasicVersionControl)
@@ -102,6 +100,11 @@ KDevSvnPlugin::~KDevSvnPlugin()
 
 bool KDevSvnPlugin::isVersionControlled(const KUrl& localLocation)
 {
+    ///TODO: also check this in the other functions?
+    if (!localLocation.isValid()) {
+        return false;
+    }
+
     SvnInfoJob* job = new SvnInfoJob(this);
 
     job->setLocation(localLocation);
