@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef SVNADDJOB_H
-#define SVNADDJOB_H
+#ifndef KDEVPLATFORM_PLUGIN_SVNADDJOB_H
+#define KDEVPLATFORM_PLUGIN_SVNADDJOB_H
 
 #include "svnjobbase.h"
 
@@ -33,7 +33,7 @@ class SvnAddJob : public SvnJobBase
 {
     Q_OBJECT
 public:
-    SvnAddJob( KDevSvnPlugin* parent, KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose );
+    SvnAddJob( KDevSvnPlugin* parent );
     QVariant fetchResults();
     void start();
     SvnInternalJobBase* internalJob() const;
