@@ -31,16 +31,18 @@
 #include "kdevsvncpp/path.hpp"
 
 #include <vcs/vcslocation.h>
+#include <QFileInfo>
 
 SvnInternalCheckoutJob::SvnInternalCheckoutJob( SvnJobBase* parent )
     : SvnInternalJobBase( parent )
+    , m_recursion( KDevelop::IBasicVersionControl::Recursive )
 {
 }
 
 bool SvnInternalCheckoutJob::isValid() const
 {
     QMutexLocker l( m_mutex );
-    return m_sourceRepository.isValid() && m_destinationDirectory.isLocalFile();
+    return m_sourceRepository.isValid() && m_destinationDirectory.isLocalFile() && QFileInfo(m_destinationDirectory.upUrl().toLocalFile()).exists();
 }
 
 void SvnInternalCheckoutJob::run()
@@ -50,17 +52,19 @@ void SvnInternalCheckoutJob::run()
     svn::Client cli(m_ctxt);
     try
     {
-        QMutexLocker l( m_mutex );
-        bool recurse = ( m_recursion == KDevelop::IBasicVersionControl::Recursive );
-        QByteArray srcba = m_sourceRepository.repositoryServer().toUtf8();
-        QByteArray destba = m_destinationDirectory.toLocalFile().toUtf8();
-        kDebug(9510) << srcba << destba;
-        cli.checkout( srcba.data(), svn::Path( destba.data() ), svn::Revision(svn::Revision::HEAD), recurse );
+        bool recurse = ( recursion() == KDevelop::IBasicVersionControl::Recursive );
+        KUrl desturl = KUrl( source().repositoryServer() );
+        desturl.cleanPath(KUrl::SimplifyDirSeparators);
+        QByteArray srcba = desturl.url( KUrl::RemoveTrailingSlash ).toUtf8();
+        KUrl destdir = KUrl(QFileInfo( destination().upUrl().toLocalFile() ).canonicalFilePath());
+        destdir.addPath( destination().fileName() );
+        QByteArray destba = destdir.toLocalFile().toUtf8();
+        kDebug(9510) << srcba << destba << recurse;
+        cli.checkout( srcba.data(), svn::Path( destba.data() ), svn::Revision::HEAD, recurse );
     }catch( svn::ClientException ce )
     {
-        QMutexLocker l( m_mutex );
         kDebug(9510) << "Exception while checking out: "
-                << m_sourceRepository.repositoryServer()
+                << source().repositoryServer()
                 << QString::fromUtf8( ce.message() );
         setErrorMessage( QString::fromUtf8( ce.message() ) );
         m_success = false;
@@ -82,9 +86,20 @@ KDevelop::VcsLocation SvnInternalCheckoutJob::source() const
     return m_sourceRepository;
 }
 
+KDevelop::IBasicVersionControl::RecursionMode SvnInternalCheckoutJob::recursion() const
+{
+    QMutexLocker l( m_mutex );
+    return m_recursion;
+}
+
+KUrl SvnInternalCheckoutJob::destination() const
+{
+    QMutexLocker l( m_mutex );
+    return m_destinationDirectory;
+}
 
 SvnCheckoutJob::SvnCheckoutJob( KDevSvnPlugin* parent )
-    : SvnJobBase( parent )
+    : SvnJobBase( parent, KDevelop::OutputJob::Silent )
 {
     setType( KDevelop::VcsJob::Import );
     m_job = new SvnInternalCheckoutJob( this );
