@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef SVNCOMMITJOB_H
-#define SVNCOMMITJOB_H
+#ifndef KDEVPLATFORM_PLUGIN_SVNCOMMITJOB_H
+#define KDEVPLATFORM_PLUGIN_SVNCOMMITJOB_H
 
 #include "svnjobbase.h"
 #include <kurl.h>
@@ -43,7 +43,6 @@ public:
     void setRecursive( bool );
     SvnInternalJobBase* internalJob() const;
 private:
-    SvnCommitDialog* m_commitdlg;
     SvnInternalCommitJob* m_job;
 };
 
