@@ -56,7 +56,7 @@ QString repairDiff(QString diff) {
             kDebug() << "found header for" << fileName;
             lines[a] = QString();
             if(lines[a+1].startsWith("======")) {
-                headers[fileName] += "\n" + lines[a+1];
+                headers[fileName] += '\n' + lines[a+1];
             lines[a+1] = QString();
             }
         }
@@ -72,7 +72,7 @@ QString repairDiff(QString diff) {
                 kDebug() << "checking for" << file;
                 if(headers.contains(file)) {
                     kDebug() << "adding header for" << file << ":" << headers[file];
-                    lines[a] = headers[file] + "\n" + lines[a];
+                    lines[a] = headers[file] + '\n' + lines[a];
                 }
             }
         }
@@ -170,7 +170,6 @@ void SvnInternalDiffJob::run()
             {
                 throw svn::ClientException( "Not enough information for a diff");
             }
-            //@TODO: Make sure there's no diff-cmd set via the users configuration file, can be done only via C api
             diff = cli.diff( svn::Path( srcba.data() ), pegRev, srcRev,
                              dstRev, recursive(), ignoreAncestry(),
                              noDiffOnDelete(), ignoreContentType() );
@@ -299,7 +298,7 @@ QVariant SvnDiffJob::fetchResults()
 void SvnDiffJob::start()
 {
 
-    disconnect( m_job, SIGNAL( done( ThreadWeaver::Job* ) ), this, SLOT( internalJobDone( ThreadWeaver::Job* ) ) );
+    disconnect( m_job, SIGNAL(done(ThreadWeaver::Job*)), this, SLOT(internalJobDone(ThreadWeaver::Job*)) );
     if( !m_job->source().isValid()
          || ( !m_job->destination().isValid() &&
                 ( m_job->srcRevision().revisionType() == KDevelop::VcsRevision::Invalid
@@ -310,8 +309,8 @@ void SvnDiffJob::start()
         setErrorText( i18n( "Not enough information given to execute diff" ) );
     }else
     {
-        connect( m_job, SIGNAL( gotDiff( const QString& ) ),
-                 this, SLOT( setDiff( const QString& ) ),
+        connect( m_job, SIGNAL(gotDiff(QString)),
+                 this, SLOT(setDiff(QString)),
                  Qt::QueuedConnection );
         ThreadWeaver::Weaver::instance()->enqueue( m_job );
     }
@@ -423,8 +422,8 @@ void SvnDiffJob::setDiff( const QString& diff )
 
             m_catJobMap[job] = l;
 
-            connect( job, SIGNAL( resultsReady( KDevelop::VcsJob* ) ), this, SLOT( addLeftText( KDevelop::VcsJob* ) ) );
-            connect( job, SIGNAL( result( KJob* ) ), this, SLOT( removeJob( KJob* ) ) );
+            connect( job, SIGNAL(resultsReady(KDevelop::VcsJob*)), this, SLOT(addLeftText(KDevelop::VcsJob*)) );
+            connect( job, SIGNAL(result(KJob*)), this, SLOT(removeJob(KJob*)) );
 
             KDevelop::ICore::self()->runController()->registerJob(job);
         }
