@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef SVNREVERTJOB_H
-#define SVNREVERTJOB_H
+#ifndef KDEVPLATFORM_PLUGIN_SVNREVERTJOB_H
+#define KDEVPLATFORM_PLUGIN_SVNREVERTJOB_H
 
 #include "svnjobbase.h"
 
