@@ -35,6 +35,8 @@
 
 SvnInternalUpdateJob::SvnInternalUpdateJob( SvnJobBase* parent )
     : SvnInternalJobBase( parent )
+    , m_recursive( false )
+    , m_ignoreExternals( false )
 {
 }
 
