@@ -19,7 +19,6 @@
 ***************************************************************************/
 
 #include "svnrecursiveadd.h"
-#include <memory>
 #include <QtTest/QtTest>
 #include <qtest_kde.h>
 #include <KTempDir>
@@ -63,7 +62,7 @@ using namespace KDevelop;
 void validatingExecJob(VcsJob* j, VcsJob::JobStatus status = VcsJob::JobSucceeded)
 {
     QVERIFY(j);
-    // Print the commmands in full, for easier bug location
+    // Print the commands in full, for easier bug location
 #if 0
     if (QLatin1String(j->metaObject()->className()) == "DVcsJob") {
         kDebug() << "Command: \"" << ((DVcsJob*)j)->getChildproc()->program() << ((DVcsJob*)j)->getChildproc()->workingDirectory();
