@@ -18,6 +18,7 @@
 */
 
 #include "helper.h"
+#include "path.h"
 
 #include <KTemporaryFile>
 #include <KIO/NetAccess>
@@ -29,6 +30,7 @@
 #include <kparts/mainwindow.h>
 
 #include <QApplication>
+#include <QFileInfo>
 #include <interfaces/iproject.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
 #include <interfaces/iplugin.h>
@@ -59,8 +61,8 @@ bool KDevelop::removeUrl(const KDevelop::IProject* project, const KUrl& url, con
         }
     }
 
-    //if we didn't find a VCS, we remove using KIO
-    if ( !KIO::NetAccess::del( url, window ) ) {
+    //if we didn't find a VCS, we remove using KIO (if the file still exists, the vcs plugin might have simply deleted the url without returning a job
+    if ( !KIO::NetAccess::del( url, window ) && url.isLocalFile() && (QFileInfo(url.toLocalFile())).exists() ) {
         KMessageBox::error( window,
             isFolder ? i18n( "Cannot remove folder <i>%1</i>.", url.pathOrUrl() )
                         : i18n( "Cannot remove file <i>%1</i>.", url.pathOrUrl() ) );
@@ -69,11 +71,16 @@ bool KDevelop::removeUrl(const KDevelop::IProject* project, const KUrl& url, con
     return true;
 }
 
+bool KDevelop::removePath(const KDevelop::IProject* project, const KDevelop::Path& path, const bool isFolder)
+{
+    return removeUrl(project, path.toUrl(), isFolder);
+}
+
 bool KDevelop::createFile(const KUrl& file)
 {
     if (KIO::NetAccess::exists( file, KIO::NetAccess::DestinationSide, QApplication::activeWindow() )) {
         KMessageBox::error( QApplication::activeWindow(),
-                            i18n( "The file <i>%1</i> exists already.", file.pathOrUrl() ) );
+                            i18n( "The file <i>%1</i> already exists.", file.pathOrUrl() ) );
         return false;
     }
 
@@ -93,6 +100,11 @@ bool KDevelop::createFile(const KUrl& file)
     return true;
 }
 
+bool KDevelop::createFile(const KDevelop::Path& file)
+{
+    return createFile(file.toUrl());
+}
+
 bool KDevelop::createFolder(const KUrl& folder)
 {
     if ( !KIO::NetAccess::mkdir( folder, QApplication::activeWindow() ) ) {
@@ -102,6 +114,11 @@ bool KDevelop::createFolder(const KUrl& folder)
     return true;
 }
 
+bool KDevelop::createFolder(const KDevelop::Path& folder)
+{
+    return createFolder(folder.toUrl());
+}
+
 bool KDevelop::renameUrl(const KDevelop::IProject* project, const KUrl& oldname, const KUrl& newname)
 {
     bool wasVcsMoved = false;
@@ -141,6 +158,11 @@ bool KDevelop::renameUrl(const KDevelop::IProject* project, const KUrl& oldname,
     }
 }
 
+bool KDevelop::renamePath(const KDevelop::IProject* project, const KDevelop::Path& oldName, const KDevelop::Path& newName)
+{
+    return renameUrl(project, oldName.toUrl(), newName.toUrl());
+}
+
 bool KDevelop::copyUrl(const KDevelop::IProject* project, const KUrl& source, const KUrl& target)
 {
     IPlugin* vcsplugin=project->versionControlPlugin();
@@ -159,3 +181,8 @@ bool KDevelop::copyUrl(const KDevelop::IProject* project, const KUrl& source, co
     KIO::CopyJob* job=KIO::copy(source, target);
     return KIO::NetAccess::synchronousRun(job, 0);
 }
+
+bool KDevelop::copyPath(const KDevelop::IProject* project, const KDevelop::Path& source, const KDevelop::Path& target)
+{
+    return copyUrl(project, source.toUrl(), target.toUrl());
+}
