@@ -22,10 +22,12 @@
 #include <QtGui/QSortFilterProxyModel>
 #include <QtCore/QThread>
 #include <qtest_kde.h>
+#include <KMimeType>
 
 #include <projectmodel.h>
+#include <projectproxymodel.h>
 #include <tests/modeltest.h>
-#include "dummyproject.h"
+#include <tests/testproject.h>
 #include <tests/kdevsignalspy.h>
 #include <tests/autotestshell.h>
 #include <tests/testcore.h>
@@ -38,52 +40,18 @@ using KDevelop::ProjectExecutableTargetItem;
 using KDevelop::ProjectLibraryTargetItem;
 using KDevelop::ProjectTargetItem;
 using KDevelop::ProjectBuildFolderItem;
+using KDevelop::Path;
 
-class AddItemThread : public QThread
-{
-Q_OBJECT
-public:
-    AddItemThread( ProjectBaseItem* _parentItem, QObject* parent = 0 )
-        : QThread( parent ), parentItem( _parentItem )
-    {
-    }
-    virtual void run()
-    {
-        this->sleep( 1 );
-        KUrl url = parentItem->url();
-        url.addPath("folder1");
-        ProjectFolderItem* folder = new ProjectFolderItem( 0, url, parentItem );
-        url.addPath( "file1" );
-        new ProjectFileItem( 0, url, folder );
-        emit addedItems();
-    }
-signals:
-    void addedItems();
-private:
-    ProjectBaseItem* parentItem;
-};
+using KDevelop::TestProject;
 
-class SignalReceiver : public QObject
+void debugItemModel(QAbstractItemModel* m, const QModelIndex& parent=QModelIndex(), int depth=0)
 {
-Q_OBJECT
-public:
-    SignalReceiver(ProjectModel* _model, QObject* parent = 0)
-        : QObject(parent), model( _model )
-    {
+    Q_ASSERT(m);
+    qDebug() << QByteArray(depth*2, '-') << m->data(parent).toString();
+    for(int i=0; i<m->rowCount(parent); i++) {
+        debugItemModel(m, m->index(i, 0, parent), depth+1);
     }
-    QThread* threadOfSignalEmission() const
-    {
-        return threadOfReceivedSignal;
-    }
-private slots:
-    void rowsInserted( const QModelIndex&, int, int )
-    {
-        threadOfReceivedSignal = QThread::currentThread();
-    }
-private:
-    QThread* threadOfReceivedSignal;
-    ProjectModel* model;
-};
+}
 
 void ProjectModelTest::initTestCase()
 {
@@ -91,8 +59,11 @@ void ProjectModelTest::initTestCase()
     KDevelop::TestCore::initialize(KDevelop::Core::NoUi);
 
     qRegisterMetaType<QModelIndex>("QModelIndex");
-    model = new ProjectModel( this );
-    modelTest = new ModelTest( model, this );
+    model = KDevelop::ICore::self()->projectController()->projectModel();
+    new ModelTest( model, this );
+    proxy = new ProjectProxyModel( model );
+    new ModelTest(proxy, proxy);
+    proxy->setSourceModel(model);
 }
 
 void ProjectModelTest::init()
@@ -102,29 +73,28 @@ void ProjectModelTest::init()
 
 void ProjectModelTest::cleanupTestCase()
 {
-    delete model;
     KDevelop::TestCore::shutdown();
 }
 
 void ProjectModelTest::testCreateFileSystemItems()
 {
     QFETCH( int, itemType );
-    QFETCH( KUrl, itemUrl );
-    QFETCH( KUrl, expectedItemUrl );
+    QFETCH( Path, itemPath );
+    QFETCH( Path, expectedItemPath );
     QFETCH( QString, expectedItemText );
-    QFETCH( QStringList, expectedItemPath );
+    QFETCH( QStringList, expectedRelativeItemPath );
     QFETCH( int, expectedItemRow );
 
     ProjectBaseItem* newitem = 0;
     switch( itemType ) {
         case ProjectBaseItem::Folder:
-            newitem = new ProjectFolderItem( 0, itemUrl );
+            newitem = new ProjectFolderItem( 0, itemPath );
             break;
         case ProjectBaseItem::BuildFolder:
-            newitem = new ProjectBuildFolderItem( 0, itemUrl );
+            newitem = new ProjectBuildFolderItem( 0, itemPath );
             break;
         case ProjectBaseItem::File:
-            newitem = new ProjectFileItem( 0, itemUrl );
+            newitem = new ProjectFileItem( 0, itemPath );
             break;
     }
     int origRowCount = model->rowCount();
@@ -135,7 +105,7 @@ void ProjectModelTest::testCreateFileSystemItems()
     QVERIFY( model->itemFromIndex( idx ) );
     QCOMPARE( model->itemFromIndex( idx ), newitem );
     QCOMPARE( newitem->text(), expectedItemText );
-    QCOMPARE( newitem->url(), expectedItemUrl );
+    QCOMPARE( newitem->path(), expectedItemPath );
     if( itemType == ProjectBaseItem::File ) {
         QCOMPARE( dynamic_cast<ProjectFileItem*>( newitem )->fileName(), expectedItemText );
     }
@@ -145,39 +115,39 @@ void ProjectModelTest::testCreateFileSystemItems()
     QCOMPARE( newitem->type(), itemType );
     QCOMPARE( model->data( idx ).toString(), expectedItemText );
     QCOMPARE( model->indexFromItem( newitem ), idx );
-    QCOMPARE( model->pathFromIndex( idx ), expectedItemPath );
-    QCOMPARE( model->pathToIndex( expectedItemPath ), idx );
+    QCOMPARE( model->pathFromIndex( idx ), expectedRelativeItemPath );
+    QCOMPARE( model->pathToIndex( expectedRelativeItemPath ), idx );
 }
 
 void ProjectModelTest::testCreateFileSystemItems_data()
 {
     QTest::addColumn<int>( "itemType" );
-    QTest::addColumn<KUrl>( "itemUrl" );
-    QTest::addColumn<KUrl>( "expectedItemUrl" );
+    QTest::addColumn<Path>( "itemPath" );
+    QTest::addColumn<Path>( "expectedItemPath" );
     QTest::addColumn<QString>( "expectedItemText" );
-    QTest::addColumn<QStringList>( "expectedItemPath" );
+    QTest::addColumn<QStringList>( "expectedRelativeItemPath" );
     QTest::addColumn<int>( "expectedItemRow" );
 
     QTest::newRow("RootFolder")
         << (int)ProjectBaseItem::Folder
-        << KUrl("file:///rootdir")
-        << KUrl("file:///rootdir/")
+        << Path(KUrl::fromPath("/rootdir"))
+        << Path(KUrl::fromPath("/rootdir/"))
         << QString::fromLatin1("rootdir")
         << ( QStringList() << "rootdir" )
         << 0;
 
     QTest::newRow("RootBuildFolder")
         << (int)ProjectBaseItem::BuildFolder
-        << KUrl("file:///rootdir")
-        << KUrl("file:///rootdir/")
+        << Path(KUrl::fromPath("/rootdir"))
+        << Path(KUrl::fromPath("/rootdir/"))
         << QString::fromLatin1("rootdir")
         << ( QStringList() << "rootdir" )
         << 0;
 
     QTest::newRow("RootFile")
         << (int)ProjectBaseItem::File
-        << KUrl("file:///rootfile")
-        << KUrl("file:///rootfile")
+        << Path(KUrl::fromPath("/rootfile"))
+        << Path(KUrl::fromPath("/rootfile"))
         << QString::fromLatin1("rootfile")
         << ( QStringList() << "rootfile" )
         << 0;
@@ -243,8 +213,8 @@ void ProjectModelTest::testChangeWithProxyModel()
 {
     QSortFilterProxyModel* proxy = new QSortFilterProxyModel( this );
     proxy->setSourceModel( model );
-    ProjectFolderItem* root = new ProjectFolderItem( 0, KUrl("file:///folder1") );
-    root->appendRow( new ProjectFileItem( 0, KUrl("file:///folder1/file1") ) );
+    ProjectFolderItem* root = new ProjectFolderItem( 0, Path(KUrl::fromPath("/folder1")) );
+    root->appendRow( new ProjectFileItem( 0, Path(KUrl::fromPath("/folder1/file1")) ) );
     model->appendRow( root );
 
     QCOMPARE( model->rowCount(), 1 );
@@ -262,13 +232,13 @@ void ProjectModelTest::testCreateSimpleHierarchy()
     QString fileName = "file";
     QString targetName = "testtarged";
     QString cppFileName = "file.cpp";
-    ProjectFolderItem* rootFolder = new ProjectFolderItem( 0, KUrl("file:///"+folderName) );
+    ProjectFolderItem* rootFolder = new ProjectFolderItem( 0, Path(KUrl::fromPath("/"+folderName)) );
     QCOMPARE(rootFolder->baseName(), folderName);
-    ProjectFileItem* file = new ProjectFileItem( 0, KUrl("file:///"+folderName+"/"+fileName), rootFolder );
+    ProjectFileItem* file = new ProjectFileItem( fileName, rootFolder );
     QCOMPARE(file->baseName(), fileName);
     ProjectTargetItem* target = new ProjectTargetItem( 0, targetName );
     rootFolder->appendRow( target );
-    ProjectFileItem* targetfile = new ProjectFileItem( 0, KUrl("file:///"+folderName+"/"+cppFileName), target );
+    ProjectFileItem* targetfile = new ProjectFileItem( 0, Path(rootFolder->path(), cppFileName), target );
 
     model->appendRow( rootFolder );
 
@@ -300,7 +270,7 @@ void ProjectModelTest::testCreateSimpleHierarchy()
     file = 0;
 
     // Check that we also find a folder with the fileName
-    new ProjectFolderItem( 0, fileName, rootFolder );
+    new ProjectFolderItem( fileName, rootFolder );
     QVERIFY( rootFolder->hasFileOrFolder( fileName ) );
 
     delete rootFolder;
@@ -312,8 +282,8 @@ void ProjectModelTest::testItemSanity()
     ProjectBaseItem* parent = new ProjectBaseItem( 0, "test" );
     ProjectBaseItem* child = new ProjectBaseItem( 0, "test", parent );
     ProjectBaseItem* child2 = new ProjectBaseItem( 0, "ztest", parent );
-    ProjectFileItem* child3 = new ProjectFileItem( 0, KUrl("file:///bcd"), parent );
-    ProjectFileItem* child4 = new ProjectFileItem(  0, KUrl("file:///abcd"), parent  );
+    ProjectFileItem* child3 = new ProjectFileItem( 0, Path(KUrl::fromPath("file:///bcd")), parent );
+    ProjectFileItem* child4 = new ProjectFileItem(  0, Path(KUrl::fromPath("file:///abcd")), parent  );
 
     // Just some basic santiy checks on the API
     QCOMPARE( parent->child( 0 ), child );
@@ -335,7 +305,7 @@ void ProjectModelTest::testItemSanity()
     model->appendRow( parent );
     QCOMPARE( parent->index(), model->index(0, 0, QModelIndex()) );
     QSignalSpy s( model, SIGNAL(dataChanged(QModelIndex,QModelIndex)) );
-    parent->setUrl( KUrl("file:///newtest") );
+    parent->setPath( Path("/newtest") );
     QCOMPARE( s.count(), 1 );
     QCOMPARE( model->data( parent->index() ).toString(), QString("newtest") );
 
@@ -369,22 +339,22 @@ void ProjectModelTest::testRename()
     QFETCH( QString, expectedItemText );
     QFETCH( int, expectedRenameCode );
 
-    DummyProject* proj = new DummyProject( "DummyProject", 0 );
-    ProjectFolderItem* rootItem = new ProjectFolderItem( proj, KUrl("file:///dummyprojectfolder"), 0);
+    const Path projectFolder = Path(KUrl::fromPath("/dummyprojectfolder"));
+    TestProject* proj = new TestProject;
+    ProjectFolderItem* rootItem = new ProjectFolderItem( proj, projectFolder, 0);
     proj->setProjectItem( rootItem );
-    model->appendRow( rootItem );
 
-    new ProjectFileItem(proj, KUrl("existing"), rootItem);
+    new ProjectFileItem("existing", rootItem);
 
     ProjectBaseItem* item = 0;
     if( itemType == ProjectBaseItem::Target ) {
         item = new ProjectTargetItem( proj, itemText, rootItem );
     } else if( itemType == ProjectBaseItem::File ) {
-        item = new ProjectFileItem( proj, KUrl(itemText), rootItem );
+        item = new ProjectFileItem( itemText, rootItem );
     } else if( itemType == ProjectBaseItem::Folder ) {
-        item = new ProjectFolderItem( proj, KUrl(itemText), rootItem );
+        item = new ProjectFolderItem( itemText, rootItem );
     } else if( itemType == ProjectBaseItem::BuildFolder ) {
-        item = new ProjectBuildFolderItem( proj, KUrl(itemText), rootItem );
+        item = new ProjectBuildFolderItem( itemText, rootItem );
     }
     Q_ASSERT( item );
 
@@ -425,6 +395,14 @@ void ProjectModelTest::testRename_data()
     << true
     << QString::fromLatin1("otherfile.cpp")
     << (int)ProjectBaseItem::RenameOk;
+
+    QTest::newRow("SourceAndDestinationFileEqual")
+    << (int)ProjectBaseItem::File
+    << QString::fromLatin1("newfile.cpp")
+    << QString::fromLatin1("newfile.cpp")
+    << false
+    << QString::fromLatin1("newfile.cpp")
+    << (int)ProjectBaseItem::RenameOk;
     
     QTest::newRow("RenameableFolder")
     << (int)ProjectBaseItem::Folder
@@ -433,6 +411,14 @@ void ProjectModelTest::testRename_data()
     << true
     << QString::fromLatin1("otherfolder")
     << (int)ProjectBaseItem::RenameOk;
+
+    QTest::newRow("SourceAndDestinationFolderEqual")
+    << (int)ProjectBaseItem::Folder
+    << QString::fromLatin1("newfolder")
+    << QString::fromLatin1("newfolder")
+    << false
+    << QString::fromLatin1("newfolder")
+    << (int)ProjectBaseItem::RenameOk;
     
     QTest::newRow("RenameableBuildFolder")
     << (int)ProjectBaseItem::BuildFolder
@@ -442,6 +428,14 @@ void ProjectModelTest::testRename_data()
     << QString::fromLatin1("otherbfolder")
     << (int)ProjectBaseItem::RenameOk;
 
+    QTest::newRow("SourceAndDestinationBuildFolderEqual")
+    << (int)ProjectBaseItem::BuildFolder
+    << QString::fromLatin1("newbfolder")
+    << QString::fromLatin1("newbfolder")
+    << false
+    << QString::fromLatin1("newbfolder")
+    << (int)ProjectBaseItem::RenameOk;
+
     QTest::newRow("ExistingFileError")
     << (int)ProjectBaseItem::Folder
     << QString::fromLatin1("mynew")
@@ -461,85 +455,97 @@ void ProjectModelTest::testRename_data()
 
 void ProjectModelTest::testWithProject()
 {
-    DummyProject* proj = new DummyProject( "DummyProject", 0 );
-    ProjectFolderItem* rootItem = new ProjectFolderItem( proj, KUrl("file:///dummyprojectfolder"), 0);
+    TestProject* proj = new TestProject();
+    ProjectFolderItem* rootItem = new ProjectFolderItem( proj, Path(KUrl::fromPath("/dummyprojectfolder")), 0);
     proj->setProjectItem( rootItem );
-    model->appendRow( rootItem );
     ProjectBaseItem* item = model->itemFromIndex( model->index( 0, 0 ) );
     QCOMPARE( item, rootItem );
     QCOMPARE( item->text(), proj->name() );
-    QCOMPARE( item->url(), proj->folder() );
+    QCOMPARE( item->path(), proj->path() );
 }
 
-void ProjectModelTest::testAddItemInThread()
+void ProjectModelTest::testItemsForPath()
 {
-    ProjectFolderItem* root = new ProjectFolderItem( 0, KUrl("file:///f1"), 0 );
-    model->appendRow( root );
-    AddItemThread t( root );
-    SignalReceiver check( model );
-    connect( model, SIGNAL(rowsInserted(QModelIndex,int,int)), &check, SLOT(rowsInserted(QModelIndex,int,int)), Qt::DirectConnection );
-    KDevelop::KDevSignalSpy spy( &t, SIGNAL(addedItems()), Qt::QueuedConnection );
-    t.start();
-    QVERIFY(spy.wait( 10000 ));
-    QCOMPARE( qApp->thread(), check.threadOfSignalEmission() );
-}
-
-void ProjectModelTest::testDeleteLots()
-{
-    delete modelTest;
-
-    const int items = 10000;
-    ProjectBaseItem* root = new ProjectBaseItem( 0, "root", 0 );
-    model->appendRow( root );
-    for ( int i = 0; i < items; ++i ) {
-        new ProjectBaseItem( 0, QString::number(i), root );
-    }
-    QCOMPARE(root->children().size(), items);
-    delete root;
-
-    modelTest = new ModelTest( model, this );
-}
-
-void ProjectModelTest::testItemsForUrl()
-{
-    QFETCH(KUrl, url);
+    QFETCH(Path, path);
     QFETCH(ProjectBaseItem*, root);
     QFETCH(int, matches);
 
     model->appendRow(root);
 
-    QList< ProjectBaseItem* > items = model->itemsForUrl(url);
+    QList< ProjectBaseItem* > items = model->itemsForPath(KDevelop::IndexedString(path.pathOrUrl()));
     QCOMPARE(items.size(), matches);
     foreach(ProjectBaseItem* item, items) {
-        QVERIFY(item->url().equals(url, KUrl::CompareWithoutTrailingSlash));
+        QVERIFY(item->path() == path);
     }
 
     model->clear();
 }
 
-void ProjectModelTest::testItemsForUrl_data()
+void ProjectModelTest::testItemsForPath_data()
 {
-    QTest::addColumn<KUrl>("url");
+    QTest::addColumn<Path>("path");
     QTest::addColumn<ProjectBaseItem*>("root");
     QTest::addColumn<int>("matches");
 
     {
-        ProjectFolderItem* root = new ProjectFolderItem(0, KUrl("file:////tmp/"));
-        ProjectFileItem* file = new ProjectFileItem(0, KUrl(root->url(), "a"), root);
-        QTest::newRow("find one") << file->url() << static_cast<ProjectBaseItem*>(root) << 1;
+        ProjectFolderItem* root = new ProjectFolderItem(0, Path(KUrl::fromPath("/tmp/")));
+        ProjectFileItem* file = new ProjectFileItem("a", root);
+        QTest::newRow("find one") << file->path() << static_cast<ProjectBaseItem*>(root) << 1;
     }
 
     {
-        ProjectFolderItem* root = new ProjectFolderItem(0, KUrl("file:////tmp/"));
-        ProjectFolderItem* folder = new ProjectFolderItem(0, KUrl(root->url(), "a"), root);
-        ProjectFileItem* file = new ProjectFileItem(0, KUrl(folder->url(), "foo"), folder);
+        ProjectFolderItem* root = new ProjectFolderItem(0, Path(KUrl::fromPath("/tmp/")));
+        ProjectFolderItem* folder = new ProjectFolderItem("a", root);
+        ProjectFileItem* file = new ProjectFileItem("foo", folder);
         ProjectTargetItem* target = new ProjectTargetItem(0, "b", root);
-        ProjectFileItem* file2 = new ProjectFileItem(0, file->url(), target);
+        ProjectFileItem* file2 = new ProjectFileItem(0, file->path(), target);
         Q_UNUSED(file2);
-        QTest::newRow("find two") << file->url() << static_cast<ProjectBaseItem*>(root) << 2;
+        QTest::newRow("find two") << file->path() << static_cast<ProjectBaseItem*>(root) << 2;
     }
 }
 
+void ProjectModelTest::testProjectProxyModel()
+{
+    ProjectFolderItem* root = new ProjectFolderItem(0, Path(KUrl::fromPath("/tmp/")));
+    new ProjectFileItem("b1", root);
+    new ProjectFileItem("a1", root);
+    new ProjectFileItem("d1", root);
+    new ProjectFileItem("c1", root);
+    model->appendRow(root);
+
+    QModelIndex proxyRoot = proxy->mapFromSource(root->index());
+    QCOMPARE(model->rowCount(root->index()), 4);
+    QCOMPARE(proxy->rowCount(proxyRoot), 4);
+    QCOMPARE(proxy->index(0, 0, proxy->index(0, 0)).data().toString(), QString("a1"));
+    QCOMPARE(proxy->index(1, 0, proxy->index(0, 0)).data().toString(), QString("b1"));
+    QCOMPARE(proxy->index(2, 0, proxy->index(0, 0)).data().toString(), QString("c1"));
+    QCOMPARE(proxy->index(3, 0, proxy->index(0, 0)).data().toString(), QString("d1"));
+
+    model->clear();
+}
+
+void ProjectModelTest::testProjectFileSet()
+{
+    TestProject* project = new TestProject;
+
+    QVERIFY(project->fileSet().isEmpty());
+    Path path(KUrl::fromPath("/tmp/a"));
+    ProjectFileItem* item = new ProjectFileItem(project, path, project->projectItem());
+    QCOMPARE(project->fileSet().size(), 1);
+    qDebug() << path << project->fileSet().begin()->toUrl();
+    QCOMPARE(Path(project->fileSet().begin()->toUrl()), path);
+    delete item;
+    QVERIFY(project->fileSet().isEmpty());
+}
+
+void ProjectModelTest::testProjectFileIcon()
+{
+    ProjectFileItem* item = new ProjectFileItem(0, Path(KUrl::fromPath("/tmp/foo.txt")));
+    const QString txtIcon = KMimeType::iconNameForUrl(item->path().toUrl());
+    QCOMPARE(item->iconName(), txtIcon);
+    item->setPath(Path(KUrl::fromPath("/tmp/bar.cpp")));
+    QCOMPARE(item->iconName(), KMimeType::iconNameForUrl(item->path().toUrl()));
+    QVERIFY(item->iconName() != txtIcon);
+}
+
 QTEST_KDEMAIN( ProjectModelTest, GUI)
-#include "projectmodeltest.moc"
-#include "moc_projectmodeltest.cpp"
