@@ -28,15 +28,8 @@
 #include <klocale.h>
 #include <ksplashscreen.h>
 
-#include <sublime/area.h>
-#include <sublime/tooldocument.h>
-
-#include <language/duchain/topducontext.h>
-#include <language/duchain/repositories/itemrepository.h>
 #include <language/duchain/duchain.h>
 
-#include "shellextension.h"
-
 #include "mainwindow.h"
 #include "sessioncontroller.h"
 #include "uicontroller.h"
@@ -49,7 +42,7 @@
 #include "session.h"
 #include "documentationcontroller.h"
 #include "sourceformattercontroller.h"
-#include "progressmanager.h"
+#include "progresswidget/progressmanager.h"
 #include "selectioncontroller.h"
 #include "debugcontroller.h"
 #include "kdevplatformversion.h"
@@ -104,7 +97,7 @@ KAboutData aboutData()
     KAboutData aboutData( "kdevplatform", "kdevplatform", 
                           ki18n("KDevelop Platform"), KDEVPLATFORM_VERSION_STR, 
                           ki18n("Development Platform for IDE-like Applications"), 
-                          KAboutData::License_LGPL_V2, ki18n( "Copyright 2004-2012, The KDevelop developers" ),
+                          KAboutData::License_LGPL_V2, ki18n( "Copyright 2004-2014, The KDevelop developers" ),
                           KLocalizedString(), "http://www.kdevelop.org" );
     aboutData.addAuthor( ki18n("Andreas Pakulat"), ki18n( "Architecture, VCS Support, Project Management Support, QMake Projectmanager" ), "apaku@gmx.de" );
     aboutData.addAuthor( ki18n("Alexander Dymo"), ki18n( "Architecture, Sublime UI, Ruby support" ), "adymo@kdevelop.org" );
@@ -134,19 +127,21 @@ CorePrivate::CorePrivate(Core *core):
 bool CorePrivate::initialize(Core::Setup mode, QString session )
 {
     m_mode=mode;
+    emit m_core->startupProgress(0);
     if( !sessionController )
     {
         sessionController = new SessionController(m_core);
     }
     if( !workingSetController && !(mode & Core::NoUi) )
     {
-        workingSetController = new WorkingSetController(m_core);
+        workingSetController = new WorkingSetController();
     }
     kDebug() << "Creating ui controller";
     if( !uiController )
     {
         uiController = new UiController(m_core);
     }
+    emit m_core->startupProgress(10);
     kDebug() << "Creating plugin controller";
 
     if( !pluginController )
@@ -157,6 +152,7 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     {
         partController = new PartController(m_core, uiController.data()->defaultMainWindow());
     }
+    emit m_core->startupProgress(20);
 
     if( !projectController )
     {
@@ -174,6 +170,7 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
         // on the document controller.
         languageController = new LanguageController(m_core);
     }
+    emit m_core->startupProgress(25);
 
     if( !runController )
     {
@@ -184,16 +181,18 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     {
         sourceFormatterController = new SourceFormatterController(m_core);
     }
+    emit m_core->startupProgress(30);
 
     if ( !progressController) 
     {
-        progressController = new ProgressManager();
+        progressController = ProgressManager::instance();
     }
 
     if( !selectionController )
     {
         selectionController = new SelectionController(m_core);
     }
+    emit m_core->startupProgress(35);
 
     if( !documentationController && !(mode & Core::NoUi) )
     {
@@ -204,19 +203,23 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     {
         debugController = new DebugController(m_core);
     }
+    emit m_core->startupProgress(40);
 
     if( !testController )
     {
         testController = new TestController(m_core);
     }
+    emit m_core->startupProgress(47);
 
     kDebug() << "initializing ui controller";
 
     sessionController.data()->initialize( session );
-    if( !sessionController.data()->activeSession() ) {
+    if( !sessionController.data()->activeSessionLock() ) {
         return false;
     }
 
+    emit m_core->startupProgress(55);
+
     // TODO: Is this early enough, or should we put the loading of the session into
     // the controller construct
     DUChain::initialize();
@@ -226,6 +229,8 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
     projectController.data()->initialize();
     documentController.data()->initialize();
 
+    emit m_core->startupProgress(63);
+
     /* This is somewhat messy.  We want to load the areas before
         loading the plugins, so that when each plugin is loaded we
         know if an area wants some of the tool view from that plugin.
@@ -237,6 +242,7 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
 
     kDebug() << "loading session plugins";
     pluginController.data()->initialize();
+    emit m_core->startupProgress(78);
 
     if(!(mode & Core::NoUi))
     {
@@ -247,12 +253,14 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
         uiController.data()->loadAllAreas(KGlobal::config());
         uiController.data()->defaultMainWindow()->show();
     }
+    emit m_core->startupProgress(90);
     runController.data()->initialize();
     sourceFormatterController.data()->initialize();
     selectionController.data()->initialize();
     if (documentationController) {
         documentationController.data()->initialize();
     }
+    emit m_core->startupProgress(95);
     debugController.data()->initialize();
     testController.data()->initialize();
 
@@ -275,6 +283,7 @@ bool CorePrivate::initialize(Core::Setup mode, QString session )
         delete doc;
     }
 
+    emit m_core->startupProgress(100);
     return true;
 }
 CorePrivate::~CorePrivate()
@@ -310,13 +319,15 @@ CorePrivate::~CorePrivate()
     testController.clear();
 }
 
-
 bool Core::initialize(KSplashScreen* splash, Setup mode, const QString& session )
 {
     if (m_self)
         return true;
 
     m_self = new Core();
+    if (splash) {
+        connect(m_self, SIGNAL(startupProgress(int)), splash, SLOT(progress(int)));
+    }
     bool ret = m_self->d->initialize(mode, session);
     if( splash ) {
         QTimer::singleShot( 200, splash, SLOT(deleteLater()) );
@@ -401,9 +412,12 @@ void Core::cleanup()
 
         //Disable the functionality of the language controller
         d->languageController.data()->cleanup();
+
+        DUChain::self()->shutdown();
     }
 
     d->m_cleanedUp = true;
+    emit shutdownCompleted();
 }
 
 KComponentData Core::componentData() const
@@ -421,6 +435,11 @@ ISession* Core::activeSession()
     return sessionController()->activeSession();
 }
 
+ISessionLock::Ptr Core::activeSessionLock()
+{
+    return sessionController()->activeSessionLock();
+}
+
 SessionController *Core::sessionController()
 {
     return d->sessionController.data();
