@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef KDEVPLATFORM_CORE_P_H
-#define KDEVPLATFORM_CORE_P_H
+#ifndef KDEVPLATFORM_PLATFORM_CORE_P_H
+#define KDEVPLATFORM_PLATFORM_CORE_P_H
 
 #include <kcomponentdata.h>
 #include <core.h>
@@ -42,6 +42,7 @@ class SelectionController;
 class DocumentationController;
 class DebugController;
 class WorkingSetController;
+class TestController;
 
 class KDEVPLATFORMSHELL_EXPORT CorePrivate {
 public:
@@ -62,6 +63,7 @@ public:
     QWeakPointer<DocumentationController> documentationController;
     QWeakPointer<DebugController> debugController;
     QWeakPointer<WorkingSetController> workingSetController;
+    QWeakPointer<TestController> testController;
 
     KComponentData m_componentData;
     Core *m_core;
