@@ -17,15 +17,14 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef DOCUMENTATIONCONTROLLER_H
-#define DOCUMENTATIONCONTROLLER_H
+#ifndef KDEVPLATFORM_DOCUMENTATIONCONTROLLER_H
+#define KDEVPLATFORM_DOCUMENTATIONCONTROLLER_H
 
 #include <interfaces/idocumentationcontroller.h>
-#include <QObject>
-#include <KAction>
 
 class DocumentationViewFactory;
-class QAction;
+
+class KAction;
 
 namespace KDevelop
 {
@@ -60,4 +59,4 @@ class DocumentationController : public KDevelop::IDocumentationController
 
 }
 
-#endif // DOCUMENTATIONCONTROLLER_H
+#endif // KDEVPLATFORM_DOCUMENTATIONCONTROLLER_H
