@@ -17,8 +17,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef LAUNCHCONFIGURATIONDIALOG_H
-#define LAUNCHCONFIGURATIONDIALOG_H
+#ifndef KDEVPLATFORM_LAUNCHCONFIGURATIONDIALOG_H
+#define KDEVPLATFORM_LAUNCHCONFIGURATIONDIALOG_H
 
 #include <QtCore/QAbstractItemModel>
 #include <QtCore/QMap>
