@@ -20,12 +20,11 @@ along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
-#ifndef KDEV_MAINWINDOW_H
-#define KDEV_MAINWINDOW_H
+#ifndef KDEVPLATFORM_MAINWINDOW_H
+#define KDEVPLATFORM_MAINWINDOW_H
 
 #include <KDE/KXmlGuiWindow>
 
-#include "core.h"
 #include <sublime/mainwindow.h>
 
 #include "shellexport.h"
@@ -35,7 +34,6 @@ namespace KTextEditor { class View; }
 namespace KDevelop
 {
 
-class Context;
 class IDocument;
 
 /**
@@ -52,8 +50,6 @@ public:
 
     /*! @p status must implement KDevelop::IStatus */
     void registerStatus(QObject* status);
-    
-    virtual QWidget* customButtonForAreaSwitcher( Sublime::Area* area );
 
 public Q_SLOTS:
     /*! Shows an error message in the status bar.
@@ -62,14 +58,17 @@ public Q_SLOTS:
     void showErrorMessage(const QString& message, int timeout);
 
     virtual Q_SCRIPTABLE void ensureVisible();
+    virtual Q_SCRIPTABLE QString windowTitle() {
+        return Sublime::MainWindow::windowTitle();
+    }
 
-public Q_SLOTS:
     virtual void setVisible( bool visible );
     void configureShortcuts();
+    virtual void loadSettings();
+    virtual void saveSettings();
 
 Q_SIGNALS:
     void finishedLoading();
-    void contextMenu( KMenu *menu, const Context *context );
 
 protected:
     //FIXME DOCUMENT!!!  queryClose() must call all of the Core cleanup() methods!
@@ -77,10 +76,6 @@ protected:
     //reimplemented from KXMLGUIBuilder to support visible menubar separators
     QAction *createCustomElement(QWidget *parent, int index, const QDomElement &element);
 
-public Q_SLOTS:
-    virtual void loadSettings();
-    virtual void saveSettings();
-protected:
     virtual void initialize();
     virtual void cleanup();
     virtual void initializeStatusBar();
@@ -91,7 +86,7 @@ protected:
 
 protected Q_SLOTS:
     virtual void tabContextMenuRequested(Sublime::View* , KMenu* );
-    virtual void tabToolTipRequested(Sublime::View* view, QPoint point);    
+    virtual void tabToolTipRequested(Sublime::View* view, Sublime::Container* container, int tab);
     virtual void dockBarContextMenuRequested(Qt::DockWidgetArea, const QPoint&);
 
 private Q_SLOTS:
