@@ -8,8 +8,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef OPENPROJECTPAGE_H
-#define OPENPROJECTPAGE_H
+#ifndef KDEVPLATFORM_OPENPROJECTPAGE_H
+#define KDEVPLATFORM_OPENPROJECTPAGE_H
 
 #include <QtGui/QWidget>
 #include <QtCore/QMap>
@@ -34,6 +34,9 @@ signals:
     void urlSelected( const KUrl& );
     void accepted();
 
+protected:
+    virtual void showEvent(QShowEvent*);
+
 private slots:
     void highlightFile(const QString&);
     void opsEntered(const KUrl& item );
