@@ -29,6 +29,8 @@
 
 #include <kurl.h>
 #include <kmimetype.h>
+#include <KTextEditor/ContainerInterface>
+#include <KSharedConfig>
 
 #include "core.h"
 
@@ -46,13 +48,17 @@ class Document;
 class Editor;
 }
 
+Q_DECLARE_METATYPE(KSharedConfig::Ptr)
+
 namespace KDevelop
 {
 
-class KDEVPLATFORMSHELL_EXPORT PartController : public IPartController
+class KDEVPLATFORMSHELL_EXPORT PartController : public IPartController, public KTextEditor::MdiContainer
 {
     friend class CorePrivate;
     Q_OBJECT
+    Q_INTERFACES( KTextEditor::MdiContainer )
+
 public:
     PartController(Core *core, QWidget *toplevel);
     virtual ~PartController();
@@ -77,6 +83,15 @@ public:
 
     bool isTextType( KMimeType::Ptr mimeType );
 
+
+    //KTextEditor::MdiContainer implementation
+    virtual void setActiveView( KTextEditor::View * view );
+    virtual KTextEditor::View * activeView();
+    virtual KTextEditor::Document * createDocument();
+    virtual bool closeDocument( KTextEditor::Document * doc );
+    virtual KTextEditor::View * createView( KTextEditor::Document * doc );
+    virtual bool closeView( KTextEditor::View * view );
+
 protected:
     virtual void loadSettings( bool projectIsLoaded );
     virtual void saveSettings( bool projectIsLoaded );
