@@ -28,6 +28,10 @@ Boston, MA 02110-1301, USA.
 #include <QtCore/QList>
 #include <QtCore/QMap>
 #include <QtGui/QItemSelectionModel>
+#include <QtGui/QGroupBox>
+#include <QtGui/QRadioButton>
+#include <QtGui/QBoxLayout>
+#include <QtGui/QLabel>
 
 #include <kaction.h>
 #include <kconfig.h>
@@ -77,8 +81,8 @@ Boston, MA 02110-1301, USA.
 #include <kio/job.h>
 #include "sessioncontroller.h"
 #include "session.h"
-#include <QApplication>
 #include <QDBusConnection>
+#include <QApplication>
 #include <vcs/models/projectchangesmodel.h>
 #include <vcs/widgets/vcsdiffpatchsources.h>
 #include <vcs/widgets/vcscommitdialog.h>
@@ -108,6 +112,7 @@ public:
     bool m_foundProjectFile; //Temporary flag used while searching the hierarchy for a project file
     bool m_cleaningUp; //Temporary flag enabled while destroying the project-controller
     QPointer<ProjectChangesModel> m_changesModel;
+    QHash< IProject*, QPointer<KJob> > m_parseJobs; // parse jobs that add files from the project to the background parser.
 
     ProjectControllerPrivate( ProjectController* p )
         : m_core(0), model(0), selectionModel(0), dialog(0), m_configuringProject(0), q(p), buildset(0), m_foundProjectFile(false), m_cleaningUp(false)
@@ -139,8 +144,8 @@ public:
         cfgDlg.setKCMArguments( QStringList()
                                     << proj->developerTempFile()
                                     << proj->projectTempFile()
-                                    << proj->projectFileUrl().url()
-                                    << proj->developerFileUrl().url()
+                                    << proj->projectFile().pathOrUrl()
+                                    << proj->developerFile().pathOrUrl()
                                     << proj->name() );
         m_configuringProject = proj;
         cfgDlg.setWindowTitle( i18n("Configure Project %1", proj->name()) );
@@ -148,19 +153,17 @@ public:
         proj->projectConfiguration()->sync();
         m_configuringProject = 0;
     }
+
     void saveListOfOpenedProjects()
     {
-        KSharedConfig::Ptr config = Core::self()->activeSession()->config();
-        KConfigGroup group = config->group( "General Options" );
-    
         KUrl::List openProjects;
-    
+        openProjects.reserve( m_projects.size() );
+
         foreach( IProject* project, m_projects ) {
-            openProjects.append(project->projectFileUrl());
+            openProjects.append(project->projectFile().toUrl());
         }
-    
-        group.writeEntry( "Open Projects", openProjects.toStringList() );
-        group.sync();
+
+        Core::self()->activeSession()->setContainedProjects( openProjects );
     }
 
     // Recursively collects builder dependencies for a project.
@@ -190,8 +193,9 @@ public:
         {
             IPlugin* plugin = *it;
             const KPluginInfo info = m_core->pluginController()->pluginInfo( plugin );
-            if (info.property("X-KDevelop-Category").toString() != "Project")
+            if (info.property("X-KDevelop-Category").toString() != "Project") {
                 continue;
+            }
             IProjectFileManager* manager = plugin->extension<KDevelop::IProjectFileManager>();
             if( manager && manager != project->projectFileManager() )
             {
@@ -277,7 +281,6 @@ public:
                                     m_core->uiController()->activeMainWindow() );
             return;
         }
-        m_currentlyOpening += url;
 
         foreach( IProject* project, m_projects )
         {
@@ -292,11 +295,14 @@ public:
             }
         }
 
+        m_currentlyOpening += url;
+
         m_core->pluginControllerInternal()->loadProjectPlugins();
 
         Project* project = new Project();
-        emit q->projectAboutToBeOpened( project );
-        if ( !project->open( url ) )
+        QObject::connect(project, SIGNAL(aboutToOpen(KDevelop::IProject*)),
+                         q, SIGNAL(projectAboutToBeOpened(KDevelop::IProject*)));
+        if ( !project->open( Path(url) ) )
         {
             m_currentlyOpening.removeAll(url);
             q->abortOpeningProject(project);
@@ -304,6 +310,11 @@ public:
         }
     }
 
+    void areaChanged(Sublime::Area* area) {
+        KActionCollection* ac = m_core->uiControllerInternal()->defaultMainWindow()->actionCollection();
+        ac->action("commit_current_project")->setEnabled(area->objectName() == "code");
+        ac->action("commit_current_project")->setVisible(area->objectName() == "code");
+    }
 };
 
 IProjectDialogProvider::IProjectDialogProvider()
@@ -476,15 +487,23 @@ void ProjectController::setupActions()
 
     d->m_openProject = action = ac->addAction( "project_open" );
     action->setText(i18nc( "@action", "Open / Import Project..." ) );
-    action->setToolTip( i18nc( "@info:tooltip", "Open / Import Project" ) );
-    action->setWhatsThis( i18nc( "@info:whatsthis", "<b>Open / Import project</b><p>Open an existing KDevelop 4 project or import an existing Project into KDevelop 4. This entry allows to select a KDevelop4 project file or an existing directory to open it in KDevelop. When opening an existing directory that does not yet have a KDevelop4 project file, the file will be created.</p>" ) );
+    action->setToolTip( i18nc( "@info:tooltip", "Open or import project" ) );
+    action->setWhatsThis( i18nc( "@info:whatsthis", "Open an existing KDevelop 4 project or import "
+                                                    "an existing Project into KDevelop 4. This entry "
+                                                    "allows to select a KDevelop4 project file or an "
+                                                    "existing directory to open it in KDevelop. "
+                                                    "When opening an existing directory that does "
+                                                    "not yet have a KDevelop4 project file, the file "
+                                                    "will be created." ) );
     action->setIcon(KIcon("project-open"));
     connect( action, SIGNAL(triggered(bool)), SLOT(openProject()) );
     
     d->m_fetchProject = action = ac->addAction( "project_fetch" );
     action->setText(i18nc( "@action", "Fetch Project..." ) );
-    action->setToolTip( i18nc( "@info:tooltip", "Fetch Project" ) );
-    action->setWhatsThis( i18nc( "@info:whatsthis", "<b>Fetch project</b><p>Guides the user through the project fetch and then imports it into KDevelop 4.</p>" ) );
+    action->setIcon( KIcon( "download" ) );
+    action->setToolTip( i18nc( "@info:tooltip", "Fetch project" ) );
+    action->setWhatsThis( i18nc( "@info:whatsthis", "Guides the user through the project fetch "
+                                                    "and then imports it into KDevelop 4." ) );
 //     action->setIcon(KIcon("project-open"));
     connect( action, SIGNAL(triggered(bool)), SLOT(fetchProject()) );
 
@@ -492,7 +511,7 @@ void ProjectController::setupActions()
 //    action->setText( i18n( "C&lose Project" ) );
 //    connect( action, SIGNAL(triggered(bool)), SLOT(closeProject()) );
 //    action->setToolTip( i18n( "Close project" ) );
-//    action->setWhatsThis( i18n( "<b>Close project</b><p>Closes the current project." ) );
+//    action->setWhatsThis( i18n( "Closes the current project." ) );
 //    action->setEnabled( false );
 
     d->m_closeProject = action = ac->addAction( "project_close" );
@@ -513,18 +532,17 @@ void ProjectController::setupActions()
     action->setText( i18n( "Commit Current Project..." ) );
     action->setIconText( i18n( "Commit..." ) );
     action->setIcon( KIcon("svn-commit") );
+    connect(d->m_core->uiControllerInternal()->defaultMainWindow(), SIGNAL(areaChanged(Sublime::Area*)),
+            SLOT(areaChanged(Sublime::Area*)));
+    d->m_core->uiControllerInternal()->area(0, "code")->addAction(action);
 
     KSharedConfig * config = KGlobal::config().data();
 //     KConfigGroup group = config->group( "General Options" );
 
-    d->m_recentAction = new KRecentFilesAction( this );
-    connect( d->m_recentAction, SIGNAL(urlSelected(KUrl)), SLOT(
-                            openProject( const KUrl& ) ));
+    d->m_recentAction = KStandardAction::openRecent(this, SLOT(openProject(KUrl)), this);
     ac->addAction( "project_open_recent", d->m_recentAction );
-    d->m_recentAction->setText( i18n( "Open Recent" ) );
-    d->m_recentAction->setToolTip( i18nc( "@info:tooltip", "Open recent project" ) );
-    d->m_recentAction->setWhatsThis(
-        i18nc( "@info:whatsthis", "<b>Open recent project</b><p>Opens recently opened project.</p>" ) );
+    d->m_recentAction->setText( i18n( "Open Recent Project" ) );
+    d->m_recentAction->setWhatsThis( i18nc( "@info:whatsthis", "Opens recently opened project." ) );
     d->m_recentAction->loadEntries( KConfigGroup(config, "RecentProjects") );
     
     KAction* openProjectForFileAction = new KAction( this );
@@ -542,6 +560,10 @@ ProjectController::~ProjectController()
 
 void ProjectController::cleanup()
 {
+    if ( d->m_currentlyOpening.isEmpty() ) {
+        d->saveListOfOpenedProjects();
+    }
+
     d->m_cleaningUp = true;
     if( buildSetModel() ) {
         buildSetModel()->storeToSession( Core::self()->activeSession() );
@@ -686,6 +708,7 @@ void ProjectController::openProjectForUrl(const KUrl& sourceUrl) {
 void ProjectController::openProject( const KUrl &projectFile )
 {
     KUrl url = projectFile;
+    QList<const Session*> existingSessions;
 
     if(!Core::self()->sessionController()->activeSession()->containedProjects().contains(url))
     {
@@ -693,12 +716,7 @@ void ProjectController::openProject( const KUrl &projectFile )
         {
             if(session->containedProjects().contains(url))
             {
-                int res = KMessageBox::questionYesNo(Core::self()->uiControllerInternal()->activeMainWindow(),
-                                i18n("The project you are opening is part of the session %1, do you want to open the session instead?", session->description()));
-                if(res == KMessageBox::Yes)
-                {
-                    Core::self()->sessionController()->loadSession(session->id().toString());
-                    
+                existingSessions << session;
 #if 0
                     ///@todo Think about this! Problem: The session might already contain files, the debugger might be active, etc.
                     //If this session is empty, close it
@@ -709,19 +727,54 @@ void ProjectController::openProject( const KUrl &projectFile )
                             window->close();
                     }
 #endif
-                    
+            }
+        }
+    }
+
+    if ( ! existingSessions.isEmpty() ) {
+        KDialog dialog(Core::self()->uiControllerInternal()->activeMainWindow());
+        dialog.setButtons(KDialog::Ok | KDialog::Cancel);
+        dialog.setWindowTitle(i18n("Project Already Open"));
+
+        QWidget contents;
+        contents.setLayout(new QVBoxLayout);
+        contents.layout()->addWidget(new QLabel(i18n("The project you're trying to open is already open in at least one "
+                                                     "other session.<br>What do you want to do?")));
+        QGroupBox sessions;
+        sessions.setLayout(new QVBoxLayout);
+        QRadioButton* newSession = new QRadioButton(i18n("Add project to current session"));
+        sessions.layout()->addWidget(newSession);
+        newSession->setChecked(true);
+        foreach ( const Session* session, existingSessions ) {
+            QRadioButton* button = new QRadioButton(i18n("Open session %1", session->description()));
+            button->setProperty("sessionid", session->id().toString());
+            sessions.layout()->addWidget(button);
+        }
+        sessions.layout()->addItem(new QSpacerItem(0, 0, QSizePolicy::Expanding, QSizePolicy::Expanding));
+        contents.layout()->addWidget(&sessions);
+
+        dialog.setMainWidget(&contents);
+        bool success = dialog.exec();
+        if (!success)
+            return;
+
+        foreach ( const QObject* obj, sessions.children() ) {
+            if ( const QRadioButton* button = qobject_cast<const QRadioButton*>(obj) ) {
+                QString sessionid = button->property("sessionid").toString();
+                if ( button->isChecked() && ! sessionid.isEmpty() ) {
+                    Core::self()->sessionController()->loadSession(sessionid);
                     return;
                 }
             }
         }
     }
-    
+
     if ( url.isEmpty() )
     {
         url = d->dialog->askProjectConfigLocation(false);
     }
 
-    if ( !url.isEmpty() )    
+    if ( !url.isEmpty() )
     {
         d->importProject(url);
     }
@@ -750,14 +803,7 @@ void ProjectController::projectImportingFinished( IProject* project )
     d->m_projectPlugins.insert( project, pluglist );
     d->m_projects.append( project );
 
-    if(!Core::self()->sessionController()->activeSession()->containedProjects().contains(project->projectFileUrl()))
-        d->saveListOfOpenedProjects();
-    
-//     KActionCollection * ac = d->m_core->uiController()->defaultMainWindow()->actionCollection();
-//     QAction * action;
-
-    //action = ac->action( "project_close" );
-    //action->setEnabled( true );
+    d->saveListOfOpenedProjects();
 
     if (Core::self()->setupFlags() != Core::NoUi)
     {
@@ -773,21 +819,7 @@ void ProjectController::projectImportingFinished( IProject* project )
     d->m_currentlyOpening.removeAll(project->projectFileUrl());
     emit projectOpened( project );
 
-    if (parseAllProjectSources())
-    {
-        KJob* parseProjectJob = new KDevelop::ParseProjectJob(project);
-        ICore::self()->runController()->registerJob(parseProjectJob);
-    }
-
-    // Add all currently open files that belong to the project to the background-parser,
-    // since more information may be available for parsing them now(Like include-paths).
-    foreach(IDocument* document, Core::self()->documentController()->openDocuments())
-    {
-        if(!project->filesForUrl(document->url()).isEmpty())
-        {
-            Core::self()->languageController()->backgroundParser()->addDocument( IndexedString(document->url()), TopDUContext::AllDeclarationsContextsAndUses, 10 );
-        }
-    }
+    reparseProject(project);
 }
 
 // helper method for closeProject()
@@ -821,9 +853,10 @@ void ProjectController::unloadUnusedProjectPlugins(IProject* proj)
 // helper method for closeProject()
 void ProjectController::closeAllOpenedFiles(IProject* proj)
 {
-    Q_FOREACH( ProjectFileItem *fileItem, proj->files() )
-    {
-        Core::self()->documentControllerInternal()->closeDocument( fileItem->url() );
+    foreach(IDocument* doc, Core::self()->documentController()->openDocuments()) {
+        if (proj->inProject(IndexedString(doc->url()))) {
+            doc->close();
+        }
     }
 }
 
@@ -886,10 +919,13 @@ ProjectModel* ProjectController::projectModel()
 
 IProject* ProjectController::findProjectForUrl( const KUrl& url ) const
 {
-    Q_FOREACH( IProject* proj, d->m_projects )
-    {
-        if( proj->inProject( url ) )
-            return proj;
+    if (d->m_projects.isEmpty()) {
+        return 0;
+    }
+
+    ProjectBaseItem* item = d->model->itemForPath(IndexedString(url));
+    if (item) {
+        return item->project();
     }
     return 0;
 }
@@ -936,12 +972,12 @@ bool ProjectController::isProjectNameUsed( const QString& name ) const
 
 KUrl ProjectController::projectsBaseDirectory() const
 {
-    KConfigGroup group = Core::self()->activeSession()->config()->group( "Project Manager" );
+    KConfigGroup group = KGlobal::config()->group( "Project Manager" );
     return group.readEntry( "Projects Base Directory",
                                      KUrl( QDir::homePath()+"/projects" ) );
 }
 
-QString ProjectController::prettyFilePath(KUrl url, FormattingOptions format) const
+QString ProjectController::prettyFilePath(const KUrl& url, FormattingOptions format) const
 {
     IProject* project = Core::self()->projectController()->findProjectForUrl(url);
     
@@ -965,7 +1001,7 @@ QString ProjectController::prettyFilePath(KUrl url, FormattingOptions format) co
         } else {
             prefixText = project->name() + '/';
         }
-        QString relativePath = project->relativeUrl(url.upUrl()).path(KUrl::AddTrailingSlash);
+        QString relativePath = KUrl::relativeUrl(project->folder(), url.upUrl());
         if(relativePath.startsWith("./"))
             relativePath = relativePath.mid(2);
         prefixText += relativePath;
@@ -973,7 +1009,7 @@ QString ProjectController::prettyFilePath(KUrl url, FormattingOptions format) co
     return prefixText;
 }
 
-QString ProjectController::prettyFileName(KUrl url, FormattingOptions format) const
+QString ProjectController::prettyFileName(const KUrl& url, FormattingOptions format) const
 {
     IProject* project = Core::self()->projectController()->findProjectForUrl(url);
     if(project && project->folder().equals(url, KUrl::CompareWithoutTrailingSlash))
@@ -1028,14 +1064,14 @@ void ProjectController::commitCurrentProject()
     IProject* project = ICore::self()->projectController()->findProjectForUrl(url);
     
     if(project && project->versionControlPlugin()) {
-        KUrl baseUrl=project->projectItem()->url();
         IPlugin* plugin = project->versionControlPlugin();
         IBasicVersionControl* vcs=plugin->extension<IBasicVersionControl>();
         
         if(vcs) {
             ICore::self()->documentController()->saveAllDocuments(KDevelop::IDocument::Silent);
 
-            VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(new VCSStandardDiffUpdater(vcs, baseUrl));
+            const Path basePath = project->path();
+            VCSCommitDiffPatchSource* patchSource = new VCSCommitDiffPatchSource(new VCSStandardDiffUpdater(vcs, basePath.toUrl()));
 
             bool ret = showVcsDiff(patchSource);
 
@@ -1048,18 +1084,18 @@ void ProjectController::commitCurrentProject()
     }
 }
 
-QString ProjectController::mapSourceBuild( const QString& path, bool reverse, bool fallbackRoot ) const
+QString ProjectController::mapSourceBuild( const QString& path_, bool reverse, bool fallbackRoot ) const
 {
-    KUrl url(path);
+    Path path(path_);
     IProject* sourceDirProject = 0, *buildDirProject = 0;
     Q_FOREACH(IProject* proj, d->m_projects)
     {
-        if(proj->folder().isParentOf(url))
+        if(proj->path().isParentOf(path))
             sourceDirProject = proj;
         if(proj->buildSystemManager())
         {
-            KUrl buildDir = proj->buildSystemManager()->buildDirectory(proj->projectItem());
-            if(buildDir.isValid() && buildDir.isParentOf(url))
+            Path buildDir = proj->buildSystemManager()->buildDirectory(proj->projectItem());
+            if(buildDir.isValid() && buildDir.isParentOf(path))
                 buildDirProject = proj;
         }
     }
@@ -1070,12 +1106,12 @@ QString ProjectController::mapSourceBuild( const QString& path, bool reverse, bo
         if(sourceDirProject && sourceDirProject->buildSystemManager())
         {
             // We're in the source, map into the build directory
-            QString relativePath = KUrl::relativeUrl(sourceDirProject->folder(), url);
+            QString relativePath = sourceDirProject->path().relativePath(path);
             
-            KUrl build = sourceDirProject->buildSystemManager()->buildDirectory(sourceDirProject->projectItem());
+            Path build = sourceDirProject->buildSystemManager()->buildDirectory(sourceDirProject->projectItem());
             build.addPath(relativePath);
             while(!QFile::exists(build.path()))
-                build = build.upUrl();
+                build = build.parent();
             return build.pathOrUrl();
         }else if(buildDirProject && fallbackRoot)
         {
@@ -1086,24 +1122,34 @@ QString ProjectController::mapSourceBuild( const QString& path, bool reverse, bo
         // Map-target is the source directory
         if(buildDirProject)
         {
-            KUrl build = buildDirProject->buildSystemManager()->buildDirectory(buildDirProject->projectItem());
+            Path build = buildDirProject->buildSystemManager()->buildDirectory(buildDirProject->projectItem());
             // We're in the source, map into the build directory
-            QString relativePath = KUrl::relativeUrl(build, url);
+            QString relativePath = build.relativePath(path);
             
-            KUrl source = buildDirProject->folder();
+            Path source = buildDirProject->path();
             source.addPath(relativePath);
             while(!QFile::exists(source.path()))
-                source = source.upUrl();
+                source = source.parent();
             return source.pathOrUrl();
         }else if(sourceDirProject && fallbackRoot)
         {
             // We're in the source directory, map to the root
-            return sourceDirProject->folder().pathOrUrl();
+            return sourceDirProject->path().pathOrUrl();
         }
     }
     return QString();
 }
 
+void ProjectController::reparseProject( IProject* project, bool forceUpdate )
+{
+    if (auto job = d->m_parseJobs.value(project)) {
+        job->kill();
+    }
+
+    d->m_parseJobs[project] = new KDevelop::ParseProjectJob(project, forceUpdate);
+    ICore::self()->runController()->registerJob(d->m_parseJobs[project]);
+}
+
 }
 
 #include "projectcontroller.moc"
