@@ -17,8 +17,8 @@ the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
 
-#ifndef ENVIRONMENTGROUPMODEL_H
-#define ENVIRONMENTGROUPMODEL_H
+#ifndef KDEVPLATFORM_ENVIRONMENTGROUPMODEL_H
+#define KDEVPLATFORM_ENVIRONMENTGROUPMODEL_H
 
 #include <QtCore/QAbstractTableModel>
 #include <QtCore/QStringList>
@@ -35,18 +35,24 @@ class EnvironmentGroupModel : public QAbstractTableModel, public EnvironmentGrou
 {
     Q_OBJECT
 public:
+    enum Role {
+        VariableRole = Qt::UserRole + 1,
+        ValueRole
+    };
+
     EnvironmentGroupModel();
-    int rowCount( const QModelIndex& ) const;
-    int columnCount( const QModelIndex& ) const;
+    int rowCount( const QModelIndex &parent = QModelIndex() ) const;
+    int columnCount( const QModelIndex &parent = QModelIndex()  ) const;
     Qt::ItemFlags flags( const QModelIndex& idx ) const;
-    QVariant data( const QModelIndex& idx, int role ) const;
-    QVariant headerData( int section, Qt::Orientation orientation, int role ) const;
-    bool setData( const QModelIndex& idx, const QVariant&, int role );
+    QVariant data( const QModelIndex& idx, int role = Qt::DisplayRole) const;
+    QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
+    bool setData( const QModelIndex& idx, const QVariant&, int role = Qt::EditRole);
     void setCurrentGroup( const QString& group );
     void loadFromConfig( KConfig* );
     void saveToConfig( KConfig* );
-    void addVariable( const QString& var, const QString& value );
-    void removeVariables( QModelIndexList variables );
+    QModelIndex addVariable( const QString& var, const QString& value );
+    void removeVariable(const QString& variable);
+    void removeVariables(const QStringList& variables);
     void removeGroup( const QString& grp );
     void changeDefaultGroup( const QString& grp );
 
