@@ -63,20 +63,11 @@ void ProjectPreferences::save()
     Core::self()->projectControllerInternal()->loadSettings(false);
 }
 
-void ProjectPreferences::load()
-{
-    KCModule::load();
-}
-
 void ProjectPreferences::slotSettingsChanged()
 {
     emit changed( true );
 }
 
-void ProjectPreferences::defaults()
-{
-}
-
 }
 #include "projectpreferences.moc"
 
