@@ -35,6 +35,7 @@ Boston, MA 02110-1301, USA.
 #include "core.h"
 #include <ktexteditor/view.h>
 #include <project/projectmodel.h>
+#include <util/path.h>
 #include <kio/netaccess.h>
 #include <kmessagebox.h>
 #include <qfile.h>
@@ -58,7 +59,8 @@ const QString SourceFormatterController::kateModeLineConfigKey = "ModelinesEnabl
 const QString SourceFormatterController::kateOverrideIndentationConfigKey = "OverrideKateIndentation";
 const QString SourceFormatterController::styleCaptionKey = "Caption";
 const QString SourceFormatterController::styleContentKey = "Content";
-const QString SourceFormatterController::supportedMimeTypesKey = "X-KDevelop-SupportedMimeTypes";
+const QString SourceFormatterController::styleMimeTypesKey = "MimeTypes";
+const QString SourceFormatterController::styleSampleKey = "StyleSample";
 
 SourceFormatterController::SourceFormatterController(QObject *parent)
 		: ISourceFormatterController(parent), m_enabled(true)
@@ -72,21 +74,19 @@ SourceFormatterController::SourceFormatterController(QObject *parent)
 	m_formatTextAction = actionCollection()->addAction("edit_reformat_source");
 	m_formatTextAction->setText(i18n("&Reformat Source"));
 	m_formatTextAction->setToolTip(i18n("Reformat source using AStyle"));
-	m_formatTextAction->setWhatsThis(i18n("<b>Reformat source</b><p>Source reformatting "
-	        "functionality using <b>astyle</b> library.</p>"));
+	m_formatTextAction->setWhatsThis(i18n("Source reformatting functionality using <b>astyle</b> library."));
 	connect(m_formatTextAction, SIGNAL(triggered()), this, SLOT(beautifySource()));
 
 	m_formatLine = actionCollection()->addAction("edit_reformat_line");
 	m_formatLine->setText(i18n("Reformat Line"));
 	m_formatLine->setToolTip(i18n("Reformat current line using AStyle"));
-	m_formatLine->setWhatsThis(i18n("<b>Reformat line</b>"
-	                                "<p>Source reformatting of line under cursor using <b>astyle</b> library.</p>"));
+	m_formatLine->setWhatsThis(i18n("Source reformatting of line under cursor using <b>astyle</b> library."));
 	connect(m_formatLine, SIGNAL(triggered()), this, SLOT(beautifyLine()));
 
 	m_formatFilesAction = actionCollection()->addAction("tools_astyle");
 	m_formatFilesAction->setText(i18n("Format Files"));
 	m_formatFilesAction->setToolTip(i18n("Format file(s) using the current theme"));
-	m_formatFilesAction->setWhatsThis(i18n("<b>Format Files</b><p>Formatting functionality using <b>astyle</b> library.</p>"));
+	m_formatFilesAction->setWhatsThis(i18n("Formatting functionality using <b>astyle</b> library."));
 	connect(m_formatFilesAction, SIGNAL(triggered()), this, SLOT(formatFiles()));
 
 	m_formatTextAction->setEnabled(false);
@@ -127,12 +127,12 @@ ISourceFormatter* SourceFormatterController::formatterForUrl(const KUrl &url)
 	KMimeType::Ptr mime = KMimeType::findByUrl(url);
 	return formatterForMimeType(mime);
 }
-KConfigGroup SourceFormatterController::configuration()
+KConfigGroup SourceFormatterController::configuration() const
 {
 	return Core::self()->activeSession()->config()->group( "SourceFormatter" );
 }
 
-static ISourceFormatter* findFirstFormatterForMimeType( const KMimeType::Ptr& mime )
+ISourceFormatter* SourceFormatterController::findFirstFormatterForMimeType( const KMimeType::Ptr& mime ) const
 {
 	static QHash<QString, ISourceFormatter*> knownFormatters;
 	if (knownFormatters.contains(mime->name()))
@@ -140,16 +140,47 @@ static ISourceFormatter* findFirstFormatterForMimeType( const KMimeType::Ptr& mi
 	
 	foreach( IPlugin* p, Core::self()->pluginController()->allPluginsForExtension( "org.kdevelop.ISourceFormatter" ) ) {
 		KPluginInfo info = Core::self()->pluginController()->pluginInfo( p );
-		if( info.property( SourceFormatterController::supportedMimeTypesKey ).toStringList().contains( mime->name() ) ) {
-			ISourceFormatter *formatter = p->extension<ISourceFormatter>();
-			knownFormatters[mime->name()] = formatter;
-			return formatter;
+		ISourceFormatter *iformatter = p->extension<ISourceFormatter>();
+		QSharedPointer<SourceFormatter> formatter(createFormatterForPlugin(iformatter));
+		if( formatter->supportedMimeTypes().contains(mime->name()) ) {
+			knownFormatters[mime->name()] = iformatter;
+			return iformatter;
 		}
 	}
 	knownFormatters[mime->name()] = 0;
 	return 0;
 }
 
+static void populateStyleFromConfigGroup(SourceFormatterStyle* s, const KConfigGroup& stylegrp)
+{
+	s->setCaption( stylegrp.readEntry( SourceFormatterController::styleCaptionKey, QString() ) );
+	s->setContent( stylegrp.readEntry( SourceFormatterController::styleContentKey, QString() ) );
+	s->setMimeTypes( stylegrp.readEntry<QStringList>( SourceFormatterController::styleMimeTypesKey, QStringList() ) );
+	s->setOverrideSample( stylegrp.readEntry( SourceFormatterController::styleSampleKey, QString() ) );
+}
+
+SourceFormatter* SourceFormatterController::createFormatterForPlugin(ISourceFormatter *ifmt) const
+{
+	SourceFormatter* formatter = new SourceFormatter();
+	formatter->formatter = ifmt;
+
+	// Inserted a new formatter. Now fill it with styles
+	foreach( const KDevelop::SourceFormatterStyle& style, ifmt->predefinedStyles() ) {
+		formatter->styles[ style.name() ] = new SourceFormatterStyle(style);
+	}
+	KConfigGroup grp = configuration();
+	if( grp.hasGroup( ifmt->name() ) ) {
+		KConfigGroup fmtgrp = grp.group( ifmt->name() );
+		foreach( const QString& subgroup, fmtgrp.groupList() ) {
+			SourceFormatterStyle* s = new SourceFormatterStyle( subgroup );
+			KConfigGroup stylegrp = fmtgrp.group( subgroup );
+			populateStyleFromConfigGroup(s, stylegrp);
+			formatter->styles[ s->name() ] = s;
+		}
+	}
+	return formatter;
+}
+
 ISourceFormatter* SourceFormatterController::formatterForMimeType(const KMimeType::Ptr &mime)
 {
 	if( !m_enabled || !isMimeTypeSupported( mime ) ) {
@@ -459,10 +490,10 @@ void SourceFormatterController::formatFiles()
 		if (item->folder())
 			folders.append(item->folder());
 		else if (item->file())
-			m_urls.append(item->file()->url());
+			m_urls.append(item->file()->path().toUrl());
 		else if (item->target()) {
 			foreach(KDevelop::ProjectFileItem *f, item->fileList())
-			m_urls.append(f->url());
+			m_urls.append(f->path().toUrl());
 		}
 	}
 
@@ -472,10 +503,10 @@ void SourceFormatterController::formatFiles()
 		folders.append(f);
 		foreach(KDevelop::ProjectTargetItem *f, item->targetList()) {
 			foreach(KDevelop::ProjectFileItem *child, f->fileList())
-			m_urls.append(child->url());
+			m_urls.append(child->path().toUrl());
 		}
 		foreach(KDevelop::ProjectFileItem *f, item->fileList())
-		m_urls.append(f->url());
+		m_urls.append(f->path().toUrl());
 	}
 
 	formatFiles(m_urls);
@@ -564,8 +595,7 @@ SourceFormatterStyle SourceFormatterController::styleForMimeType( const KMimeTyp
 		KConfigGroup fmtgrp = configuration().group( formatter.at(0) );
 		if( fmtgrp.hasGroup( formatter.at(1) ) ) {
 			KConfigGroup stylegrp = fmtgrp.group( formatter.at(1) );
-			s.setCaption( stylegrp.readEntry( styleCaptionKey, "" ) );
-			s.setContent( stylegrp.readEntry( styleContentKey, "" ) );
+			populateStyleFromConfigGroup(&s, stylegrp);
 		}
 		return s;
 	}
