@@ -33,8 +33,6 @@
 #include "../session.h"
 #include "../uicontroller.h"
 
-Q_DECLARE_METATYPE( KDevelop::ISession* )
-
 using namespace KDevelop;
 
 using QTest::kWaitForSignal;
@@ -43,7 +41,7 @@ using QTest::kWaitForSignal;
 
 QString sessionDir( ISession* s )
 {
-    return SessionController::sessionDirectory() + '/' + s->id().toString();
+    return SessionController::sessionDirectory(s->id().toString());
 }
 
 void verifySessionDir( const QString& sessiondir, const QString& name, bool exists )
@@ -75,6 +73,7 @@ void SessionControllerTest::initTestCase()
     TestCore::initialize(Core::NoUi);
     m_core = Core::self();
     qRegisterMetaType<KDevelop::ISession*>();
+    qRegisterMetaType<KDevelop::Session*>();
 }
 
 void SessionControllerTest::init()
@@ -84,10 +83,11 @@ void SessionControllerTest::init()
 
 void SessionControllerTest::cleanupTestCase()
 {
-    foreach( const QString& name, m_sessionCtrl->sessionNames() )
+    foreach( const Session* session, m_sessionCtrl->sessions() )
     {
-        if (m_sessionCtrl->activeSession()->name() != name)
-            m_sessionCtrl->deleteSession( name );
+        TryLockSessionResult lock = m_sessionCtrl->tryLockSession(session->id());
+        if (lock.lock)
+            m_sessionCtrl->deleteSession( lock.lock );
     }
 
     TestCore::shutdown();
@@ -118,15 +118,10 @@ void SessionControllerTest::renameSession()
     KDevelop::Session *s = m_sessionCtrl->createSession( sessionName );
     QCOMPARE( sessionName, s->name() );
     verifySessionDir( s );
-    QSignalSpy spy(s, SIGNAL(nameChanged(QString,QString)));
+    QSignalSpy spy(s, SIGNAL(sessionUpdated(KDevelop::ISession*)));
     s->setName( newSessionName );
     QCOMPARE( newSessionName, s->name() );
-    
     QCOMPARE( spy.size(), 1 );
-    QList<QVariant> arguments = spy.takeFirst();
-
-    QCOMPARE( sessionName, arguments.at(1).toString() );
-    QCOMPARE( newSessionName, arguments.at(0).toString() );
 
     verifySessionDir( s );
 }
@@ -138,15 +133,10 @@ void SessionControllerTest::canRenameActiveSession()
     KDevelop::Session *s = m_sessionCtrl->createSession( sessionName );
     QCOMPARE( sessionName, s->name() );
     m_sessionCtrl->loadSession( sessionName );
-    QSignalSpy spy(s, SIGNAL(nameChanged(QString,QString)));
+    QSignalSpy spy(s, SIGNAL(sessionUpdated(KDevelop::ISession*)));
     s->setName( newSessionName );
     QCOMPARE( newSessionName, s->name() );
-    
     QCOMPARE( spy.size(), 1 );
-    QList<QVariant> arguments = spy.takeFirst();
-
-    QCOMPARE( sessionName, arguments.at(1).toString() );
-    QCOMPARE( newSessionName, arguments.at(0).toString() );
 
     verifySessionDir( s );
 }
@@ -160,8 +150,13 @@ void SessionControllerTest::deleteSession()
     QCOMPARE( sessionCount+1, m_sessionCtrl->sessionNames().count() );
     verifySessionDir( s );
     QSignalSpy spy(m_sessionCtrl, SIGNAL(sessionDeleted(QString)));
-    m_sessionCtrl->deleteSession( sessionName );
+    {
+        TryLockSessionResult lock = m_sessionCtrl->tryLockSession(sessionId);
+        QVERIFY(lock.lock);
+        m_sessionCtrl->deleteSession( lock.lock );
+    }
     QCOMPARE( sessionCount, m_sessionCtrl->sessionNames().count() );
+    QVERIFY( !m_sessionCtrl->sessionNames().contains(sessionId) );
 
     QCOMPARE(spy.size(), 1);
     QList<QVariant> arguments = spy.takeFirst();
@@ -222,5 +217,55 @@ void SessionControllerTest::temporary()
     // dir / UID can be different, hence don't verifySessionDir
 }
 
+void SessionControllerTest::tryLockSession()
+{
+    const QString id1 = QUuid::createUuid().toString();
+    m_sessionCtrl->createSession( id1 )->setTemporary(true);
+    const QString id2 = QUuid::createUuid().toString();
+    m_sessionCtrl->createSession( id2 )->setTemporary(true);
+    {
+        // acquired scoped lock
+        QVERIFY(!SessionController::isSessionRunning(id1));
+        QCOMPARE(SessionController::sessionRunInfo(id1), SessionRunInfo());
+        TryLockSessionResult initial = SessionController::tryLockSession(id1);
+        QVERIFY(initial.lock);
+        QCOMPARE(initial.lock->id(), id1);
+        QCOMPARE(initial.runInfo, SessionRunInfo());
+        QVERIFY(SessionController::isSessionRunning(id1));
+
+        SessionRunInfo info = SessionController::sessionRunInfo(id1);
+        QVERIFY(info != initial.runInfo);
+        QVERIFY(info.isRunning);
+        QCOMPARE(info.holderApp, QCoreApplication::applicationName());
+        QCOMPARE(info.holderPid, static_cast<int>(QCoreApplication::applicationPid()));
+
+        // this should fail
+        TryLockSessionResult repeated = SessionController::tryLockSession(id1);
+        QVERIFY(!repeated.lock);
+        QCOMPARE(repeated.runInfo, info);
+
+        // this should pass (different id)
+        QVERIFY(!SessionController::isSessionRunning(id2));
+        TryLockSessionResult other = SessionController::tryLockSession(id2);
+        QVERIFY(other.lock);
+        QCOMPARE(other.lock->id(), id2);
+        QCOMPARE(other.runInfo, SessionRunInfo());
+        QVERIFY(SessionController::isSessionRunning(id2));
+    }
+
+    // scope left, sessions are now unlocked again
+    QVERIFY(!SessionController::isSessionRunning(id1));
+    QCOMPARE(SessionController::sessionRunInfo(id1), SessionRunInfo());
+    QVERIFY(!SessionController::isSessionRunning(id2));
+    QCOMPARE(SessionController::sessionRunInfo(id2), SessionRunInfo());
+
+    // can re-lock it here
+    TryLockSessionResult final = SessionController::tryLockSession(id1);
+    QVERIFY(SessionController::isSessionRunning(id1));
+    QVERIFY(final.lock);
+    QCOMPARE(final.lock->id(), id1);
+    QCOMPARE(final.runInfo, SessionRunInfo());
+}
+
 QTEST_KDEMAIN( SessionControllerTest, GUI)
 #include "sessioncontrollertest.moc"
