@@ -18,20 +18,21 @@
  ***************************************************************************/
 #include "textdocument.h"
 
+#include <QFile>
 #include <QPointer>
+#include <QTextCodec>
 #include <QMenu>
 #include <QAction>
 #include <QVBoxLayout>
 #include <QWidget>
 #include <QLabel>
+#include <QLayout>
 
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kconfiggroup.h>
 #include <kstandarddirs.h>
 #include <kxmlguifactory.h>
-#include <kactioncollection.h>
-#include <kstatusbar.h>
 #include <kdeversion.h>
 
 #include <ktexteditor/view.h>
@@ -42,9 +43,6 @@
 #include <ktexteditor/configinterface.h>
 #include <ktexteditor/sessionconfiginterface.h>
 
-#include <sublime/area.h>
-#include <sublime/view.h>
-
 #include <interfaces/context.h>
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/ilanguagecontroller.h>
@@ -52,6 +50,8 @@
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iproject.h>
 
+#include <vcs/interfaces/icontentawareversioncontrol.h>
+
 #include <language/interfaces/editorcontext.h>
 
 #include <project/projectutils.h>
@@ -67,6 +67,19 @@ namespace KDevelop {
 
 const int MAX_DOC_SETTINGS = 20;
 
+// This sets cursor position and selection on the view to the given
+// range. Selection is set only for non-empty ranges
+// Factored into a function since its needed in 3 places already
+static void selectAndReveal( KTextEditor::View* view, const KTextEditor::Range& range ) {
+    Q_ASSERT(view);
+    if (range.isValid()) {
+        view->setCursorPosition(range.start());
+        if (!range.isEmpty()) {
+            view->setSelection(range);
+        }
+    }
+}
+
 struct TextDocumentPrivate {
     TextDocumentPrivate(TextDocument *textDocument)
         : encoding(""), m_textDocument(textDocument)
@@ -152,9 +165,72 @@ struct TextDocumentPrivate {
                 break;
         }
 
+        // In some cases, the VCS (e.g. git) can know whether the old contents are "valuable", i.e.
+        // not retrieveable from the VCS. If that is not the case, then the document can safely be
+        // reloaded without displaying a dialog asking the user.
+        if ( dirty ) {
+            queryCanRecreateFromVcs(document);
+        }
         setStatus(document, dirty);
     }
 
+    // Determines whether the current contents of this document in the editor
+    // could be retrieved from the VCS if they were dismissed.
+    void queryCanRecreateFromVcs(KTextEditor::Document* document) const {
+        IProject* project = 0;
+        // Find projects by checking which one contains the file's parent directory,
+        // to avoid issues with the cmake manager temporarily removing files from a project
+        // during reloading.
+        foreach ( KDevelop::IProject* current, Core::self()->projectController()->projects() ) {
+            if ( current->folder().isParentOf(document->url()) ) {
+                project = current;
+                break;
+            }
+        }
+        if (!project) {
+            return;
+        }
+        IContentAwareVersionControl* iface;
+        iface = qobject_cast< KDevelop::IContentAwareVersionControl* >(project->versionControlPlugin());
+        if (!iface) {
+            return;
+        }
+        if ( !qobject_cast<KTextEditor::ModificationInterface*>( document ) ) {
+            return;
+        }
+
+        CheckInRepositoryJob* req = iface->isInRepository( document );
+        if ( !req ) {
+            return;
+        }
+        QObject::connect(req, SIGNAL(finished(bool)),
+                         m_textDocument, SLOT(repositoryCheckFinished(bool)));
+        // Abort the request when the user edits the document
+        QObject::connect(m_textDocument->textDocument(), SIGNAL(textChanged(KTextEditor::Document*)),
+                         req, SLOT(abort()));
+    }
+
+    void repositoryCheckFinished(bool canRecreate) {
+        if ( state != IDocument::Dirty && state != IDocument::DirtyAndModified ) {
+            // document is not dirty for whatever reason, nothing to do.
+            return;
+        }
+        if ( ! canRecreate ) {
+            return;
+        }
+        KTextEditor::ModificationInterface* modIface = qobject_cast<KTextEditor::ModificationInterface*>( document );
+        Q_ASSERT(modIface);
+        // Ok, all safe, we can clean up the document. Close it if the file is gone,
+        // and reload if it's still there.
+        setStatus(document, false);
+        modIface->setModifiedOnDisk(KTextEditor::ModificationInterface::OnDiskUnmodified);
+        if ( QFile::exists(document->url().path()) ) {
+            m_textDocument->reload();
+        } else {
+            m_textDocument->close(KDevelop::IDocument::Discard);
+        }
+    }
+
     void setStatus(KTextEditor::Document* document, bool dirty)
     {
         QIcon statusIcon;
@@ -219,7 +295,7 @@ struct TextDocumentPrivate {
 
     void saveSessionConfig()
     {
-        if(!document->url().isValid()) {
+        if(!document || !document->url().isValid()) {
             return;
         }
         if (KTextEditor::ParameterizedSessionConfigInterface *sessionConfigIface =
@@ -281,17 +357,36 @@ public:
     TextEditorWidgetPrivate()
     {
         widget = 0;
-        statusBar = 0;
         widgetLayout = 0;
         view = 0;
         statusLabel = 0;
     }
+
+    void viewEditModeChanged(KTextEditor::View* view, KTextEditor::View::EditMode mode)
+    {
+#ifdef KTEXTEDITOR_HAS_VIMODE
+        if ( ! statusLabel ) {
+            statusLabel = new QLabel();
+            view->layout()->addWidget(statusLabel);
+        }
+        if ( mode == KTextEditor::View::EditViMode ) {
+            statusLabel->setText(view->viewMode() + "    <i>" + view->document()->url().fileName() + "</i>");
+            statusLabel->setHidden(false);
+        }
+        else {
+            statusLabel->setHidden(true);
+        }
+#else
+        Q_UNUSED(view);
+        Q_UNUSED(mode);
+#endif
+    }
     QWidget* widget;
     QVBoxLayout* widgetLayout;
     QPointer<KTextEditor::View> view;
-    KStatusBar *statusBar;
     QLabel* statusLabel;
     QString status;
+    const TextView* textView;
 
 };
 
@@ -348,7 +443,7 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
 
         d->setStatus(d->document, false);
 
-        /* It appears, that by default a part will be deleted the the
+        /* It appears, that by default a part will be deleted the
            first view containing it is deleted.  Since we do want
            to have several views, disable that behaviour.  */
         d->document->setAutoDeletePart(false);
@@ -593,8 +688,7 @@ void TextDocument::setTextSelection(const KTextEditor::Range &range)
     KTextEditor::View *view = d->document->activeView();
 
     if (view) {
-        view->setCursorPosition(range.start());
-        view->setSelection( range );
+        selectAndReveal(view, range);
     }
 }
 
@@ -635,21 +729,9 @@ KDevelop::TextView::~TextView()
 
 QWidget * KDevelop::TextView::createWidget(QWidget * parent)
 {
-    TextDocument* doc = static_cast<TextDocument*>(document());
-    KTextEditor::View* view = static_cast<KTextEditor::View*>(doc->createViewWidget(parent));
-    if(d->initialRange.isValid()) {
-        if(d->initialRange.isEmpty())
-            view->setCursorPosition(d->initialRange.start());
-        else {
-            view->setCursorPosition(d->initialRange.end());
-            view->setSelection(d->initialRange);
-        }
-    }
-    TextEditorWidget* teWidget = new TextEditorWidget(parent);
-    teWidget->setEditorView(view);
-    connect(teWidget, SIGNAL(statusChanged()),
-            this, SLOT(sendStatusChanged()));
-            
+    TextEditorWidget* teWidget = new TextEditorWidget(this, parent);
+    connect(teWidget, SIGNAL(statusChanged()), this, SLOT(sendStatusChanged()));
+
     d->editor = teWidget;
     connect(d->editor, SIGNAL(destroyed(QObject*)), this, SLOT(editorDestroyed(QObject*)));
     
@@ -674,15 +756,27 @@ QString KDevelop::TextView::viewState() const
         } else {
             KTextEditor::Cursor cursor = d->editor->editorView()->cursorPosition();
             return QString("Cursor=%1,%2").arg(cursor.line()).arg(cursor.column());
-        }    }else
+        }
+    }
+    else
     {
         kDebug() << "TextView's internal KTE view disappeared!";
         return QString();
     }
 }
 
-void KDevelop::TextView::setInitialRange(KTextEditor::Range range) {
-    d->initialRange = range;
+void KDevelop::TextView::setInitialRange(const KTextEditor::Range& range)
+{
+    if(d->editor && d->editor->isInitialized()) {
+        selectAndReveal(d->editor->editorView(), range);
+    } else {
+        d->initialRange = range;
+    }
+}
+
+KTextEditor::Range KDevelop::TextView::initialRange() const
+{
+    return d->initialRange;
 }
 
 void KDevelop::TextView::setState(const QString & state)
@@ -690,17 +784,10 @@ void KDevelop::TextView::setState(const QString & state)
     static QRegExp reCursor("Cursor=([\\d]+),([\\d]+)");
     static QRegExp reSelection("Selection=([\\d]+),([\\d]+),([\\d]+),([\\d]+)");
     if (reCursor.exactMatch(state)) {
-        if (d->editor && d->editor->editorView())
-            d->editor->editorView()->setCursorPosition(KTextEditor::Cursor(reCursor.cap(1).toInt(), reCursor.cap(2).toInt()));
-        else
-            setInitialRange(KTextEditor::Range(KTextEditor::Cursor(reCursor.cap(1).toInt(), reCursor.cap(2).toInt()), 0));
+        setInitialRange(KTextEditor::Range(KTextEditor::Cursor(reCursor.cap(1).toInt(), reCursor.cap(2).toInt()), 0));
     } else if (reSelection.exactMatch(state)) {
         KTextEditor::Range range(reSelection.cap(1).toInt(), reSelection.cap(2).toInt(), reSelection.cap(3).toInt(), reSelection.cap(4).toInt());
-        if (d->editor && d->editor->editorView()) {
-            d->editor->editorView()->setCursorPosition(range.end());
-            d->editor->editorView()->setSelection(range);
-        } else
-            setInitialRange(range);
+        setInitialRange(range);
     }
 }
 
@@ -709,6 +796,18 @@ QString KDevelop::TextDocument::documentType() const
     return "Text";
 }
 
+QIcon KDevelop::TextDocument::defaultIcon() const
+{
+    if (d->document) {
+        KMimeType::Ptr mime = KMimeType::mimeType(d->document->mimeType());
+        KIcon icon(mime->iconName());
+        if (!icon.isNull()) {
+            return icon;
+        }
+    }
+    return PartDocument::defaultIcon();
+}
+
 KTextEditor::View *KDevelop::TextView::textView() const
 {  
     if (d->editor)
@@ -730,14 +829,17 @@ void KDevelop::TextView::sendStatusChanged()
     emit statusChanged(this);
 }
 
-KDevelop::TextEditorWidget::TextEditorWidget(QWidget* parent)
+KDevelop::TextEditorWidget::TextEditorWidget(const TextView* view, QWidget* parent)
 : QWidget(parent), KXMLGUIClient(), d(new TextEditorWidgetPrivate)
 {
     d->widgetLayout = new QVBoxLayout(this);
     d->widgetLayout->setMargin(0);
     d->widgetLayout->setSpacing(0);
+    d->textView = view;
+    d->view = 0;
 
     setLayout(d->widgetLayout);
+    initialize();
 }
 
 KDevelop::TextEditorWidget::~TextEditorWidget()
@@ -745,6 +847,17 @@ KDevelop::TextEditorWidget::~TextEditorWidget()
     delete d;
 }
 
+void KDevelop::TextEditorWidget::initialize()
+{
+    if(d->view)
+        return;
+    TextDocument* doc = static_cast<TextDocument*>(d->textView->document());
+    KTextEditor::View* view = qobject_cast<KTextEditor::View*>(doc->createViewWidget(this));
+    KTextEditor::Range ir = d->textView->initialRange();
+    selectAndReveal(view, ir);
+    setEditorView(view);
+}
+
 void KDevelop::TextEditorWidget::viewStatusChanged(KTextEditor::View* view, const KTextEditor::Cursor& )
 {
     // This fetches the virtual cursor, which expands tab characters properly, i.e. instead of col == 1
@@ -769,6 +882,9 @@ void KDevelop::TextEditorWidget::setEditorView(KTextEditor::View* view)
     
     viewStatusChanged(view, view->cursorPosition());
 
+    connect(view, SIGNAL(viewEditModeChanged(KTextEditor::View*,KTextEditor::View::EditMode)),
+            this, SLOT(viewEditModeChanged(KTextEditor::View*,KTextEditor::View::EditMode)));
+
     d->widgetLayout->insertWidget(0, d->view);
     setFocusProxy(view);
 }
@@ -778,9 +894,23 @@ QString KDevelop::TextEditorWidget::status() const
     return d->status;
 }
 
-KTextEditor::View* KDevelop::TextEditorWidget::editorView() const
+KTextEditor::View* KDevelop::TextEditorWidget::editorView()
 {
+    if(!d->view)
+        initialize();
     return d->view;
 }
 
+bool KDevelop::TextEditorWidget::isInitialized() const
+{
+    return d->view!=0;
+}
+
+void KDevelop::TextEditorWidget::showEvent(QShowEvent* event)
+{
+    if(!d->view)
+        initialize();
+    QWidget::showEvent(event);
+}
+
 #include "textdocument.moc"
