@@ -21,6 +21,7 @@
 #include <QMap>
 #include <QAction>
 #include <QPointer>
+#include <QTimer>
 #include <QApplication>
 #include <QListWidget>
 #include <QToolBar>
@@ -38,6 +39,7 @@
 #include <sublime/area.h>
 #include <sublime/view.h>
 #include <sublime/tooldocument.h>
+#include <sublime/holdupdates.h>
 
 #include "core.h"
 #include "shellextension.h"
@@ -111,6 +113,9 @@ public:
         {
             activeSublimeWindow = defaultMainWindow = 0;
         }
+
+        m_assistantTimer.setSingleShot(true);
+        m_assistantTimer.setInterval(100);
     }
 
     void widgetChanged(QWidget*, QWidget* now)
@@ -134,6 +139,7 @@ public:
 
     //Currently shown assistant popup.
     QPointer<AssistantPopup> currentShownAssistant;
+    QTimer m_assistantTimer;
 
 private:
     UiController *m_controller;
@@ -224,18 +230,6 @@ UiController::~UiController()
 
 void UiController::setupActions()
 {
-#if (QT_VERSION >= QT_VERSION_CHECK(4, 8, 0))
-    if (d->defaultMainWindow->menuBar()->isNativeMenuBar()) {
-        KActionCollection* ac = d->defaultMainWindow->actionCollection();
-
-        // When running on an appmenu-enabled system, one cannot add widgets in the
-        // menubar corner. In this case, move area switcher to main toolbar.
-        KAction* switcherAction = new KAction(this);
-        switcherAction->setText(i18n("Area Switcher")); // For the toolbar edit dialog
-        switcherAction->setDefaultWidget(d->defaultMainWindow->areaSwitcher());
-        ac->addAction("area_switcher", switcherAction);
-    }
-#endif
 }
 
 void UiController::mainWindowDeleted(MainWindow* mw)
@@ -419,7 +413,7 @@ void UiController::selectNewToolViewToAdd(MainWindow *mw)
     {
         ViewSelectorItem *item = new ViewSelectorItem(it.value()->title(), list);
         item->factory = it.key();
-        if (toolViewPresent(it.value(), mw->area())) {
+        if (!item->factory->allowMultiple() && toolViewPresent(it.value(), mw->area())) {
             // Disable item if the toolview is already present.
             item->setFlags(item->flags() & ~Qt::ItemIsEnabled);
         }
@@ -460,6 +454,7 @@ void UiController::showSettingsDialog()
     kDebug() << "blacklist" << blacklist;
     KSettings::Dialog cfgDlg( QStringList() << "kdevplatform",
                                         activeMainWindow() );
+    cfgDlg.setMinimumSize( 550, 300 );
     cfgDlg.setComponentBlacklist( blacklist );
     cfgDlg.exec();
 }
@@ -500,11 +495,8 @@ void UiController::saveAllAreas(KSharedConfig::Ptr config)
     uiConfig.writeEntry("Main Windows Count", wc);
     for (int w = 0; w < wc; ++w)
     {
-        Sublime::MainWindow *mw = mainWindows()[w];
-
         KConfigGroup mainWindowConfig(&uiConfig,
                                       QString("Main Window %1").arg(w));
-        mainWindowConfig.writeEntry("currentArea", mw->area()->objectName());
 
         foreach (Sublime::Area* defaultArea, defaultAreas())
         {
@@ -550,10 +542,6 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
     {
         KConfigGroup mainWindowConfig(&uiConfig,
                                       QString("Main Window %1").arg(w));
-        QString currentArea = mainWindowConfig.readEntry("currentArea", "");
-        
-        if(currentArea == "test") ///@todo The area was renamed, and it will lead to a crash, so this is a dirty temporary workaround
-            currentArea = "review";
         
         Sublime::MainWindow *mw = mainWindows()[w];
 
@@ -591,12 +579,8 @@ void UiController::loadAllAreas(KSharedConfig::Ptr config)
             }
         }
 
-        // FIXME: check that an area of this name exists.
-        if (!currentArea.isEmpty())
-            showArea(currentArea, mw);
-        else
-            // Force reload of the changes.
-            showAreaInternal(mw->area(), mw);
+        // Force reload of the changes.
+        showAreaInternal(mw->area(), mw);
 
         mw->enableAreaSettingsSave();
     }
@@ -635,7 +619,7 @@ Sublime::View* UiController::addToolViewToArea(IToolViewFactory* factory,
     Sublime::View* view = doc->createView();
     area->addToolView(
         view,
-        p == Sublime::Position::AllPositions ? Sublime::dockAreaToPosition(factory->defaultPosition()) : p);
+        p == Sublime::AllPositions ? Sublime::dockAreaToPosition(factory->defaultPosition()) : p);
 
     connect(view, SIGNAL(raise(Sublime::View*)),
             SLOT(raiseToolView(Sublime::View*)));
@@ -662,40 +646,31 @@ void UiController::showErrorMessage(const QString& message, int timeout)
     QMetaObject::invokeMethod(mw, "showErrorMessage", Q_ARG(QString, message), Q_ARG(int, timeout));
 }
 
-void UiController::hideAssistant(const KDevelop::IAssistant::Ptr& assistant)
+void UiController::hideAssistant()
 {
-    if(d->currentShownAssistant && d->currentShownAssistant->assistant() == assistant) {
-        disconnect(d->currentShownAssistant->assistant().data(), SIGNAL(hide()), this, SLOT(assistantHide()));
-        disconnect(d->currentShownAssistant->assistant().data(), SIGNAL(actionsChanged()), this, SLOT(assistantActionsChanged()));
-        
-        AssistantPopup* oldPopup = d->currentShownAssistant;
-        d->currentShownAssistant = 0;
-        oldPopup->hide();
-        oldPopup->deleteLater(); //We have to do deleteLater, so we don't get problems when an assistant hides itself
+    if (d->currentShownAssistant) {
+        d->currentShownAssistant->hide();
     }
 }
 
 void UiController::popUpAssistant(const KDevelop::IAssistant::Ptr& assistant)
 {
-    assistantHide();
     if(!assistant)
         return;
-    
+
     Sublime::View* view = d->activeSublimeWindow->activeView();
     if( !view )
     {
         kDebug() << "no active view in mainwindow";
         return;
     }
+
     TextEditorWidget* textWidget = dynamic_cast<TextEditorWidget*>(view->widget());
     if(textWidget && textWidget->editorView()) {
-
-        d->currentShownAssistant = new AssistantPopup(textWidget->editorView(), assistant);
-        if(assistant->actions().count())
-            d->currentShownAssistant->show();
-
-        connect(assistant.data(), SIGNAL(hide()), SLOT(assistantHide()), Qt::DirectConnection);
-        connect(assistant.data(), SIGNAL(actionsChanged()), SLOT(assistantActionsChanged()), Qt::DirectConnection);
+        if ( !d->currentShownAssistant ) {
+            d->currentShownAssistant = new AssistantPopup;
+        }
+        d->currentShownAssistant->reset(textWidget->editorView(), assistant);
     }
 }
 
@@ -704,16 +679,6 @@ const QMap< IToolViewFactory*, Sublime::ToolDocument* >& UiController::factoryDo
     return d->factoryDocuments;
 }
 
-void UiController::assistantHide() {
-    if(d->currentShownAssistant)
-        hideAssistant(d->currentShownAssistant->assistant());
-}
-
-void UiController::assistantActionsChanged() {
-    if(d->currentShownAssistant)
-        popUpAssistant(d->currentShownAssistant->assistant());
-}
-
 }
 
 
