@@ -16,8 +16,8 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef WORKINGSETCONTROLLER_H
-#define WORKINGSETCONTROLLER_H
+#ifndef KDEVPLATFORM_WORKINGSETCONTROLLER_H
+#define KDEVPLATFORM_WORKINGSETCONTROLLER_H
 
 #include <QObject>
 #include <QSet>
@@ -48,7 +48,7 @@ class WorkingSetController : public QObject
     Q_OBJECT
 
 public:
-    WorkingSetController(KDevelop::Core* core) ;
+    WorkingSetController();
     void initialize();
     void cleanup();
 
@@ -63,7 +63,7 @@ public:
      * NOTE: Never pass an empty @p id, this means there is no working set
      *       for the given area you got that @p id from.
      */
-    WorkingSet* getWorkingSet(const QString& id, const QString& icon = QString());
+    WorkingSet* getWorkingSet(const QString& id);
 
     QList<WorkingSet*> allWorkingSets() const;
 
@@ -84,10 +84,6 @@ Q_SIGNALS:
 private slots:
     void areaCreated(Sublime::Area* area);
 
-    bool usingIcon(const QString& icon);
-
-    bool iconValid(const QString& icon);
-
     void nextDocument();
     void previousDocument();
     void showGlobalToolTip();
@@ -107,11 +103,11 @@ private slots:
 
 private:
     void setupActions();
+    const QString makeSetId(const QString& prefix) const;
 
     QSet<QString> m_usedIcons;
     QMap<QString, WorkingSet*> m_workingSets;
     WorkingSet* m_emptyWorkingSet;
-    KDevelop::Core* m_core;
     QTimer* m_hideToolTipTimer;
     QPointer<KDevelop::ActiveToolTip> m_tooltip;
     // This is set to true while the working-set controller is forcing a working-set
@@ -121,4 +117,4 @@ private:
 
 }
 
-#endif // WORKINGSETMANAGER_H
+#endif // KDEVPLATFORM_WORKINGSETMANAGER_H
