@@ -23,7 +23,6 @@
 
 #include <KTextEditor/Document>
 #include <KColorUtils>
-#include <KIconEffect>
 
 #include <QApplication>
 
@@ -41,33 +40,81 @@ using namespace KDevelop;
 
 bool WorkingSet::m_loading = false;
 
-WorkingSet::WorkingSet(QString id, QString icon)
-    : m_id(id), m_iconName(icon)
+namespace {
+
+QIcon generateIcon(const WorkingSetIconParameters& params)
 {
-    //Give the working-set icons one color, so they are less disruptive
-    QImage imgActive(KIconLoader::global()->loadIcon(icon, KIconLoader::NoGroup, 16).toImage());
-    QImage imgInactive = imgActive;
+    QImage pixmap(16, 16, QImage::Format_ARGB32);
+    // fill the background with a transparent color
+    pixmap.fill(QColor::fromRgba(qRgba(0, 0, 0, 0)));
+    const uint coloredCount = params.coloredCount;
+    // coordinates of the rectangles to draw, for 16x16 icons specifically
+    QList<QRect> rects;
+    rects << QRect(1, 1, 5, 5) << QRect(1, 9, 5, 5) << QRect(9, 1, 5, 5) << QRect(9, 9, 5, 5);
+    if ( params.swapDiagonal ) {
+        rects.swap(1, 2);
+    }
 
-    QColor activeIconColor = QApplication::palette().color(QPalette::Active, QPalette::Highlight);
-    QColor inActiveIconColor = QApplication::palette().color(QPalette::Active, QPalette::Base);
-
-    KIconEffect::colorize(imgActive, KColorUtils::mix(inActiveIconColor, activeIconColor, 0.7), 0.5);
-    KIconEffect::colorize(imgInactive, KColorUtils::mix(inActiveIconColor, activeIconColor, 0.3), 0.5);
-
-    m_activeIcon = QIcon(QPixmap::fromImage(imgActive));
-    m_inactiveIcon = QIcon(QPixmap::fromImage(imgActive));
-
-    QImage imgNonPersistent = imgInactive;
-
-    KIconEffect::deSaturate(imgNonPersistent, 1.0);
-
-    m_inactiveNonPersistentIcon = QIcon(QPixmap::fromImage(imgNonPersistent));
-    //effect.apply(KIconLoader::global()->loadIcon(icon, KIconLoader::NoGroup, 16), KIconLoader::NoGroup, );
+    QPainter painter(&pixmap);
+    // color for non-colored squares, paint them brighter if the working set is the active one
+    const int inact = 40;
+    QColor darkColor = QColor::fromRgb(inact, inact, inact);
+    // color for colored squares
+    // this code is not fragile, you can just tune the magic formulas at random and see what looks good.
+    // just make sure to keep it within the 0-360 / 0-255 / 0-255 space of the HSV model
+    QColor brightColor = QColor::fromHsv(params.hue, qMin<uint>(255, 215 + (params.setId*5) % 150),
+                                         205 + (params.setId*11) % 50);
+    // Y'UV "Y" value, the approximate "lightness" of the color
+    // If it is above 0.6, then making the color darker a bit is okay,
+    // if it is below 0.35, then the color should be a bit brighter.
+    float brightY = 0.299 * brightColor.redF() + 0.587 * brightColor.greenF() + 0.114 * brightColor.blueF();
+    if ( brightY > 0.6 ) {
+        if ( params.setId % 7 < 2 ) {
+            // 2/7 chance to make the color significantly darker
+            brightColor = brightColor.darker(120 + (params.setId*7) % 35);
+        }
+        else if ( params.setId % 5 == 0 ) {
+            // 1/5 chance to make it a bit darker
+            brightColor = brightColor.darker(110 + (params.setId*3) % 10);
+        }
+    }
+    if ( brightY < 0.35 ) {
+        // always make the color brighter to avoid very dark colors (like rgb(0, 0, 255))
+        brightColor = brightColor.lighter(120 + (params.setId*13) % 55);
+    }
+    int at = 0;
+    foreach ( const QRect& rect, rects ) {
+        QColor currentColor;
+        // pick the colored squares; you can get different patterns by re-ordering the "rects" list
+        if ( (at + params.setId*7) % 4 < coloredCount ) {
+            currentColor = brightColor;
+        }
+        else {
+            currentColor = darkColor;
+        }
+        // draw the filling of the square
+        painter.setPen(QColor(currentColor));
+        painter.setBrush(QBrush(currentColor));
+        painter.drawRect(rect);
+        // draw a slight set-in shadow for the square -- it's barely recognizeable,
+        // but it looks way better than without
+        painter.setBrush(Qt::NoBrush);
+        painter.setPen(QColor(0, 0, 0, 50));
+        painter.drawRect(rect);
+        painter.setPen(QColor(0, 0, 0, 25));
+        painter.drawRect(rect.x() + 1, rect.y() + 1, rect.width() - 2, rect.height() - 2);
+        at += 1;
+    }
+    return QIcon(QPixmap::fromImage(pixmap));
 }
 
-WorkingSet::WorkingSet( const KDevelop::WorkingSet& rhs ) : QObject()
+}
+
+WorkingSet::WorkingSet(const QString& id)
+    : QObject()
+    , m_id(id)
+    , m_icon(generateIcon(id))
 {
-    m_id =  rhs.m_id + "_copy_";
 }
 
 void WorkingSet::saveFromArea( Sublime::Area* a, Sublime::AreaIndex * area, KConfigGroup setGroup, KConfigGroup areaGroup )
@@ -340,7 +387,6 @@ void WorkingSet::saveFromArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex
 
     KConfigGroup setGroup = setConfig.group(m_id);
     deleteGroupRecursive(setGroup);
-    setGroup.writeEntry("iconName", m_iconName);
 
     KConfigGroup areaGroup = setConfig.group(m_id + '|' + area->title());
     QString lastActiveView = areaGroup.readEntry("Active View", "");
@@ -429,11 +475,9 @@ bool WorkingSet::isPersistent() const {
     return group.readEntry("persistent", false);
 }
 
-QIcon WorkingSet::inactiveIcon() const {
-    if(isPersistent())
-        return m_inactiveIcon;
-    else
-        return m_inactiveNonPersistentIcon;
+QIcon WorkingSet::icon() const
+{
+    return m_icon;
 }
 
 bool WorkingSet::isConnected( Sublime::Area* area )
@@ -446,12 +490,6 @@ QString WorkingSet::id() const
   return m_id;
 }
 
-WorkingSet* WorkingSet::clone()
-{
-  WorkingSet* ret = new WorkingSet( *this );
-  return ret;
-}
-
 bool WorkingSet::hasConnectedAreas() const
 {
   return !m_areas.isEmpty();
@@ -527,14 +565,4 @@ void WorkingSet::changed( Sublime::Area* area )
   emit setChangedSignificantly();
 }
 
-QIcon WorkingSet::activeIcon() const
-{
-  return m_activeIcon;
-}
-
-QString WorkingSet::iconName() const
-{
-  return m_iconName;
-}
-
 #include "workingset.moc"
