@@ -16,13 +16,14 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef WORKINGSET_H
-#define WORKINGSET_H
+#ifndef KDEVPLATFORM_WORKINGSET_H
+#define KDEVPLATFORM_WORKINGSET_H
 
 #include <QObject>
 #include <QIcon>
 #include <KConfigGroup>
 #include <QPointer>
+#include <QDebug>
 
 namespace Sublime {
 class Area;
@@ -32,19 +33,49 @@ class View;
 
 namespace KDevelop {
 
+/// Contains all significant parameters which control the appearance of a working set icon
+struct WorkingSetIconParameters {
+    WorkingSetIconParameters(const QString& id)
+        : setId(qHash(id) % 268435459)
+        , coloredCount((setId % 15 < 4) ? 1 : (setId % 15 < 10) ? 2 : (setId % 15 == 14) ? 4 : 3)
+        , hue((setId % 273 * 83) % 360)
+        , swapDiagonal(setId % 31 < 16)
+    { };
+    // calculate layout and colors depending on the working set ID
+    // modulo it so it's around 2^28, leaving some space before uint overflows
+    const uint setId;
+    // amount of colored squares in this icon (the rest is grey or whatever you set as default color)
+    // use 4-6-4-1 weighting for 1, 2, 3, 4 squares, because that's the number of arrangements for each
+    const uint coloredCount;
+    const uint hue;
+    bool swapDiagonal;
+    // between 0 and 100, 100 = very similar, 0 = very different
+    // 20 points should make a significantly different icon.
+    uint similarity(const WorkingSetIconParameters& other) const {
+        int sim = 100;
+        uint hueDiff = qAbs<int>(hue - other.hue);
+        hueDiff = hueDiff > 180 ? 360 - hueDiff : hueDiff;
+        sim -= hueDiff > 35 ? 50 : (hueDiff * 50) / 180;
+        if ( coloredCount != other.coloredCount ) {
+            sim -= 50;
+        }
+        else if ( coloredCount == 2 && swapDiagonal != other.swapDiagonal ) {
+            sim -= 35;
+        }
+        return sim;
+    };
+};
+
+
 class WorkingSet : public QObject {
     Q_OBJECT
 
 public:
-    WorkingSet(QString id, QString icon);
+    WorkingSet(const QString& id);
 
     bool isConnected(Sublime::Area* area);
 
-    QString iconName() const;
-
-    QIcon activeIcon() const;
-
-    QIcon inactiveIcon() const;
+    QIcon icon() const;
 
     bool isPersistent() const;
 
@@ -52,9 +83,6 @@ public:
 
     QString id() const;
 
-    ///Creates a copy of this working-set with a new identity
-    WorkingSet* clone();
-
     QStringList fileList() const;
 
     bool isEmpty() const;
@@ -64,8 +92,7 @@ public:
 
     ///Loads this working-set directly from the configuration file, and stores it in the given area
     ///Does not ask the user, this should be done beforehand.
-    ///@param clear If this is true, the area will be cleared before
-    void loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex, bool clear = true);
+    void loadToArea(Sublime::Area* area, Sublime::AreaIndex* areaIndex);
 
     bool hasConnectedAreas() const;
 
@@ -90,17 +117,14 @@ private:
     void changed(Sublime::Area* area);
 
     void saveFromArea(Sublime::Area* area, Sublime::AreaIndex *areaIndex, KConfigGroup setGroup, KConfigGroup areaGroup);
-    void loadToArea(Sublime::Area* area, Sublime::AreaIndex *areaIndex, KConfigGroup setGroup, KConfigGroup areaGroup);
-
-    WorkingSet(const WorkingSet& rhs);
+    void loadToArea(Sublime::Area* area, Sublime::AreaIndex *areaIndex, KConfigGroup setGroup, KConfigGroup areaGroup, QMultiMap<QString, Sublime::View*>& recycle);
 
     QString m_id;
-    QString m_iconName;
-    QIcon m_activeIcon, m_inactiveIcon, m_inactiveNonPersistentIcon;
+    QIcon m_icon;
     QList<QPointer<Sublime::Area> > m_areas;
     static bool m_loading;
 };
 
 }
 
-#endif // WORKINGSET_H
+#endif // KDEVPLATFORM_WORKINGSET_H
