@@ -63,7 +63,7 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
     // title bar
     {
         QHBoxLayout* topLayout = new QHBoxLayout;
-        m_setButton = new WorkingSetToolButton(this, set, mainwindow);
+        m_setButton = new WorkingSetToolButton(this, set);
         m_setButton->hide();
 
         topLayout->addSpacing(5);
@@ -71,7 +71,13 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
         topLayout->addWidget(icon);
         topLayout->addSpacing(5);
 
-        QLabel* name = new QLabel(i18n("<b>Working Set</b>"));
+        QString label;
+        if (m_set->isConnected(mainwindow->area())) {
+            label = i18n("<b>Active Working Set</b>");
+        } else {
+            label = i18n("<b>Working Set</b>");
+        }
+        QLabel* name = new QLabel(label);
         name->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
         topLayout->addWidget(name);
          topLayout->addSpacing(10);
@@ -113,9 +119,9 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
     {
         QHBoxLayout* actionsLayout = new QHBoxLayout;
 
-        QLabel* label = new QLabel(i18n("Documents:"));
-        label->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
-        actionsLayout->addWidget(label);
+        m_documentsLabel = new QLabel(i18n("Documents:"));
+        m_documentsLabel->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
+        actionsLayout->addWidget(m_documentsLabel);
 
         actionsLayout->addStretch();
 
@@ -129,7 +135,7 @@ WorkingSetToolTipWidget::WorkingSetToolTipWidget(QWidget* parent, WorkingSet* se
 
         m_subtractButton = new QPushButton;
         m_subtractButton->setIcon(KIcon("list-remove"));
-        m_subtractButton->setText(i18n("Subtract All"));
+        m_subtractButton->setText(i18n("Remove All"));
         m_subtractButton->setToolTip(i18n("Remove all documents that are part of this working set from the currently active working set."));
         m_subtractButton->setFlat(true);
         connect(m_subtractButton, SIGNAL(clicked(bool)), m_setButton, SLOT(subtractSet()));
@@ -294,19 +300,20 @@ void WorkingSetToolTipWidget::updateFileButtons()
         (*it)->m_label->setIsActiveFile(it.key() == activeFile);
     }
 
-    // NOTE: allways hide merge&subtract all on current working set
+    // NOTE: always hide merge&subtract all on current working set
     // if we want to enable mergeButton, we have to fix it's behavior since it operates directly on the
     // set contents and not on the m_fileWidgets
     m_mergeButton->setHidden(allOpen || currentWorkingSet == m_set);
-    m_subtractButton->setHidden(noneOpen || mainWindow->area()->workingSet() == m_set->id());
+    m_subtractButton->setHidden(noneOpen || currentWorkingSet == m_set);
     m_deleteButton->setHidden(m_set->hasConnectedAreas());
+    m_documentsLabel->setHidden(m_mergeButton->isHidden() && m_subtractButton->isHidden() && m_deleteButton->isHidden());
 
-    if(m_set->id() == mainWindow->area()->workingSet()) {
+    if(currentWorkingSet == m_set) {
         disconnect(m_openButton, SIGNAL(clicked(bool)), m_setButton, SLOT(loadSet()));
         connect(m_openButton, SIGNAL(clicked(bool)), m_setButton, SLOT(closeSet()));
         connect(m_openButton, SIGNAL(clicked(bool)), this, SIGNAL(shouldClose()));
         m_openButton->setIcon(KIcon("project-development-close"));
-        m_openButton->setText(i18n("Close"));
+        m_openButton->setText(i18n("Stash"));
     }else{
         disconnect(m_openButton, SIGNAL(clicked(bool)), m_setButton, SLOT(closeSet()));
         connect(m_openButton, SIGNAL(clicked(bool)), m_setButton, SLOT(loadSet()));
