@@ -17,8 +17,8 @@
     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-#ifndef WORKINGSETWIDGET_H
-#define WORKINGSETWIDGET_H
+#ifndef KDEVPLATFORM_WORKINGSETWIDGET_H
+#define KDEVPLATFORM_WORKINGSETWIDGET_H
 
 #include <QPointer>
 
@@ -30,8 +30,6 @@ class Area;
 
 namespace KDevelop {
 
-class MainWindow;
-
 class WorkingSetController;
 class WorkingSet;
 
@@ -43,7 +41,7 @@ class WorkingSetWidget : public WorkingSetToolButton {
     Q_OBJECT
 
 public:
-    WorkingSetWidget(MainWindow* parent, Sublime::Area* area);
+    WorkingSetWidget(Sublime::Area* area, QWidget* parent = 0);
     virtual void setVisible( bool visible );
 
 private slots:
@@ -56,4 +54,4 @@ private:
 
 }
 
-#endif // WORKINGSETWIDGET_H
+#endif // KDEVPLATFORM_WORKINGSETWIDGET_H
