@@ -53,7 +53,10 @@ namespace Sublime {
 
 class ContainerTabBar : public KTabBar {
     public:
-    ContainerTabBar(Container* container) : KTabBar(container), m_container(container) {
+    ContainerTabBar(Container* container)
+        : KTabBar(container), m_container(container)
+    {
+        installEventFilter(this);
     }
     
     virtual bool event(QEvent* ev) {
@@ -80,6 +83,25 @@ class ContainerTabBar : public KTabBar {
         }
         KTabBar::mousePressEvent(event);
     }
+
+    bool eventFilter(QObject* obj, QEvent* event) override
+    {
+        if (obj != this) {
+            return QObject::eventFilter(obj, event);
+        }
+
+        // TODO Qt6: Move to mouseDoubleClickEvent when fixme in qttabbar.cpp is resolved
+        // see "fixme Qt 6: move to mouseDoubleClickEvent(), here for BC reasons." in qtabbar.cpp
+        if (event->type() == QEvent::MouseButtonDblClick) {
+            // block tabBarDoubleClicked signals with RMB, see https://bugs.kde.org/show_bug.cgi?id=356016
+            auto mouseEvent = static_cast<const QMouseEvent*>(event);
+            if (mouseEvent->button() == Qt::MidButton) {
+                return true;
+            }
+        }
+
+        return QObject::eventFilter(obj, event);
+    }
     Container* m_container;
 };
 
@@ -89,6 +111,7 @@ bool sortViews(const View* const lhs, const View* const rhs)
 }
 
 struct ContainerPrivate {
+    QBoxLayout* layout;
     QMap<QWidget*, View*> viewForWidget;
 
     ContainerTabBar *tabBar;
@@ -204,9 +227,9 @@ Container::Container(QWidget *parent)
     l->setMargin(0);
     l->setSpacing(0);
 
-    m_tabBarLayout = new QBoxLayout(QBoxLayout::LeftToRight);
-    m_tabBarLayout->setMargin(0);
-    m_tabBarLayout->setSpacing(0);
+    d->layout = new QBoxLayout(QBoxLayout::LeftToRight);
+    d->layout->setMargin(0);
+    d->layout->setSpacing(0);
 
     d->documentListMenu = new QMenu(this);
     d->documentListButton = new QToolButton(this);
@@ -216,28 +239,29 @@ Container::Container(QWidget *parent)
     d->documentListButton->setAutoRaise(true);
     d->documentListButton->setToolTip(i18n("Show sorted list of opened documents"));
     d->documentListButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
-    m_tabBarLayout->addWidget(d->documentListButton);
+    d->layout->addWidget(d->documentListButton);
     d->tabBar = new ContainerTabBar(this);
     d->tabBar->setContextMenuPolicy(Qt::CustomContextMenu);
-    m_tabBarLayout->addWidget(d->tabBar);
+    d->layout->addWidget(d->tabBar);
     d->fileStatus = new QLabel( this );
     d->fileStatus->setFixedSize( QSize( 16, 16 ) );
-    m_tabBarLayout->addWidget(d->fileStatus);
+    d->layout->addWidget(d->fileStatus);
     d->fileNameCorner = new UnderlinedLabel(d->tabBar, this);
-    m_tabBarLayout->addWidget(d->fileNameCorner);
+    d->layout->addWidget(d->fileNameCorner);
     d->statusCorner = new StatusLabel(d->tabBar, this);
-    m_tabBarLayout->addWidget(d->statusCorner);
-    l->addLayout(m_tabBarLayout);
+    d->layout->addWidget(d->statusCorner);
+    l->addLayout(d->layout);
 
     d->stack = new QStackedWidget(this);
     l->addWidget(d->stack);
 
     connect(d->tabBar, SIGNAL(currentChanged(int)), this, SLOT(widgetActivated(int)));
-    connect(d->tabBar, SIGNAL(tabCloseRequested(int)), this, SLOT(closeRequest(int)));
+    connect(d->tabBar, SIGNAL(tabCloseRequested(int)), this, SLOT(requestClose(int)));
     connect(d->tabBar, SIGNAL(tabMoved(int,int)), this, SLOT(tabMoved(int,int)));
     connect(d->tabBar, SIGNAL(wheelDelta(int)), this, SLOT(wheelScroll(int)));
     connect(d->tabBar, SIGNAL(contextMenu(int,QPoint)), this, SLOT(contextMenu(int,QPoint)));
-    connect(d->tabBar, SIGNAL(mouseMiddleClick(int)), this, SLOT(closeRequest(int)));
+    connect(d->tabBar, SIGNAL(mouseMiddleClick(int)), this, SLOT(requestClose(int)));
+    connect(d->tabBar, SIGNAL(mouseDoubleClick(int)), this, SLOT(doubleClickTriggered(int)));
     connect(d->documentListMenu, SIGNAL(triggered(QAction*)), this, SLOT(documentListActionTriggered(QAction*)));
 
     KConfigGroup group = KGlobal::config()->group("UiSettings");
@@ -245,6 +269,7 @@ Container::Container(QWidget *parent)
     d->tabBar->setTabsClosable(true);
     d->tabBar->setMovable(true);
     d->tabBar->setExpanding(false);
+    d->tabBar->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
 }
 
 void Container::setLeftCornerWidget(QWidget* widget)
@@ -260,7 +285,7 @@ void Container::setLeftCornerWidget(QWidget* widget)
     if(!widget)
         return;
     widget->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Preferred);
-    m_tabBarLayout->insertWidget(0, widget);
+    d->layout->insertWidget(0, widget);
     widget->show();
 }
 
@@ -294,9 +319,9 @@ void Container::wheelScroll(int delta)
     widgetActivated( nextIndex );
 }
 
-void Container::closeRequest(int idx)
+void Container::requestClose(int idx)
 {
-    emit closeRequest((widget(idx)));
+    emit requestClose(widget(idx));
 }
 
 void Container::widgetActivated(int idx)
@@ -418,7 +443,7 @@ void Container::setCurrentWidget(QWidget* w)
     d->tabBar->blockSignals(true);
     d->tabBar->setCurrentIndex(d->stack->indexOf(w));
     d->tabBar->blockSignals(false);
-    if (View *view = d->viewForWidget[w])
+    if (View* view = viewForWidget(w))
     {
         statusChanged(view);
         if (!d->tabBar->isVisible())
@@ -477,7 +502,7 @@ bool Container::hasWidget(QWidget *w)
 
 View *Container::viewForWidget(QWidget *w) const
 {
-    return d->viewForWidget[w];
+    return d->viewForWidget.value(w);
 }
 
 void Container::setTabBarHidden(bool hide)
@@ -519,7 +544,7 @@ void Container::contextMenu( int currentTab, const QPoint& pos )
 
     if (triggered) {
         if ( triggered == closeTabAction ) {
-            closeRequest(currentTab);
+            requestClose(currentTab);
         } else if ( triggered == closeOtherTabsAction ) {
             // activate the remaining tab
             widgetActivated(currentTab);
@@ -532,7 +557,7 @@ void Container::contextMenu( int currentTab, const QPoint& pos )
             }
             // finally close other tabs
             foreach( QWidget* tab, otherTabs ) {
-                closeRequest(tab);
+                requestClose(tab);
             }
         } else if ( triggered == closeAllTabsAction ) {
             // activate last tab
@@ -540,7 +565,7 @@ void Container::contextMenu( int currentTab, const QPoint& pos )
             // close all
             QList<QWidget*> tabs;
             for ( int i = 0; i < count(); ++i ) {
-                closeRequest(widget(i));
+                requestClose(widget(i));
             }
         } // else the action was handled by someone else
     }
@@ -561,6 +586,11 @@ QRect Container::tabRect(int tab) const
     return d->tabBar->tabRect(tab).translated(d->tabBar->mapToGlobal(QPoint(0, 0)));
 }
 
+void Container::doubleClickTriggered(int tab)
+{
+    emit tabDoubleClicked(viewForWidget(widget(tab)));
+}
+
 void Container::documentListActionTriggered(QAction* action)
 {
     Sublime::View* view = action->data().value< Sublime::View* >();
