@@ -16,8 +16,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#ifndef SUBLIMEVIEW_H
-#define SUBLIMEVIEW_H
+#ifndef KDEVPLATFORM_SUBLIMEVIEW_H
+#define KDEVPLATFORM_SUBLIMEVIEW_H
 
 #include <QtCore/QObject>
 #include <QtCore/QMetaType>
