@@ -52,12 +52,9 @@ public:
     }
     void procFinished( int code, QProcess::ExitStatus status )
     {
-        Q_UNUSED(code)
         m_lineMaker->flushBuffers();
-        if( code == 0 && status == QProcess::NormalExit )
-            emit m_exec->completed();
-        else
-            procError( QProcess::UnknownError );
+        if( status == QProcess::NormalExit )
+            emit m_exec->completed(code);
     }
 };
 
@@ -147,7 +144,22 @@ void CommandExecutor::setCommand( const QString& command )
 
 void CommandExecutor::kill()
 {
-    d->m_process->close();
+    d->m_process->kill();
+}
+
+QString CommandExecutor::command() const
+{
+    return d->m_command;
+}
+
+QStringList CommandExecutor::arguments() const
+{
+    return d->m_args;
+}
+
+QString CommandExecutor::workingDirectory() const
+{
+    return d->m_workDir;
 }
 
 }
