@@ -17,10 +17,11 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef MAIN_H
-#define MAIN_H
+#ifndef KDEVPLATFORM_MAIN_H
+#define KDEVPLATFORM_MAIN_H
 
 #include <QObject>
+#include <QAtomicInt>
 #include <language/duchain/topducontext.h>
 
 namespace KDevelop {
@@ -39,11 +40,13 @@ class Manager : public QObject {
         QSet<KUrl> m_waiting;
         uint m_total;
         KCmdLineArgs* m_args;
+        QAtomicInt m_allFilesAdded;
 
     public slots:
         // delay init into event loop so the DUChain can always shutdown gracefully
         void init();
         void updateReady(KDevelop::IndexedString url, KDevelop::ReferencedTopDUContext topContext);
+        void finish();
 };
 
 #endif
