@@ -80,21 +80,31 @@ void encode( KConfigGroup cfg, EnvironmentGroupListPrivate* d )
     cfg.sync();
 }
 
+EnvironmentGroupList::EnvironmentGroupList( const EnvironmentGroupList& rhs )
+    : d( new EnvironmentGroupListPrivate( *rhs.d ) )
+{
+}
+
+EnvironmentGroupList& EnvironmentGroupList::operator=( const EnvironmentGroupList& rhs )
+{
+    *d = *rhs.d;
+    return *this;
+}
+
 EnvironmentGroupList::EnvironmentGroupList( KSharedConfigPtr config )
-    : d(new EnvironmentGroupListPrivate)
+    : d( new EnvironmentGroupListPrivate )
 {
     KConfigGroup cfg( config, envGroup );
     decode( cfg, d );
 }
 
 EnvironmentGroupList::EnvironmentGroupList( KConfig* config )
-    : d(new EnvironmentGroupListPrivate)
+    : d( new EnvironmentGroupListPrivate )
 {
     KConfigGroup cfg( config, envGroup );
     decode( cfg, d );
 }
 
-
 EnvironmentGroupList::~EnvironmentGroupList()
 {
     delete d;
@@ -102,12 +112,12 @@ EnvironmentGroupList::~EnvironmentGroupList()
 
 const QMap<QString, QString> EnvironmentGroupList::variables( const QString& group ) const
 {
-    return d->m_groups[group];
+    return d->m_groups[group.isEmpty() ? d->m_defaultGroup : group];
 }
 
 QMap<QString, QString>& EnvironmentGroupList::variables( const QString& group )
 {
-    return d->m_groups[group];
+    return d->m_groups[group.isEmpty() ? d->m_defaultGroup : group];
 }
 
 
@@ -118,6 +128,10 @@ QString EnvironmentGroupList::defaultGroup() const
 
 void EnvironmentGroupList::setDefaultGroup( const QString& group )
 {
+    if( group.isEmpty() ) {
+        return;
+    }
+
     if( d->m_groups.contains( group ) )
     {
         d->m_defaultGroup = group;
@@ -149,7 +163,7 @@ void EnvironmentGroupList::removeGroup( const QString& group )
 }
 
 EnvironmentGroupList::EnvironmentGroupList()
-    : d( new EnvironmentGroupListPrivate)
+    : d( new EnvironmentGroupListPrivate )
 {
 }
 
