@@ -19,8 +19,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef FILEUTILS_H
-#define FILEUTILS_H
+#ifndef KDEVPLATFORM_FILEUTILS_H
+#define KDEVPLATFORM_FILEUTILS_H
 
 #include "utilexport.h"
 
@@ -32,7 +32,7 @@ namespace KDevelop {
  * Removes the local directory @p dir with all its contents.
  *
  * This is especially useful in cases where we want to remove
- * a directory syncronously. The alternative @c KIO::NetAccess::del
+ * a directory synchronously. The alternative @c KIO::NetAccess::del
  * uses a nested eventloop *and* requires a UI. The function below
  * requires neither but is of course limited to local files.
  *
@@ -47,4 +47,4 @@ bool KDEVPLATFORMUTIL_EXPORT removeDirectory(const QString& dir);
 
 }
 
-#endif // FILEUTILS_H
+#endif // KDEVPLATFORM_FILEUTILS_H
