@@ -224,11 +224,7 @@ class TestSet {
         emb_insertion += clock() - start;
         
         start = clock();
-        ///FIXME: what is the expected outcome?
-        ///       turns out that the below is often
-        ///       *not* true - is this what we want?
-        ///       => add proper Q_VERIFY!
-        realSet.find(i) == realSet.end();
+        bool contained = realSet.find(i) != realSet.end();
         std_contains += clock() - start;
         
         start = clock();
@@ -236,6 +232,7 @@ class TestSet {
         emb_contains += clock() - start;
         
         QVERIFY(set.contains(i));
+        QVERIFY(contained);
         set.verify();
     }
     
