@@ -44,7 +44,7 @@ using namespace KDevelop;
 
 struct DVcsJobPrivate
 {
-    DVcsJobPrivate() : childproc(new KProcess), vcsplugin(0)
+    DVcsJobPrivate() : childproc(new KProcess), vcsplugin(0), ignoreError(false)
     {}
 
     ~DVcsJobPrivate() {
@@ -56,9 +56,11 @@ struct DVcsJobPrivate
     QByteArray  output;
     QByteArray  errorOutput;
     IPlugin* vcsplugin;
-    
+
     QVariant results;
     OutputModel* model;
+
+    bool ignoreError;
 };
 
 DVcsJob::DVcsJob(const QDir& workingDir, IPlugin* parent, OutputJob::OutputJobVerbosity verbosity)
@@ -69,9 +71,10 @@ DVcsJob::DVcsJob(const QDir& workingDir, IPlugin* parent, OutputJob::OutputJobVe
     d->vcsplugin = parent;
     d->childproc->setWorkingDirectory(workingDir.absolutePath());
     d->model = new OutputModel;
+    d->ignoreError = false;
     setModel(d->model);
     setCapabilities(Killable);
-    
+
     connect(d->childproc, SIGNAL(finished(int,QProcess::ExitStatus)),
             SLOT(slotProcessExited(int,QProcess::ExitStatus)));
     connect(d->childproc, SIGNAL(error(QProcess::ProcessError)),
@@ -79,7 +82,7 @@ DVcsJob::DVcsJob(const QDir& workingDir, IPlugin* parent, OutputJob::OutputJobVe
 
     connect(d->childproc, SIGNAL(readyReadStandardOutput()),
                 SLOT(slotReceivedStdout()));
-    
+
 }
 
 DVcsJob::~DVcsJob()
@@ -136,6 +139,11 @@ QByteArray DVcsJob::errorOutput() const
     return d->errorOutput;
 }
 
+void DVcsJob::setIgnoreError(bool ignore)
+{
+    d->ignoreError = ignore;
+}
+
 void DVcsJob::setResults(const QVariant &res)
 {
     d->results = res;
@@ -148,7 +156,7 @@ QVariant DVcsJob::fetchResults()
 
 void DVcsJob::start()
 {
-    Q_ASSERT_X(!d->status==JobRunning, "DVCSjob::start", "Another proccess was started using this job class");
+    Q_ASSERT_X(d->status != JobRunning, "DVCSjob::start", "Another proccess was started using this job class");
 
     const QDir& workingdir = directory();
     if( !workingdir.exists() ) {
@@ -176,12 +184,12 @@ void DVcsJob::start()
     if(d->vcsplugin)
         service = d->vcsplugin->objectName();
     setObjectName(service+": "+dvcsCommand().join(" "));
-    
+
     d->status = JobRunning;
     d->childproc->setOutputChannelMode(KProcess::SeparateChannels);
     //the started() and error() signals may be delayed! It causes crash with deferred deletion!!!
     d->childproc->start();
-    
+
     d->model->appendLine(directory().path() + "> " + dvcsCommand().join(" "));
 }
 
@@ -199,10 +207,12 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
 {
     d->status = JobFailed;
 
-    //Do not use d->childproc->exitCode() to set an error! If we have FailedToStart exitCode will return 0,
-    //and if exec is used, exec will return true and that is wrong!
-    setError(verbosity()==Verbose ? OutputJob::FailedShownError : UserDefinedError);
-    setErrorText( i18n("Process exited with status %1", d->childproc->exitCode() ) );
+    setError(OutputJob::FailedShownError); //we don't want to trigger a message box
+
+    d->errorOutput = d->childproc->readAllStandardError();
+
+    QString completeErrorText = i18n("Process '%1' exited with status %2\n%3", d->childproc->program().join(" "), d->childproc->exitCode(), QString::fromLocal8Bit(d->errorOutput) );
+    setErrorText( completeErrorText );
 
     QString errorValue;
     //if trolls add Q_ENUMS for QProcess, then we can use better solution than switch:
@@ -228,32 +238,31 @@ void DVcsJob::slotProcessError( QProcess::ProcessError err )
         errorValue = "UnknownError";
         break;
     }
-    kDebug() << "oops, found an error while running" << dvcsCommand() << ":" << errorValue 
+    kDebug() << "oops, found an error while running" << dvcsCommand() << ":" << errorValue
                                                      << "Exit code is:" << d->childproc->exitCode();
-    
-    d->errorOutput = d->childproc->readAllStandardError();
-    displayOutput(d->errorOutput);
+    displayOutput(QString::fromLocal8Bit(d->errorOutput));
     d->model->appendLine(i18n("Command finished with error %1.", errorValue));
-    
-    //Even if it was a silent process we want to provide some feedback to the user about what went wrong
-    //so we show the output then.
-    if(verbosity()==Silent)
+
+    if(verbosity()==Silent) {
+        setVerbosity(Verbose);
         startOutput();
+    }
     emitResult();
 }
 
 void DVcsJob::slotProcessExited(int exitCode, QProcess::ExitStatus exitStatus)
 {
     d->status = JobSucceeded;
+    d->model->appendLine(i18n("Command exited with value %1.", exitCode));
 
     if (exitStatus == QProcess::CrashExit)
         slotProcessError(QProcess::Crashed);
 
-    else if (exitCode != 0)
+    else if (exitCode != 0 && !d->ignoreError)
         slotProcessError(QProcess::UnknownError);
 
-    d->model->appendLine(i18n("Command exited with value %1.", exitCode));
-    jobIsReady();
+    else
+        jobIsReady();
 }
 
 void DVcsJob::displayOutput(const QString& data)
@@ -264,11 +273,11 @@ void DVcsJob::displayOutput(const QString& data)
 void DVcsJob::slotReceivedStdout()
 {
     QByteArray output = d->childproc->readAllStandardOutput();
-    
+
     // accumulate output
     d->output.append(output);
-    
-    displayOutput(output);
+
+    displayOutput(QString::fromLocal8Bit(output));
 }
 
 VcsJob::JobStatus DVcsJob::status() const
