@@ -11,14 +11,11 @@
 
 #include "vcspluginhelper.h"
 
-#include <QtDesigner/QExtensionFactory>
 #include <QAction>
 #include <QVariant>
 #include <QMenu>
 
-#include <kpluginfactory.h>
 #include <kaboutdata.h>
-#include <kpluginloader.h>
 #include <klocale.h>
 #include <kglobal.h>
 #include <kconfig.h>
@@ -44,8 +41,10 @@
 #include <interfaces/contextmenuextension.h>
 #include <interfaces/iproject.h>
 #include <project/projectmodel.h>
+#include <util/path.h>
 #include <language/interfaces/codecontext.h>
 #include <vcs/interfaces/ibasicversioncontrol.h>
+#include "interfaces/idistributedversioncontrol.h"
 #include <vcs/widgets/vcscommitdialog.h>
 #include <vcs/models/vcsannotationmodel.h>
 #include <vcs/vcsjob.h>
@@ -58,22 +57,18 @@
 #include <language/duchain/duchain.h>
 #include <language/interfaces/editorcontext.h>
 
-#include <config-kdevplatform.h>
-#ifdef HAVE_KOMPARE
-#include <interfaces/ipatchdocument.h>
-#endif
 #include <interfaces/ipatchsource.h>
 #include <KTemporaryFile>
 #include <qtextedit.h>
 #include "vcsstatusinfo.h"
 #include <qboxlayout.h>
 #include <qlabel.h>
-#include <QMenu>
 #include "widgets/vcsdiffpatchsources.h"
 #include "widgets/flexibleaction.h"
 #include <interfaces/isession.h>
 #include "vcsevent.h"
 #include <KCompositeJob>
+#include <KTextEditor/HighlightInterface>
 #include <QClipboard>
 #include <QApplication>
 #include <ktexteditor/modificationinterface.h>
@@ -96,18 +91,21 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
     KAction * revertAction;
     KAction * diffForRevAction;
     KAction * diffForRevGlobalAction;
-    QPointer<QTimer> modificationTimer;
+    KAction * pushAction;
+    KAction * pullAction;
     
-    void createActions(QObject * parent) {
+    void createActions(VcsPluginHelper* parent) {
         commitAction = new KAction(KIcon("svn-commit"), i18n("Commit..."), parent);
         updateAction = new KAction(KIcon("svn-update"), i18n("Update"), parent);
         addAction = new KAction(KIcon("list-add"), i18n("Add"), parent);
-        diffToBaseAction = new KAction(KIcon("vcs_diff"), i18n("Show Differences..."), parent);
+        diffToBaseAction = new KAction(KIcon("text-x-patch"), i18n("Show Differences..."), parent);
         revertAction = new KAction(KIcon("archive-remove"), i18n("Revert"), parent);
         historyAction = new KAction(KIcon("view-history"), i18n("History..."), parent);
         annotationAction = new KAction(KIcon("user-properties"), i18n("Annotation..."), parent);
-        diffForRevAction = new KAction(KIcon("vcs_diff"), i18n("Show Diff..."), parent);
-        diffForRevGlobalAction = new KAction(KIcon("vcs_diff"), i18n("Show Diff (all files)..."), parent);
+        diffForRevAction = new KAction(KIcon("text-x-patch"), i18n("Show Diff..."), parent);
+        diffForRevGlobalAction = new KAction(KIcon("text-x-patch"), i18n("Show Diff (all files)..."), parent);
+        pushAction = new KAction(KIcon("arrow-up-double"), i18n("Push"), parent);
+        pullAction = new KAction(KIcon("arrow-down-double"), i18n("Pull"), parent);
         
         connect(commitAction, SIGNAL(triggered()), parent, SLOT(commit()));
         connect(addAction, SIGNAL(triggered()), parent, SLOT(add()));
@@ -118,6 +116,8 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
         connect(annotationAction, SIGNAL(triggered()), parent, SLOT(annotation()));
         connect(diffForRevAction, SIGNAL(triggered()), parent, SLOT(diffForRev()));
         connect(diffForRevGlobalAction, SIGNAL(triggered()), parent, SLOT(diffForRevGlobal()));
+        connect(pullAction, SIGNAL(triggered()), parent, SLOT(pull()));
+        connect(pushAction, SIGNAL(triggered()), parent, SLOT(push()));
     }
     
     bool allLocalFiles(const KUrl::List& urls)
@@ -144,7 +144,12 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
         menu->setIcon(KIcon(ICore::self()->pluginController()->pluginInfo(plugin).icon()));
         
         menu->addAction(commitAction);
-        menu->addAction(updateAction);
+        if(plugin->extension<IDistributedVersionControl>()) {
+            menu->addAction(pushAction);
+            menu->addAction(pullAction);
+        } else {
+            menu->addAction(updateAction);
+        }
         menu->addSeparator();
         menu->addAction(addAction);
         menu->addAction(revertAction);
@@ -153,8 +158,6 @@ struct VcsPluginHelper::VcsPluginHelperPrivate {
         menu->addAction(annotationAction);
         menu->addAction(diffToBaseAction);
         
-        addAction->setEnabled(!allVersioned);
-        
         const bool singleVersionedFile = ctxUrls.count() == 1 && allVersioned;
         historyAction->setEnabled(singleVersionedFile);
         annotationAction->setEnabled(singleVersionedFile && allLocalFiles(ctxUrls));
@@ -180,6 +183,23 @@ VcsPluginHelper::VcsPluginHelper(KDevelop::IPlugin* parent, KDevelop::IBasicVers
 VcsPluginHelper::~VcsPluginHelper()
 {}
 
+void VcsPluginHelper::addContextDocument(const KUrl &url)
+{
+    d->ctxUrls.append(url);
+}
+
+void VcsPluginHelper::disposeEventually(KTextEditor::View *, bool dont)
+{
+    if ( ! dont ) {
+        deleteLater();
+    }
+}
+
+void VcsPluginHelper::disposeEventually(KTextEditor::Document *)
+{
+    deleteLater();
+}
+
 void VcsPluginHelper::setupFromContext(Context* context)
 {
     d->ctxUrls.clear();
@@ -189,7 +209,7 @@ void VcsPluginHelper::setupFromContext(Context* context)
         if (prjctx) {
             foreach(KDevelop::ProjectBaseItem* item, prjctx->items()) {
                 if(!item->target())
-                    d->ctxUrls.append(item->url());
+                    d->ctxUrls.append(item->path().toUrl());
             }
         }
     }
@@ -261,17 +281,20 @@ void VcsPluginHelper::revert()
 
 void VcsPluginHelper::revertDone(KJob* job)
 {
-    d->modificationTimer = new QTimer;
-    d->modificationTimer->setInterval(100);
-    connect(d->modificationTimer, SIGNAL(timeout()), SLOT(delayedModificationWarningOn()));
+    QTimer* modificationTimer = new QTimer;
+    modificationTimer->setInterval(100);
+    connect(modificationTimer, SIGNAL(timeout()), SLOT(delayedModificationWarningOn()));
+    connect(modificationTimer, SIGNAL(timeout()), modificationTimer, SLOT(deleteLater()));
+
     
-    d->modificationTimer->setProperty("urls", job->property("urls"));
-    d->modificationTimer->start();
+    modificationTimer->setProperty("urls", job->property("urls"));
+    modificationTimer->start();
 }
 
 void VcsPluginHelper::delayedModificationWarningOn()
 {
-    KUrl::List urls = d->modificationTimer->property("urls").value<KUrl::List>();
+    QObject* timer = sender();
+    KUrl::List urls = timer->property("urls").value<KUrl::List>();
     
     foreach(const KUrl& url, urls) {
         IDocument* doc=ICore::self()->documentController()->documentForUrl(url);
@@ -283,8 +306,6 @@ void VcsPluginHelper::delayedModificationWarningOn()
             modif->setModifiedOnDiskWarning(true);
         }
     }
-    
-    d->modificationTimer->deleteLater();
 }
 
 
@@ -348,20 +369,14 @@ void VcsPluginHelper::diffForRevGlobal()
 void VcsPluginHelper::history(const VcsRevision& rev)
 {
     SINGLEURL_SETUP_VARS
-    KDevelop::VcsJob *job = iface->log(url, rev, VcsRevision::createSpecialRevision( VcsRevision::Start ));
-    if (!job) {
-        return;
-    }
-
-    KDialog* dlg = new KDialog();
+    KDialog* dlg = new KDialog(ICore::self()->uiController()->activeMainWindow());
+    dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setButtons(KDialog::Close);
     dlg->setCaption(i18nc("%1: path or URL, %2: name of a version control system",
                           "%2 History (%1)", url.pathOrUrl(), iface->name()));
-    KDevelop::VcsEventWidget* logWidget = new KDevelop::VcsEventWidget(url, job, dlg);
+    KDevelop::VcsEventWidget* logWidget = new KDevelop::VcsEventWidget(url, rev, iface, dlg);
     dlg->setMainWidget(logWidget);
     dlg->show();
-    connect( dlg, SIGNAL(closeClicked()), job, SLOT(kill()) );
-    connect( dlg, SIGNAL(closeClicked()), dlg, SLOT(deleteLater()) );
 }
 
 void VcsPluginHelper::annotation()
@@ -372,26 +387,39 @@ void VcsPluginHelper::annotation()
     if (!doc)
         doc = ICore::self()->documentController()->openDocument(url);
 
-    if (doc && doc->textDocument()) {
+    KTextEditor::AnnotationInterface* annotateiface = qobject_cast<KTextEditor::AnnotationInterface*>(doc->textDocument());
+    KTextEditor::AnnotationViewInterface* viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(doc->textDocument()->activeView());
+    if (viewiface && viewiface->isAnnotationBorderVisible()) {
+        viewiface->setAnnotationBorderVisible(false);
+        return;
+    }
+
+    if (doc && doc->textDocument() && iface) {
         KDevelop::VcsJob* job = iface->annotate(url);
-        if( !job ) 
+        if( !job )
         {
             kWarning() << "Couldn't create annotate job for:" << url << "with iface:" << iface << dynamic_cast<KDevelop::IPlugin*>( iface );
             return;
         }
-        KTextEditor::AnnotationInterface* annotateiface = qobject_cast<KTextEditor::AnnotationInterface*>(doc->textDocument());
-        KTextEditor::AnnotationViewInterface* viewiface = qobject_cast<KTextEditor::AnnotationViewInterface*>(doc->textDocument()->activeView());
+
+        QColor foreground(Qt::black);
+        QColor background(Qt::white);
+        if ( KTextEditor::HighlightInterface* iface = qobject_cast<KTextEditor::HighlightInterface*>(doc->textDocument()) ) {
+            KTextEditor::Attribute::Ptr style = iface->defaultStyle(KTextEditor::HighlightInterface::dsNormal);
+            foreground = style->foreground().color();
+            if (style->hasProperty(QTextFormat::BackgroundBrush)) {
+                background = style->background().color();
+            }
+        }
 
         if (annotateiface && viewiface) {
-            KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument());
+            KDevelop::VcsAnnotationModel* model = new KDevelop::VcsAnnotationModel(job, url, doc->textDocument(),
+                                                                                   foreground, background);
             annotateiface->setAnnotationModel(model);
             viewiface->setAnnotationBorderVisible(true);
             connect(doc->textDocument()->activeView(),
                     SIGNAL(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)),
                     this, SLOT(annotationContextMenuAboutToShow(KTextEditor::View*,QMenu*,int)));
-            connect(doc->textDocument()->activeView(),
-                    SIGNAL(annotationBorderVisibilityChanged(KTextEditor::View*, bool)),
-                    SLOT(annotationVisibilityChange(KTextEditor::View*,QMenu*,int)));
         } else {
             KMessageBox::error(0, i18n("Cannot display annotations, missing interface KTextEditor::AnnotationInterface for the editor."));
             delete job;
@@ -450,13 +478,6 @@ void VcsPluginHelper::annotationContextMenuAboutToShow( KTextEditor::View* view,
     menu->addAction(new FlexibleAction(KIcon("view-history"), i18n("History..."), new HistoryFunction(this, rev), menu));
 }
 
-void VcsPluginHelper::annotationVisibilityChange(KTextEditor::View* view, QMenu* menu, int visible)
-{
-    Q_UNUSED(view);
-    Q_UNUSED(menu);
-    Q_UNUSED(visible);
-}
-
 void VcsPluginHelper::update()
 {
     EXECUTE_VCS_METHOD(update);
@@ -485,6 +506,23 @@ void VcsPluginHelper::commit()
         commitDialog->exec();
     }
 }
+
+void VcsPluginHelper::push()
+{
+    foreach(const KUrl& url, d->ctxUrls) {
+        VcsJob* job = d->plugin->extension<IDistributedVersionControl>()->push(url, VcsLocation());
+        ICore::self()->runController()->registerJob(job);
+    }
+}
+
+void VcsPluginHelper::pull()
+{
+    foreach(const KUrl& url, d->ctxUrls) {
+        VcsJob* job = d->plugin->extension<IDistributedVersionControl>()->pull(VcsLocation(), url);
+        ICore::self()->runController()->registerJob(job);
+    }
+}
+
 }
 
 
