@@ -8,13 +8,12 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef VCSPLUGINHELPER_H
-#define VCSPLUGINHELPER_H
+#ifndef KDEVPLATFORM_VCSPLUGINHELPER_H
+#define KDEVPLATFORM_VCSPLUGINHELPER_H
 
 #include "vcsexport.h"
 
 #include <kurl.h>
-#include <memory>
 #include "vcsrevision.h"
 
 class KJob;
@@ -25,8 +24,11 @@ class QMenu;
 namespace KTextEditor
 {
 class View;
+class Document;
 }
 
+using KTextEditor::View;
+
 namespace KDevelop
 {
 class VcsDiff;
@@ -46,6 +48,7 @@ public:
     virtual ~VcsPluginHelper();
 
     void setupFromContext(KDevelop::Context*);
+    void addContextDocument(const KUrl& url);
     KUrl::List const & contextUrlList();
     QMenu* commonActions();
 
@@ -56,18 +59,24 @@ public Q_SLOTS:
     void history(const VcsRevision& rev = VcsRevision::createSpecialRevision( VcsRevision::Base ));
     void annotation();
     void annotationContextMenuAboutToShow( KTextEditor::View* view, QMenu* menu, int line);
-    void annotationVisibilityChange(KTextEditor::View* view, QMenu* menu, int visible);
     void diffToBase();
     void diffForRev();
     void diffForRevGlobal();
     void update();
+    void pull();
+    void push();
     void diffJobFinished(KJob* job);
     
     void revertDone(KJob* job);
+    void disposeEventually(KTextEditor::Document*);
+    void disposeEventually(View*, bool);
+
+private Q_SLOTS:
     void delayedModificationWarningOn();
+
 private:
     struct VcsPluginHelperPrivate;
-    std::auto_ptr<VcsPluginHelperPrivate> d;
+    QScopedPointer<VcsPluginHelperPrivate> d;
 };
 
 } // namespace KDevelop
