@@ -29,48 +29,28 @@
 #include "vcsdiff.h"
 #include <interfaces/iplugincontroller.h>
 #include <KComboBox>
+#include <KTextEdit>
 #include <interfaces/isession.h>
 #include <interfaces/ibasicversioncontrol.h>
 
 using namespace KDevelop;
 
-VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater, const KUrl& url, IBasicVersionControl* vcs)
-    : VCSDiffPatchSource(updater), m_vcs(vcs)
+VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater)
+    : VCSDiffPatchSource(updater), m_vcs(updater->vcs())
 {
     Q_ASSERT(m_vcs);
-    m_base = url;
-    
-    QScopedPointer<VcsJob> statusJob(vcs->status(url));
-    QVariant varlist;
-
-    if( statusJob->exec() && statusJob->status() == VcsJob::JobSucceeded )
-    {
-        varlist = statusJob->fetchResults();
-
-        foreach( const QVariant &var, varlist.toList() )
-        {
-            VcsStatusInfo info = qVariantValue<KDevelop::VcsStatusInfo>( var );
-            
-            m_infos += info;
-            if(info.state()!=VcsStatusInfo::ItemUpToDate)
-                m_selectable[info.url()] = info.state();
-        }
-    }
-    else
-        kDebug() << "Couldn't get status for urls: " << url;
-
     m_commitMessageWidget = new QWidget;
     QVBoxLayout* layout = new QVBoxLayout(m_commitMessageWidget.data());
 
-    m_commitMessageEdit = new QTextEdit;
+    m_commitMessageEdit = new KTextEdit;
     m_commitMessageEdit.data()->setFont( KGlobalSettings::fixedFont() );
     m_commitMessageEdit.data()->setLineWrapMode(QTextEdit::NoWrap);
-    m_vcs->setupCommitMessageEditor(url, m_commitMessageEdit.data());
+    m_vcs->setupCommitMessageEditor(updater->url(), m_commitMessageEdit.data());
     
     QHBoxLayout* titleLayout = new QHBoxLayout;
     titleLayout->addWidget(new QLabel(i18n("Commit Message:")));
     
-    m_oldMessages = new KComboBox;
+    m_oldMessages = new KComboBox(m_commitMessageWidget.data());
     
     m_oldMessages->addItem(i18n("Old Messages"));
     foreach(QString message, oldMessages())
@@ -119,10 +99,45 @@ void VCSCommitDiffPatchSource::oldMessageChanged(QString text)
     }
 }
 
+void VCSCommitDiffPatchSource::jobFinished(KJob *job)
+{
+    if (!job || job->error() != 0 )
+    {
+        QString details = job ? job->errorText() : QString();
+        if (details.isEmpty()) {    //errorText may be empty
+            details = i18n("For more detailed information please see the Version Control toolview");
+        }
+        KMessageBox::detailedError(0, i18n("Unable to commit"), details, i18n("Commit unsuccessful"));
+    }
+
+    deleteLater();
+}
+
 VCSDiffPatchSource::VCSDiffPatchSource(VCSDiffUpdater* updater)
     : m_updater(updater)
 {
     update();
+    KDevelop::IBasicVersionControl* vcs = m_updater->vcs();
+    KUrl url = m_updater->url();
+
+    QScopedPointer<VcsJob> statusJob(vcs->status(url));
+    QVariant varlist;
+
+    if( statusJob->exec() && statusJob->status() == VcsJob::JobSucceeded )
+    {
+        varlist = statusJob->fetchResults();
+
+        foreach( const QVariant &var, varlist.toList() )
+        {
+            VcsStatusInfo info = qVariantValue<KDevelop::VcsStatusInfo>( var );
+            
+            m_infos += info;
+            if(info.state()!=VcsStatusInfo::ItemUpToDate)
+                m_selectable[info.url()] = info.state();
+        }
+    }
+    else
+        kDebug() << "Couldn't get status for urls: " << url;
 }
 
 VCSDiffPatchSource::VCSDiffPatchSource(const KDevelop::VcsDiff& diff)
@@ -149,6 +164,10 @@ QString VCSDiffPatchSource::name() const {
     return m_name;
 }
 
+uint VCSDiffPatchSource::depth() const {
+    return m_depth;
+}
+
 void VCSDiffPatchSource::updateFromDiff(VcsDiff vcsdiff)
 {
     if(!m_file.isValid())
@@ -169,11 +188,13 @@ void VCSDiffPatchSource::updateFromDiff(VcsDiff vcsdiff)
         t2 << vcsdiff.diff();
     }
 
-    kDebug() << "using file" << m_file << vcsdiff.diff();
+    kDebug() << "using file" << m_file << vcsdiff.diff() << "base" << vcsdiff.baseDiff();
 
     m_name = "VCS Diff";
     m_base = vcsdiff.baseDiff();
-    
+    m_base.addPath("/");
+    m_depth = vcsdiff.depth();
+
     emit patchChanged();
 }
 
@@ -191,7 +212,7 @@ bool VCSCommitDiffPatchSource::canSelectFiles() const {
     return true;
 }
 
-QMap< KUrl, KDevelop::VcsStatusInfo::State> VCSCommitDiffPatchSource::additionalSelectableFiles() const {
+QMap< KUrl, KDevelop::VcsStatusInfo::State> VCSDiffPatchSource::additionalSelectableFiles() const {
     return m_selectable;
 }
 
@@ -227,24 +248,29 @@ bool VCSCommitDiffPatchSource::finishReview(QList< KUrl > selection) {
         message = m_commitMessageEdit.data()->toPlainText();
 
     kDebug() << "Finishing with selection" << selection;
-    QString text = i18n("Files will be committed:\n");
+    QString files;
     foreach(const KUrl& url, selection)
-        text += ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + '\n';
+        files += "<li>"+ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + "</li>";
 
-    text += i18n("\nWith message:\n %1", message);
+    QString text = i18n("<qt>Files will be committed:\n<ul>%1</ul>\nWith message:\n <pre>%2</pre></qt>", files, message);
 
-    int res = KMessageBox::warningContinueCancel(0, text, i18n("About to commit to repository"));
+    int res = KMessageBox::warningContinueCancel(0, text, i18n("About to commit to repository"),
+                                                 KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
+                                                 "ShouldAskConfirmCommit");
     if (res != KMessageBox::Continue) {
         return false;
     }
 
     emit reviewFinished(message, selection);
-    
-    VcsJob* job=m_vcs->commit(message, selection, KDevelop::IBasicVersionControl::NonRecursive);
-    ICore::self()->runController()->registerJob(job);
 
-    deleteLater();
-    
+    VcsJob* job = m_vcs->commit(message, selection, KDevelop::IBasicVersionControl::NonRecursive);
+    if (!job) {
+        return false;
+    }
+
+    connect (job, SIGNAL(finished(KJob*)),
+             this, SLOT(jobFinished(KJob*)));
+    ICore::self()->runController()->registerJob(job);
     return true;
 }
 
@@ -268,20 +294,18 @@ bool showVcsDiff(IPatchSource* vcsDiff)
     }
 }
 
-VcsDiff VCSStandardDiffUpdater::update() const {
+VcsDiff VCSStandardDiffUpdater::update() const
+{
     QScopedPointer<VcsJob> diffJob(m_vcs->diff(m_url,
                                    KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Base),
                                    KDevelop::VcsRevision::createSpecialRevision(KDevelop::VcsRevision::Working)));
-
-    VcsDiff diff;
-    bool correctDiff = diffJob->exec();
-    if (correctDiff)
-        diff = diffJob->fetchResults().value<VcsDiff>();
-
-    if (!correctDiff)
+    const bool success = diffJob ? diffJob->exec() : false;
+    if (!success) {
         KMessageBox::error(0, i18n("Could not create a patch for the current version."));
+        return {};
+    }
 
-    return diff;
+    return diffJob->fetchResults().value<VcsDiff>();
 }
 
 VCSStandardDiffUpdater::VCSStandardDiffUpdater(IBasicVersionControl* vcs, KUrl url) : m_vcs(vcs), m_url(url) {
